.\" $Id: Timer.n,v 1.1 1992/12/14 13:21:53 davy Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH Timer 3Xb " February 1992" "Version 1.1" "Xb Reference Manual"
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
Timer Management
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Xb/Timer.h>\fP
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
This tool implements the input functions which manage Timer.
.sp 1
.SH 
\fBFUNCTIONS\fP
.IP
.nf
.ta .50i 1.50i
XbTimerRec* \fBXbCreateTimerRec\fP (\fIw, timer_interval, nb_steps, mod\fP) 
	Widget	\fIw\fP;
    	unsigned long	\fItimer_interval\fP;
	unsigned int	\fInb_steps\fP;
	XbTimerMod	\fImod\fP;
.fi
.RS .8i
.IP \fIw\fP 1.2i
Widget.
.IP \fItimer_interval\fP
Interval (in ms) between two timer expirations
.IP \fInb_steps\fP
Number of steps used by the "value" parameter to reach its final value.
.IP \fImod\fP
Indicates which function is used to modify the "value" parameter.
.RE
.HP .8i
.IP
The \fBXbCreateTimerRec\fP function creates and initializes a \fIXbTimerRec\fP
structure.
.br
This timer will be start by XbStartTimer and stop by XbStopTimer.
.br
On each expiration, a user proc will be called with a "value" parameter.
This integer parameter, whose range is 100 to 1000, varies according a
predefined function.
.br
When no more need, the user must free the XbTimerRec structure with 
XbFreeTimerRec.
.HP .5i
.IP
.nf
.ta .50i 1.50i
XbTimerRec* \fBXbResetTimerRec\fP (\fItr, w, timer_interval, nb_steps, mod\fP)
	XbTimerRec*	\fItr\fP;
	Widget	\fIw\fP;
    	unsigned long	\fItimer_interval\fP;
	unsigned int	\fInb_steps\fP;
	XbTimerMod	\fImod\fP;
.fi
.RS .8i
.IP \fItr\fP 1.2i
XbTimerRec to modify
.IP \fIw\fP
Widget.
.IP \fItimer_interval\fP
Interval (in ms) between two timer expirations
.IP \fInb_steps\fP
Number of steps used by the "value" parameter to reach its final value.
.IP \fImod\fP
Indicates which function is used to modify the "value" parameter.
.RE
.HP .8i
.IP
The \fBXbResetTimerRec\fP function permits to modify an existing XbTimerRec.
.HP .5i
.IP
.nf
.ta .50i 1.50i
void \fBXbFreeTimerRec\fP (\fItr\fP)
	XbTimerRec*	\fItr\fP;
.fi
.RS .8i
.IP \fItr\fP 1.2i
XbTimerRec to free
.RE
.HP .5i
.IP
.nf
.ta .50i 1.50i
void \fBXbStartTimer\fP (\fItr, proc, closure\fP)
	XbTimerRec*	\fItr\fP;
	void	(* \fIproc\fP) ();
	caddr_t	\fIclosure\fP;
.fi
.RS .8i
.IP \fItr\fP 1.2i
Timer parameters (Set by XbCreateTimerRec)
.IP \fIproc\fP
User function called on each timer expiration by
proc (\fIw, closure, value\fP) 
where value is an integer whose range is 100 to 1000.
.IP \fIclosure\fP
Closure parameter of proc
.RE
.HP .8i
.IP
The \fBXbStartTimer\fP function permits to start a Timer.
.HP .5i
.IP
.nf
.ta .50i 1.50i
void \fBXbStopTimer\fP (\fItr\fP)
	XbTimerRec*	\fItr\fP;
.fi
.RS .8i
.IP \fItr\fP 1.2i
Timer parameters (Set by XbCreateTimerRec)
.RE
.HP .8i
.IP
the \fBXbStopTimer\fP function permits to stop a Timer.
.HP .5i
.sp 1
.SH 
\fBTYPES\fP
.IP
.nf
.ta .25i
typedef enum
{
	\fILinearInc\fP,
	\fILinearDec\fP,
	\fIFastSlowInc\fP,
	\fIFastSlowDec\fP,
	\fISlowFastInc\fP,
	\fISlowFastDec\fP,
} \fBXbTimerMod\fP;
.fi
.fi
.sp 1
.RS .8i
.IP \fBLinearInc\fP 1.2i
linear incrementation
.RE
.HP .8i
.nf
.ta .25i 1.2i
typedef struct
{
	Widget	widget;
	unsigned long	timer_interval;
	unsigned int	nb_steps;
	XbTimerMod	mod;
	unsigned int	count;
	Boolean	stop;
	XtIntervalId	timer_id;
	unsigned int	value;
	void	(*proc) ();
	caddr_t	closure;
} \fBXbTimerRec\fP;
.fi
.fi
.HP .5i
.sp 1
.nrPN \n%
