.\" $Id: ch01.ms,v 1.1.1.1 1992/03/18 09:35:42 uep Exp $
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.bp
.NH1
OBJECT IN \s12Go\s0
.NH2
Go Architecture
.LP
\fBGo\fP provides the application with
an \fBobject oriented\fP and fully \fBextensible support for 2D graphical
representation\fP.
.LP
\fBGo\fP is composed with four main parts (see figure 1.1):
.RS .3i
.IP "\fIthe graphic object management itself:\fP" .5i
\fIGo\fP maintains graphical objects, object compositions, method propagations,
resources, constraint supports, ...
.IP "\fIthe interface with the window/graphic system:\fP" .5i
\fIGoInterf\fP guarantees the portability of \fBGo\fP across various platform.
.IP "\fIthe input management:\fP" .5i
\fIGoUI\fP is responsible for event interpretation and allows to
customize the object behavior with respect of the user preferences.
.IP "\fIthe export/import from/to the external world:\fP" .5i
\fIGoStream\fP allows to exchange or to save/restore graphical representations.
.RE
.LP
This architecture which clearly separates the main functionalities allows
to extend independently each of the \fBGo\fP components.
.sp2
.DS B
.PS
Box1: box dotted height 0.5i width 4.2i "Workspace or Object Bases"
move to Box1.s
line dotted down 0.275i
Box2: box dotted height 0.5i width 4.2i "Application Core"
Box3: box dotted height 0.5i width 2.0i with .nw at Box2.sw-(0.0i,0.5i) "Dialog"
Box4: box dotted height 0.5i width 2.0i with .nw at Box3.sw "Presentation"
Box5: box dotted height 0.5i width 2.0i with .nw at Box4.sw "Toolkit"
Box60: box height 0.5i width 0.75i with .nw at Box2.ne+(0.2i,0.0i) "\fBGoStream\fP"
Box61: box height 1.05i width 1.5i with .ne at Box2.se+(0.05i,-0.2i) "\fBGo\fP"
Box62: box height 1.05i width 0.5i with .ne at Box61.nw-(0.1i,0.0i) "\fBGoUI\fP"
Box7: box dotted height 0.5i width 4.2i with .nw at Box5.sw "Graphic and Window System"
Box63: box height 0.5i width 2.0i with .se at Box7.ne+(0.0i,0.15i) "\fBGoInterface\fP"
.PE
.DE
.DS C
\fI figure 1.1 : Go Based Application Architecture\fP
.DE
.NH2
Go Classes Organization
.LP
In \fBGo\fP, every thing mentioned in the above architecture is
implemented as \fIobjects\fP. Thus the following classes are defined:
.IP "\fIGo Class\fP"
This class is the super class for every graphic object class. It defines
the common external interface of the graphic objects (\fIGos\fP) and it
also defines their internal structure (\fIGo\fP tree, coordinate system,
associations, ...).
.IP "\fIGoInterf Class\fP"
This class is the super class for every window/graphic system interface
object class. It defines the common functionalities of these systems and
provides \fIGos\fP with output, input and query methods. Porting \fBGo\fP
in a new environment often consists in implementing a new \fIGoInterf\fP
subclass. Each subclass implements the specific code for the given
window/graphic system. \fIGoInterf\fP is independent of the class \fIGo\fP
and subclasses and could be used in an other context.
.IP "\fIGoStream Class\fP"
This class is the super class for every importation/exportation object
class. It defines the interface for saving/restoring objects in a given
medium. The \fIGoStream\fP class does not make any supposition of the
external format, it is done by the subclass. \fIGoStream\fP is independent
of the class \fIGo\fP and subclasses and could be used in an other context
(applications can use \fIGoStream\fP subclass instances for saving/retrieving
their own objects).
.IP "\fIGoUI Class\fP"
This class is the super class for user interaction object class. It provide
the applications with ways allowing to attach actions to events. It also
gives a set of predefined common interactive actions for \fIGo\fP direct
manipulations. \fIGoUI\fP subclasses defines specific interaction actions
for specific \fIGo\fP subclasses. There is at most one \fIGoUI\fP subclass
instance per application.
.LP
In addition, \fBGo\fP provides a set of ``tools'' objects
which are used by the four above basic classes. These tools are independent
of the basic classes and can be used in other contexts. Among these tools,
there is the \fISharedObject\fP object class which is used as the super
class for the graphical attribute object subclasses and can be used
for other purposes. They allow to share attributes between several objects.
.LP
\fIPredefined Go Classes\fP are subclasses of the \fIGo\fP class, they
define high level graphic objects like geometric, textual, graph, image objects.
Probably, most of application programmers will derive directly these classes
instead of deriving lower level object classes like the \fIGo\fP classes.
.NH 2
Go Programming Style
.LP
.IP "Metaclass notion"
With the metaclass notion, the class itself is an object and has a real
existence in the system beside the class instances. This notion exists
in some object oriented systems or languages but not in C++. The metaclass
allows to define dynamic common attributes and behavior for all instances
of a given class. In \fBGo\fP, metaclasses inherit from supermetaclasses
like classes inherit from superclasses. For a given \fIGo\fP subclass,
the corresponding metaclass \fImust\fP exist. This is a small constraint
(the metaclass code is light) and loads a little bit the source code
but this notion brings some significant advantages (for example, preconditions
and postconditons can be set at the metaclass level and will be automatically
invoked for each instance of the corresponding \fIGo\fP class).
.IP "Protected vs Private members"
For performance reasons, \fIprotected\fP members have been preferred instead
of \fIprivate\fP. This allows a better extensibility and a better efficiency
in the subclassing process but this losts an important aspect of the
object oriented technology: the security when accessing the internal data.
It is recommended to be careful about this aspect when creating new subclasses.
.IP "Virtual members"
In the basic \fBGo\fP classes, most of the methods (public or protected) are
virtual allowing to override them in subclasses. When their implementations are
mandatory in the subclasses, they are marked ``= 0'' in the header file.
.IP "Friend classes"
Usually, in \fBGo\fP, the metaclass in friend for the class and the reverse
as well.
.IP "Multiple-inheritance"
The multiple inheritance is not used in \fBGo\fP.
.IP "Header files"
There is one header file per object class and one per object metaclass.
Metaclass header files are usually prefixed by ``m'' (i.e. mGo.h).
.IP "Member naming"
Some conventions have been chosen for naming object members:
.RS .8i
\(bu regular public member names starts with a lower case letter.
\(bu member starting with the ``_'' character is protected or private.
.RE
