.\" $Id: ch01.ms,v 1.2 1992/12/28 15:44:28 davy Exp $
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.bp
.NH1
END USER ENVIRONMENT DESCRIPTION
.LP
This chapter gives a quick overview of what the end user is and what
the environment requirements are from both the end user and application
programmer points of view. It intends to explain how \fBGoPATH\fP answers
to this requirements.
.NH2
The End User Needs
.LP
What the end user wants to do:
.IP \(bu 0.5i
Create/Modify information
.IP \(bu 0.5i
Access/Present information
.IP \(bu 0.5i
Communicate information
.LP
Information means data managed by the user and processed by applications.
.LP
He/she does not want to know anything about computer technology
(operating systems, network and distributed services and applications,
window systems and graphic technology, device management, ...).
But, the end user can be happy to adapt his/her environment to
his/her preferences. He/she only wants to work efficiently!
.LP
To hide the technology complexity and to provide the user with real world
\fBmetaphors\fP, the graphical representation is one of the most common ways
(others are voice and video representations).
A \fIGraphical User Interface (GUI)\fP usually provides such functionalities
including the \fIDesktop Metaphor\fP.
.LP
A typical \fIGraphical User Interface (GUI)\fP includes (almost)
everything needed for the dialog between the application and the user. It
allows the user to control the application process through dialog
objects such as \fImenus, dialog boxes, list boxes, ...\fP. It also
provides objects to display simple data (\fIsimple text, pixmaps\fP).
In addition to the application process control, the user efficiency will be
improved by \fBdirect manipulation\fP of application objects.
The user needs to make the applications communicate together,
the best example is the \fIcut/copy and paste\fP facility but other
more complex cooperations are required.
.LP
These requirements have impacts on the environment architecture.
.NH2
The Application Programmer Needs
.LP
The application programmer has to write applications which satisfy the
end user requirements. These applications have to hide the physical
environment and have to be customizable. They have to provide ergonomic
interfaces.
.LP
To achieve his/her work, the application programmer wants high level tools
to avoid duplicated work, to make applications communicate. He needs
default behavior but also flexibility for implementing new \fIlook and feel\fP's.
He/she needs extension capability because it is not possible to provide a
complete environment for every kind of applications. Another important issue
is the portability across various platform. The software cost is so high that
the reusability and the portability must be a basic requirement.
.LP
Existing environments (	\fIOSF/Motif\u\s4TM\s0\d, XView\u\s4TM\s0\d, Athena Widgets,
MS/Windows\u\s4TM\s0\d, Presentation Manager\u\s4TM\s0\d, ...\fP)
provide toolkits for application/user dialog. These toolkits provide
a set of dialog objects allowing to control the application process (e.g. menus,
buttons, forms, ...). Nevertheless, these toolkits do not provide
high level facilities for application objects (data) representation such
as two-dimensional graphical representation. For example, in some application
domains (CAD-CAM, publishing, tutoring, geography, decision support, ...),
applications have to display graphical data with very sophisticated structures,
and also want the user to interact with them.
This requires from the programmers a high expertise in low level graphic
libraries along with an important development task. Yet the reusability is
not guaranteed at all.
.LP
\fBGoPATH\fP intends to fill that lack. \fBGoPATH\fP helps
graphical application programmers by providing
them with object libraries (\fBGo\fP) which may be integrated into
their favorite \fIGUI\fP environments: Xt toolkits (\fIOSF/Motif\u\s4TM\s0\d,
XView\u\s4TM\s0\d, ...\fP) but also \fIMS/Windows\u\s4TM\s0\d\fP, and
on top of other graphic systems (e.g. \fIPostScript\u\s4TM\s0\d\fP).

.NH2
The Typical Architecture
.LP
The \fIfigure 1.1\fP shows the typical architecture for an interactive application.
The application role is to make a link between the user workspace and
the user him/herself.
.sp 2
.nf
.sp2
.DS B
.PS
Box1: box height 0.5i width 4.0i "Workspace or Object Bases"
move to Box1.s
line down 0.275i
Box2: box height 0.5i width 4.0i "Application Core"
Box3: box height 0.5i width 2.0i with .nw at Box2.sw "Dialog"
Box4: box height 0.5i width 2.0i with .nw at Box3.sw "Presentation"
Box5: box height 0.5i width 2.0i with .nw at Box4.sw "Toolkit"
Box6: box height 1.5i width 2.0i with .ne at Box2.se "\fBObject\fP" "\fBRepresentation\fP"
Box7: box height 0.5i width 4.0i with .nw at Box5.sw "Graphic and Window System"
.PE
.DE
.DS C
\fI figure 1.1 : Application Architecture\fP
.DE
.sp2
.LP
The \fIWorkspace\fP (or \fIObject Bases\fP) represents the user's electronic
environment. It contains the \fBsemantic\fP aspect of the information used by
the user. The real organization of the \fIWorkspace\fP is hidden, the user
will see this workspace through an external representation provided
by applications. Specially \fIDesktops\fP, \fIObject Managers\fP, ... will play
an important role in order to offer some real world metaphor, but also some
interfaces (programming interface, protocol, ...) for applications.
.LP
The role of the \fIApplication Core\fP is to compute user requests and send
these requests to the real objects. The \fIApplication Core\fP is
usually "user interface independent", it does not care about the user dialog
itself, but it needs interfaces to create the external representation
of the workspace objects. These interfaces have to be as natural as possible,
that means application programmers who have to display \fInatural\fP objects
to the user require object oriented interfaces. Programmers and users must
have the same object visibility.
.LP
\fIDialog\fP and \fIPresentation\fP are usually defined in a given
"Style Guide" and provide the user with dialog objects in order to control
application processes. These layers are based on \fItoolkits\fP which provides
dialog objects (menus, buttons, ...).
It is clear that applications are relatively independent of the way
the user generates commands (e.g. the action may be triggered by a \fIpush
button\fP or a \fIpulldown menu item\fP, it does not matter for the
application). The user dialog may be defined for an expert or for a
novice and may be prototyped and generated by an \fIInterface Builder\fP.
\fIDialog\fP and \fIPresentation\fP layers are usually called \fIUIMS\fP
(User Interface Management System).
.LP
\fIObject representation\fP layer provides facilities in order to give
an user understandable presentation of the workspace (e.g. 2D or 3D graphics,
video, audio, ...). Unlike the dialog and presentation layers, the
object externalization is very close to applications; applications have to
control object presentations and interactions. Thus, this layer must be very \fIopen\fP
and \fIextendable\fP. Because this part requires an important piece of work,
it must be \fIportable\fP, easily \fIreusable\fP and \fIcustomizable\fP.
In addition, it is not
possible to list in a \fIGuide\fP all the possible representations or interactions,
new object classes in the workspace will be required new external representations.
.NH2
Target Environments
.LP
\fBGoPATH\fP intends to complete existing environments with a powerful
graphical representation and interaction based on objects. It tends to provide
the application with a common interface.
.LP
Target environments are \fBUnix\fP\u\s4TM\s0\d with
\fBX Window System\fP\u\s4TM\s0\d and \fBOSF Motif\fP\u\s4TM\s0\d or X toolkits,
\fBMS-DOS\fP\u\s4TM\s0\d with \fBMS-Windows\fP\u\s4TM\s0\d, \fBOS/2\fP\u\s4TM\s0\d
with \fBPresentation Manager\fP\u\s4TM\s0\d, \fBPostScript\fP\u\s4TM\s0\d.
.LP
Such environments provide provisions for User/Applications dialog and
presentation (dialog objects are menus, buttons, ...) but not for the dialog
(application control) itself. The dialog has to be managed by a specific manager
(i.e. UIMS, separated or linked to the application). They do not provide
high level facilities for graphical representation.
.LP
For these reasons, \fBGoPATH\fP has been designed to be \fBextensible\fP and
\fBportable\fP (independent of the underlaying graphic system),
\fBinteractive\fP and user \fBcustomizable\fP.
