.\" $Id: ch02.ms,v 1.2 1992/12/28 15:44:46 davy Exp $
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.bp
.NH1
THE ROLE OF \s12Go\s0
.LP
This chapter gives the main goal of the existence of \fBGoPATH\fP and
which requirements it is going to fulfill. It discusses the role of the
object libraries called \fBGo\fP in the application object presentation and
interactions.
.NH2
The Role of Interactive Applications
.LP
The role of an application is to manage data. An interactive application is
controlled by the user. That means that the data
are updated with respect to the user actions
(events).
.LP
An interactive application maintains its own (internal) objects (data)
representing the semantic part of the application.
The application semantic is independent of the input
and output methods; it does not make any output on a display and it does not
recognize any input event.
.LP
An interactive application provides the external
representation of the semantic objects and some dialog
facilities in order to interact on it.
In the user/application dialog, it is possible to identify two parts; one
for the application sequencing control and one for semantic object
representation and interaction.
.LP
The first dialog type is usually based on the existing environments
(OSF/Motif\u\s4TM\s0\d, XView\u\s4TM\s0\d, Athena, MS-Windows\u\s4TM\s0\d,
Presentation Manager\u\s4TM\s0\d) by using dialog objects
such as menus, forms, buttons, messages, caution boxes, ... The dialog
is controlled by a dialog manager usually linked to the application.
UIMSs (User Interface Management Systems) normally are in charge of this
task.
.LP
The second part (semantic object external representation and interaction) can
also be called \fIapplication object support\fP. It is responsible for
presenting the object status to the user and for allowing him/her to modify
this status by \fIdirect manipulations\fP. The external representation is chosen
to give to the user a metaphor as close as possible to the real world. The direct
manipulation allows the user to manipulate objects by obvious actions (like
he/she would do in a physical environment).
.LP
Existing graphic systems (MS-Windows\u\s4TM\s0\d, Presentation Manager\u\s4TM\s0\d,
X Window System\u\s4TM\s0\d, PostScript\u\s4TM\s0\d, ...) providing provisions
for graphic outputs are more basic than it is expected by interactive applications.
They do not provide an \fIextensible\fP object oriented interface,
they do not ensure \fIportability\fP or \fIreusability\fP, they do not allow
\fIcustomization\fP for object interactions. \fBGoPATH\fP intends to solve
these problems.
.NH2
Application Object Support
.LP
An application who wants to present to the user any information
(application object) needs some facilities.
\fBGoPATH\fP provides the application with
an object oriented and fully \fBextensible support for 2D graphical
representation\fP. This toolkit is simply called \fBGo\fP.
.LP
\fBGo\fP libraries are composed with four main parts (see figure 2.1):
.RS .3i
.IP "\fIthe graphic object management itself:\fP" .5i
\fIGo\fP maintains graphical objects, object compositions, method propagations,
resources, constraint supports, ...
.IP "\fIthe interface with the window/graphic system:\fP" .5i
\fIGoInterf\fP guarantees the portability of \fBGo\fP across various platform.
.IP "\fIthe input management:\fP" .5i
\fIGoUI\fP is responsible for event interpretation and allows to
customize the object behavior with respect of the user preferences.
.IP "\fIthe export/import from/to the external world:\fP" .5i
\fIGoStream\fP allows to exchange or to save/restore graphical representations.
.RE
.LP
This architecture which clearly separates the main functionalities allows
to satisfy most of the requirements.
.sp2
.DS B
.PS
Box1: box dotted height 0.5i width 4.2i "Workspace or Object Bases"
move to Box1.s
line dotted down 0.275i
Box2: box dotted height 0.5i width 4.2i "Application Core"
Box3: box dotted height 0.5i width 2.0i with .nw at Box2.sw-(0.0i,0.5i) "Dialog"
Box4: box dotted height 0.5i width 2.0i with .nw at Box3.sw "Presentation"
Box5: box dotted height 0.5i width 2.0i with .nw at Box4.sw "Toolkit"
Box60: box height 0.5i width 0.75i with .nw at Box2.ne+(0.2i,0.0i) "\fBGoStream\fP"
Box61: box height 1.05i width 1.5i with .ne at Box2.se+(0.05i,-0.2i) "\fBGo\fP"
Box62: box height 1.05i width 0.5i with .ne at Box61.nw-(0.1i,0.0i) "\fBGoUI\fP"
Box7: box dotted height 0.5i width 4.2i with .nw at Box5.sw "Graphic and Window System"
Box63: box height 0.5i width 2.0i with .se at Box7.ne+(0.0i,0.15i) "\fBGoInterface\fP"
.PE
.DE
.DS C
\fI figure 2.1 : Go Based Application Architecture\fP
.DE
.NH2
How Requirements are Satisfied
.NH 3
Extensibility
.LP
It is not possible to create a limited graphic object library which matches
all applications needs in terms of shape, complexity, behavior, etc ...
.LP
\fBGo\fP is an object oriented toolkit written in \fBC++\fP (but
also will provide a \fIC language binding\fP for C applications).
Using this object oriented technology, \fBGo\fP is fully \fBextensible\fP
allowing the application programmer to easily create his/her own graphic
objects. Creating a new object class may be performed by subclassing
a predefined graphic object class or by subclassing the \fIGo\fP super
class.
.LP
For example, the code for defining the \fIGoPolygon\fP class (implementing
a polygon object defined by its outline and its background attributes and able to be
modified, resized, deformed, rotated, ...), as a derivation from the \fIGoPolyline\fP
class, is less than 400 lines including header files.
.LP
Subclassing the \fIGo\fP super class offers a wide open range of any
kind of implementation (i.e. ``lightweight'' \fIGo\fP are possible).
.NH 3
Portability
.LP
Data presentation is very close to the application itself and must
be portable across various platforms (Unix\u\s4TM\s0\d stations, PCs).
.LP
\fBGo\fP is Window/Graphic system independent and can be easily
ported on top of standard existing platforms by subclassing the
\fIGoInterf\fP class. A \fIGoInterf\fP subclass implements the
graphic primitives (geometric, text, image) used by \fIGo\fP instances
at drawing time. It is also responsible for delivering events coming
from the window system and for returning information about the
device (resolutions, colors, ...).
.LP
Switching between different \fIGoInterf\fP instances may be \fIdynamic\fP:
for example, generating a PostScript\u\s4TM\s0\d file describing a graphical scheme
displayed in an X window may be performed by replacing the \fIXGoInterf\fP
instance by a \fIPSGoInterf\fP instance.
.NH 3
User Interaction
.LP
\fBGo\fP offers a powerful feature to interact with graphic objects.
The \fBinteractions\fP are performed by a set of dedicated object classes
(\fIGoUI\fP).
First of all, the \fIGoUI\fP object class is responsible for dispatching
events (collected by the \fIInputDispatcher\fP) to the sensitive areas
called \fIGoSensors\fP.
.LP
\fIGoSensors\fP define the shapes and the appearances of the sensitive areas.
When receiving an event, the \fIGoSensor\fP starts an interaction
(\fIGInteractor\fP) which executes an interaction program. An interaction
program implements the interaction itself.
.LP
An interaction program can be a piece of code interpreted by an interpretor.
This allows to define interactions outside the application itself.
Such an interpretor is provided, it is able to interpret a simple
language (called \fIgoui\fP language) for event translations. This is the
simplest way to take into account the user preferences.
.NH 3
Application Interaction
.LP
A \fBGo\fP based application acts on objects through methods and it may be
notified of any \fIGo\fP modification (coordinate system, attributes, ...
and even creation and destruction) by a \fIcallback\fP mechanism.
\fICallbacks\fP may be \fIpre-conditions\fP (the callback procedure is 
called before the action and can refuse or modify the action) or
\fPpost-conditions\fP (the callback procedure is called after the action is
performed) and allow to implement constraints on \fIGo\fP instances.
.LP
\fBGo\fP does not intrinsically allow geometric constraints, but it provides
support for constraint management. For example, for the \fImove\fP operation,
a \fIpre-condition\fP might control the confinement of the object and/or a
\fIpost-condition\fP might require other object alignments (this mechanism
is used by \fIGoUI\fP for constrainted interactions).
Constraints are not exclusively geometric and it is possible to combine
graphical constraints with semantic constraints. A set of predefined
geometric constraints such as alignments or confinement will be offered.
.LP
An application may also associate private data with a graphic object
instance (e.g. private data may be hypermedia references combined with
sensitive areas (\fIGoSensors\fP) and interaction programs like ``scripts'').
Such associations are defined as couples (\fIKey, Value\fP).
.NH 3
Go Import/Export
.LP
The application may want to export a \fBGo\fP structure to the external
world or to import from an other format a structured graphic or image.
.LP
\fBGo\fP allows to import/export \fIGo\fP subtrees from/to various
existing formats by using a
\fIGoStream\fP subclass instance. \fIGo's\fP do not care about the
stream format but use instead \fIGoStream\fP objects in order to store or retrieve
themselves. A \fBGo\fP based application may use \fIGoStream's\fP to insert/restore
private information in/from streams. \fIGoStream's\fP should be the privileged
mechanism for inter application communications (e.g. cut/copy/paste), see
\fIGClipboard(3Go), GConverter(3Go)\fP.
.LP
Two formats are provided: one is an ASCII format (\fIGoAscii\fP and the
other a portable binary format \fIGoBinary\fP).
Typical formats which might be generated from a \fIGoStream\fP file are
\fISGML\fP content portions, \fICGM\fP, \fITIFF\fP for images,
\fICompound Text\fP for text, ...
.NH2
A Go Based Application
.LP
A \fIGo Based Application\fP is an interactive application which uses
\fBGo\fP in order to present its data.
.LP
An interactive application will probably create dialog objects allowing the
user to control the process. These dialog objects (main window, menus, dialog
boxes, ...) are created using a given toolkit (e.g. Motif\u\s4TM\s0\d, Athena, ...). This
dialog is controlled by the user and may be managed by the application itself
or by an \fIUIMS\fP.
.LP
The objective of the application is to display, to create
or to modify information (application data).
To graphically display data, the application has to create appropriate \fIGo\fP
subclass instances. These \fIGo's\fP have to be organized and compound in order
to give the expected presentation. This work is the most important because the
user understanding depends on it.
.LP
To represent complex data structure, programmers might use \fBinteractive tools\fP
(see section \fIGo Companions\fP).
allowing to create the graphical presentation. Such tools would save \fIGoStream's\fP
which would be retrieved at the application run time. In that case, the application,
instead of creating \fIGo's\fP directly, would have to create \fIGoStream\fP instances
and restore the graphical presentation from files. This allows to customize the
graphical presentation, for example, the application can load the French version
or the English version of a scheme. \fBGo\fP plus \fBGo Companions\fP can be
viewed as a \fB2D presentation and interaction builder\fP.
.LP
To display the graphical presentation (\fIGo tree's\fP), the application has to
create one or more \fIGoInterf\fP instances and link the \fIGo's\fP to them. For
example, in addition to dialog objects, the application would create
\fIWork Area\fP objects dedicated to the information displaying. In that
case, \fIGoInterf\fP subclass instances able to draw in these work areas
should be created (e.g a \fIXmGoInterf\fP for widget based work areas).
.LP
If the application wants to make sensitive the graphical presentation,
it will use the \fIGoUI\fP object set in order to interpret the user events
and take the appropriate action. The
\fIGo\fP behavior may statically be defined in the application code and/or may
be customized in ascii description files (\fIinteraction programs\fP).
When \fIGo's\fP are displayed, the application may control or simply
be notified of the user actions by using pre/postconditions.
.LP
Before exiting, the application may use \fIGoStream\fP subclass instances
to save the new graphical status of data. It also be possible to save
application private data into a \fIGoStream\fP file. This capability
might be used to exchange graphics and data between applications.
.NH 2
Go Companions
.LP
As mentioned in the previous section, it will be easier for application
programmers to create \fIGoStream\fP files using interactive tools. These
files will contain the graphical presentation of the application data
and will be loaded at the appropriate time during the execution.
Thus, \fBGo\fP is accompanied with interactive tools which are \fIWYSIWYG\fP*
editors:
.FS
* WYSIWYG: What You See Is What You Get!
.FE
.IP
\(bu \fBgodraw\fP allows to create, edit and compose objects.
.br
\(bu \fBgopaint\fP** is dedicated for image editing.
.br
\(bu \fBgowrite\fP is dedicated for text editing.
.br
\(bu \fBgohyper\fP allows to create sensitive areas and associate
scripts to them.
.br
\(bu \fBattributes editors\fP allow to edit \fIGo\fP attributes
(colors, patterns, dashes, ...). They can be considered as attribute servers.
.FS
** Not yet available.
.FE
.LP
All these editors will be able to cooperate: \fIgodraw\fP will be able to
integrate in a complex structured graphic a piece of text edited by \fIgowrite\fP
or a image edited by \fIgopaint\fP. A pattern generated by the \fIpattern\fP
editor will can be used by the other editors.
.LP
The \fBGo Companions\fP will contribute to improve the \fIDesktop\fP.
.LP
A set of objects (called \fIGo Extensions\fP) are provided in order to
increase the productivity when writing \fBGo\fP applications. These objects
provide the clipboard interface, some usefull converters, help support,
bases for writing editors, etc ...
