.\" $Id: ch03.ms,v 1.2 1992/12/28 15:45:17 davy Exp $
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.bp
.NH1
OBJECT ORIENTED APPROACH
.LP
This chapter describes how an object oriented design provides extensibility and
reusability for \fBGoPATH\fP and specially for the object libraries.
.LP
\fBGo\fP uses the Object Oriented Technology, that means it adheres to the
Object Oriented Programming (\fBOOP\fP) concepts, methodology and style.
.NH 2
Object Oriented Programming
.LP
The Object Oriented Programming provides the programmer with an object view
of his/her world (data) similar to the users view of the real world. In the
graphical domain, programmer's objects are visible and thus the programmer
and the user have to manage the same objects: one the internal representations,
the other the external representations.
.LP
Objects are seen by both the programmer and the user as a collection
of attributes (or data item) and a behavior (or functions). Attributes
(color, line width, font, shape, ...) have only one semantic from both
the user and the programmer and the functions (or methods) are invoked
by the programmer when a given user event occurs.
.LP
Objects are organized in \fBClasses\fP. An Object Class defines the
attributes and the behavior of \fIinstances\fP of the class. For
example: the \fIGoPolygon\fP class defines the polygon object
with attributes like points, background and outline colors, ...
Actions can be performed in order to modify the attributes, the user
uses the mouse and the programmer the functions (or methods). The
object concept introduces a strong limit between attributes and functions
to manipulates them.
.LP
From a given object class, it is possible to define a subclass by adding
some attributes or behavior. Subclasses inherit attributes and behavior
from one or several (multiple-inheritance) superclasses. For example, the
\fIGoRegPolygon\fP class defines
the regular polygon object class as a subclass of the \fIGoPolygon\fP class.
The \fIGoRegPolygon\fP class inherits attributes and behavior from the
\fIGoPolygon\fP class and introduces the regularity constraint. The
subclassing mechanism allows \fIextensibility\fP and \fIreusability\fP
in the software development.
.NH 2
Objects In Go
.LP
In \fBGo\fP, almost everything is object, that means
extensible and reusable. Objects in \fBGo\fP have been grouped
in several sets:
.IP "\fIGo kernel\fP"
These classes are the base of the \fBGo\fP developments. They include classes
like \fIGo\fP, \fIGoInterf\fP, \fIGoStream\fP and \fIGoUI\fP. These classes
are abstract classes and are designed to be subclassed as described below.
.IP "\fIGo Interfaces\fP"
These classes are subclasses of the \fIGoInterf\fP class. They implement
specific interfaces for specific graphic/window systems (i.e. X). The
\fIGoInterf\fP class implements lot of functionalities which can be
reimplemented in subclasses in order to take in account the device
capabilities. \fIXGoInterf\fP, \fIWinGoInterf\fP or \fIPSGoInterf\fP
are such subclasses.
.IP "\fIGo Streams\fP"
These classes are subclasses of the \fIGoStream\fP class. They are
responsible for managing a given format when storing/retrieving objects
from the external world. \fIGoAscii\fP and \fIGoBinary\fP are
such classes.
.IP "\fIGo User Interactions\fP"
These classes are subclasses of the \fIGoUI\fP class, \fIGoSensor\fP classes
and interaction classes. They implement
specific interactions for specific \fIGo\fP subclasses. They also may
offer new application dependent interactions. \fIBGoUI\fP
is an example of such subclasses.
.IP "\fITools\fP"
.br
These classes are \fIGo\fP independent, they can be used in other contexts.
They include classes like \fISet\fP, \fIArray\fP, \fIList\fP, graphic
attributes (\fIFont\fP, \fIColor\fP, ...) and a number of other classes.
.IP "\fIBGo\fP"
.br
These classes define higher level objects. They are subclasses of the
\fIGo kernel\fP classes and use \fITools\fP classes. They are organized
in hierarchies of subclasses: geometric objects, textual objects,
image objects, graph and tree objects. Lot of new subclasses will be
derived from these high level object classes.
.LP
\fBGo\fP does not use the \fImultiple-inheritance\fP but implements
the \fBmetaclass\fP notion (\fIsee also ``About The GoPATH Object Model''\fP).
With this notion, the class itself is
an object and has a real existence in the system beside the class
instances. This allows to define dynamic common attributes for all instances
of a given class. In \fBGo\fP, metaclasses inherit from supermetaclasses
like classes inherit from superclasses.
.LP
The \fBShared Object\fP notion is also used for graphical attributes
like \fIFont\fP, \fIColor\fP, ... This allows to share attributes between
several graphical objects. By naming the shared objects, it is possible
to access them without any knowledge of their location.
