.\" $Id: ch04.ms,v 1.2 1992/12/28 15:46:06 davy Exp $
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.bp
.NH1
\s12Go\s0 DESCRIPTION
.NH2
Overview
.LP
\fBGo\fP consists of libraries allowing an application
to make a graphical representation of its internal objects and to allow
the user to interact on this external graphic representation.
.LP
The \fBGo\fP libraries* allow the creation and
the management of \fIobject instances\fP which are graphic objects (\fIGo\fP),
resources (\fIPen, Color, ...\fP**) and tools (\fICoordSys, Stack, ...\fP**).
The following text describes how these objects cooperate to build a graphic
presentation of the application data.
.FS
* Libraries are libgo.a, libbgo.a, libgoext.a and libXb.a in the
Unix\u\s2TM\s0\d environment
and a set of DLL (Dynamic Link Library) in the MS-Windows\u\s2TM\s0\d
environment. Both include the PostScript\u\s2TM\s0\d interface.
.br
** Real class names for these objects start with ``G'' (i.e. GPen, GStack).
For a better legibility of the document, in most of cases, the ``G'' has
been forgotten.
.FE
.NH3
Go Instances
.LP
A \fIGo\fP is an instance of the \fIGo\fP class. The \fIGo\fP class
is the super class of all other graphic object classes. A \fIGo\fP is
an object which may be used to \fBdraw\fP something.
.LP
The \fIGo\fP geometry (dimensions, positions) is expressed in its own
coordinate system. The \fIGo\fP coordinate system is not necessarily orthogonal
and it is expressed either in the \fBGo\fP absolute coordinate system (which is
in millimeters and its origin is the upper left corner) or relatively to another
coordinate system (typically its parent coordinate system). Any coordinate
system modification is allowed (scaling on X or Y axes, rotation, mirror, ...).
The coordinate system, the output attributes (colors, line styles, fonts, ...)
and private data are the main information used by the draw routine.
.LP
Any \fIGo\fP subclass inherits the \fIGo\fP class methods. These methods
mostly involve the coordinate system modification (\fImove, rescale,
rotate, setCoordSys, ...\fP) and the object tree management (\fIsee below\fP).
Other methods for the condition and association management (\fIadd or remove
pre/postCond, add, remove, set and get association\fP) are also inherited from
the \fIGo\fP class.
.LP
Additional methods are defined by each subclass
.LP
\fIGo's\fP use resources or tools which are objects. Resources may be shared or
not, they are: \fIColor, Font, Pattern, Colormap, ...\fP.
.NH3
Go Structure
.LP
Go's are organized in hierarchies or \fIGo trees\fP. The application is able to
create one or more \fIGo trees\fP. A \fIGo\fP is a node of a \fIGo tree\fP.
Any \fIGo\fP may be compound and have \fIGo\fP children.
A subtree may be viewed as a leaf (access to a node inside the subtree is
forbidden), in that case, the subtree is seen as a single object.
.LP
The \fIGo\fP class offers methods in order to navigate within the \fIGo tree\fP
(\fIparent, child, next, ...\fP) and to modify it: \fIreparent\fP,
\fIdestroy\fP \fIGo (sub)trees\fP.
.LP
The place of a \fIGo\fP instance in the tree defines its
place in the displaying order: a \fIGo\fP parent will be below its children (top
down order), a \fIGo\fP will be below its next brother (left to right order).
The tree organization is also taken into account in order to determine which
\fIGo\fP is interested by an event when managing user input (see \fIGoUI\fP).
.LP
The \fIGo\fP absolute coordinate system may be affected by the
coordinate modifications of its ancestors. For example, if one of the ancestor
is scaled, the \fIGo\fP absolute coordinate system will be scaled too.
Nevertheless, its relative coordinate system will be left unchanged.
.LP
The root of a \fIGo tree\fP may be a regular \fIGo\fP or a \fBGoRoot\fP
instance. A \fIGoRoot\fP allows to link the \fIGo (sub)tree\fP to a graphic
system through a \fBGoInterf\fP subclass instance (\fIsee below\fP).
.NH3
Go Outputs
.LP
When a \fIGo tree\fP is reparented to a \fIGoRoot\fP and this \fIGoRoot\fP is
linked to a \fIGoInterf\fP instance, output may be performed and the graphic
objects may be visible.
.LP
A \fIGo\fP instance will be effectively visible, if it is \fImapped\fP and if
all of its ancestors are \fImapped\fP (including the \fIGoRoot\fP). If it is
\fImapped\fP but one of its ancestor is not \fImapped\fP, it is \fImappable\fP.
.LP
The \fIGoInterf\fP class guarantees the graphic system independence and is the
super class for other classes which implements the real interfaces for given
graphic system (\fIX Window system\u\s4TM\s0\d, MS-Windows\u\s4TM\s0\d,
PostScript\u\s4TM\s0\d, ...\fP). It offers a set of output,
but also input and query methods.
.NH3
Go And User Inputs
.LP
\fIGo's\fP are output only but users can act on them by direct manipulations.
The input management is done by the cooperation between the
\fBGoUI\fP, the \fBGoSensor\fP, the \fBGInteractor\fP and the
\fBGInteractorPgm\fP objects (see also \fIAbout GoPATH Interactions\fP).
.LP
When an user event occurs, it goes from a \fIGoInterf\fP instance
to the corresponding \fIGoUI\fP instance. There is one \fIGoUI\fP
instance per window (\fIGoInterf\fP) allowing specific behaviors in every
window. The \fIGoui\fP object dispatches
the event (\fBGEvent\fP) to a \fIGoSensor\fP with respect to the focus
status, the grabbing state and/or the mouse position.
.LP
\fIGoSensors\fP are objects which make \fIGo's\fP sensitive and provide the
user with appropriate feedbacks (e.g. squares around selected \fPGo's\fP).
When the \fIsensor\fP receives the event, it starts an interaction,
if not already started and gives the event to the interaction object
(a \fIGInteractor\fP instance). The \fIinteractor\fP takes the appropriate
action (with respect to the interaction program (\fGInteractorPgm\fP) and
the interaction status).
.LP
Interaction program can be \fIC++\fP code but also pieces of interpretable
code. The \fIGTranslatorPgm\fP class implements the interpretation of
the simple \fIgoui\fP language for event translation. This language is
used for taking into account the user preferences.
.NH3
Go/Application Communication
.LP
Usually, \fIGo trees\fP are external representations of application objects, so
mechanisms are available to allow communications between the application
and \fIGo's\fP: \fBMethods\fB, \fBCallbacks\fP and \fBAssociations\fP.
.LP
Methods are functions allowing to query or modify some \fIGo\fP internal data
or attributes.
.LP
The application can be notified on any modification or event occurring on a
Go by setting callback procedure. Callbacks may be \fIPreconditions\fP or
\fIPostconditions\fP. A Precondition callback is invoked before the action on
the \fIGo\fP, preconditions are able to refuse or in some case to modify the
action. Postconditions are called after the action is performed.
.LP
The application can also link data to the \fIGo\fP by using \fIAssociations\fP.
Associations allow to attach any application data to the \fIGo\fP. Associations
can be grouped into types, then the application can organize set or get
subsets of associations. Associations can be seen by applications as private
properties for the \fIGo\fP.
.NH3
Export/Import Go's
.LP
\fBGo\fP offers a way to export/import a \fIGo (sub)tree\fP to/from an external
format; this is done by using a \fBGoStream\fP subclass instance. The
\fIGoStream\fP class is the super class for subclasses implementing specific
format translations.
.LP
\fIGoStream\fP instances leave \fIGo's\fP independent of the effective external
format (i.e. ASCII or binary format) and
offers methods to write or to read the \fIGo\fP characteristics.
\fIGoStream\fP instances also hide the medium, it can be a memory buffer,
a file, a network connection, ...
.LP
Filters can be implemented in order to translate the \fIGoStream\fP formats
into or from already existing other formats like \fISGML, TIFF, ODIF,
CGM, ...\fP. \fIGIF\fP and \fITIFF\fP format translators already exist.
.NH3
Predefined Go Classes
.LP
The application developer may create his/her own \fIGo\fP subclasses but
\fBGo\fP offers a set of \fIpredefined Go\fP subclasses usable directly
in applications or as superclasses of new \fIGo\fP subclasses.
.LP
These predefined \fIGo\fP are
\fIGoGeometric\fP and subclasses (polyline, polygon, curves, bezier,
cubic, ...),
\fIGoText\fP and subclasses (mono font or multi font and attributes),
\fIGoImage\fP (color, gray or monochrome) and some more complex structured
graphic objects: \fIGoGraph, GoTree, ...\fP. See \fIPREDEFINED Go's\fP section).
.NH3
Application Oriented Classes
.LP
In addition to the graphical objects, \fBGo\fP provides a set of object classes
in order to minimize the \fBGo\fP based application development effort. These
objects allow to develop cooperative applications with similar look and
behavior.
.LP
These object classes include the clipboard interface (for \fIcut/copy/paste\fP
operations), a number of converters and filters for translating formats,
help support, basic classes for editors. These functionalities are independent
of the dialog objects (menu bar, form, dialog box, ...) so that the
user interface can be designed separately (by using an \fIGUI\fP builder).
.LP
User interfaces, depending of OSF/Motif\u\s4TM\s0\d and MS-Windows\u\s4TM\s0\d
are available and are used for defining the \fBGo Companions\fP look & feel.
.bp
.NH2
The Go Class Hierarchy
.NH3
Metaclasses
.LP
\fBGo\fP introduces the \fIMetaclass\fP notion. This notion gives a real
existence of the class (as an object) and allows to define dynamic common
attributes and behaviors for all instances of this class. This provides
a \fIGo\fP object management at the class level.
.LP
There is a \fIMetaclass\fP for every \fIGo\fP (sub)class. For example:
if \fIGoFoo\fP is a subclass of the \fIGo\fP class, the \fIGoFooMetaclass\fP
class will exist and it will be a subclass of the \fIGoMetaclass\fP class.
The way to access the metaclass object will be by using the member method
\fIGoFoo::getMetaclass()\fP.
The figures 4.1 and 4.2 gives an example of the \fIGo Metaclass\fP and
the \fIGo Class\fP class hierarchies.
.LP
Mainly, metaclasses allow to add or remove \fIPreconditions\fP and
\fIPostconditions\fP in callback lists at the class level. These callback
procedures will be invoked for every \fIGo\fP instance belonging to this class.
Most of available actions on \fIGo\fP instances allow pre and postconditions at
the class level, including preconditions and postconditions on instance
creations.
.LP
The object \fIMetaclasses\fP are also used by \fIgoui\fP in order to
retrieve the object action list available for user interactions. All
available \fIMetaclasses\fP are organized in a list.
.sp 2
.DS B
.PS
down
Box1: box height 0.50i width 1.i "GoMetaclass"
line down .3i
line left 1.i
line down .3i
Box2: box height 0.50i width 1.5i "GoRootMetaclass"
move up .8i
move right 1.i
line right 1.i
line down .3i
Box3: box height 0.50i width 1.5i "GoSensorMetaclass"
.PE
.DE
.DS C
\fIfigure 4.1 : Go Metaclass hierarchy\fP
.DE
.sp 1
.DS B
.PS
down
Box1: box height 0.50i width 1.0i "Go"
line down .3i
line left .6i
line down .3i
Box2: box height 0.50i width 1.0i "GoRoot"
move up .8i
move right .6i
line right .6i
line down .3i
Box3: box height 0.50i width 1.0i "GoSensor"
.PE
.DE
.DS C
\fIfigure 4.2 : Go object class hierarchy\fP
.DE
.sp 1
.NH3
Go Class
.LP
The \fIGo\fP class is the super class for every graphic object class. The
\fIGo\fP class defines all the basic methods available on any graphic object
instance. Specific methods are defined in \fIGo\fP subclasses.
.LP
Precondition and postcondition callbacks may be set for all available
operations. Preconditions allow to accept, to refuse and in some case to change
an operation (i.e. coordinate system modification); they are called just before
the action processing. Postconditions are called just after the action
processing. One can use pre/post conditions at the class level instead of
instance level, by using the metaclasses.
For example, preconditions on creation/restoring instance and postconditions
on deletion instance are possible: in that the \fIcreate()\fP, \fIrestore()\fP
and \fIdestroy()\fP methods of the object have to be used instead of
\fInew\fP and \fIdelete\fP.
.NH4
Go Construction/Destruction
.LP
The \fIGo\fP class is an \fIabstract class\fP, that means
it is not possible to create directly a \fIGo\fP instance; a \fIGo\fP instance
is created by creating a \fIGo\fP subclass (i.e. \fIGoRectangle\fP). No public
\fIconstructor\fP methods are available. For a subclass of \fIGo\fP, \fInew\fP
will create a new instance of this subclass, but NO precondition or
postcondition will be called for this instance. Instead,
\fIGoSubClass::create()\fP should be used.
.LP
After creation, a \fIGo\fP instance may be either \fIreparented\fP in an
existing \fIGo tree\fP, or used as a root of other \fIGo's\fP.
.LP
The \fIdestructor\fP is called when a Go subclass destructor is called
(.i.e \fIdelete my_rectangle\fP). At this time the \fIGo\fP is removed from
the \fIGo tree\fP and all resources freed. When calling \fIdelete\fP,
pre and postconditions are NOT invoked, instead, the \fIdestroy()\fP should be
preferred.
.NH4
Editing/Navigating The Go Tree
.LP
A \fIGo tree\fP is a set of \fIGo\fP instances organized in a hierarchical
way. A branch of the tree is called a subtree. The root of a \fIGo tree\fP
may be any \fIGo\fP or an instance of the \fIGoRoot\fP class.
A \fIGoRoot\fP instance have to be
``connected'' to a \fIGoInterf\fP instance in order to map the \fIGo tree\fP
onto a given output.
.LP
In addition to the graphic composition, the tree organization have
consequences on the object drawing: a child is drawn on \fItop\fP of its
parent and \fIunder\fP its next brother. There is no graphic attribute
inheritance between parent and children, however the coordinate system
transformations (move, rotate, ...) have impacts on the children
(see below).
.LP
The \fIGo\fP class offers methods for \fIGo tree\fP management, so it is
possible to ``reparent'' (\fIreparent()\fP) a \fIGo\fP or to
``rebrother'' (\fIshift()\fP) it. These methods have pre and postconditions.
Other methods allow to navigate in the
\fIGo tree\fP (\fIparent(), previous(), next(), child(), lastchild()\fP) or to get
information such as \fIisAncestor()\fP or \fIroot()\fP.
.LP
It is also possible to make that a \fIGo subtree\fP looks like a leaf of a \fIGo
tree\fP (\fIleaf()\fP), in that case the \fIchild()\fP function will return
\fINULL\fP. The method \fIunleaf()\fP restores the \fIGo subtree\fP access.
.NH4
Modifying Go Geometry
.LP
The \fIGo\fP class offers a set of functions allowing to transform the
\fIGo\fP geometry. Transforming the geometry means to apply a transformation
function  to the \fIGo\fP coordinate system in which positions and dimensions
are expressed. For example, the radius of a \fIGoCircle\fP will be scaled
if a scaling is applied to its coordinate system.
.LP
The coordinate system is defined by its origin point \fI(O)\fP and two vectors
\fI(I, J)\fP. The absolute coordinate system of a \fIGo\fP instance is defined
relatively to the \fBGo\fP reference coordinate system (\fIin millimeters,
origin at the upper left corner\fP). It may also be expressed relatively
to another coordinate system. Then, modifications can be done
relatively to another coordinate system (\fIRelative transformations\fP)
or in the absolute coordinate system (\fIAbsolute transformations\fP).
The coordinate system transformations (translation, rotation, ...)are
applied to the entire subtree.
Other geometry transformations may be available in \fIGo\fP subclasses (i.e
moving a point in a polyline, changing the length or the width of a rectangle,
changing the font of a text), these modifications affect the object geometry
or attributes but not necessary the coordinate system.
.LP
General transformations of the coordinate system can be performed by using
\fIsetCoordSys()\fP.
Methods allowing usual transformations are also available:
\fImove()\fP,
\fIrescale()\fP or \fIrotate()\fP either relatively to the parent coordinate
system or relatively to the absolute coordinate system.
.LP
Pre and postconditions are available to control the geometry modifications.
This is specially useful to implement constraints (alignment, confinement, ...).
They can also be use to control the geometry propagation in the \fIGo tree\fP
(a given deformation may be not desired for \fIGo's\fP in a subtree).
.NH4
Inquiry Go Geometry
.LP
The \fBGo\fP class provides the application developer with methods
in order to get the \fIGo\fP coordinate system expressed either relatively to
any other coordinate system or to the absolute coordinate system
(\fIcoordsys(), origin(), matrix()\fP).
.NH4
Overall Dimensions
.LP
The \fIGo\fP class offers a set of methods to know the overall dimensions
of a \fIGo\fP. This is the clipping region (a region is a list of rectangle).
.LP
Methods return either
the clipping region of the \fIGo\fP (\fImyclip(), myOpaqueClip\fP) or the
clipping region of the \fIGo\fP subtree (\fIclip(), opaqueClip()\fP).
.LP
The opaque region is included in the clipping region.
Moreover, the method \fIcontains()\fP returns \fIGTRUE\fP
if a given point belongs to the object drawings.
.NH4
Mapping/Unmapping Go's
.LP
The \fIGo\fP class provides methods to map (\fImap()\fP) or to unmap
(\fIunmap()\fP a \fIGo\fP.
.LP
A \fIGo\fP can be unmapped, that means it is not drawn (its \fImapped\fP flag
is \fIGFALSE\fP). It can be mappable; its \fImapped\fP flag is \fIGTRUE\fP but
one of its ancestors is not
mapped (including the \fIGoRoot\fP). A \fIGo\fP can be mapped, that means
it is drawn on the output device through the \fIGoInterf\fP.
.LP
The \fIGo\fP class provides methods to map (\fImap()\fP) or to unmap
(\fIunmap()\fP a \fIGo\fP. Pre and post conditions are available for
these operations.
.LP
When a \fIGo\fP is mapped, the redisplay of damaged areas is
managed by \fBGo\fP.
.NH4
Go And Application Communications
.LP
\fBPreconditions, Postconditions:\fP
.LP
Applications which want to control modifications of \fIGo's\fP or to be
notified when
events occur on graphic objects can attach callback procedures to
\fIGo\fP instances or at the \fIGo\fP class level. The callback procedures
can be \fBpreconditions\fP of \fBpostconditions\fP.
.LP
Precondition callbacks
are invoked just before actions, they can accept or refuse the action, or
in some cases, change the modification. An action will be performed
if preconditions return \fIGTRUE\fP and if, when the action affects \fIGo's\fP
in the subtree, all the preconditions in the subtree are satisfied. If one
of these preconditions returns \fIGFALSE\fP, the action is canceled.
.LP
Postcondition callbacks are invoked after action is performed. Like the
preconditions, if the action affects some \fIGo's\fP in the subtree, the
postconditions attached to such \fIGo's\fP are called.
.LP
Pre and postconditions attached to the instance are called before
pre and postconditions attached to the class (metaclass).
.LP
All of the available actions on \fIGo's\fP may be controlled by pre and
postconditions. Specially the creation and the destruction of
instances may be controlled by such conditions. It is the responsibility
of \fIGo\fP subclass programmers to provide the pre and postcondition
facilities for the added actions.
.LP
Methods such as \fIaction\fP\fIPrecond()\fP and \fIaction\fP\fIPostcond()\fP
are used to add or remove conditions which will be invoked when \fIaction\fP
will be requested.
.LP
\fBAssociations:\fP
.LP
Usually \fIGo's\fP do not include semantic but if an application wants to link
some private data with them, it is possible by using the association mechanism.
An \fBassociation\fP is defined by the couple
(\fIassociation key, association value\fP). The association key is
a long integer identifying the association and the association
value is a four byte
value or any data buffer. \fIGo\fP instances maintain an \fBAssoc\fP 
class instance which manages all \fIGo\fP associations and the method
\fIassoc()\fP allows to get it and add or remove associations\u\s41\s0\d.
.FS
1) This \fIAssoc\fP instance is also used to store some internal management
information (i.e. pre/post conditions).
.FE
.NH4
Selecting/Unselecting Go's
.LP
The \fIGo\fP class provides functions to select (\fIselect()\fP) or to unselect
(\fIunselect()\fP) \fIGo\fP instances.
.LP
The \fIselected\fP status can be used for any purpose. It is often used in
graphical editors for starting action selected objects like ``\fImove
all selected objects\fP''.
.LP
Preconditions and postconditions can be defined for these methods and in the
case of editors it may be decided to create a \fIGoSensor\fP (to make sensitive
the object) or/and to decorate the object for giving the selection feedback
to the end user.
.NH4
Interactive Actions
.LP
Most methods defined in the \fIGo\fP class may be used in a
\fIGTranslatorPgm\fP, that means invokable by a user event. Methods have an
ascii name maintained at the class level (actions()\fP) and these names may
be used in customization files as action names (for example: the
\fIGo::destroy()\fP string may be used to call the method \fIdestroy()\fP).
.NH4
Saving/Restoring Go's
.LP
In order to save \fIGo\fP (sub)trees, the \fIGo\fP class allows to create
data streams by calling the method \fIsave()\fP. These streams are managed by
\fBGoStream\fP subclass instances.
The stream format is defined by the \fIGoStream\fP subclass
and is hidden to \fIGo's\fP.
.LP
To restore a \fIGo\fP (sub)tree from a data stream, the \fIGoStream\fP instance
interprets the stream and asks the appropriate \fIGo\fP subclass to create a
new
instance by reading parameters from the stream. The \fIrestore()\fP method
expects to retrieve the values previously saved by the \fIsave()\fP method.
.LP
The data stream contains the information needed to restore the objects
independently of the context (i.e. parent object) at the save time. After
the restore, the objects will get back the same appearance. This is very useful
when using \fIGoStreams\fP for inter-application communications
(cut/copy/paste), each application having its own context.
.LP
Pre and postconditions are available before and after performing a save or
a restore operation. Applications are able to use postconditions in order
to save/restore their own data. The \fIGoStream\fP is independent of the
object classes which are saved or restored, thus applications are able to save
and restore private objects.
.LP
See also \fIConverter(3Go), ClipboardInterf(3Go), Tiff(3Go), Gif(3Go)\fP.
.bp
.NH3
GoRoot Class
.LP
The \fBGoRoot\fP class is a subclass of the \fIGo\fP class. An
instance of such a class is responsible to link a \fIGoInterf\fP instance
to a \fIGo\fP tree.
.LP
The method \fIsetInterf()\fP allows to attach a given instance of
\fIGoInterf\fP subclass to a \fIGoRoot\fP. If no \fIGoInterf\fP is attached
to a \fIGoRoot\fP, a \fIpseudo\fP interface is used for the \fIGoInterf\fP
query methods (it does nothing for output/input methods).
.LP
A \fIGoRoot\fP instance is responsible of managing \fIexpose\fP events and
redrawing \fIGo's\fP. At every time, \fIGoRoot\fP maintains the \fIregion\fP
to be
redrawn and the drawing is effectively performed when explicitly
calling the method \fIflush()\fP. The damaged region computation can be
frozen and unfrozen (methods \fIenableDamage(), disableDamage()).
.LP
Starting with a \fIGoRoot\fP, the corresponding \fIGoUI\fP instances and
the \fIGoSensors\fP can navigate in the \fIGo\fP tree in order to
determine which objects are interested with the events. The navigation is
\fITop-Down\fP.
.bp
.NH3
GoInterf Class
.LP
The \fIGoInterf\fP class defines a generic output and input interface
for graphic system. As it is not clear in its name, \fIGoInterf\fP is
independent of \fIGo's\fP and may be used by other piece of software.
.LP
\fBGo\fP uses \fIGoInterf\fP as the interface between \fIGo's\fP and the
underlaid \fIGraphic System\fP (i.e. \fIX Window System\u\s4TM\s0\d\fP).
\fIGoInterf\fP keeps the \fBGo\fP drawing process independent of the graphic
system (unit, coordinate system, graphic primitives, fonts, ...). There is
one \fIGoInterf\fP subclass per graphic system, existing subclasses are
\fIXGoInterf\fP for the X Window System\u\s4TM\s0\d, \fIXmGoInterf\fP
for OSF/Motif\u\s4TM\s0\d,
\fIWinGoInterf\fP for MS-Windows\u\s4TM\s0\d and \fIPSGoInterf\fP for
PostScript\u\s4TM\s0\d.
.LP
It cannot be guaranteed that a given \fBGoInterf\fP subclass implements
correctly all defined methods (see in the \fIGo Reference Manual\fP,
the limitations of every \fIGoInterf\fP subclasses).
.sp 1
.DS B
.PS
down
Box1: box height 0.50i width 1.0i "GoInterf"
line down .3i
line left 1.2i
line down .3i
Box4: box height 0.50i width 1.0i "XGoInterf"
line down .3i
box height .50i width 1.0i "XmGoInterf"
move up 1.6i
move right 1.2i
line down .3i
Box5: box height 0.50i width 1.0i "WinGoInterf"
move up .8i
line right 1.2i
line down .3i
Box6: box height 0.50i width 1.0i "PSGoInterf"
.PE
.DE
.DS C
\fIfigure 4.3 : GoInterf class hierarchy\fP
.DE
.sp 1
.NH4
Construction/Destruction
.LP
The \fIGoInterf\fP class constructor is only called through
subclass constructors: \fBXGoInterf\fP, \fBXmGoInterf\fP,
\fBPSGoInterf\fP, \fBWinGoInterf\fP. Each \fIGoInterf\fP subclass offers
specific constructors, for example, the \fIXGoInterf\fP constructor may require
a \fIX Window Id\fP, the \fIPSGoInterf\fP constructor may require a
file descriptor.
.LP
Postcondition callbacks may be called just before the destruction of
\fIGoInterf\fP instances.
.LP
.NH4
Output Methods
.LP
A set of output methods is provided by the \fBGoInterf\fP class. These methods
allow to draw on the output device. 
.LP
A typical output method is the following:
.br
.RS 0.5i
\fImethod(attributes, cs, parameters ..., quality)\fP
.RE
Where
.RS .5i
.IP \fIattributes\fP .5i
.br
Specifies a pen, a brush, a text brush and/or a image brush, depending of
the method.
.IP \fIcs\fP .5i
.br
Specifies the coordinate system in which \fIparameters\fP are expressed.
.IP \fIparameters\fP .5i
Specifies the parameters of the given methods (points, string, ...).
.IP \fIquality\fP .5i
.br
Specifies the drawing quality. For response time reason, it could be useful
to have an approximative drawing. There are 5 quality levels: minimum,
bad, medium, good and max quality.
.RE
.LP
Available output methods allow to perform linear drawings (\fIpolylines,
polygons, arcs, curves, ...\fP), filled drawings (\fIfilled polygons, arcs, ...\fP), text drawing and image drawing.
.NH4
Input Methods
.LP
A set of methods is offered in order to manage user events and to control the
pointer (\fIget, set, ...\fP).
Input methods allow to set the input event mask (buttons, keys, ...).
.LP
See also \fIInputDispatcher(3Go)\fP.
.NH4
Cursor and Bell Methods
.LP
The \fIGoInterf\fP class allows to set the cursor shape (\fIpushCursor()\fP)
or to restore it (\fIpopCursor()\fP). Cursors are either an predefined
identifier (i.e \fIGCURSOR_ARROW\fP) or a resource \fIShCursor\fP*.
.FS
* Not available yet.
.FE
.LP
It is also possible to active the bell (\fIbell()\fP).
.NH4
Query Methods
.LP
A set of query methods are available to get information about the
real output device: resolutions, fonts metrics, ... These methods may be
used by \fIGo's\fP expecting such information in order to compute their shape,
the size or the clipping region.
.LP
These methods allow to get device characteristics (\fIwidth, height,
pixel sizes, depth, background color\fP), string metrics (\fIbearings, ascent,
descent, width\fP), font metrics (\fIunderline characteristics, spacing,
strikeout, ...\fP).
.bp
.NH3
GoUI Classes
.LP
\fIGoUI classes\fP mean classes involved in the user interactions which are:
.IP
GoUI
.br
GoSensor
.br
GInteractor
.br
GInteractorPgm
.NH4
The GoUI Class
.LP
There is one \fIGoUI\fP instance per \fIGoInterf\fP and \fIGoRoot\fP instances.
\fIGoUI\fP is responsible to dispatch events occuring in the window and
coming from the \fIGoInterf\fP to the concerned \fIGoSensors\fP. Thus,
\fIGoUI\fP maintains the list of the sensitive areas.
.LP
\fIGoUI\fP provides the focus management (the focus is defines by the
\fIGoSensor\fP receiving the keyboard events) and the grabbing management
(a \fIGoSensor\fP will grab the events when all the events will be sent to it).
.LP
A subclass of \fBGoUI\fP called \fIBGoUIEditor\fP which has been designed
for the \fBGo Companions\fP. This class provides an editing context:
selected objects, current parent, ... and some convenient methods for
object creations.
.NH4
The GoSensor Class
.LP
The \fIGoSensor\fP class only makes sensitive its parent. Thus, to make
sensitive a \fIGo\fP, it is just necessary to create a \fIGoSensor\fP
instance and reparent it under the \fIGo\fP.
.LP
Interactions started when events occur depend on the \fBname\fP of the
\fIGoSensor\fP and on the \fIGo\fP class. For example, if the sensor
called \fIedit\fP is the child of a \fIGoRectangle\fP instance, when
an event will occur the \fIGInteractorPgm\fP ``\fIGoRectangle.edit\fP''
will be invoked. Interaction program names follow the class hierarchy names,
thus, if ``\fIGoRectangle.edit\fP'' program does not exist and if the
\fIGoRectangle\fP class is a subclass of \fIGoPolygon\fP, the interaction
program ``\fIGoPolygon.edit\fP'' will be searched, etc ...
.LP
Some \fIGoSensor\fP subclasses exist, they are:
.IP\fIClipSensor\fP
making sensitive the bounding box area of its parent.
.IP \fIFullSensor\fP
making sensitive the entire window where its parent is displayed.
.IP \fIPointSensor\fP
making sensitive the point in the \fIGoPolypoint\fP class and subclass. A
small circle is drawn at the point location.
.NH4
The GInteractor Class
.LP
The \fIGInteractor\fP class is the abstract class for the interaction
object classes. It maintains the status of the interaction (eg. \fIRUNNING,
DONE, CANCELED\fP) and the link with the interaction program
(\fIGInteractorPgm\fP).
.LP
Some classes has been defined: \fIGrabber\fP classes which manage grabbing
interaction programs, \fITranslator\fP class which manages event translation
programs (the simple \fIGoUI\fP language).
.NH4
The GInteractorPgm Class
.LP
The \fIGInteractorPgm\fP class is the abstract class for all interaction
program object classes. Interaction programs implement the interaction
itself.
.LP
Interaction program can be shared between several concurrent interactions (their
execution context is maintained by the \fIGInteractor\fP objects).
.LP
A number of interaction program has be designed in order to interact on the
\fIGo\fP's. Most of them are \fIGrabberPgm\fP subclasses. The
\fITranslatorPgm\fP class implements the \fIGoUI\fP simple language
interpretor (see \fITranslator(3Go)\fP).
.bp
.NH3
GoStream Class
.LP
The \fBGoStream\fP class allows to export/import any kind of data, and in
particular \fIGo\fP trees, to/from an external data stream. It is an abstract
class, which means that applications may only use \fIGoStream\fP subclasses
instances to serve their purposes. A GoStream stores the data stream in a
\fIMedium\fP object (see \fIMedium(3Go)\fP) that may represent a file, a
network connection, a shared memory segment, ... depending on the \fIMedium\fP
subclass used.
.LP
The \fIGoStream\fP class is independent of \fIGo\fP subclasses
and can be used to store or retrieve any kind of object; \fIObjectStream\fP
would have been a better class name. As a consequence, applications may
store/retrieve their own objects by writing two functions (one for saving and
one for retrieving) and binding them to a string associated with their data
type, just like \fIGo\fP subclasses do (see \fIGoStream::bind()\fP method).
To make explanations and examples easier to understand, we will use the word
"\fIfamilyname\fP" to refer to this string.
\fIGoStream\fP will be in charge of calling these functions at the appropriate
time. Note that contents of a \fIGoStream\fP created with such private "save"
functions might not be fully understandable by other applications that do not
have access to the corresponding private "restore" function. 
.LP
Applications can also add/read private data when saving/restoring \fIGo\fP's by
using \fIGo\fP pre/postconditions \fIsavePostCond\fP and \fIrestorePostCond\fP.
This capability can be used to exchange structured graphics and associated
semantics between cooperative applications (see also \fIgodraw\fP).
.sp1
.LP
\fBGoAscii\fP inherits behavior from \fIGoStream\fP and encodes its data stream
in an ASCII format (see \fIGoAscii(3Go)\fP). \fBGoBinary\fP inherits
behavior for \fIGoStream\fP and encodes its data
stream in a portable binary format (see \fIGoBinary(3Go)\fP).
.NH4
Doing the right bindings
.LP
Before trying to save or restore an object, one must make sure that
\fIGoStream\fP class as learned how to save or retrieve such an object, i.e.
the
object private \fIsave()\fP and \fIrestore()\fP functions have been bound to a
string identifying the object type or class, \fIfamilyname\fP (see \fIbind()\fP
method). If the application initializes the toolkit by calling \fIGoInit()\fP,
all \fIGoStream\fP instances will know how to save or restore any \fIGo\fP or
\fISharedObject\fP subclass (except \fIShArray\fP) that is a part of the Go
distribution tape. Any other binding will have to be performed by the
application.
.NH4
Opening/Closing A Stream
.LP
To save/restore a \fIGo\fP subtree, one has to create a \fIGoStream\fP subclass
instance, associate the appropriate \fIMedium\fP to it and open it. A stream can
be opened in \fIwrite\fP (it is truncated), in \fIappend\fP (the \fIGo\fP
subtree is added at the end of the stream) or in \fIread\fP. The function
\fIclose()\fP closes the stream.
.LP
When the stream is closed, it is possible to modify the associated \fIMedium\fP
(i.e. changing the file name or the memory buffer). This allows to keep
the same \fIGoStream\fP instance for several save/restore sessions.
.NH4
Saving Objects
.LP
When a \fIGoStream\fP is opened in \fIwrite\fP, the application may ask to save
a given object by calling \fIsaveObj()\fP with the object \fIfamilyname\fP.
\fIGoStream\fP will call the appropriate function depending on
\fIfamilyname\fP. The same object may be saved many other times during the same
saving session with no additional cost of disk or memory space.
.NH4
Restoring Objects
.LP
When a \fIGoStream\fP is opened in \fIread\fP, the application may ask to
restore an object by calling \fIrestoreObj()\fP method. \fIGoStream\fP will
call the appropriate function depending on the object description on its data
stream and return the object along with its \fIfamilyname\fP.
.NH4
Writing And Reading Parameters
.LP
If a new type of object wants to write its save and restore functions, it has
to be able to save its private data. \fIGoStream\fP provides quite a few
methods to write and read basic parameters (e.g. \fIwriteInt()\fP,
\fIreadInt()\fP, \fIwriteString()\fP, \fIreadString()\fP ...). Such methods are
only meant to be used from within a save or restore function. Note that the
called by on \fIGo\fP \fIsavePrecond\fP, \fIsavePostcond\fP,
\fIrestorePrecond\fP and \fIrestorePostcond\fP are considered to be a part of
\fIGo\fP save or restore functions and, as such, may use these \fIGoStream\fP
methods.
.bp
.NH2
Resource Classes
.LP
This section discusses classes which define resources used when
drawing \fIGo's\fP. These resources are \fIshared objects\fP, that means
they can be shared between several \fIGo\fP instance.
.NH3
SharedObject Class
.LP
The \fBSharedObject\fP class is the basic super class for all resources.
A \fISharedObject\fP instance maintains a reference count which is incremented
or decremented when a new instance is created or destroyed.
.LP
A \fISharedObject\fP is defined by a set of values and an interest bit mask.
When a new \fISharedObject\fP subclass instance is created, an existing
shared object matching the requested instance is searched for. If such
an object already exists, the reference count is incremented and the shared
object is returned. A shared object is effectively destroyed only if the
reference count becomes 0.
.LP
A shared object my be \fBnamed\fP. A name refers a single shared object. Using
a name when creating or modifying a shared object affect a unique object.
It is a way to control the object sharing.
.LP
Postconditions are available  to be notified when a modification occurs.
.LP
A ``regular''
object class has been defined for each \fISharedObject\fP subclass; these
classes give a regular interface for shared objects (for example, the
\fIPen\fP class gives a regular programming interface to the \fIShPen\fP
class). In addition, these object classes offer pre and postconditions in order
to control modifications of the object value.
.NH3
SharedObject Subclasses
.LP
Shared objects are graphic attributes which are used by the \fIGoInterf\fP
to perform the output requests. Most of graphic objects which are able to
draw something includes such resources. Predefined \fIGo's\fP described
in the next chapter offer an interface to manage these resources.
.LP
The following resource object classes are defined:
.RS .5i
.IP "\fBShBrush and Brush\fP
The \fIShBrush\fP class defines a shared object used by
\fIGoInterf's\fP when drawing filled areas. It includes colors and patterning
attributes. The \fIBrush\fP class defines a regular interface for \fIShBrush\fP.
.IP "\fBShColor and Color\fP
The \fIShColor\fP class defines a color as a set of three values: a RGB
value, a gray scale value or an halftone value. The halftone is a
\fIShPattern\fP instance. Such objects are included in \fIShBrush\fP,
\fIShPen\fP, \fIShTextBrush\fP and \fIShColormap\fP. The \fIColor\fP class
defines a regular interface for \fIShColor\fP.
.IP "\fBShColormap and Colormap\fP
The \fIShColormap\fP class defines a color (\fIShColor\fP) array. This shared
object is used by the \fIGoInterf\fP to draw a \fIShPixelArray\fP. Each
\fIShColormap\fP entry represents a pixel value in the pixel array. The
\fIColormap\fP class gives a regular interface for \fIShColormap\fP.
.IP "\fBShDash and Dash\fP
The \fIShDash\fP class defines an object as a set of dashes and gaps. This
shared object is used by the \fIGoInterf\fP when drawing lines, it is included
in the \fIShPen\fP. The \fIDash\fP class defines a regular interface for
\fIShDash\fP.
.IP "\fBShFont and Font\fP
The \fIShFont\fP class defines a font as a set of strings which identify the
registered name, the family name, the typographic weight, the slant code, the
typographic proportionate width, the typographic style, the spacing code, the
character set registered name, and the character encoding. \fIShFont\fP objects
are used by the \fIGoInterf\fP when drawing text. The height information is
given as a parameter of the \fIGoInterf\fP \fIstring()\fP method.
\fITextBrush\fP objects include \fIShFont\fP objects. The \fIFont\fP class
defines a regular programming interface for \fIShFont\fP.
.IP "\fBShImageBrush and ImageBrush\fP
The \fIShImageBrush\fP class defines objects which mainly contains
\fIShColormap\fP. \fIShImageBrush\fP object are used by the \fIGoInterf\fP when
displaying pixel arrays. The \fIImageBrush\fP class defines a regular
programming interface for \fIShImageBrush\fP.
.IP "\fBShPattern and Pattern\fP
The \fIShPattern\fP class defines objects used by \fIGoInterf's\fP in the
patterning operation. A pattern is defined by a pixel array
(\fIShPixelArray\fP), a color map (\fIShColormap\fP) and a size in millimeters.
\fIShPattern\fP instances are included in \fIShPen\fP, \fIShBrush\fP,
\fIShTextBrush\fP and \fIShColor\fP objects.
.IP "\fBShPen and Pen\fP
The \fIShPen\fP class defines objects used by \fIGoInterf's\fP when drawing
lines or curves. They contain lines attributes (width, cap style, join style,
dashing, ...), colors and patterning attributes. The \fIPen\fP class defines a
regular programming interface for \fIShPen\fP.
.IP "\fBShPixelArray and PixelArray\fP
The \fIShPixelArray\fP class defines objects which are two dimensional pixel
arrays. A pixel is a value used as index in a colormap (\fIShColormap\fP) by
the \fIGoInterf\fP when displaying images or patterns. Other attributes define
the pixel array: (\fIbit and byte order, depth, encoding, ...). The
\fIPixelArray\fP class defines a regular programming interface for
\fIShPixelArray\fP.
.IP "\fBShTextBrush and TextBrush\fP
The \fIShTextBrush\fP class defines objects used by \fIGoInterf's\fP
when drawing text. They contains font attributes (\fIShFont\fP), colors
(\fIShColor's\fP) and patterning attributes (\fIShPattern's\fP). The
\fITextBrush\fP class defines a regular programming interface for
\fIShTextBrush\fP.
.RE
