.\" $Id: ch07.ms,v 1.3 1992/12/28 15:51:37 davy Exp $
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.bp
.NH1
USING \s12GoPATH\s0
.LP
How can graphical applications use \fBGoPATH\fP to display their internal
objects and let the user interact on them?
.NH2
Displaying Objects
.LP
For purely 2D graphic applications (e.g. graphic editor), the use of
\fBGoPATH\fP is trivial. Such applications have no semantic attached to
graphic objects, but for most applications, graphical presentations reflect
complex internal data (e.g. decision support, CAD-CAM, ...)
.LP
Applications which want to present graphically data,
have (at least) two possibilities with the \fBGo\fP libraries: either
they use graphic objects as they are defined (i.e for graphic only) and keeps
their own internal representation, or else, application programmers create new
specific \fIGo\fP subclasses including semantic aspects.
.NH3
Keeping An Internal Representation
.LP
Applications managing objects may not be happy with the hierarchy
structure of the \fIGo\fP tree or may offer other than 2D external
representation. In these cases, they might prefer to keep their own internal
organization for storing object semantic.
.LP
Applications have then, to create \fIGo\fP trees corresponding
to the desired 2D graphic representations (this can be done by retreiving
\fIGoStream\fP files edited by \fBgodraw\fP). If they want to control the
user interactions, they have to set \fIpreconditions\fP functions; or,
if they want to be notified when actions  occur on the external
representation they have to set \fIpostconditions\fP. By this way,
they are able to keep their internal data in conformance with the
external representation.
.LP
In addition, applications can link their internal and external representations
by defining \fIassociations\fP. This allows to maintain
any kind of links between \fBGo\fP objects and applications (Note that
\fBgodraw\fP can save some semantic values).
.LP
When \fIGo's\fP are saved in streams (\fIGoStream\fP subclass instances), it
is the application responsibility to save links (associations) and constraints
(pre and postconditions). To do that, the applications can set
\fIpostconditions\fP on save/restore actions and save/retrieve
their private objects into/from the streams (see \fIGoStream(3Go)\fP).
.NH3
Including Object Semantic In GoPATH
.LP
Application satisfied with the \fIGo\fP hierarchic structure can define
new classes which will be subclasses of \fIGo\fP (sub)classes. These
subclasses will allow to store some semantic information inside graphic
objects themselves.
They will probably provide specific methods for semantic management.
.LP
Such classes directly use the \fBGoStream\fP interface to save (graphic and
semantic) data in streams.
.NH2
User Direct Manipulations
.LP
The \fBGo\fP libraries provide facilities allowing the user to interact on
the 2D graphic representation of objects by direct manipulations. The behavior
may be defined in ascii files (usually suffixed by \fI.goui\fP)
and can be customized with respect to the user preferences.
.LP
Applications may want to be notified when given events occur on sensitive
areas (\fIGoSensors\fP). The simplest interactions is to start an action
when an event occurs on a given sensitive area.
In that case, they have first to add entries in
\fI.goui\fP files (or add dynamically such entry using the \fIadd()\fP
method of the \fIGTranslatorPgm\fP class) and second, they have to declare the
corresponding functions (using the global function \fIGBind()\fP of the
\fIGTranslatorPgm\fP class, see \fIGTranslatorPgm(3Go)\fP).
.LP
Applications can use predefined \fIGoSensor\fP classes but they can create new
instances everywhere. For example, if an application wants to pop
a menu when the mouse button 1 is pressed on a selected polyline, it can
use a predefined sensor called \fIpolyline\fP. If the application
wants to make sensitive a given part of the \fIGoRoot\fP, it can create
its own \fIGoSensor\fP instances somewhere in the \fIGoRoot\fP subtree.
.LP
Note: if the application developer creates new \fIGo\fP subclasses,
probably, he/she will have to extend the \fIGoUI\fP part (in fact,
InteractorPgm classes) in order to take in account some new interaction types.
.NH2
Making GoPATH Based Applications
.NH3
Unix\u\s4TM\s0\d Environment
.LP
The following text gives some information about using \fBGoPATH\fP in the
Unix\u\s4TM\s0\d environment. See also the \fIGoPATH Installation Guide\fP.
.NH4
Include files
.LP
Include files are usually located in \fI/usr/local/include/Go\fP, in
\fI/usr/local/include/Go/Tools\fP and in \fI/usr/local/include/Go/Ext\fP, thus
it is recommended to include files as follows:
.IP
\fI#include <Go/filename.h>\fP
.br
\fI#include <Go/Tools/filename.h>\fP
.br
or
.br
\fI#include <Go/Ext/filename.h>\fP
.LP
There is one header file by object class. The name of this file is either the
class name for the \fBGo\fP basic classes (i.e \fIGo.h\fP,
\fIGoRoot\fP, \fIGoStream\fP, ...) and without the \fIGo\fP prefix for
predefined \fIGo\fP subclasses and tools (e.g. \fICircle.h\fP is the hearder
file for the \fIGoCircle\fP class). Due to system limitations, some file
names are truncated.
.LP
A class header file contains everything
needed for creating and using instances of this class. For example, the header
file \fIPolyline.h\fP includes also other necessary header files (i.e.
\fIGo.h, Pen.h, ...\fP).
.LP
To be able to display, to interact or to save/restore objects appropriate
header files have to be included (for example: \fIXGoInterf.h, GoUI.h, ...\fP.
See also the \fIGoPATH Reference Manual\fP.
.NH4
Libraries
.LP
\fBGo\fP libraries are usually located in \fI/usr/local/lib/Go\fP, thus it is
recommended to add the \fI-L/usr/local/lib/Go\fP option when calling
\fIld(1)\fP.
.LP
The \fBGo\fP libraries are:
.IP "\fBlibgo.a:\fP"
contains the \fBGo\fP kernel (\fIGo\fP, \fIGoStream\fP, \fIGoInterf\fP
and \fIGoUI\fP), the tools (\fIPen, Brush, ...\fP).
.IP "\fBlibbgo.a:\fP"
contains the predefined \fIGo\fP classes: geometric, textual, image
and graph. It also includes the \fIBGoUI\fP class which implements specific
interactions for the predefined \fIGo\fP classes.
.IP "\fBlibgoext.a:\fP
contains higher level objects for creating applications: clipboard management,
format converters, graphical object editors, help, ...
.IP "\fBlibXb.a:\fP
contains some widgets which are used in some \fBGo\fP companions.
.LP
These libraries include the \fIC\fP interface.
.NH4
GoENVIRON Shell Variable
.LP
Applications need to localize files (customization files (\fI.goui\fP),
\fIGoStream\fP files, help files, ...). A shell variable \fBGoENVIRON\fP
has been defined, it localizes the ``root'' directory for these files.
There is a subdirectory per application (for example: the \fIgodraw\fP
subdirectory contains files and directories for interaction files,
help files, ...).
.LP
The \fIGoENVIRON\fP variable is also used by the \fIPSGoInterf\fP instances
for retrieving the ``prologue'' of the generated PostScript\u\s4TM\s0\d
files and the font metrics.
.LP
Dictionaries are also stored under the \fIGoENVIRON\fP directory, these
dictionaries are used by the multi-column text formatter when cutting words
in various languages (English, French, Spanish, ...).
.LP
The function \fIGetFilePath()\fP of the \fBGo\fP library allows to retrieve
an environment file. First, it looks in the current working directory,
if the requested file is not in this directory, it takes in account the
\fIGoENVIRON\fP variable. If the \fIGoENVIRON\fP variable is not set,
it looks in \fI/usr/local/lib/Go\fP.
.NH 4
Motif Environment
.LP
A new widget (\fBGraphic Widget\fP) has been developed and is distributed
with \fBGo\fP (libgo.a). This widget is a subclass of the \fIMotif\u\s4TM\s0\d
DrawingArea\fP widget. It allows to ease the intergration between
Motif\u\s4TM\s0\d and \fBGo\fP. See also \fIXbGraphic(3Go)\fP.
.LP
Other widgets are also distributed (libXb.a) and may be used in other
environments (they are independent of the \fBGo\fP libraries).
.NH3
MS-Windows\u\s4TM\s0\d Environment
.LP
The following text gives some information about using \fBGoPATH\fP in the
MS-Windows\u\s4TM\s0\d environment. See the \fIGoPATH Installation Guide\fP.
.sp 1
\fITo be completed\fP.
.bp
.NH2
Simple Go Based Application
.NH3
The International Text Viewer
.LP
This simple application shows on the screen a set of flags, when the
user clics on a flag a text in the associated language is displayed.
.LP
From the programmer point of view, this simple application tends to show
the main concepts of \fBGo\fP: \fIGoInterf\fP, \fIGoUI\fP, \fIGoStream\fP,
\fIAssociations\fP, ... and the use of \fIgodraw\fP.
.NH3
The Principles
.IP "Creating Flags and Texts"
All the objects have been created by using \fBgodraw\fP and stored in 
a \fIGoStream\fP file. Thus, it is very easy to add new flags and texts, to
modify the texts, ...
.IP "Identifying Objects"
\fIAssociations\fP (\fIAssoc\fP) have been defined with \fBgodraw\fP
in order to identify the objects at the loading time. The association key
are "language" and the value "some nationality". Flags and texts have
the same nationality two by two.
.IP "Interactions"
The user interactions are very simple: "press a button on a flag". The
\fIGoUI\fP file allows to determine which button will be used to start
the text mapping. The function is "\fIMapAnotherText\fP".
.bp
.NH3
The Source Code
.LP
.nf
.ta 0.5i 1.0i 1.50i 2.0i 2.5i
/*
 * \fISimple International Text Viewer\fP
 */

#include <Go/Tools/FilePath.h>
#include <Go/Tools/Atom.h>
#include <Go/Tools/Error.h>
#include <Go/Tools/Bind.h>

#include <Go/Init.h>

#include <Go/XGoInterf.h>
#include <Go/XInDisp.h>

#include <Go/GoUI.h>
#include <Go/FullSensor.h>
#include <Go/Translator.h>
#include <Go/GoRoot.h>

#include <Go/Text.h>

#include <Go/Ext/Converter.h>


#define TRANSLATOR_FILE "flags.goui"
#define GOSTREAM_FILE    "flags.str"
#define LANGUAGE_KEY    "language"
#define SELECTION_KEY    "selection"

/* \fISome global variables\fP */
GoRoot*    goroot;
XGoInterf* gointerf;
GoUI*      goui;
Go* current_text = NULL;
Go* current_rect = NULL;

GAtom language_key;
GAtom selection_key;

/* \fIFunction declarations\fP */
void create_goroot_and_gointerf ();
void initialize_goui ();
void read_my_gostream ();
void restore_assoc (void*, Go*, GoStream*);
void event_loop ();
void map_another_text (GoRoot*, const GPoint*);
void test_and_map (char*, Go*);
.bp
/*
 * \fBMAIN PROGRAM\fP
 */
\fBmain\fP (int, char**)
{
    create_goroot_and_gointerf();
    initialize_goui();
    read_my_gostream();
    event_loop();
}

/*
 * \fBINITIALIZE GoRoot, GoInterf and GoUI\fP
 */
void \fBcreate_goroot_and_gointerf\fP ()
{
    gointerf = new XGoInterf;
    gointerf->map();

    // \fIChange the background color;\fP
    GShColor* color = gointerf->colorFromName("gray93");
    gointerf->background(color);
    color->destroy();

    goroot = GoRoot::create();

    // \fIGoRoot has to know GoInterf in order to manage the expose events;\fP
    goroot->interf((GoInterf*)gointerf);

    // \fIInit and run the global input dispatcher. I choose the X one;\fP
    GInputDispatcher() = new XInputDispatcher(gointerf->display());

    // \fIspecific to XInputDispatcher;\fP
    ((XInputDispatcher*)GInputDispatcher())->addXGoInterf(gointerf);
}


void \fBinitialize_goui\fP ()
{
    // \fICreate a GoUI instance;\fP
    goui = new GoUI(gointerf);

    // \fIGet the fullpath of the GoUI file, this uses the GoENVIRON shell variable;\fP
    char* filename = GGetFilePath("app-files/flags", TRANSLATOR_FILE);
    if (! filename)
	GError("File %s does not exist.\\n", TRANSLATOR_FILE);

    // \fILoad the translators file;\fP
    GLoadTranslatorPgms(filename);
    GFREE(filename);
.bp
    // \fITranslators have to know the "map_another_text" function;\fP
    // \fIwhich is registered in the translator file (see below);\fP
    GBind("MapAnotherText", &map_another_text);

    // \fI Create the sensor referenced in the translator file;\fP
    GoFullSensor* toplevel = GoFullSensor::create("toplevel", goroot);
}


/*
 * \fBREAD the GoStream and INITIALIZE the Go tree\fP
 */
void \fBread_my_gostream\fP ()
{
    // \fIGet the fullname of the GoStream file;\fP
    char* filename = GGetFilePath("app-files/flags", GOSTREAM_FILE);
    if (! filename)
	GError("File %s does not exist.\\n", GOSTREAM_FILE);

    // \fIRegister in the GoStream class the restore methodes;\fP
    // \fIfor Graphic Objects, Tools and Extensions;\fP
    GoExtensionsInit();

    // \fIAsk to be notified when an object is restored in order\fP
    // \fIto restore the associations saved by godraw;\fP
    (void)Go::metaclass()->restorePostcond(restore_assoc, NULL);

    language_key = GCreateAtom(LANGUAGE_KEY);
    selection_key = GCreateAtom(SELECTION_KEY);

    // \fIRead the GoStream file;\fP
    // \fI GSet are used to return loaded objects;\fP
    GSet restored_go;
    GSet restored_shared;
    uint nb_restored_go = 0;
    uint nb_restored_shared = 0;
    GConverter converter;
    if (converter.gostreamFileToGo(filename, &restored_go, nb_restored_go,
				&restored_shared, nb_restored_shared) == GOK) {
	if (nb_restored_go)
	    for (Go* go = (Go*)restored_go.first(); go;
		 go = (Go*)restored_go.next())
		 go->reparent(goroot);
	else {
	    GFREE(filename);
	    GError("File %s is empty.\\n", GOSTREAM_FILE);
	}
	GFREE(filename);
    } else {
	GFREE(filename);
	GError("An error occured during the %s file loading.\\n", GOSTREAM_FILE);
    }
}


void \fBrestore_assoc\fP (void*, Go* go, GoStream* stream)
{
    /*
     * \fIGodraw stores associations as follows:\fP
     *	char	:	0x61      	# 'a' like assoc
     *	String	:	"language"	# key
     *	String	:	"spanish"	# value
     *	char	:	0x65     	# 'e' like end of assoc
     */
    const char notYetFinished = 'a';
    char c;
    char* key = NULL;
    char* val = NULL;

    for (;;) {
	/*
	 * \fIRead the saved associations in GoStream file;\fP
	 */
	stream->readChar(&c);
	if (c != notYetFinished)
	    break;
	// \fIGoStream makes the needed memory allocation;\fP
	stream->readString(0, &key);
	stream->readString(0, &val);

	if (strcmp(key, LANGUAGE_KEY) == 0)  {
	    if (go->getMetaclass()->isSubclass(GoTextual::metaclass())) {
		// \fIThis object is a text: store the language value\fP
		// \fIas an assoc in the go\fP
		go->assoc()->set(language_key, strlen(val) + 1, val);
		go->unmap();
	    } else {
		// \fIThis object should be a flag: store the language value\fP
		// \fIas an assoc in the go\fP
		go->assoc()->set(language_key, strlen(val) + 1, val);
	    }
	} else
	    if (strcmp(key, SELECTION_KEY) == 0)  {
		// \fIThis object is a selection rectangle: it will be\fP
		// \fIused to highlight tge current flag\fP.
		go->assoc()->set(selection_key, strlen(val) + 1, val);
		go->unmap();
	    }
	GFREE(val);
	GFREE(key);
    }
}
.bp
/*
 * \fBMANAGE USER INPUT\fP
 */

static GIdle \fBflush\fP(void* closure)
{
    // \fIthis function is called when no event is available on the input queue\fP
    // \fIand before\fP \fBhandle_next_event\fP

    ((GoRoot*)closure)->flush();
    return GIDLE_AFTER_NEXTEVENT;

}

void \fBevent_loop\fP ()
{
    // \fIInit the global application input_dispatcher;\fP
    // \fII use the X one;\fP
    GInputDispatcher() = new XInputDispatcher(gointerf->display());
    GInputDispatcher()->idleProc(flush, goroot);

    // \fISpecific to XInputDispatcher;\fP
    ((XInputDispatcher*)GInputDispatcher())->addXGoInterf(gointerf);
   
    // main loop; 
    (void)GInputDispatcher()->runEventLoop();

    // \fBNOT REACHED HERE\fP
}

void \fBmap_another_text\fP (GoRoot* root, const GPoint* p)
{
    Go* go = root->goAt(*p, 0.5);
    if (go && !go->getMetaclass()->isSubclass(GoTextual::metaclass())) {
	// \fIThe user clicked on a flag or on a selection rectangle;\fP
	int n;
	char* lang_flag = (char*)go->assoc()->get(language_key, n);
	if (lang_flag == NULL)   // This is a selection rectangle;
	    return;

	// \fIUnmap the current text and the current hightlight rectangle\fP
	if (current_text != NULL) {
	    current_text->unmap();
	    current_text = NULL;
	}
	if (current_rect != NULL) {
	    current_rect->unmap();
	    current_rect = NULL;
	}

	// \fIFor every go, execute the test_and_map() function\fP
	root->forEveryGo (test_and_map, lang_flag);
    }
}
.bp
void \fBtest_and_map\fP (char* flag, Go* go)
{
    char* flag_lang = (char*)flag;
    // \fIIs the Go a text?;\fP
    if (!current_text &&
	go->getMetaclass()->isSubclass(GoTextual::metaclass())) {
	int n;
	const char* text_lang =(const char*)go->assoc()->get(language_key, n);
	// \fIIs the language the expected one?;\fP
	if (strcmp(text_lang, flag_lang) == 0) {
	    current_text = go;
	    go->map();
	    // \fIIf the expected rectangle is already found, stop!\fP
	    if (current_rect)
		goroot->stopRecursion (NULL);
	}
	return;
    }

    // \fIIs the Go a highlight rectangle?;\fP
    if (!current_rect) {
	int n;
	const char* rect_lang = (const char*)go->assoc()->get(selection_key, n);
	if (!rect_lang)
	    // \fIThe Go is not a "highlight rectangle";\fP
	    return;
	
	if (strcmp(rect_lang, flag_lang) == 0) {
	    current_rect = go;
	    go->map();
	    // \fIIf the expected text is already found, stop!\fP
	    if (current_text)
		goroot->stopRecursion (NULL);
	}
	return;
    }
}
.fi
.NH3
GoUI File
.LP
.nf
#
# The only possible action is "MapAnotherText"
# it invoked when the user press the button 1
# The sensor ``toplevel'' of ``GoRoot'' will receive the event
#
.ta 1.0i 2.0i
GoRoot.toplevel	press<1>	MapAnotherText(go, pos)
.fi
.bp
.NH3
Imakefile File
.LP
.nf
/*
 * \fIImakefile for go-/bin/examples/flags\fP
 */

/* \fIAsk for Optimization\fP */
SetOptimize()

/* \fIAsk for use X and Go (Include, Libraries)\fP */
UseX()
UseGo()  /* or UseInstalledGo() */

/* \fIAsk makedepend on flags.cc\fP */
SetDependList(flags.cc)

/* \fIMake entries\fP */
SetMakeList(flags)
MakeProgram(flags, flags.o)
SetClearList(flags)

/* \fIInstall flags, flags.str, flags.goui in $GoENVIRON/app-files/flags\fP */
InstallBin(flags)
SetInstallAppName(flags)
InstallAppFiles(flags.str flags.goui)
.fi
.LP
See also \fBGo Installation Guide\fP.
