.\" $Id: Arc.n,v 1.2 1992/12/28 16:47:34 mbikina Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991, 1992 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoArc 3Go "December 1992" "Version 1.2" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoArc\fP \(em the Arc object class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Arc.h>\fP
.SH 
\fBCLASS\fP
.IP
\fBGoArc\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGoGeometric\fP class
.IP \(em 3
\fBGoStdDS\fP class
.IP \(em 3
\fBGo\fP class.
.RE
.SH
\fBDESCRIPTION\fP
.IP
\fBGoArc\fP is one of the basic graphic objects. Its shape is an ellipse arc
with the following characteristics :
.RS 10
.IP \(bu 3
the origin of its relative coordinate system is the center of the ellipse
.IP \(bu 3
the coordinate system axes are the ellipse axes
.IP \(bu 3
\fIradiusX\fP and \fIradiusY\fP, two positive Numbers represent the ellipse
radii with respect to the axes
.IP \(bu 3
\fIamplitude\fP, a GNumber (possibly negative) represents the angle
intercepting the arc. A positive value means a clockwise drawing and a negative
value means counterclockwise (Remember that coordinate systems are indirect).
.IP \(bu 3
\fIstart\fP, a GNumber (possibly negative) represents the angle (\fIOM, Ox\fP)
where \fIM\fP is either of the arc extremities and \fIOx\fP is the X axis of
its coordinate system.
.IP \(bu 3
\fIclosed\fP, a GBool that indicates if one must draw addtional segments (one
or two depending on \fIpie\fP attribute) to close the arc outline. This
attribute will only make sense if the arc has a visible outline (see
\fBGoGeometric\fP::\fBoutline\fP()). The default value is GFALSE.
.IP \(bu 3
\fIpie\fP, a GBool giving additional information on the arc shape. If set to
GTRUE, the arc is considered to be limited by the two radii associated with
\fIstart\fP and \fIamplitude\fP angles. If set to GFALSE, the arc is delimited
its chord. This attribute will affect the arc background (if visible). The arc
outline (if visible) will only be affected if \fIclosed\fP is set to GTRUE.
The default value is GFALSE.
.sp 1
.br
.nf
.ta .15i .25i 1.0i
class GoArc : public GoGeometric {

	public:

		static GoArcMetaclass* metaclass ();
		static GoArc* create ();
		static GoArc* create (GNumber, GNumber = 1,
			GNumber = 2*PI, GNumber = 0);

		GoArc (GNumber = 1, GNumber = 1,
			GNumber = 2*PI, GNumber = 0);
		GNumber start () const;
		GNumber amplitude () const;
		GNumber radiusX () const;
		GNumber radiusY () const;
		GBool pie ();
		GBool closed ();

		GBool reset (GNumber, GNumber, GNumber, GNumber);
		GBool start (GNumber);
		GBool amplitude (GNumber);
		GBool radiusX (GNumber);
		GBool radiusY (GNumber);
		GBool pie (GBool);
		GBool closed (GBool);

		/*
		 * \fBpre and post conditions:\fP
		 */

		void resetPrecond (GBool (*) (void*, const GoArc*,
			GNumber*, GNumber*, GNumber*, GNumber*),
			void*, GAddOrRemove = GADD);
		void resetPostcond (void (*) (void*, GoArc*),
			void*, GAddOrRemove = GADD);
		void radiusXPrecond (GBool (*) (void*, const GoArc*, GNumber*),
			void*, GAddOrRemove = GADD);
		void radiusXPostcond (void (*) (void*, GoArc*),
			void*, GAddOrRemove = GADD);
		void radiusYPrecond (GBool (*) (void*, const GoArc*, GNumber*),
			void*, GAddOrRemove = GADD);
		void radiusYPostcond (void (*) (void*, GoArc*),
			void*, GAddOrRemove = GADD);
		void amplitudePrecond (GBool (*) (void*, const GoArc*, GNumber*),
			void*, GAddOrRemove = GADD);
		void amplitudePostcond (void (*) (void*, GoArc*),
			void*, GAddOrRemove = GADD);
		void startPrecond (GBool (*) (void*, const GoArc*, GNumber*),
			void*, GAddOrRemove = GADD);
		void startPostcond (void (*) (void*, GoArc*),
			void*, GAddOrRemove = GADD);
		void piePrecond (GBool (*) (void*, const GoArc*, GBool*),
			void*, GAddOrRemove = GADD);
		void piePostcond (void (*) (void*, GoArc*),
			void*, GAddOrRemove = GADD);
		void closedPrecond (GBool (*) (void*, const GoArc*, GBool*),
			void*, GAddOrRemove = GADD);
		void closedPostcond (void (*) (void*, GoArc*),
			void*, GAddOrRemove = GADD);

		/*
		 * \fBpre conditions calls:\fP
		 */
		GBool callRadiusXPrecond(GNumber*)   const;
    		GBool callRadiusYPrecond(GNumber*)   const;
    		GBool callAmplitudePrecond(GNumber*) const;
    		GBool callStartPrecond(GNumber*)     const;
    		GBool callResetPrecond(GNumber* radx, GNumber* rady,
			   GNumber* amplitude, GNumber* start) const;
    		GBool callPiePrecond(GBool*)    const;
    		GBool callClosedPrecond(GBool*) const;
};
.fi
.SH
\fBPUBLIC METHODS\fP
.IP
\fBGoArcMetaclass\fP* \fBmetaclass\fP ();
.RS .8i
.IP \fIDescription\fP .3i
This static member function returns the \fBGoArcMetaclass\fP instance.
.RE
.sp 1
.IP
.nf
\fBGoArc\fP* \fBcreate\fP ();
\fBGoArc\fP* \fBcreate\fP (GNumber \fIradX\fP, GNumber \fIradY\fP = 1, GNumber \fIampl\fP = 2*PI, GNumber \fIstrt\fP = 0);
.fi
.RS .8i
.IP \fIDescription\fP .3i
These static member functions are constructors with pre/postconditions.
They return a pointer on a new instance of \fBGoArc\fP if no precondition
refuses the creation, else they return NULL;
.IP \fIradX\fP .3i
Specifies the radiusX value.
.IP \fIradY\fP .3i
Specifies the radiusY value.
.IP \fIampl\fP .3i
Specifies the amplitude angle value.
.IP \fIstrt\fP .3i
Specifies the start angle value.
.RE
.sp 1
.IP
\fBGoArc\fP (GNumber \fIradX\fP = 1, GNumber \fIradY\fP = 1, GNumber \fIampl\fP = 2*PI, GNumber \fIstrt\fP = 0);
.RS .8i
.IP \fIDescription\fP .3i
Constructor.
.IP \fIradX\fP .3i
Specifies the radiusX value.
.IP \fIradY\fP .3i
Specifies the radiusY value.
.IP \fIampl\fP .3i
Specifies the amplitude angle value.
.IP \fIstrt\fP .3i
Specifies the start angle value.
.RE
.sp 1
.IP
.nf
GNumber \fBradiusX\fP ();
GNumber \fBradiusY\fP ();
GNumber \fBamplitude\fP ();
GNumber \fBstart\fP ();
GBool \fBpie\fP ();
GBool \fBclosed ();
.fi
.RS .8i
.IP \fIDescription\fP .3i
These methods return the arc specific parameters values.
.RE
.sp 1
.IP
.nf
GBool \fBreset\fP (GNumber \fIradX\fP, GNumber \fIradY\fP, GNumber \fIampl\fP, GNumber \fIstrt\fP);
GBool \fBradiusX\fP (GNumber \fIradX\fP);
GBool \fBradiusY\fP (GNumber \fIradY\fP);
GBool \fBamplitude\fP (GNumber \fIampl\fP);
GBool \fBstart\fP (GNumber \fIstrt\fP);
GBool \fBpie\fP (GBool is_pie);
GBool \fBclosed (GBool is_closed);
.fi
.RS .8i
.IP \fIDescription\fP .3i
These methods set new values for the arc specific attributes.
.br
If none of the \fBresetPrecond\fP (resp. \fBradiusXPrecond\fP,
\fBradiusYPrecond\fP, \fBamplitudePrecond\fP, \fBstartPrecond\fP,
\fBpiePrecond\fP, \fBclosedPrecond\fP) preconditions returned GFALSE, the
action is performed with parameters \fIradX\fP, \fIradY\fP, \fIampl\fP and
\fIstrt\fP (resp. \fIis_pie\fP, \fIis_closed\fP) possibly modify by the
preconditions. If the action succeeds, \fBresetPostcond\fP (resp.
\fBradiusXPostcond\fP, \fBradiusYPostcond\fP, \fBamplitudePostcond\fP,
\fBstartPostcond\fP, \fBpiePostcond\fP, \fBclosedPostcond\fP) postconditions
are called and the method returns GTRUE. Otherwise, it returns GFALSE.
.IP \fIradX\fP .3i
Specifies the new radiusX value.
.IP \fIradY\fP .3i
Specifies the new radiusY value.
.IP \fIampl\fP .3i
Specifies the new amplitude angle value.
.IP \fIstrt\fP .3i
Specifies the new start angle value.
.IP \fIis_pie\fP .3i
Specifies the new value for pie attribute.
.IP \fIis_closed\fP .3i
Specifies the new value for closed attribute.
.RE
.sp 1
.IP
.nf
void \fBresetPrecond\fP (GBool (*\fIf\fP) (void*, const GoArc* \fIarc\fP,
			GNumber* \fIradX\fP, GNumber* \fIradY\fP, GNumber* \fIampl\fP, GNumber* \fIstrt\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBresetPostcond\fP (void (*\fIf\fP) (void*, GoArc* \fIarc\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBradiusXPrecond\fP (GBool (*\fIf\fP) (void*, const GoArc* \fIarc\fP, GNumber* \fIradX\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBradiusXPostcond\fP (void (*\fIf\fP) (void*, GoArc* \fIarc\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBradiusYPrecond\fP (GBool (*\fIf\fP) (void*, const GoArc* \fIarc\fP, GNumber* \fIradY\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBradiusYPostcond\fP (void (*\fIf\fP) (void*, GoArc* \fIarc\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBamplitudePrecond\fP (GBool (*\fIf\fP) (void*, const GoArc* \fIarc\fP, GNumber* \fIampl\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBamplitudePostcond\fP (void (*\fIf\fP) (void*, GoArc* \fIarc\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBstartPrecond\fP (GBool (*\fIf\fP) (void*, const GoArc* \fIarc\fP, GNumber* \fIstrt\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBstartPostcond\fP (void (*\fIf\fP) (void*, GoArc* \fIarc\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBpiePrecond\fP (GBool (*\fIf\fP) (void*, const GoArc* \fIarc\fP, GBool* \fIis_pie\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBpiePostcond\fP (void (*\fIf\fP) (void*, GoArc* \fIarc\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBclosedPrecond\fP (GBool (*\fIf\fP) (void*, const GoArc* \fIarc\fP, GBool* \fIis_closed\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBclosedPostcond\fP (void (*\fIf\fP) (void*, GoArc* \fIarc\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.fi
.RS .8i
.IP \fIDescription\fP .3i
These methods allow to add or remove functions to the pre/post conditions lists
triggered by \fBreset\fP (GNumber, GNumber, GNumber, GNumber), \fBradiusX\fP
(GNumber), \fBradiusY\fP (GNumber), \fBamplitude\fP (GNumber), \fBstart\fP
(GNumber), \fIpie\fP (GBool) and \fIclosed\fP (GBool) member functions.
.IP \fIf\fP .3i
Specifies programmer's function to be added/removed.
.IP \fIclosure\fP .3i
Specifies programmer's parameter to call the fonction with.
.IP \fIarc\fP .3i
Specifies the \fBGoArc\fP object involved (i.e. \fIthis\fP).
.IP \fIradX\fP .3i
Specifies the new radiusX value. May be modified by \fIf\fP.
.IP \fIradY\fP .3i
Specifies the new radiusY value. May be modified by \fIf\fP.
.IP \fIampl\fP .3i
Specifies the new amplitude angle. May be modified by \fIf\fP.
.IP \fIstrt\fP .3i
Specifies the new start angle. May be modified by \fIf\fP.
.IP \fIis_pie\fP .3i
Specifies the new value for pie attribute. May be modified by \fIf\fP.
.IP \fIis_closed\fP .3i
Specifies the new value for closed attribute. May be modified by \fIf\fP.
.IP \fIadd\fP .3i
Specifies whether to add or remove the function \fIf\fP from the list.
.RE
.sp 1
.IP
.nf
GBool \fBcallRadiusXPrecond\fP(GNumber*) const;
GBool \fBcallRadiusYPrecond\fP(GNumber*) const;
GBool \fBcallAmplitudePrecond\fP(GNumber*) const;
GBool \fBcallStartPrecond\fP(GNumber*) const;
GBool \fBcallResetPrecond\fP(GNumber*\fIradx\fP, GNumber* \fIrady\fP,
		   GNumber* \fIamplitude\fP, GNumber* \fIstart\fP) const;
GBool \fBcallPiePrecond\fP(GBool*) const;
GBool \fBcallClosedPrecond\fP(GBool*) const;
.fi
.RS .8i
.IP \fIDescription\fP .3i
These methods calls the corresponding pre conditions.
.RE
.SH
\fBC BINDING\fP
.SS 
\fBHeader\fP
.IP
#include <Go/cArc.h>
.SS 
\fBResources\fP
.IP
The following table defines a set of Go resources used by the programmer
to specify data.  The programmer can also set the resource values for the 
inherited classes to set attributes for this object.
The codes in the access column indicate if the given resource can be set by
using \fBGoSetValues\fP (\fBS\fP), retrieved by using \fBGoGetValues\fP
(\fBG\fP), or is not applicable (\fBN/A\fP).
.br
For superclass resources, see superclass man pages.
.br
See also Section 2.
.sp 1
.ps 8
.DS
.TS
center box;
cB sss
lB lB lB lB
l l l l.
GoArc Resource GSet
.sp
=
Name	Type	Default	Access
.sp
_
goNamplitude	GNumber	dynamic	GS
goNclosed	GBool	GFALSE	GS
goNpie	GBool	GFALSE	GS
goNradiusX	GNumber	dynamic	GS
goNradiusY	GNumber	dynamic	GS
goNstart	GNumber	dynamic	GS
.TE
.DE
.ps 10
.SS 
\fBFunctions\fP
.IP
void \fBGoArcInitialize\fP ();
.RS .8i
.IP \fIDescription\fP .3i
This function must be called before any use of the GoArc C Binding.
.RE
.sp 1
.IP
.nf
GNumber \fBGoArcAmplitude\fP (GObjectId \fIarc\fP);
GBool \fBGoArcClosed\fP (GObjectId \fIarc\fP);
GObjectId \fBGoArcCreate\fP (GNumber \fIradX\fP, GNumber \fIradY\fP, GNumber \fIampl\fP, GNumber \fIstrt\fP);
GObjectId \fBGoArcMetaclass\fP ();
GBool \fBGoArcPie\fP (GObjectId \fIarc\fP);
GNumber \fBGoArcRadiusX\fP (GObjectId \fIarc\fP);
GNumber \fBGoArcRadiusY\fP (GObjectId \fIarc\fP);
GBool \fBGoArcReset\fP (GObjectId \fIarc\fP, GNumber \fIradX\fP, GNumber \fIradY\fP,
		GNumber \fIamplitude\fP, GNumber \fIstart\fP);
GBool \fBGoArcSetAmplitude\fP (GObjectId \fIarc\fP, GNumber \fIvalue\fP);
GBool \fBGoArcSetClosed\fP (GObjectId \fIarc\fP, GBool \fIvalue\fP);
GBool \fBGoArcSetPie\fP (GObjectId \fIarc\fP, GBool \fIvalue\fP);
GBool \fBGoArcSetRadiusX\fP (GObjectId \fIarc\fP, GNumber \fIvalue\fP);
GBool \fBGoArcSetRadiusY\fP (GObjectId \fIarc\fP, GNumber \fIvalue\fP);
GBool \fBGoArcSetStart\fP (GObjectId \fIarc\fP, GNumber \fIvalue\fP);
GNumber \fBGoArcStart\fP (GObjectId \fIarc\fP);
.fi
.sp 1
.RS .8i
.IP \fIDescription\fP .3i
See \fBGoArc\fP following members :
.sp 1
.nf
GNumber amplitude ().
GBool closed ().
GoArc* create (GNumber, GNumber, GNumber, GNumber).
GoMetaclass* metaclass ().
GBool pie ().
GNumber radiusX ().
GNumber radiusY ().
GBool reset (GNumber, GNumber, GNumber, GNumber).
GBool amplitude (GNumber).
GBool closed (GBool).
GBool pie (GBool).
GBool radiusX (GNumber).
GBool radiusY (GNumber).
GBool start (GNumber).
GNumber start ().
.fi
.RE
.sp 1
.IP
.nf
void \fBGoArcAmplitudePostcond\fP (GObjectId \fIarc\fP,
		void (*\fIf\fP) (GObjectId),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoArcAmplitudePrecond\fP (GObjectId \fIarc\fP, 
		GBool (*\fIf\fP) (GObjectId, GNumber*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoArcClosedPostcond\fP (GObjectId \fIarc\fP,
		void (*\fIf\fP) (GObjectId),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoArcClosedPrecond\fP (GObjectId \fIarc\fP, 
		GBool (*\fIf\fP) (GObjectId, GBool*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoArcPiePostcond\fP (GObjectId \fIarc\fP,
		void (*\fIf\fP) (GObjectId),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoArcPiePrecond\fP (GObjectId \fIarc\fP, 
		GBool (*\fIf\fP) (GObjectId, GBool*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoArcRadiusXPostcond\fP (GObjectId \fIarc\fP,
		void (*\fIf\fP) (GObjectId),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoArcRadiusXPrecond\fP (GObjectId \fIarc\fP, 
		GBool (*\fIf\fP) (GObjectId, GNumber*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoArcRadiusYPostcond\fP (GObjectId \fIarc\fP,
		void (*\fIf\fP) (GObjectId),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoArcRadiusYPrecond\fP (GObjectId \fIarc\fP, 
		GBool (*\fIf\fP) (GObjectId, GNumber*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoArcResetPostcond\fP (GObjectId \fIarc\fP,
		void (*\fIf\fP) (GObjectId),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoArcResetPrecond\fP (GObjectId \fIarc\fP, 
		GBool (*\fIf\fP) (GObjectId, GNumber*, GNumber*, GNumber*, GNumber*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoArcStartPostcond\fP (GObjectId \fIarc\fP,
		void (*\fIf\fP) (GObjectId),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoArcStartPrecond\fP (GObjectId \fIarc\fP, 
		GBool (*\fIf\fP) (GObjectId, GNumber*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
.fi
.sp 1
.RS .8i
.IP \fIDescription\fP .3i
See \fBGoArc\fP following members :
.sp 1
.nf
void amplitudePostcond (void (*\fIf\fP) (void*, GoArc*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void amplitudePrecond (GBool (*\fIf\fP) (void*, GoArc*, GNumber*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void closedPostcond (void (*\fIf\fP) (void*, GoArc*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void closedPrecond (GBool (*\fIf\fP) (void*, GoArc*, GBool*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void piePostcond (void (*\fIf\fP) (void*, GoArc*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void piePrecond (GBool (*\fIf\fP) (void*, GoArc*, GBool*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void radiusXPostcond (void (*\fIf\fP) (void*, GoArc*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void radiusXPrecond (GBool (*\fIf\fP) (void*, GoArc*, GNumber*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void radiusYPostcond (void (*\fIf\fP) (void*, GoArc*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void radiusYPrecond (GBool (*\fIf\fP) (void*, GoArc*, GNumber*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void resetPostcond (void (*\fIf\fP) (void*, GoArc*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void resetPrecond (GBool (*\fIf\fP) (void*, GoArc*, GNumber*, GNumber*, GNumber*, GNumber*), 
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void startPostcond (void (*\fIf\fP) (void*, GoArc*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void startPrecond (GBool (*\fIf\fP) (void*, GoArc*, GNumber*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.fi
.RE
.SH
\fBUSER INTERACTIONS\fP
.IP
The following strings may be associated with event description strings in GoUI
files to perform actions on \fBGoArc\fP objects (see \fBGoUI\fP documentation
for more information on this topic). Most of the time, these strings refer to
name-like public functions or have an obvious signification, thus description
will only be given if absolutely necessary.
.sp 1
.IP 
\fBradiusX\fP (GNumber)
.br
\fBradiusY\fP (GNumber)
.br
\fBamplitude\fP (GNumber)
.br
\fBstart\fP (GNumber)
.br
\fBpie\fP (GBool)
.br
\fBclosed\fP (GBool)
.br
\fBreset\fP (GNumber, GNumber, GNumber, GNumber)
.RS .8i
.IP \fIDescription\fP .3i
same as member functions.
.RE
.SH
\fBUSAGE INFORMATION\fP
.IP
If willing to use pre/postconditions on object creation,
one should use \fBGoArc::create\fP instead of the public
\fBGoArc\fP constructor; this is highly recommended.
.SH
\fBSEE ALSO\fP
.IP
\fBGo\fP, \fBGoMetaclass\fP, \fBGoStdDS\fP, \fBGoStdDSMetaclass\fP,
\fBGoGeometric\fP, \fBGoGeometricMetaclass\fP and \fBGoArcMetaclass\fP classes.
.nrPN \n%

