.\" $Id: BGoUIEd.n,v 1.1 1993/01/04 15:03:50 smadja Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH BGoUIEditor 3Go "December 1992" "Version 1.2" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBBGoUIEditor\fP \(em a predefined user interface.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/BGoUIEd.h>\fP
.sp 1
.SH
\fBCLASS\fP
.IP
\fBBGoUIEditor\fP inherits behavior from:
.RS 10
\fBGoUISelector\fP.
.sp 1
.SH
\fBDESCRIPTION\fP
.IP
The \fBBGoUIEditor\fP class implements some specific user interfaces to create particular Go like geometrics, text, image. The class uses some predefined grabbers and implements the \fIcurrent parent\fP management.
.sp
.br
.nf
.ta .15i .25i 1.0i


	typedef void (*GoUICreateGoPostcond)(void* \fIclosure\fP,
				Go* \fIcreated_go\fP);

	#define BGOUI_LINE_HEIGHT_AT_CREATION_TIME 7 /* mm: font and margin */

	class BGoUIEditor : public GoUISelector {

	public:

		BGoUIEditor(GoRoot*);
		~BGoUIEditor();

		/*
		 * current parent management 
		 */
		Go* currentParent() const;
		void currentParent(Go*);

		/*
		 * root management
		 */

		void root(GoRoot* new_goroot);

		/*
		 * a tool 
		 */
		
		void chooseBox((void (*postvcond)(void* closure, GBool done, GBox&), void* closure);

		/*
		 * specific creations;
		 */

		void createRectangle(GoUICreateGoPostcond proc = NULL,
                        	 void* closure = NULL,
                        	 const char* subclass_name = NULL);

		void createSquare(GoUICreateGoPostcond proc = NULL,
	                      void* closure = NULL,
	                      const char* subclass_name = NULL);

		 void createCircle(GoUICreateGoPostcond proc = NULL,
                      	void* closure = NULL,
                      	const char* subclass_name = NULL);

		 void createEllipse(GoUICreateGoPostcond proc = NULL,
                       void* closure = NULL,
                       const char* subclass_name = NULL);

		 void createPolyline(GoUICreateGoPostcond proc = NULL,
                       void* closure = NULL,
                       const char* subclass_name = NULL);

		 void createHandPolyline(GoUICreateGoPostcond proc = NULL,
                       void* closure = NULL,
                       const char* subclass_name = NULL);
	
		 void createPolygon(GoUICreateGoPostcond proc = NULL,
                       void* closure = NULL,
                       const char* subclass_name = NULL);

		 void createPolypoint(GoUICreateGoPostcond proc = NULL,
                       void* closure = NULL,
                       const char* subclass_name_must_be_non_null);

		void createCircleArc(GoUICreateGoPostcond proc = NULL,
                         void* closure = NULL,
                         const char* subclass_name = NULL);

		void createEllipseArc(GoUICreateGoPostcond proc = NULL,
                          void* closure = NULL,
                          const char* subclass_name = NULL);

		void createImage(GNumber width, GNumber height,
                     GoUICreateGoPostcond proc = NULL,
                     void* closure = NULL,
                     const char* subclass_name = NULL);

		void createRegPolygon(int nb_edge,
                          GoUICreateGoPostcond proc = NULL,
                          void* closure = NULL,
                          const char* subclass_name = NULL);

		void createLabel(GoUICreateGoPostcond proc = NULL,
                     void* closure = NULL,
                     const char* subclass_name = NULL);

		void createSimpleText(GoUICreateGoPostcond proc = NULL,
                          void* closure = NULL,
                          const char* subclass_name = NULL);

		void createSimpleFormText(GoUICreateGoPostcond proc = NULL,
                              void* closure = NULL,
                              const char* subclass_name = NULL);

		 /*
		  * action on selected Objects
		  * and misc methods;
		  */

		 void actOnAllSelectedSubtrees(const char* program,
                                  const GEvent* = NULL,
                                  void (*)(void*,int state_result) = NULL,
                                  void* closure = NULL);
		 void actOnAllSelectedGos(const char* program,
                             const GEvent* = NULL,
                             void (*)(void*, int state_result) = NULL,
                             void* closure= NULL);
	};
.fi
.bp
.SH
\fBBGoUIEditor CONSTRUCTOR\fP
.sp 1
.LP
.IP
\fBGoUIEditor\fP(GoRoot* \fIgoroot\fP)
.RS .8i
.IP \fIDescription\fP .5i
.sp
The constructor \fIbinds\fP the BGoUIEditor public methods. So these methods can be used in a customization file without any declaration by the application.
.br
It also \fIcreates\fP the following predefined interactor programs (see Interactor (3Go) and the corresponding interactor program):
.IP 
.RS .8i
- GMoveGrabberPgm,
.br
- GRotateGrabberPgm,
.br
- GRescaleGrabberPgm,
.br
- GRescaleRectangleGrabberPgm,
.br
- GRotateGrabberPgm,
.br
- GRotateAroundCenterGrabberPgm,
.br
- GMoveThisGrabberPgm,
.br
- GRotateThisGrabberPgm,
.br
- GRescaleThisGrabberPgm,
.br
- GRescaleThisRectangleGrabberPgm,
.br
- GChoosePointPgm,
.br
- GXAxisGrabberPgm,
.br
- GYAxisGrabberPgm,
.br
- GEditRectanglePgm,
.br
- GEditSquarePgm,
.br
- GEditRegPolygonPgm,
.br
- GEditPolylinePgm,
.br
- GEditPolygonPgm,
.br
- GEditPolypointPgm,
.br
- GEditEllipsePgm,
.br
- GEditCirclePgm,
.br
- GEditArcBeginPgm,
.br
- GEditArcEndPgm,
.br
- GEditArcRadiiPgm,
.br
- GEditArcRadxyPgm,
.br
- GEditHandPolylinePgm,
.br
- GEditImagePgm,
.br
- GMoveArcPointPgm,
.br
- GMovePolypointPgm,
.br
- GMovePolylinePgm,
.br
- GMovePolygonPgm,
.br
.RE
.sp
It sets the \fIdepth\fP of all fast drawing to 16.
It sets the maximun number of drawing gos during a fast drawing to 16 (see GoCSGrabber (3Go) for explanations).
.br
It sets the \fIcurrent parent\fP to \fIgoroot\fP.
.RE
.sp 
.IP
~\fBBGoUIEditor\fP()
.RS .8i
.IP  \fIDescription\fP .5i
The method deletes the current BGoUIEditor instance. It  \fIdoes not remove\fP the \fIbinding\fP of the public methods and the created interactor programs.
.RE
.bp
.SH
\fBOBJECTS CREATION METHODS\fP
.sp 1
.IP
void \fBcreateRectangle\fP (GoUICreateGoPostcond \fIprocedure\fP = NULL, void* \fPclosure\fP = NULL,const char* \fIsubclass_name\fP = NULL);
.IP
void \fBcreateSquare\fP (GoUICreateGoPostcond \fIproc\fP = NULL, void* \fPclosure\fP = NULL,const char* \fIsubclass_name\fP = NULL);
.IP
void \fBcreateCircle\fP (GoUICreateGoPostcond \fIproc\fP = NULL, void* \fPclosure\fP = NULL,const char* \fIsubclass_name\fP = NULL);
.IP
void \fBcreateEllipse\fP (GoUICreateGoPostcond \fIproc\fP = NULL, void* \fPclosure\fP = NULL,const char* \fIsubclass_name\fP = NULL);
.IP
void \fBcreateRegPolygon\fP (int \fInb_edges\fP, GoUICreateGoPostcond \fIproc\fP = NULL, void* \fPclosure\fP = NULL,const char* \fIsubclass_name\fP = NULL);
.IP
void \fBcreatePolyline\fP (GoUICreateGoPostcond \fIproc\fP = NULL, void* \fPclosure\fP = NULL,const char* \fIsubclass_name\fP = NULL);
.IP
void \fBcreatePolygon\fP (GoUICreateGoPostcond \fIproc\fP = NULL, void* \fPclosure\fP = NULL,const char* \fIsubclass_name\fP = NULL);
.IP
.RS .8i
.IP \fIDescription\fP .5i
The above creation methods create a wanted Go.
.br
First it asks the user to choose a point (see ChoosePoint (3Go)) and runs the "edit" program with the created Go.
.br
Before editing the created Go, it is reparented onto the \fIcurrent parent\fP.
.br
Note that the GoSquare does not exist yet, so the \fIcreateSquare\fP creates a \fIrectangle\fP but with equal \fIwidth\fP and \fIheight\fP.
.br
.IP \fIprocedure,closure\fP .5i
Specifies the \fIprocedure\fP to be called when the creation is terminated or cancelled. If the user did cancel the creation, \fIprocedure\fP is called with a NULL \fIgo\fP. Otherwise the \fIgo\fP field of \fPprocedure\fP is the created one.
.br
\fPprocedure\fP may be NULL.
.IP \fPsubclass_name\fP .5i
Specifies the \fIsubclass name\fP of the wanted go. It may be NULL: in this case the method will create respectively \fIrectangle\fP etc... If \fIsubclass name\fP does not correspond to a subclass of \fIrectangle\fP etc..., the \fPprocedure\fP is called with a NULL go.
.RE
.sp
.IP
void \fBcreateHandPolyline\fP (GoUICreateGoPostcond \fIprocedure\fP = NULL, void* \fPclosure\fP = NULL,const char* \fIsubclass_name\fP = NULL);
.IP
.RS .8i
.IP \fIDescription\fP .5i
The method creates a polyline.
.br
First it asks the user to choose a point (see ChoosePoint (3Go)) and runs the "handEdit" program with the created GoPolyline (see EditHandPolyline (3Go)).
.br
Before editing the created Go, it is reparented onto the \fIcurrent parent\fP.
.br
.IP \fIprocedure,closure\fP .5i
Specifies the \fIprocedure\fP to be called when the creation is terminated or cancelled. If the user did cancel the creation, \fIprocedure\fP is called with a NULL \fIgo\fP. Otherwise the \fIgo\fP field of \fIprocedure\fP is the created \fIpolyline\fP.
.br
\fIprocedure\fP may be NULL.
.IP \fPsubclass_name\fP .5i
Specifies the \fIsubclass name\fP of the wanted go. It may be NULL: in this case the method will create a \fIpolyline\fP. If \fIsubclass name\fP does not correspond to a subclass of \fIpolyline\fP etc..., the \fIprocedure\fP is called with a NULL polyline.
.RE
.sp
.IP
void \fBcreatePolypoint\fP (GoUICreateGoPostcond \fIproc\fP = NULL, void* \fPclosure\fP = NULL,const char* \fInon_null_subclass_name\fP);
.IP
.RS .8i
.IP \fIDescription\fP .5i
The creation method creates a subclass of GoPolypoint. It is used to create for instance a \fBCurve\fP. It uses the "GoPolypoint.edit" program which calls the \fIdraw\fP method of the wanted subclass on each new mouse position.
.br
First it asks the user to choose a point (see ChoosePoint (3Go)) and runs the "edit" program with the created subclass of GoPolypoint (see EditPolypoint (3Go)).
.br
Before editing the created Go, it is reparented onto the \fIcurrent parent\fP.
.br
.IP \fIprocedure,closure\fP .5i
Specifies the \fIprocedure\fP to be called when the creation is terminated or cancelled. If the user did cancel the creation, \fIprocedure\fP is called with a NULL \fIgo\fP. Otherwise the \fIgo\fP field of \fIprocedure\fP is the created \fIpolypoint\fP.
.br
\fIprocedure\fP may be NULL.
.IP \fPsubclass_name\fP .5i
Specifies the \fIsubclass name\fP of the wanted go. \fISubclass_name\fP must be NON NULL. If \fIsubclass name\fP does not correspond to a subclass of \fIpolypoint\fP or is NULL,  the \fIprocedure\fP is called with a NULL go.
.RE
.sp
.IP
void \fBcreateCircleArc\fI(GoUICreateGoPostcond \fIprocedure\fP = NULL,void* \fIclosure\fP = NULL, const char* \fIsubclass_name\fP = NULL);
.IP
void \fBcreateEllipseArc\fI(GoUICreateGoPostcond \fIprocedure\fP = NULL,void* \fIclosure\fP = NULL, const char* \fIsubclass_name\fP = NULL);
.RS .8i
.IP \fIDescription\fP .5i
The methods create a GoArc  (like a \fIcircle\fP or like an \fIellipse\fP). It asks the user to choose first the \fIcenter\fP and it runs the "GoArc.editRadii" program to edit  the circle arc and the "GoArc.edit" program to edit the ellipse arc (see EditArc (3Go)).
.br
Before the edition it reparents the \fIgo\fP onto the \fIcurrent parent\fP.
.br
After it asks the user to choose a point to select the \fIstart\fP angle of the \fIarc\fP.
.br
After it asks the user to edit the \fIamplitude\fP of the arc. It runs the GoArc.editEnd" program.
.IP \fIprocedure,closure\fP .5i
Specifies the \fIprocedure\fP to be called when the creation is terminated or cancelled. If the user did cancel the creation, \fIprocedure\fP is called with a NULL \fIgo\fP. Otherwise the \fIgo\fP field of \fIprocedure\fP is the created \fIarc\fP.
.br
\fIprocedure\fP may be NULL.
.br
Cancel the creation means that \fIone\fP of the above interactor is cancelled.
.IP \fPsubclass_name\fP .5i
Specifies the \fIsubclass name\fP of the wanted \fIarc\fP. It may be NULL: in this case the method will create a GoArc. If \fIsubclass name\fP does not correspond to a subclass GoArc, the \fIprocedure\fP is called with a NULL go.
.RE
.sp
.IP
void \fBcreateImage\fP(GNumber \fIwidth\fP, GNumber \fIheight\fP, GoUICreateGoPostcond \fIprocedure\fP = NULL,void* \fIclosure\fP = NULL, const char* \fPsubclass_name\fP = NULL)
.RS .8i
.IP \fIDescription\fP .5i
If \fIwidth\fP or \fIheight\fP is 0, the method waits for the user to define a rectangle on the screen.
.br
If \fIwidth\fP and \fIheight\fP are not 0, the method waits for the user to locate the predefined rectangle on the screen.
.br
After if creates a GoImage and reparents it onto the \fIcurrent parent\fP.
.IP \fPwidth,height\fP .5i
.br
Specify the wanted \fIwidth\fP and \fIheight\fP
.IP \fIprocedure,closure\fP .5i
Specifies the \fIprocedure\fP to be called when the creation is terminated or cancelled. If the user did cancel the creation, \fIprocedure\fP is called with a NULL \fIgo\fP. Otherwise the \fIgo\fP field of \fIprocedure\fP is the created \fIimage\fP.
.br
\fIprocedure\fP may be NULL.
.br
Cancel the creation means that \fIone\fP of the above interactors is cancelled.
.IP \fPsubclass_name\fP .5i
Specifies the \fIsubclass name\fP of the wanted \fIimage\fP. It may be NULL: in this case the method will create a GoImage. If \fIsubclass name\fP does not correspond to a subclass GoImage, the \fIprocedure\fP is called with a NULL go.
.RE
.sp
.IP
void \fBcreateLabel\fP(GoUICreateGoPostcond \fIprocedure\fP = NULL, void* \fIclosure\fP = NULL, const char* \fIsubclass_name\fP = NULL)
.IP
void \fBcreateSimpleText\fP(GoUICreateGoPostcond \fIprocedure\fP = NULL, void* \fIclosure\fP = NULL, const char* \fIsubclass_name\fP = NULL)
.IP
void \fBcreateSimpleFormText\fP(GoUICreateGoPostcond \fIprocedure\fP = NULL, void* \fIclosure\fP = NULL, const char* \fIsubclass_name\fP = NULL)
.RS .8i
.IP \fIDescription\fP .5i
The methods creates the wanted text. It asks the user to choose a point to place the text and sets the text line width to BGOUI_LINE_HEIGHT_AT_CREATION_TIME.
.br
On completion the  \fItext\fP is reparented onto the \fIcurrent parent\fP and \fIselected\fP.
.IP \fIprocedure,closure\fP .5i
Specifies the \fIprocedure\fP to be called when the creation is terminated or cancelled. If the user did cancel the creation, \fIprocedure\fP is called with a NULL \fIgo\fP. Otherwise the \fIgo\fP field of \fIprocedure\fP is the created \fItext\fP.
.br
\fIprocedure\fP may be NULL.
.IP \fPsubclass_name\fP .5i
Specifies the \fIsubclass name\fP of the wanted go. It may be NULL: in this case the method will create a\fItext\fP. If \fIsubclass name\fP does not correspond to a subclass of \fItext\fP etc..., the \fIprocedure\fP is called with a NULL text.
.RE
.sp
.sp 1
.IP
.bp
.SH
\fBSPECIFIC BGO METHODS (OTHER THAN CREATION)\fP
.sp 1
.IP
Go*  \fBcurrentParent\fP() const;
.br
void \fBcurrentParent\fP(Go* \fIgo\fP);
.RS .8i
.IP \fIDescription\fP .5i
The method gets/sets \fIcurrent_parent\fP used at creation time.
.IP \fIgo\fP .5i
Specifies the wanted current parent.
.RE
.IP
void \fBroot\fP(GoRoot* \fIgoroot\fP)
.RS .8i
.IP \fIDescription\fP .5i
The method call the superclass (GoUISelector) \fIroot\fP method and resets the \fIcurrent parent\fP to \fIgoroot\fP.
.IP \fIgoroot\fP .5i
Specifies the new \fIgoroot\fP. The BGoUIEditor instance is now attached to \fIgoroot\fP (see GoUI (3Go)).
.RE
.sp 1
.IP
void \fBchooseBox\fP((void (*\fIprocedure\fP)(void* closure, GBool done, GBox& box), void* \fIclosure\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to select a box onto the device.
.IP \fIprocedure,closure\fP .5i
Specifies the \fIprocedure\fP to be called when the creation is terminated or cancelled. If the user did cancel the creation, \fIprocedure\fP is called with the \fIdone\fP parameter GFALSE. Otherwise the \fIdone\fP is GTRUE and \fIbox\fP is available.
.br
Note that \fIbox\fP will be deleted after the call of \fIprocedure\fP.
.RE
.sp
.IP
void \fBactOnAllSelectedSubtrees\fP(const char* \fIprogram\fP, const GEvent* \fIevent\fP = NULL, void (*\fIprocedure\fP)(void*,int state_result) = NULL, void* \fIclosure\fP = NULL);
.IP
void \fBactOnAllSelectedGos\fP(const char* \fIprogram\fP, const GEvent* \fIevent\fP= NULL, void (*\fIprocedure\fP)(void*, int state_result) = NULL, void* \fIclosure\fP = NULL);
.RS .8i
.IP \fIDescription\fP .5i
.br
The method \fIgroups\fP all selected Go or all selected Subtree by calling the corresponding \fIgroup()\fP method (see GoUISelector (3Go)). The \fIgroup\fP creates a GoComposite.
.br
The method asks the user to choose a point. After it runs the wanted \fIprogram\fP under a GoFullSensor.
.br
On completion \fIprocedure\fP is called with the \fIstate\fP (see Interactor (3Go)) of the last used interactor and \fIungroup()\fP  method is called (see GoUISelector (3Go)).
.IP \fIprogram\fP .5i
.br
Specifies the wanted \fIprogram\fP. This \fIprogram\fP must defined a valid "GoComposite.\fIprogram\fP" name.
.IP \fIevent\fP .5i
.br
Specify the \fIevent\fP passed to the first \fIchoosePoint\fP interactor via the GoFullSensor creation.
.IP \fIprocedure,closure\fP .5i
.br
Specify the \fIprocedure, closure\fP to be called on completion of the interaction.
.RE
.bp
.SH
\fBC BINDING\fP
.IP
\fITo be defined\fP
.SH
\fBUSAGE INFORMATION\fP
.IP
The BGoUIEditor class is useful to serialize the call of unitary grabbers. For instance \fIcreateRectangle\fP runs first a \fIchoosepoint\fP and after an \fIedition\fP. 
.br
It also manages the \fIcurrent parent\fP.
.sp 2
.SH
\fBBUGS\fP 
.sp 1
Each instance (one per GoRoot) of BGoUIEditor resets the \fImaxDrawDepth\fP and the \fPmaxDrawCount\fP variables of the following GoCSGrabberPgm programs:
.IP
.RS .10i
- GMoveGrabberPgm,
.br
- GRotateGrabberPgm,
.br
- GRescaleGrabberPgm,
.br
- GRescaleRectangleGrabberPgm,
.br
- GRotateGrabberPgm,
.br
- GRotateAroundCenterGrabberPgm,
.RE
.SH
\fBSEE ALSO\fP
.IP
\fBGoUISelector\fP (3GO), \fBGoUI\fP (3Go), \fBGo (3Go)\fP and subclasses, \fBGrabber (3Go)\fP and subclasses.
.nrPN \n%







