.\" $Id: BSpline.n,v 1.1.1.1 1992/03/18 09:37:50 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoBSpline 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoBSpline\fP \(em the BSpline object class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/BSpline.h>\fP
.SH
\fBCLASS\fP
.IP
\fBGoBSpline\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGoCubic\fP class
.IP \(em 3
\fBGoCurve\fP class
.IP \(em 3
\fBGoPolypoint\fP class.
.IP \(em 3
\fBGoGeometric\fP class.
.IP \(em 3
\fBGoStdDS\fP class.
.IP \(em 3
\fBGo\fP class.
.RE
.SH
\fBDESCRIPTION\fP
.IP
\fBGoBSpline\fP is a subclass of \fBGoCubic\fP implementing tensed B-splines.
.br
A tensed B-spline is a generalized B-spline with tension. For a discussion
about \fItension\fP see \fBGoCubic\fP man pages. In this case, \fItension\fP
normally varies from 0 to 1. A tensed B-spline with \fItension\fP 1 is the
normal B-spline. A B-spline is an approximating spline; the curve approximates
the control polyline, it does not pass through the control points though, but it
yields a smooth appearance.
.sp 1
.br
.nf
.ta .15i .25i 1.0i
class GoBSpline : public GoCubic {

	public:

		static GoBSplineMetaclass* metaclass ();
		static GoBSpline* create ();
		static GoBSpline* create (int, const GPoint*);
		GoBSpline ();
		GoBSpline (int, const GPoint*);
};
.fi
.SH
\fBPUBLIC METHODS\fP
.IP
\fBGoBSplineMetaclass\fP* \fBmetaclass\fP ()
.RS .8i
.IP \fIDescription\fP .3i
This static member function returns the \fBGoBSplineMetaclass\fP instance.
.RE
.sp 1
.IP
.nf
\fBGoBSpline\fP* \fBcreate\fP ();
\fBGoBSpline\fP* \fBcreate\fP (int \fInb\fP, const GPoint* \fIpts\fP);
.fi
.RS .8i
.IP \fIDescription\fP .3i
These static member functions are constructors with pre/postconditions.
They return a pointer on a new instance of \fBGoBSpline\fP if no precondition
refuses the creation, else they return NULL;
.IP \fInb\fP .3i
Specifies the number of control points in the array \fIpts\fP
.IP \fIpts\fP .3i
Specifies the control points array.
.RE
.sp 1
.IP
.nf
GoBSpline();
GoBSpline(int \fInb\fP, const GPoint* \fIpts\fP);
.fi
.RS .8i
.IP \fIDescription\fP .3i
constructor
.IP \fInb\fP .3i
Specifies the number of control points in the array \fIpts\fP
.IP \fIpts\fP .3i
Specifies the control points array.
.RE
.SH
\fBC BINDING\fP
.SS 
\fBResources\fP
.IP
Inherited. See superclasses manual pages.
.SS 
\fBFunctions\fP
.IP
void \fBGoBSplineInitialize\fP ();
.RS .8i
.IP \fIDescription\fP .3i
This function must be called before any use of the GoBSpline C Binding.
.RE
.sp 1
.IP
.nf
GObjectId \fBGoBSplineCreate\fP (int \fInb\fP, GPoint* \fIpts\fP);
GObjectId \fBGoBSplineMetaclass\fP ();
.fi
.sp 1
.RS .8i
.IP \fIDescription\fP .3i
See \fBGoBSpline\fP following members :
.sp 1
.nf
GoBSpline* create (int, GPoint*).
GoMetaclass* metaclass ().
.fi
.RE
.SH
\fBUSER INTERACTIONS\fP
.IP
Inherited.
.SH
\fBUSAGE INFORMATION\fP
.IP
If willing to use pre/postconditions on object creation,
one should use \fBGoBSpline::create\fP instead of the public
\fBGoBSpline\fP constructor; this is highly recommended.
.SH
\fBSEE ALSO\fP
.IP
\fBGo\fP, \fBGoMetaclass\fP, \fBGoStdDS\fP, \fBGoStdDSMetaclass\fP,
\fBGoGeometric\fP, \fBGoGeometricMetaclass\fP, \fBGoPolypoint\fP,
\fBGoPolypointMetaclass\fP, \fBGoCurve\fP, \fBGoCurveMetaclass\fP,
\fBGoCubic\fP, \fBGoCubicMetaclass\fP and \fBGoBSplineMetaclass\fP classes.
.nrPN \n%
