.\" $Id: Bezier.n,v 1.1.1.1 1992/03/18 09:37:59 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoBezier 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoBezier\fP \(em the Bezier object class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Bezier.h>\fP
.SH
\fBCLASS\fP
.IP
\fBGoBezier\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGoCurve\fP class
.IP \(em 3
\fBGoPolypoint\fP class.
.IP \(em 3
\fBGoGeometric\fP class.
.IP \(em 3
\fBGoStdDS\fP class.
.IP \(em 3
\fBGo\fP class.
.RE
.SH
\fBDESCRIPTION\fP
.IP
A \fBGoBezier\fP object is one of the basic curves. A bezier curve of \fIn-th\fP
order is characterized by \fIn+1\fP control points. In general the curve does
not pass through all control points, but it passes through the two end points,
and is tangent at the end points to the corresponding edge of the polygon of the
control points. The curve will always lie within the convex hull of the control
points. The curve does not provide localized control : moving a control point
will change the shape of every part of the curve.
.sp 1
.br
.nf
.ta .15i .25i 1.0i
class GoBezier : public GoCurve {

	public:

		static GoBezierMetaclass* metaclass ();
		static GoBezier* create ();
		static GoBezier* create (int, const GPoint*);
		GoBezier ();
		GoBezier (int, const GPoint*);
};
.fi
.SH
\fBPUBLIC METHODS\fP
.IP
\fBGoBezierMetaclass\fP* \fBmetaclass\fP ()
.RS .8i
.IP \fIDescription\fP .3i
This static member function returns the \fBGoBezierMetaclass\fP instance.
.RE
.sp 1
.IP
.nf
\fBGoBezier\fP* \fBcreate\fP ();
\fBGoBezier\fP* \fBcreate\fP (int \fInb\fP, const GPoint* \fIpts\fP);
.fi
.RS .8i
.IP \fIDescription\fP .3i
These static member functions are constructors with pre/postconditions.
They return a pointer on a new instance of \fBGoBezier\fP if no precondition
refuses the creation, else they return NULL;
.IP \fInb\fP .3i
Specifies the number of control points in the array \fIpts\fP
.IP \fIpts\fP .3i
Specifies the control points array.
.RE
.sp 1
.IP
.nf
GoBezier();
GoBezier(int \fInb\fP, const GPoint* \fIpts\fP);
.fi
.RS .8i
.IP \fIDescription\fP .3i
constructor
.IP \fInb\fP .3i
Specifies the number of control points in the array \fIpts\fP
.IP \fIpts\fP .3i
Specifies the control points array.
.RE
.SH
\fBC BINDING\fP
.SS 
\fBResources\fP
.IP
Inherited. See superclasses manual pages.
.SS 
\fBFunctions\fP
.IP
void \fBGoBezierInitialize\fP ();
.RS .8i
.IP \fIDescription\fP .3i
This function must be called before any use of the GoBezier C Binding.
.RE
.sp 1
.IP
.nf
GObjectId \fBGoBezierCreate\fP (int \fInb\fP, GPoint* \fIpts\fP);
GObjectId \fBGoBezierMetaclass\fP ();
.fi
.sp 1
.RS .8i
.IP \fIDescription\fP .3i
See \fBGoBezier\fP following members :
.sp 1
.nf
GoBezier* create (int, GPoint*).
GoMetaclass* metaclass ().
.fi
.RE
.SH
\fBUSER INTERACTIONS\fP
.IP
Inherited.
.SH
\fBUSAGE INFORMATION\fP
.IP
If willing to use pre/postconditions on object creation,
one should use \fBGoBezier::create\fP instead of the public
\fBGoBezier\fP constructor; this is highly recommended.
.SH
\fBSEE ALSO\fP
.IP
\fBGo\fP, \fBGoMetaclass\fP, \fBGoStdDS\fP, \fBGoStdDSMetaclass\fP,
\fBGoGeometric\fP, \fBGoGeometricMetaclass\fP, \fBGoPolypoint\fP,
\fBGoPolypointMetaclass\fP \fBGoCurve\fP, \fBGoCurveMetaclass\fP and
\fBGoBezierMetaclass\fP classes.
.nrPN \n%
