.\" $Id: BusLink.n,v 1.1.1.1 1992/03/18 09:38:04 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoBusLink 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoBusLink\fP \(em the bus link object class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/BusLink.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGoBusLink\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGoLink\fP class.
.IP \(em 3
\fBGoGraphElement\fP class.
.IP \(em 3
\fBGo\fP class.
.RE
.sp 1
.SH
\fBDESCRIPTION\fP
.IP
\fBGoBusLink\fP instances draw a polyline between their two extrem nodes. This polyline is composed of three segments (two horizontal segments and one vertical or two vertical segments and one horizontal).
.br
In tree placement predefined algorithms, the link's orientation is not checked. The link's orientation depends on the result of the GoGraphStruct::positionType() method.
.IP
.nf
.ta .15i .25i 1.0i
class GoBusLink {
	public:
		// getting values;
		GPen& pen();
		short orientation() const;

		// setting values;
		GBool orientation(short \fIorientation_value\fP);

		// others;
		GoBusLink();
		static GoMetaclass* metaclass();
		static GoBusLink* create();
		static GoBusLink* create(short \fIorientation\fP);
};
.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
GPen& \fBpen\fP();
.RS .8i
.IP \fIDescription\fP .5i
.br
This method returns the pen reference used by the link.
.RE
.sp 1
.IP
short \fBorientation\fP();
.RS .8i
.IP \fIDescription\fP .5i
.br
This method returns the link's orientation.
.br
Values are :
.RS 8
.IP \(em 3
\fBGHORIZONTAL\fP : the link is composed of two vertical segments and one horizontal segment.
.IP \(em 3
\fBGVERTICAL\fP : the link is composed of two horizontal segments and one vertical segment.
.IP \(em 3
\fBGUNDEFINED\fP : the orientation can be GHORIZONTAL or GVERTICAL.
.RE 2
The default value is \fBGUNDEFINED\fP.
.RE
.sp 1
.IP
GBool \fBorientation\fP(\fIorientation_value\fP);
.RS .8i
.IP \fIDescription\fP .5i
.br
Sets the link's orientation. Returns GFALSE if an error occurred, otherwise returns GTRUE.
.IP \fIorientation_value\fP .5i
.br
Specifies the link's orientation.
.RE
.sp 1
.IP
\fBGoBusLink\fP();
.RS .8i
.IP \fIDescription\fP .5i
This method allows to create a new instance of the \fIGoBusLink\fP class.
.RE
.sp 1
.IP
static GoMetaclass* \fBmetaclass\fP();
.RS .8i
.IP \fIDescription\fP .5i
Returns a pointer to the metaclass object of the \fIthis\fP.
.RE
.sp1
.IP
GoBusLink* \fBcreate\fP();
.RS .8i
.IP \fIDescription\fP .5i
Creates a new GoBusLink instance. Returns the created link.
.RE
.sp1
.IP
GoBusLink* \fBcreate\fP(short \fIorientation\fP);
.RS .8i
.IP \fIDescription\fP .5i
Creates a new GoBusLink instance and sets its orientation to \fIorientation\fP.
Returns the created link.
.IP \fIorientation\fP .5i
.br
Specifies the link's orientation.
.RE
.sp1
.RE
.sp 2
.SH
\fBUSER INTERACTION\fP
.IP
No user interaction.
.RE
.sp 2
.SH
\fBC BINDING\fP
.SS 
\fBHeader\fP
.IP
#include <Go/cBusLink.h>
.DE
.SS 
\fBResources\fP
.IP
The following table defines a set of Go resources used by the programmer
to specify data.  The programmer can also set the resource values for the 
inherited classes to set attributes for this object.
The codes in the access column indicate if the given resource can be set by using \fBGoSetValues\fP (\fBS\fP), retrieved by using \fBGoGetValues\fP (\fBG\fP), or is not applicable (\fBN/A\fP).
.br
For superclass resources, see superclass man pages.
.br
See also Section 2.
.sp 1
.ps 8
.DS
.TS
center box;
cB sss
lB lB lB lB
l l l l.
GoBusLink Resource GSet
.sp
=
Name	Type	Default	Access
.sp
_
goNorientation	short	GUNDEFINED	SG
.TE
.DE
.ps 10

.SS 
\fBFunctions\fP
.IP
void \fBGoBusLinkInitialize\fP();
.RS .8i
.IP \fIDescription\fP .5i
This function must be called before any use of the GoBusLink C Binding.
.RE
.sp 1
.IP
GObjectId \fBGoCreateGoBusLink\fP();
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoBusLink* GoBusLink::create().
.RE
.sp 1
.IP
GObjectId \fBGoBusLinkMetaclass\fP();
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoMetaclass* GoBusLink::metaclass().
.RE
.sp 1
.IP
short \fBGoGetBusLinkOrientation\fP(GObjectId \fIlink\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP short GoBusLink::orientation().
.RE
.sp 1
.IP
GBool \fBGoSetBusLinkOrientation\fP(GObjectId \fIlink\fP, short \fIorientation\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBool GoBusLink::orientation(short \fIorientation\fP).
.RE
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBGoLink\fP class.
.nrPN \n%
