.\" $Id: Cubic.n,v 1.1.1.1 1992/03/18 09:38:17 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoCubic 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoCubic\fP \(em the cubic object class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Cubic.h>\fP
.SH 
\fBCLASS\fP
.IP
\fBGoCubic\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGoCurve\fP class
.IP \(em 3
\fBGoPolypoint\fP class
.IP \(em 3
\fBGoGeometric\fP class
.IP \(em 3
\fBGoStdDS\fP class
.IP \(em 3
\fBGo\fP class.
.RE
.SH
\fBDESCRIPTION\fP
.IP
\fBGoCubic\fP is the base class of several curve classes. A longer curve can be
made up of series of curve segments joining at the end points. In the case of
cubic segmented curves, each segment of the curve is determined by an
evaluation window of exactly four control points. The first four control points
describe the first segment of the curve, then this evaluation window shifts to
next series of four points. The appropriate shift in control points between
segments is an important attribute of a curve type which will be referred to as
evaluation shift from now onwards.
.IP
The points on the curve segment are calculated using the basis matrix of the
particular type of the curve and the geometric vector of the corresponding
control points. Choosing the basis matrix suitably, we can have various types
of interpolating and approximating splines. The closeness of the curve to the
control polyline can be varied by making the basis matrix as function of
another parameter known as \fItension\fP. A very tense spline looks more like
its control polyline than an untense spline.
.IP
\fBGoCubic\fP implements the common functions for all the cubic spline
subclasses. Each subclass has to provide the fuction to initialize the basis
matrix when requested. The subclass can introduce additional parameters for the
basis matrix (e.g. some of the splines like Beta Spline and Tau Spline have a
parameter called bias) or ignore the \fItension\fP parameter if not interested.
A subclass whose evaluation shift is different from 1 has to implement the
virtual function evalShift() as the default value of the evaluation shift for
the GoCubic class is 1.
.sp 1
.br
.nf
.ta .15i .25i 1.0i
class GoCubic : public GoCurve {

	public:

		static GoCubicMetaclass* metaclass ();

		GNumber tension () const;
		GBool tension (GNumber);

		/*
		 * \fBpre and post conditions:\fP
		 */

		void tensionPrecond (GBool (*) (void*, const GoCubic*),
			void*, GAddOrRemove  = GADD);
		void tensionPostcond (void (*) (void*, GoCubic*),
			void*, GAddOrRemove  = GADD);
};
.fi
.SH
\fBPUBLIC METHODS\fP
.IP
\fBGoCubicMetaclass\fP* \fBmetaclass\fP ()
.RS .8i
.IP \fIDescription\fP .3i
This static member function returns the \fBGoCubicMetaclass\fP instance.
.RE
.sp 1
.IP
GNumber \fBtension\fP() const;
.RS .8i
.IP \fIDescription\fP .3i
This method returns the cubic tension.
.RE
.sp 1
.IP
GBool \fBtension\fP(GNumber \fItens\fP);
.RS .8i
.IP \fIDescription\fP .3i
This method modifies the cubic tension.
.br
If none of the \fBtensionPrecond\fP preconditions returned GFALSE, the action
is performed with parameter \fItens\fP possibly modify by the preconditions.
If the action succeeds, \fBtensionPostcond\fP postconditions are called and the
method returns GTRUE. Otherwise, it returns GFALSE.
.IP \fItens\fP .3i
Specifies the new tension value.
.RE
.sp 1
.IP
.nf
void \fBtensionPrecond\fP (GBool (*\fIf\fP) (void* \fIclosure\fP, const GoCubic* \fIcubic\fP, GNumber* \fInewTens\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBtensionPostcond\fP (void (*\fIf\fP) (void* \fIclosure\fP, GoCubic* \fIcubic\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .3i
These methods allow to add or remove functions to the pre/post conditions lists
triggered by \fBtension\fP (GNumber) member function.
.IP \fIf\fP .3i
Specifies programmer's function to be added/removed.
.IP \fIclosure\fP .3i
Specifies programmer's parameter to call the fonction with.
.IP \fIcubic\fP .3i
Specifies the \fBGoCubic\fP object involved (i.e. \fIthis\fP).
.IP \fInewTens\fP .3i
Specifies the new tension. May be modified by \fIf\fP.
.IP \fIadd\fP .3i
Specifies whether to add or remove the function \fIf\fP from the list.
.RE
.SH
\fBC BINDING\fP
.SS 
\fBHeader\fP
.IP
#include <Go/cCubic.h>
.DE
.SS 
\fBResources\fP
.IP
The following table defines a set of Go resources used by the programmer
to specify data.  The programmer can also set the resource values for the 
inherited classes to set attributes for this object.
The codes in the access column indicate if the given resource can be set by
using \fBGoSetValues\fP (\fBS\fP), retrieved by using \fBGoGetValues\fP
(\fBG\fP), or is not applicable (\fBN/A\fP).
.br
For superclass resources, see superclass man pages.
.br
See also Section 2.
.sp 1
.ps 8
.DS
.TS
center box;
cB sss
lB lB lB lB
l l l l.
GoCubic Resource GSet
.sp
=
Name	Type	Default	Access
.sp
_
goNtension	GNumber	dynamic	GS
.TE
.DE
.ps 10

.SS 
\fBFunctions\fP
.IP
void \fBGoCubicInitialize\fP ();
.RS .8i
.IP \fIDescription\fP .3i
This function must be called before any use of the GoCubic C Binding.
.RE
.sp 1
.IP
.nf
GObjectId \fBGoCubicMetaclass\fP ();
GBool \fBGoCubicSetTension\fP (GObjectId \fIcubic\fP, GNumber \fIw\fP);
GNumber \fBGoCubicTension\fP (GObjectId \fIcubic\fP);
.fi
.sp 1
.RS .8i
.IP \fIDescription\fP .3i
See \fBGoCubic\fP following members :
.sp 1
.nf
GoMetaclass* metaclass ().
GBool tension (GNumber).
GNumber tension ().
.fi
.RE
.sp 1
.IP
.nf
void \fBGoCubicTensionPrecond\fP (GObjectId \fIcubic\fP, 
		GBool (*\fIf\fP) (GObjectId, GNumber*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoCubicTensionPostcond\fP (GObjectId \fIcubic\fP, 
		void (*\fIf\fP) (GObjectId),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
.fi
.sp 1
.RS .8i
.IP \fIDescription\fP .3i
See \fBGoCubic\fP following members :
.sp 1
.nf
void tensionPrecond (GBool (*\fIf\fP) (void*, GoCubic*, GNumber*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void tensionPostcond (void (*\fIf\fP) (void*, GoCubic*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.fi
.RE
.SH
\fBUSER INTERACTIONS\fP
.IP
The following strings may be associated with event description strings in GoUI
files to perform actions on \fBGoCubic\fP objects (see \fBGoUI\fP
documentation for more information on this topic). Most of the time,
these strings refer to name-like public functions or have an obvious
signification, thus description will only be given if absolutely necessary.
.sp 1
.IP
\fBtension\fP (GNumber)
.RS .8i
.IP \fIDescription\fP .3i
same as member functions.
.RE
.SH
\fBUSAGE INFORMATION\fP
.IP
\fBGoCubic\fP is an abstract class, thus it has no public constructor :
creation may only occur through subclasses constructors.
.RE
.SH
\fBSEE ALSO\fP
.IP
\fBGo\fP, \fBGoMetaclass\fP, \fBGoStdDS\fP, \fBGoStdDSMetaclass\fP,
\fBGoGeometric\fP, \fBGoGeometricMetaclass\fP, \fBGoPolypoint\fP,
\fBGoPolypointMetaclass\fP, \fBGoCurve\fP, \fBGoCurveMetaclass\fP
and \fBGoCubicMetaclass\fP classes.
.nrPN \n%

