.\" $Id: EdAsRect.n,v 1.2 1992/12/28 13:07:43 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991, 1992 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH EditAsRectangle 3Go "December 1992" "Version 1.2" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBEditAsRectangle\fP \(em the class used to compute a width and height according a defined \fIgravity\fP. It is not a grabber.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/EdAsRect.h>\fP
.sp 1
.SH
\fBCLASS\fP
.IP
\fBGEditAsRectangle\fP does not inherit behavior from any class.
.RS 10
\fBGEditAsRectangle\fP class,
.IP \(em 3
.RE
.sp 1
.SH
\fBDESCRIPTION\fP
.IP
The \fBGEditAsRectangle\fP class is used to compute a \fIwidth\fP, a \fIheight\fP and/or \fItop left position\fP of a rectangle according a \fIgravity\fP. see \fIcompute\fP method for \fIgravity\fP explanations.
.RE
.sp 2
.nf
.ta .15i .25i 1.0i

/*
 * defines for rectangle manipulation
 */

#define G_NO_GRAVITY		(1<<0)
#define G_MOVE_SOUTH		(1<<1)
#define G_MOVE_EAST		(1<<2)
#define G_MOVE_NORTH		(1<<3)
#define G_MOVE_WEST		(1<<4)
#define G_OPPOSITE_GRAVITY	(1<<5)
#define G_AS_SQUARE		(1<<6)

/*
 * Note that the following "bitwise or" values are also valid:
 *   G_NO_GRAVITY | G_AS_SQUARE
 *
 *   G_MOVE_SOUTH | G_MOVE_EAST
 *   G_MOVE_SOUTH | G_MOVE_WEST
 *   G_MOVE_NORTH | G_MOVE_EAST
 *   G_MOVE_NORTH | G_MOVE_WEST
 */

extern int GRectangleGravityToCursorIdent(int gravity);

class GEditAsRectangle
{
  public:
    GEditAsRectangle (GNumber width, GNumber height,
		      int gravity);
    
    virtual ~GEditAsRectangle ();

    virtual void  compute (const GPoint& point);

    // read resulting values;
    
    const GPoint& topLeft() const ;
    GNumber width() const ; 
    GNumber height() const;
    int gravity() const ;
};
.fi
.sp 2
.SH
\fBPUBLIC METHODS\fP
.IP
\fBGEditAsRectangle\fP(GNumber \fIinitial_width\fP, GNumber \fIinitial_height\fP, int \fIgravity\fP)
.RS .8i
.IP \fIDescription\fP .5i
The constructor its initial initial_width,initial_height with \fIinitial_width/initial_height\fP and the wanted \fIgravity\fP used at compute time. The initial top left of the rectangle is the point (0,0).
.IP \fIinitial_width, initial_height\fP .5i
.br
Specify the initial width and height of the rectangle.
.IP \fIgravity\fP .5i
.br
Specifies the constraints to used during the computation (see \fIcompute\fP())./
.RE
.sp
.IP
\fBcompute\fP(const GPoint& \fIposition\fP)
.RS .8i
.IP \fIDescription\fP .5i
The method is called during a resize of a rectangle. The behavior is the following:
.br
- G_NO_GRAVITY: The segment [\fItopLeft\fP, position] is always the rectangle diagonal line.
.IP
- G_OPPOSITE_GRAVITY: The pointer drags whichever rectangle side it crosses first. As soon as a side is dragged beyond its opposite rectangle side. it goes back to its initial position and the opposite size is dragged instead.
.IP
- G_AS_SQUARE: The width and the height of the rectangle are seen equal during the grab processing. The method takes the largest size to get the square width. Note that if \fIcoordsys\fP is deformed, the square will be shown deformed during the grab processing. G_AS_SQUARE only works with G_NO_GRAVITY. If not set G_NO_GRAVITY is assumed.
.IP
- G_MOVE_xxxx: where xxx is NORTH, SOUTH, EAST, WEST or a bitwise combinaison of the G_MOVE_xxx bit: Only the corresponding rectangle size follows the position.
.RE
.sp 1
.IP
const GPoint& \fBtopLeft\fP() const ;
.IP
GNumber \fBwidth\fP() const ; 
.IP
GNumber \fBheight\fP() const;
.IP
int \fBgravity\fP() const ;
.RS .8i
.IP \fIDescription\fP.
These methods return the values computed by the \fIcompute\fP method.
.RE
.sp
.SH
\fBPUBLIC FUNCTION\fP
.IP
int \fBGRectangleGravityToCursorIdent(int \fIgravity\fP);
.RS .8i
.IP \fIDescription\fP .5i
This external function returns the best \fIcursor\fP to be used for an interaction programmed with \fIgravity\fP.
.SH
\fBC BINDING\fP
.IP
\fITo be defined.\fP
.sp
.SH
\fBUSAGE INFORMATION\fP
.IP
.br
The GEditAsRectangle class is used as a \fIcomputer\fP by interactor which wants to \fIresize\fP an object as a rectangle.
.sp
.SH
\fBSEE ALSO\fP
.IP
\fBEditRectangle (3Go), EditImage (3Go), Cursor (3Go).\fP
.nrPN \n%





