.\" $Id: FrForm.n,v 1.2 1992/12/28 10:33:22 andre Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH FrFormatter 3Go "December 1992" "Version 1.2" "Go Reference Manual"
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBFrFormatter\fP \(em The framed formatter abstract class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/FrForm.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGFrFormatter\fP inherits behavior from class \fBGFormatter\fP.
.RS 10
.RE
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
When linked with a \fBGFrFormatter\fP, a \fBGoText\fP is confined inside a frame which may be multi-columned, multi-boxed or inside a circle. To create a new frame formatter class, the programmer has to describe just a few functions.
.br
.sp 1
A new kind of justification is available: \fBGLR_JUSTIFICATION\fP. In this case,
the text string is aligned on both left and right sides. With this justification,
the words are separated between themselves with a glue of variable width
(See KNUTH - The Art of Computer Programming). To tune the glue between words,
the application can constraint its strechability and its shrinkability. The words may be hyphenized
(according to the chosen language rules) to adjust the frame content.
The hyphenizer uses dictionnaries of patterns and exceptions which are
specific to each country. When the justification is set to this value, the
text string is not editable and must be changed before.
.br
.sp1
This formatter lets the text contain several paragraphs. An indentation (exprimed in
percent of the column width) can be used for each first line of a paragraph when the
justification is set to GLEFT_JUSTIFICATION or GLR_JUSTIFICATION.
.br
.sp1
The \fBGoUI\fP object provides function to change interactively the frame (width, height)
of the text.
.br
.sp 2
.br
.nf
.ta .15i .25i 1.50i


class GFrFormatterCtxt::public GFormatterCtxt
{
public:

    GLanguage	language();
    void	language (GLanguage);
    uchar	strechLevel();
    void	strechLevel (uchar);
    GNumber	shrinkLevel();
    void	shrinkLevel (GNumber);
    GNumber	indentation();
    void	indentation (GNumber);
}

.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.sp1
.IP
GLanguage \fBGFrFormatterCtxt::language\fP()
.br
void \fBGFrFormatterCtxt::language\fP (GLanguage \fIlg\fP)
.RS .8i
.IP \fIDescription\fP .5i
These functions are used to get/set the language employed for the hyphenation
when the justification is set to GLR_JUSTIFICATION. If no hyphenization is desired,
set the language to GNO_LANGUAGE.
.IP \fIlg\fP .5i
.br
Specifies the language. 7 values are availables: GGERMAN, GSPANISH, GFRENCH, GENGLISH,
GITALIAN, GPORTUGUESE and GNO_LANGUAGE. The default value is GNO_LANGUAGE.
.RE
.sp 1
.IP
uchar \fBGFrFormatterCtxt::stretchLevel\fP()
.br
void \fBGFrFormatterCtxt::stretchLevel\fP (uchar \fIsl\fP)
.RS .8i
.IP \fIDescription\fP .5i
These functions are used to get/set the stretching level of the glue width when the
justification is set to GLR_JUSTIFICATION.
.IP \fIsl\fP .5i
.br
Specifies the stretching level. This factor lets the glue between two words stretched
to this value multiplied by the width of a the space character. This value must be > 0 and 
is set to 2 by default.
.RE
.sp 1
.IP
GNumber \fBGFrFormatterCtxt::shrinkLevel\fP()
.br
void \fBGFrFormatterCtxt::shrinkLevel\fP (GNumber \fIsl\fP)
.RS .8i
.IP \fIDescription\fP .5i
These functions are used to get/set the shrinking level of the glue width when the
justification is set to GLR_JUSTIFICATION.
.IP \fIsl\fP .5i
.br
Specifies the shrinking level. This factor lets the glue between two words shrinked
to this value multiplied by the width of a the space character. This value must be
contained between 0 and 1 and is set to 1/3 by default.
.RE
.sp 1
.IP
GNumber \fBGFrFormatterCtxt::indentation\fP()
.br
void \fBGFrFormatterCtxt::indentation\fP (GNumber \fIi\fP)
.RS .8i
.IP \fIDescription\fP .5i
These functions are used to get/set the indentation.
.IP \fIi\fP .5i
.br
Specifies the indentation value, which is a percent of the column width.
The value must be contained between 0 and 1 and is set to 0.1, by default.
.RE
.sp 1
.SH
\fBUSER INTERACTIONS\fP
.IP
.br
.sp1
The \fBGoUI\fP object provides two functions to resize the frame of the 
formatter (See GoUI).
.RE
.SH
\fBC BINDING\fP
.SS
\fBHeader\fP
.IP
#include <Go/cFrForm.h>
.br
.SS
\fBFunctions\fP
.sp 1
.RE
.IP
GObjectId \fBGFrFormatterCreate\fP()
.RS .8i
.IP \fIDescription\fP .5i
This function creates an instance of the GFrFormatter class.
.sp1
.RE
.IP
void \fBGFrFormatterCtxtSetLanguage\fP (GFrFormatterCtxt*, GLanguage);
.br
GLanguage \fBGFrFormatterCtxtGetLanguage\fP (GFrFormatterCtxt*);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GFrFormatter::language (GLanguage) and GLanguage
GFrFormatter::language().
.sp1
.RE
.IP
void \fBGFrFormatterCtxtSetShrinkLevel\fP (GFrFormatterCtxt*, GNumber);
.br
GNumber \fBGFrFormatterCtxtGetShrinkLevel\fP (GFrFormatterCtxt*);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GFrFormatter::shrinkLevel (GNumber) and GNumber
GFrFormatter::shrinkLevel().
.sp1
.RE
.IP
void \fBGFrFormatterCtxtSetStrechLevel\fP (GFrFormatterCtxt*, uchar);
.br
uchar \fBGFrFormatterCtxtGetStrechLevel\fP (GFrFormatterCtxt*);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GFrFormatter::strechLevel (uchar) and uchar
GFrFormatter::strechLevel().
.sp1
.RE
.IP
void \fBGFrFormatterCtxtSetIndentation\fP (GFrFormatterCtxt*, GNumber);
.br
GNumber \fBGFrFormatterCtxtGetIndentation\fP (GFrFormatterCtxt*);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GFrFormatter::indentation (GNumber) and GNumber
GFrFormatter::indentation().
.sp1
.RE
.SH
\fBSEE ALSO\fP
.IP
\fBGoText\fP, \fBGFrFormatter\fP, \fBGSimpleFormatter\fP, \fBGMCFormatter\fP, \fBGMBFormatter\fP and \fBGCircleFormatter\fP  classes.
.nrPN \n%
