.\" $Id: Geometric.n,v 1.1.1.1 1992/03/18 09:38:35 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoGeometric 3Go "February 1992" "Version 1.1" "Go reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoGeometric\fP \(em the geometric object abstract class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Geometric.h>\fP
.SH 
\fBCLASS\fP
.IP
\fBGoGeometric\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGoStdDS\fP class
.IP \(em 3
\fBGo\fP class.
.RE
.SH
\fBDESCRIPTION\fP
.IP
A \fBGoGeometric\fP object is the base class for all geometric graphical
objects. A geometric object is defined by an outline and/or a background.
\fBGoGeometric\fP manages a \fBGPen\fP to draw the outline (if any) and a
\fBGBrush\fP to draw the background (if any).
.sp 1
.br
.nf
.ta .15i .25i 1.0i
class GoGeometric : public GoStdDS {

	public:

		static GoGeometricMetaclass* metaclass ();

		GPen& pen () const;
		GBrush& brush () const;
		GBool outline () const;
		GBool background () const;
		GBool virtual outline (GBool);
		GBool virtual background (GBool);

		/*
		 * \fBpre and post conditions:\fP
		 */

		void outlinePrecond (GBool (*) (void*, const GoGeometric*, GBool*),
			void*, GAddOrRemove = GADD) const;
		void outlinePostcond (void (*) (void*, GoGeometric*),
			void*, GAddOrRemove = GADD) const;
		void backgroundPrecond (GBool (*) (void*, const GoGeometric*, GBool*),
			void*, GAddOrRemove = GADD) const;
		void backgroundPostcond (void (*) (void*, GoGeometric*),
			void*, GAddOrRemove = GADD) const;
};
.fi
.SH
\fBPUBLIC METHODS\fP
.IP
\fBGoGeometricMetaclass\fP* \fBmetaclass\fP ()
.RS .8i
.IP \fIDescription\fP .3i
This static member function returns the \fBGoGeometricMetaclass\fP instance.
.RE
.IP
.nf
GPen& \fBpen\fP () const;
GBrush& \fBbrush\fP () const;
.fi
.RS .8i
.IP \fIDescription\fP .3i
These functions return a reference to the GPen (resp GBrush) of the object.
.RE
.IP
.nf
GBool \fBoutline\fP () const;
GBool \fBbackground\fP () const;
.fi
.RS .8i
.IP \fIDescription\fP .3i
These functions return GTRUE if the GoGeometric has an outline (resp
background), else GFALSE.
.RE
.IP
.nf
GBool \fBoutline\fP (GBool \fIyes\fP);
GBool \fBbackground\fP (GBool \fIyes\fP);
.fi
.RS .8i
.IP \fIDescription\fP .3i
Request to set the value of the outline (resp. background) flag to \fIyes\fP.
.br
If none of the \fBoutlinePrecond\fP (resp. \fBbackgroundPrecond\fP)
preconditions returned GFALSE, the action is performed with the parameter
\fIyes\fP possibly modify by the preconditions. If the action succeeds,
\fBoutlinePostcond\fP (resp. \fBbackgroundPostcond\fP) postconditions are
called and the method returns GTRUE. Otherwise, it returns GFALSE.
.IP \fIyes\fP .3i
If GTRUE, outline (resp background) is set, else it is unset.
.RE
.IP
.nf
void \fBoutlinePrecond\fP (GBool (*\fIf\fP)  (void* \fIclosure\fP, GoGeometric* \fIgogeom\fP, GBool* \fInew\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBoutlinePostcond\fP (void (*\fIf\fP)  (void* \fIclosure\fP, GoGeometric* \fIgogeom\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBbackgroundPrecond\fP (GBool (*\fIf\fP)  (void* \fIclosure\fP, GoGeometric* \fIgogeom\fP, GBool* \fInew\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBbackgroundPostcond\fP (void (*\fIf\fP)  (void* \fIclosure\fP, GoGeometric* \fIgogeom\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .3i
These methods allow to add or remove functions to the pre/post conditions lists
triggered by \fBoutline\fP (GBool) and \fPbackground\fP (GBool) member functions.
.IP \fIf\fP .3i
Specifies the programmer's function to add/remove from the list.
.IP \fIclosure\fP .3i
Specifies the programmer's parameter to call the function with.
.IP \fIgogeom\fP .3i
Specifies the \fBGoGeometric\fP object involved (i.e. \fIthis\fP).
.IP \fInew\fP .3i
Specifies a pointer to the value intended to be set (precondition only); the
value pointed to may be modify by \fIf\fP.
.RE
.SH
\fBC BINDING\fP
.SS 
\fBHeader\fP
.IP
#include <Go/cGeometric.h>
.DE
.SS 
\fBResources\fP
.IP
The following table defines a set of Go resources used by the programmer
to specify data.  The programmer can also set the resource values for the 
inherited classes to set attributes for this object.
The codes in the access column indicate if the given resource can be set by
using \fBGoSetValues\fP (\fBS\fP), retrieved by using \fBGoGetValues\fP
(\fBG\fP), or is not applicable (\fBN/A\fP).
.br
For superclass resources, see superclass man pages.
.br
See also Section 2.
.sp 1
.ps 8
.DS
.TS
center box;
cB sss
lB lB lB lB
l l l l.
GoGeometric Resource GSet
.sp
=
Name	Type	Default	Access
.sp
_
goNbackground	GBool	GFALSE	GS
goNbrush	GObjectId	dynamic	G
goNoutline	GBool	GTRUE	GS
goNpen	GObjectId	dynamic	G
.TE
.DE
.ps 10
.SS 
\fBFunctions\fP
.IP
void \fBGoGeometricInitialize\fP ();
.RS .8i
.IP \fIDescription\fP .3i
This function must be called before any use of the GoGeometric C Binding.
.RE
.IP
.nf
GBool \fBGoGeometricBackground\fP (GObjectId \fIgeometric\fP);
GObjectId \fBGoGeometricBrush\fP (GObjectId \fIgeometric\fP);
GObjectId \fBGoGeometricMetaclass\fP ();
GBool \fBGoGeometricOutline\fP (GObjectId \fIgeometric\fP);
GObjectId \fBGoGeometricPen\fP (GObjectId \fIgeometric\fP);
GBool \fBGoGeometricSetBackground\fP (GObjectId \fIgeometric\fP, GBool \fIyes\fP);
GBool \fBGoGeometricSetOutline\fP (GObjectId \fIgeometric\fP, GBool \fIyes\fP);
.fi
.sp 1
.RS .8i
.IP \fIDescription\fP .3i
See \fBGoGeometric\fP following members :
.sp 1
.nf
GBool background ().
GBrush& brush ().
GoMetaclass* metaclass ().
GBool outline ().
GPen& pen ().
GBool background (GBool).
GBool outline (GBool).
.fi
.RE
.sp 1
.IP
.nf
void \fBGoGeometricBackgroundPrecond\fP (GObjectId \fIgeometric\fP, 
		GBool (*\fIf\fP) (const GObjectId, *GBool),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoGeometricBackgroundPostcond\fP (GObjectId \fIgeometric\fP, 
		void (*\fIf\fP) (GObjectId, GBool),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoGeometricOutlinePrecond\fP (GObjectId \fIgeometric\fP, 
		GBool (*\fIf\fP) (const GObjectId, *GBool),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoGeometricOutlinePostcond\fP (GObjectId \fIgeometric\fP, 
		void (*\fIf\fP) (GObjectId, GBool),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
.fi
.sp 1
.RS .8i
.IP \fIDescription\fP .3i
See \fBGoGeometric\fP following members :
.sp 1
.nf
void backgroundPrecond (GBool (*\fIf\fP) (void*, const GoGeometric*, GBool*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void backgroundPostcond (void (*\fIf\fP) (void*, GoGeometric*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void outlinePrecond (GBool (*\fIf\fP) (void*, const GoGeometric*, GBool*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void outlinePostcond (void (*\fIf\fP) (void*, GoGeometric*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.fi
.RE
.SH
\fBUSER INTERACTIONS\fP
.IP
The following strings may be associated with event description strings in GoUI
files to perform actions on \fBGoGeometric\fP objects (see \fBGoUI\fP
documentation for more information on this topic). Most of the time, these
strings refer to name-like public functions or have an obvious signification,
thus description will only be given if absolutely necessary.
.IP
.nf
\fBoutline\fP (GBool)
\fBbackground\fP (GBool)
.if
.RS .8i
.IP \fIDescription\fP .3i
see member functions.
.RE
.SH
\fBUSAGE INFORMATION\fP
.IP
\fBGoGeometric\fP is an abstract class, thus it has no public constructor :
creation may only occur through subclasses constructors.
.SH
\fBSEE ALSO\fP
.IP
\fBGo\fP, \fBGoMetaclass\fP, \fBGoStdDS\fP, \fBGoStdDSMetaclass\fP,
\fBPen\fP, \fBBrush\fP, and \fBGoGeometricMetaclass\fP classes.
.nrPN \n%

