.\" $Id: Graph.n,v 1.1.1.1 1992/03/18 09:38:41 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoGraph 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoGraph\fP \(em the graph object class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Graph.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGoGraph\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGoGraphStruct\fP class
.IP \(em 3
\fBGo\fP class.
.RE
.sp 1
.SH
\fBDESCRIPTION\fP
.IP
GoGraph is composed of nodes and links. An orientation is defined, so each node has previous nodes, next nodes, previous links and next links. Each link is connected to two nodes (one is its previous node, the other is its next node). Nodes may be isolated.
.br
No predefined algorithms for node's placement are proposed.
.IP
.nf
.ta .15i .25i 1.0i
class GoGraph {
	public:
		// pre and post conditions;
		void addNodePrecond(GBool (*)\fIfunction\fP(void*, GoGraph*, GoGraphNode*, GBool*, GoMetaclass*), 
.br
					void* \fIclosure\fP, GAddOrRemove = GADD);
		void addNodePostcond(void (*)\fIfunction\fP(void*, GoGraph*, GoGraphNode*, GBool*, GoMetaclass*), 
.br
					void* \fIclosure\fP, GAddOrRemove = GADD);
		void removeNodePrecond(GBool (*)\fIfunction\fP(void*, GoGraph*, GoGraphNode*), 
.br
					void* \fIclosure\fP, GAddOrRemove = GADD);
		void removeNodePostcond(void (*)\fIfunction\fP(void*, GoGraph*, GoGraphNode*),
.br
					void* \fIclosure\fP, GAddOrRemove = GADD);
		void addLinkPrecond(GBool (*)\fIfunction\fP(void*, GoGraph*, GoGraphNode*, GoGraphNode*,
.br
					GoMetaclass*), void* \fIclosure\fP, GAddOrRemove = GADD);
		void addLinkPostcond(void (*)\fIfunction\fP(void*, GoGraph*, GoGraphNode*, GoGraphNode*, 
.br
					GoMetaclass*), void* \fIclosure\fP, GAddOrRemove = GADD);
		void removeLinkPrecond(GBool (*)\fIfunction\fP(void*, GoGraph*, GoLink*), 
.br
					void* \fIclosure\fP, GAddOrRemove = GADD);
		void removeLinkPostcond(void (*)\fIfunction\fP(void*, GoGraph*, GoLink*), 
.br
					void* \fIclosure\fP, GAddOrRemove = GADD);
		
		// others;
		GoGraph();

		static GoMetaclass* metaclass();
		static GoGraph* create();

		GoGraphNode* addNode(GoGraphNode* \fIextrem\fP, GBool \fIis_previous\fP = GTRUE, 
.br
					GoMetaclass* \fIlinkclass\fP = NULL);
		GBool removeNode(GoGraphNode* \fInode\fP);
		GoLink* addLink(GoGraphNode* \fIprev\fP, GoGraphNode* \fInext\fP, GoMetaclass* \fIlinkclass\fP = NULL);
		GBool removeLink(GoLink* \fIlink\fP);
		GBool removeLink(GoGraphNode* \fInode1\fP, GoGraphNode \fInode2\fP);
		void rotateGraph(GNumber \fIangle\fP, GPoint& \fIcenter\fP=*(GPoint*)NULL);
};
.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
.nf
void \fBaddNodePrecond\fP (GBool (*\fIproc\fP)(void* \fIclosure\fP, GoGraph* \fIgraph\fP, GoGraphNode* \fIextrem\fP, 
.br
				GBool* \fIis_previous\fP, GoMetaclass* \fIlinkclass\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBaddNodePostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GoGraph* \fIgraph\fP, GoGraphNode* \fIextrem\fP, 
.br
				GBool* \fIis_previous\fP, GoMetaclass* \fIlinkclass\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or to remove pre or postcondition procedures when a node is added to the \fIgraph\fP.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when a node will be added to the \fIgraph\fP. The precondition procedure is
called before the node is added. It can either accept or refuse the modification.
The postcondition procedure is invoked after the node is added.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the pre/postcondition procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the modify
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp 1
.IP
.nf
void \fBremoveNodePrecond\fP (GBool (*\fIproc\fP)(void* \fIclosure\fP, GoGraph* \fIgraph\fP, GoGraphNode* \fInode\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBremoveNodePostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GoGraph* \fIgraph\fP, GoGraphNode* \fInode\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or to remove pre or postcondition procedures when a node is removed from the \fIgraph\fP.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when a node will be removed from the \fIgraph\fP. The precondition procedure is
called before the node is removed. It can either accept or refuse the modification.
The postcondition procedure is invoked after the node is removed.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the pre/postcondition procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the modify
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp 1
.IP
.nf
void \fBaddLinkPrecond\fP (GBool (*\fIproc\fP)(void* \fIclosure\fP, GoGraph* \fIgraph\fP, GoGraphNode* \fIprev\fP, 
.br
				GoGraphNode* \fInext\fP, GoMetaclass* \fIlinkclass\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBaddLinkPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GoGraph* \fIgraph\fP, GoGraphNode* \fIprev\fP, 
.br
				GoGraphNode* \fInext\fP, GoMetaclass* \fIlinkclass\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or to remove pre or postcondition procedures when a link is added to the \fIgraph\fP.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when a link will be added to the \fIgraph\fP. The precondition procedure is
called before the link is added. It can either accept or refuse the modification.
The postcondition procedure is invoked after the link is added.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the pre/postcondition procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the modify
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp 1
.IP
.nf
void \fBremoveLinkPrecond\fP (GBool (*\fIproc\fP)(void* \fIclosure\fP, GoGraph* \fIgraph\fP, GoLink* \fIlink\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBremoveLinkPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GoGraph* \fIgraph\fP, GoLink* \fIlink\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or to remove pre or postcondition procedures when a link is removed from the \fIgraph\fP.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when a link will be removed from the \fIgraph\fP. The precondition procedure is
called before the link is removed. It can either accept or refuse the modification.
The postcondition procedure is invoked after the link is removed.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the pre/postcondition procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the modify
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp 1
.IP
\fBGoGraph\fP();
.RS .8i
.IP \fIDescription\fP .5i
This method allows to create a new instance of the \fIGoGraph\fP class.
.RE
.sp 1
.IP
static GoMetaclass* \fBmetaclass\fP();
.RS .8i
.IP \fIDescription\fP .5i
Returns a pointer to the metaclass object of the \fIthis\fP.
.RE
.sp1
.IP
static GoGraph* \fBcreate\fP();
.RS .8i
.IP \fIDescription\fP .5i
Creates a new GoGraph instance. Returns the created graph.
.RE
.sp1
.IP
GoGraphNode* \fBaddNode\fP(GoGraphNode* \fIextrem\fP, GBool \fIis_previous\fP, GoMetaclass* \fIlinkclass\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method adds a node to the graph. It consists in creating a new node, attaching it to its \fIextrem\fP node with a new link. This method returns the created node Id.
.IP \fIextrem\fP .5i
.br
The created node will be connected to the \fIextrem\fP node. If \fIextrem\fP node is NULL, the created node will be isolated and no link will be created.
.br
.IP \fIis_previous\fP .5i
If GTRUE, the \fIextrem\fP node is a previous node for the created node, otherwise the \fIextrem\fP node is a next node for the created node.
.br
Default value is GTRUE.
.br
.IP \fIlinkclass\fP .5i
.br
Specifies the class of the link created to connect the new node to its extrem node. The default value is NULL. In this case the \fIlinkclass\fP is the class returned by the \fIdefaultLinkType()\fP method of GoGraphStruct class.
.br
.RE
.sp 1
.IP
GBool \fBremoveNode\fP(GoGraphNode* \fInode\fP);
.RS .8i
.IP \fIDescription\fP .5i
Removes the \fInode\fP and all links connected to \fInode\fP. Returns GFALSE if an error occurred, otherwise returns GTRUE.
.IP \fInode\fP .5i
.br
Specifies the node to remove.
.br
.RE
.sp 1
.IP
GoLink* \fBaddLink\fP(GoGraphNode* \fIprev\fP, GoGraphNode* \fInext\fP, GoMetaclass* \fIlinkclass\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method adds a link between two nodes. This method returns the created link Id.
.IP \fIprev\fP .5i
.br
Specifies the previous node of the link.
.br
.IP \fInext\fP .5i
.br
Specifies the next node of the link.
.br
.IP \fIlinkclass\fP .5i
.br
Specifies the class of the  new link. The default value is NULL. In this case the \fIlinkclass\fP is the class returned by the \fIdefaultLinkType()\fP method of GoGraphStruct class.
.br
.RE
.sp 1
.IP
GBool \fBremoveLink\fP(GoLink* \fIlink\fP);
.RS .8i
.IP \fIDescription\fP .5i
Removes a link.
.IP \fIlink\fP .5i
.br
Specifies the link to remove. Returns GFALSE if an error occurred, otherwise returns GTRUE.
.RE
.sp 1
.IP
GBool \fBremoveLink\fP(GoGraphNode* \fInode1\fP, GoGraphNode* \fInode2\fP);
.RS .8i
.IP \fIDescription\fP .5i
Removes the link connecting the two nodes. Returns GFALSE if an error occurred, otherwise returns GTRUE.
.IP \fInode1\fP .5i
.br
Specifies one extrem node of the link to remove.
.IP \fInode2\fP .5i
.br
Specifies the other extrem node of the link to remove.
.RE
.sp 1
.IP
void \fBrotateGraph\fP(GNumber \fIangle\fP, GPoint& \fIcenter\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to rotate a graph without rotating nodes on themselves.
.IP \fIangle\fP .5i
.br
Specifies the rotation angle expressed in radians.
.IP \fIcenter\fP .5i
.br
Specifies the rotation center.
.br
Default value: the graph's center.
.RE
.sp 1
.RE
.sp 2
.SH
\fBUSER INTERACTION\fP
.IP
\fISee GoGraphMetaclass(3Go)\fP.
.RE
.sp 2
.SH
\fBC BINDING\fP
.SS 
\fBHeader\fP
.IP
#include <Go/cGraph.h>
.DE
.SS 
\fBResources\fP
.IP
No resources.
.SS 
\fBFunctions\fP
.IP
void \fBGoGraphInitialize\fP();
.RS .8i
.IP \fIDescription\fP .5i
This function must be called before any use of the GoGraph C Binding.
.RE
.sp 1
.IP
GObjectId \fBGoCreateGoGraph\fP();
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoGraph* GoGraph::create().
.RE
.sp 1
.IP
GObjectId \fBGoGraphMetaclass\fP();
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoMetaclass* GoGraph::metaclass().
.RE
.sp 1
.IP
void \fBGoAddGraphNodePrecond\fP(GObjectId \fIgraph\fP, 
.br
			GBool(*\fIcb\fP)(GObjectId, GObjectId, GObjectId, GBool*, GObjectId), 
.br
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoGraph::addNodePrecond(GBool(*\fIcb\fP)
.br
			(void*, GoGraph*, GoGraphNode*, GBool*, GoMetaclass*), 
.br
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoAddGraphNodePostcond\fP(GObjectId \fIgraph\fP, 
.br
			void(*\fIcb\fP)(GObjectId, GObjectId, GObjectId, GBool*, GObjectId), 
.br
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoGraph::addNodePostcond(void(*\fIcb\fP)
.br
			(void*, GoGraph*, GoGraphNode*, GBool*, GoMetaclass*), 
.br
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoRemoveGraphNodePrecond\fP(GObjectId \fIgraph\fP, 
.br
			GBool(*\fIcb\fP)(GObjectId, GObjectId, GObjectId), 
.br
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoGraph::removeNodePrecond(void(*\fIcb\fP)
.br
			(void*, GoGraph*, GoGraphNode*), 
.br
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoRemoveGraphNodePostcond\fP(GObjectId \fIgraph\fP, 
.br
			void(*\fIcb\fP)(GObjectId, GObjectId, GObjectId), 
.br
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoGraph::removeNodePostcond(void(*\fIcb\fP)
.br
			(void*, GoGraph*, GoGraphNode*), 
.br
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoAddGraphLinkPrecond\fP(GObjectId \fIgraph\fP, 
.br
			GBool(*\fIcb\fP)(GObjectId, GObjectId, GObjectId, GObjectId, GObjectId), 
.br
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoGraph::addLinkPrecond(GBool(*\fIcb\fP)
.br
		(void*, GoGraph*, GoGraphNode*, GoGraphNode*, GoMetaclass*), 
.br
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoAddGraphLinkPostcond\fP(GObjectId \fIgraph\fP, 
.br
			void(*\fIcb\fP)(GObjectId, GObjectId, GObjectId, GObjectId, GObjectId), 
.br
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoGraph::addLinkPostcond(void(*\fIcb\fP)
.br
		(void*, GoGraph*, GoGraphNode*, GoGraphNode*, GoMetaclass*), 
.br
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoRemoveGraphLinkPrecond\fP(GObjectId \fIgraph\fP, 
.br
			GBool(*\fIcb\fP)(GObjectId, GObjectId, GObjectId), 
.br
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoGraph::removeLinkPrecond(GBool(*\fIcb\fP)
.br
			(void*, GoGraph*, GoLink*), 
.br
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoRemoveGraphLinkPostcond\fP(GObjectId \fIgraph\fP, 
.br
			void(*\fIcb\fP)(GObjectId, GObjectId, GObjectId), 
.br
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoGraph::removeLinkPostcond(void(*\fIcb\fP)
.br
			(void*, GoGraph*, GoLink*), 
.br
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
GObjectId \fBGoAddGraphNode\fP(GObjectId \fIgraph\fP, GObjectId \fInode\fP, GBool \fIis_previous\fP, 
.br
			GObjectId \fIlink_class\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoGraphNode* GoGraph::addNode(GoGraphNode* \fInode\fP, GBool \fIis_previous\fP, 
.br
			GoMetaclass* \fIlink_class\fP);
.RE
.sp 1
.IP
GBool \fBGoRemoveGraphNode\fP(GObjectId \fIgraph\fP, GObjectId \fInode\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBool GoGraph::removeNode(GoGraphNode* \fInode\fP);
.RE
.sp 1
.IP
GObjectId \fBGoAddGraphLink\fP(GObjectId \fIgraph\fP, GObjectId \fIprevious_node\fP,
.br
		GObjectId \fInext_node\fP, GObjectId \fIlinkclass\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoLink* GoGraph::addLink(GoGraphNode* \fIprevious_node\fP, 
.br
			GoGraphNode* \fInext_node\fP, GoMetaclass* \fIlinkclass\fP);
.RE
.sp 1
.IP
GBool \fBGoRemoveGraphLink\fP(GObjectId \fIgraph\fP, GObjectId \fIlink\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBool GoGraph::removeLink(GoLink* \fIlink\fP);
.RE
.sp 1
.IP
void \fBGoRotateGraph\fP(GObjectId \fIgraph\fP, GNumber \fIangle\fP, GPoint \fIcenter\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoGraph::rotateGraph(GNumber \fIangle\fP, GPoint& \fIcenter\fP);
.RE
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBGoGraphStruct\fP, \fBGoGraphNode\fP, \fBGoLink\fP classes.
.nrPN \n%
