.\" $Id: GraphNode.n,v 1.1.1.1 1992/03/18 09:38:51 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoGraphNode 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoGraphNode\fP \(em the graph node object class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/GraphNode.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGoGraphNode\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGoNode\fP class
.IP \(em 3
\fBGoGraphElement\fP class
.IP \(em 3
\fBGo\fP class.
.RE
.sp 1
.SH
\fBDESCRIPTION\fP
.IP
A GoGraphNode instance has previous nodes, next nodes, previous links and next links.
.br
Each node may be detach from a node and reattach to another node. Each node may be moved from a graph to another graph.
.IP
.nf
.ta .15i .25i 1.0i
class GoGraphNode {
	public:
		// getting values;
		GoGraphNode** nextNode() const;
		GoGraphNode** previousNode() const;
		GoGraphNode** allNode() const;
		GoLink** nextLink() const;
		GoLink** previousLink() const;
		GoLink** allLink() const;
		GoLink* link(const GoGraphNode* \fIother_node\fP) const;
		ushort nbPreviousLink() const;
		ushort nbNextLink() const;

		// pre and post conditions;
		void attachNodePrecond(GBool (*)\fIfunction\fP(void*, GoGraphNode*, GoGraphNode*, GBool*, 
.br
					GoMetaclass*, GoGraph*), void* \fIclosure\fP, GAddOrRemove = GADD);
		void attachNodePostcond(void (*)\fIfunction\fP(void*, GoGraphNode*, GoGraphNode*, GBool*, 
.br
					GoMetaclass*, GoGraph*), void* \fIclosure\fP, GAddOrRemove = GADD);
		
		// others;
		GoGraphNode();

		static GoMetaclass* metaclass();
		static GoGraphNode* create();

		GBool attachNode(GoGraphNode* \fInew_extrem\fP, GBool \fIis_previous\fP = GTRUE, 
.br
					GoMetaclass* \fIlinkclass\fP = NULL, GoGraph* \fInew_graph\fP = NULL);
};
.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
GoGraphNode** \fBnextNode\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
.br
This method returns a pointer on an array filled with the node's next nodes. The last element of the array is NULL. It is the application's responsability to free this array.
.RE
.sp 1
.IP
GoGraphNode** \fBpreviousNode\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
.br
This method returns a pointer on an array filled with the node's previous nodes. The last element of the array is NULL. It is the application's responsability to free this array.
.RE
.sp 1
.IP
GoGraphNode** \fBallNode\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
.br
This method returns a pointer on an array filled with all nodes connected to the node. The last element of the array Is NULL. It is the application's responsability to free this array.
.RE
.sp 1
.IP
GoLink** \fBnextLink\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
.br
This method returns a pointer on an array filled with the node's next links. The last element of the array is NULL. It is the application's responsability to free this array.
.RE
.sp1
.IP
GoLink** \fBpreviousLink\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
.br
This method returns a pointer on an array filled with the node's previous links. The last element of the array is NULL. It is the application's responsability to free this array.
.RE
.sp1
.IP
GoLink** \fBallLink\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
.br
This method returns a pointer on an array filled with all links connected to the node. The last element of the array is NULL. It is the application's responsability to free this array.
.RE
.sp 1
.IP
GoLink* \fBlink\fP(const GoGraphNode* \fIother_node\fP) const;
.RS .8i
.IP \fIDescription\fP .5i
.br
This method returns the link connected between this node and \fIother_node\fP.
.IP \fIother_node\fP .5i
.br
Specifies the second extremity of the desired link.
.RE
.sp 1
.IP
ushort \fBnbPreviousLink\fP();
.RS .8i
.IP \fIDescription\fP .5i
.br
Returns the number of previous links of the node.
.RE
.sp 1
.IP
ushort \fBnbNextLink\fP();
.RS .8i
.IP \fIDescription\fP .5i
.br
Returns the number of next links of the node.
.RE
.sp 1
.IP
.nf
void \fBattachNodePrecond\fP (GBool (*\fIproc\fP)(void* \fIclosure\fP, GoGraphNode* \fInode\fP, GoGraphNode* \fInew_extrem\fP, 
.br
						GBool* \fIis_previous\fP, GoMetaclass* \fIlinkclass\fP, GoGraph* \fInew_graph\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBattachNodePostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GoGraphNode* \fInode\fP, GoGraphNode* \fInew_extrem\fP, 
.br
						GBool* \fIis_previous\fP, GoMetaclass* \fIlinkclass\fP, GoGraph* \fInew_graph\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or to remove pre or postcondition procedures when a node is attached to a \fInew_extrem\fP node or a \fInew_graph\fP.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when a node will be attached to a \fInew_extrem\fP or a \fInew_graph\fP. The precondition procedure is
called before the node is attached. It can either accept or refuse the modification.
The postcondition procedure is invoked after the node is attached.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the pre/postcondition procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the modify
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp 1
.IP
\fBGoGraphNode\fP();
.RS .8i
.IP \fIDescription\fP .5i
This method allows to create a new instance of the \fIGoGraphNode\fP class.
.RE
.sp 1
.IP
static GoMetaclass* \fBmetaclass\fP();
.RS .8i
.IP \fIDescription\fP .5i
Returns a pointer to the metaclass object of the \fIthis\fP.
.RE
.sp1
.IP
static GoGraphNode* \fBcreate\fP();
.RS .8i
.IP \fIDescription\fP .5i
Creates a new GoGraphNode instance. Returns the created node.
.RE
.sp1
.IP
GBool \fBattachNode\fP(GoGraphNode* \fInew_extrem\fP, GBool \fIis_previous\fP, GoMetaclass* \fIlinkclass\fP, GoGraph* \fInew_graph\fP);
.RS .8i
.IP \fIDescription\fP .5i
.br
Allows to change the node's extrem node or to "reparent" the node to another graph. Also allows to attach a node created by the GoGraphNodeClass::create() method to a graph.
.br
All links connected to the node are removed. A new link is created to connect the node to \fInew_extrem\fP.
.br
This method returns GFALSE is an error occurred, otherwise it returns GTRUE.
.IP \fInew_extrem\fP .5i
.br
Specifies the new extrem node. If \fInew_extrem\fP is NULL, \fInew_graph\fP must be specified.
.IP \fIis_previous\fP .5i
.br
If GTRUE, \fInew_extrem\fP is a previous node of the node, otherwise \fInew_extrem\fP is a next node of the node.
.br
Default value is GTRUE.
.IP \fIlinkclass\fP .5i
.br
Specifies the class of the link created to connect the node to its new extrem node. The default value is NULL. In this case the \fIlinkclass\fP is the class returned by the \fIdefaultLinkType()\fP method of GoGraphStruct class.
.IP \fInew_graph\fP .5i
.br
Specifies the new graph to attach node. This parameter is only checked if \fInew_extrem\fP is NULL. In this case the node will have no extrem node and no link will be created.
.RE
.sp 1
.RE
.sp 2
.SH
\fBUSER INTERACTION\fP
.IP
\fISee GoGraphNodeMetaclass (3Go)\fP.
.RE
.sp 2
.SH
\fBC BINDING\fP
.SS 
\fBHeader\fP
.IP
#include <Go/cGraphNode.h>
.DE
.SS 
\fBResources\fP
.IP
The following table defines a set of Go resources used by the programmer
to specify data.  The programmer can also set the resource values for the 
inherited classes to set attributes for this object.
The codes in the access column indicate if the given resource can be set by using \fBGoSetValues\fP (\fBS\fP), retrieved by using \fBGoGetValues\fP (\fBG\fP), or is not applicable (\fBN/A\fP).
.br
For superclass resources, see superclass man pages.
.br
See also Section 2.
.sp 1
.ps 8
.DS
.TS
center box;
cB sss
lB lB lB lB
l l l l.
GoGraphNode Resource GSet
.sp
=
Name	Type	Default	Access
.sp
_
goNallLink	GObjectId	dynamic	G
goNallNode	GObjectId	dynamic	G
goNnbNextLink	int	dynamic	G
goNnbPreviousLink	int	dynamic	G
goNnextLink	GObjectId	dynamic	G
goNnextNode	GObjectId	dynamic	G
goNpreviousLink	GObjectId	dynamic	G
goNpreviousNode	GObjectId	dynamic	G
.TE
.DE
.ps 10

.SS 
\fBFunctions\fP
.IP
void \fBGoGraphNodeInitialize\fP();
.RS .8i
.IP \fIDescription\fP .5i
This function must be called before any use of the GoGraphNode C Binding.
.RE
.sp 1
.IP
GObjectId \fBGoCreateGoGraphNode\fP();
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoGraphNode* GoGraphNode::create().
.RE
.sp 1
.IP
GObjectId \fBGoGraphNodeMetaclass\fP();
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoMetaclass* GoGraphNode::metaclass().
.RE
.sp 1
.IP
GObjectId \fBGoGetNextGraphNode\fP(GObjectId \fInode\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoGraphNode** GoGraphNode::nextNode().
.RE
.sp 1
.IP
GObjectId \fBGoGetPreviousGraphNode\fP(GObjectId \fInode\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoGraphNode** GoGraphNode::previousNode().
.RE
.sp 1
.IP
GObjectId \fBGoGetAllGraphNode\fP(GObjectId \fInode\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoGraphNode** GoGraphNode::allNode().
.RE
.sp 1
.IP
GObjectId \fBGoGetGraphNodeNextLink\fP(GObjectId \fInode\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoLink** GoGraphNode::nextLink().
.RE
.sp 1
.IP
GObjectId \fBGoGetGraphNodePreviousLink\fP(GObjectId \fInode\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoLink** GoGraphNode::previousLink().
.RE
.sp 1
.IP
GObjectId \fBGoGetGraphNodeAllLink\fP(GObjectId \fInode\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoLink** GoGraphNode::allLink().
.RE
.sp 1
.IP
ushort \fBGoGetGraphNodeNbPreviousLink\fP(GObjectId \fInode\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP ushort GoGraphNode::nbPreviousLink().
.RE
.sp 1
.IP
ushort \fBGoGetGraphNodeNbNextLink\fP(GObjectId \fInode\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP ushort GoGraphNode::nbNextLink().
.RE
.sp 1
.IP
void \fBGoAttachGraphNodePrecond\fP(GObjectId \fInode\fP, 
.br
	GBool(*\fIcb\fP)(GObjectId, GObjectId, GObjectId, GBool*, GObjectId, 
.br
	GObjectId), GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoGraphNode::attachNodePrecond(GBool (*\fIcb\fP)
.br
	(void*, GoGraphNode*, GoGraphNode*, GBool*, GoMetaclass*, 
.br
	GoGraph*),
.br
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoAttachGraphNodePostcond\fP(GObjectId \fInode\fP, 
.br
	void(*\fIcb\fP)(GObjectId, GObjectId, GObjectId, GBool*, GObjectId, GObjectId), 
.br
	GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoGraphNode::attachNodePostcond(void (*\fIcb\fP)
.br
	(void*, GoGraphNode*, GoGraphNode*, GBool*, GoMetaclass*, 
.br
	GoGraph*),
.br
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
GBool \fBGoAttachGraphNode\fP(GObjectId \fInode\fP, GObjectId \fIextremNode\fP, GBool \fIisPrevious\fP, GObjectId \fIlinkclass\fP, GObjectId \fIgraph\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBool GoGraphNode::attachNode(GoGraphNode* \fIextremNode\fP, 
.br
	GBool \fIisPrevious\fP, GoMetaclass* \fIlinkclass\fP, GoGraph* \fIgraph\fP).
.RE
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBGoGraph\fP, \fBGoGraphElement\fP, \fBGoNode\fP and \fBGoLink\fP classes.
.nrPN \n%
