.\" $Id: GraphStr.n,v 1.1.1.1 1992/03/18 09:38:56 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoGraphStruct 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoGraphStruct\fP \(em the graph structure object abstract class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/GraphStr.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGoGraphStruct\fP inherits behavior from the \fBGo\fP class.
.sp 1
.SH
\fBDESCRIPTION\fP
.IP
The \fBGoGraphStruct\fP class is the common superclass for tree and graph graphic objects, so it defines common characteristics.
.br
Tree and graph objects are defined a set of nodes connected by links, and they guarantee the link-node connection when nodes are moved. Many link-node connection types and link types are provided.
.br
The application defines the default link type used for creating links. But in each method, the default link type can be overriden.
.br
A method to call node placement algorithm is provided. The tree object defines four placement algorithms, but the application may define its own algorithm.
.br
Tree and graph objects may have a background.
.IP
.nf
.ta .15i .25i 1.0i
class GoGraphStruct {
	public:
		// getting values;
		const GoNode* firstNode() const;
		ushort numberNodes() const;
		ushort numberLinks() const;
		GBool background() const;
		GBrush& brush() const;
		ushort positionType() const;
		ushort anchoringType() const;
		GoMetaclass* defaultLinkType() const;

		// setting values;
		void background(GBool \fIback\fP);
		GBool positionType(ushort \fIposition\fP);
		GBool anchoringType(ushort \fItype\fP);
		GBool defaultLinkType(GoMetaclass* \fItype\fP);
		void applicationFunction(void (*)(void*, Go*, GoNode*, const GPoint&)\fIfunction\fP, void* \fIclosure\fP);
		
		// others;
		static GoMetaclass* metaclass();

		void makePosition(GoNode* \fInode\fP = NULL, const GPoint& \fIpoint\fp = *(GPoint*)NULL);
};
.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
int \fBfirstNode\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
Returns the root node if the object is a tree object, or the first node which was added if the object is a graph object.
.RE
.sp 1
.IP
ushort \fBnumberNodes\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
Returns the number of nodes belonging to graph or tree object.
.RE
.sp 1
.IP
ushort \fBnumberLinks\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
Returns the number of links belonging to graph or tree object.
.RE
.sp 1
.IP
GBool \fBbackground\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
Returns GTRUE if the graph or tree object has a background, otherwise this function returns GFALSE.
.RE
.sp 1
.IP
GBrush& \fBbrush\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
Returns the brush instance used to draw the background.
.RE
.sp 1
.IP
ushort \fBpositionType\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
Indicates how the object is displayed when the \fImakePosition\fP 
function is called.
.br
The returned value is only significant when the graphic object is a tree 
object. If the object is a graph object, \fImakePosition\fP method always calls the application's algorithm.
.br
Values are :
.RS 8
.IP \(em 3
\fBGLEFT_TO_RIGHT\fP : call a predefined algorithm.
.IP \(em 3
\fBGRIGHT_TO_LEFT\fP : call a predefined algorithm.
.IP \(em 3
\fBGUP_TO_BOTTOM\fP : call a predefined algorithm.
.IP \(em 3
\fBGBOTTOM_TO_UP\fP : call a predefined algorithm.
.IP \(em 3
\fBGAPPLICATION_DEFINE\fP : call the application's algorithm.
.RE 2
The default value is \fBGUP_TO_BOTTOM\fP.
.RE
.sp 1
.IP
ushort \fBanchoringType\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
Indicates the link-node connection type.
.br
Values are :
.RS 8
.IP \(em 3
\fBGCENTER\fP : link is hooked on the center of the node clip.
.IP \(em 3
\fBGANGLE\fP : link is hooked on a angle of the node clip.
.IP \(em 3
\fBGMIDDLE_WIDTH\fP : link is hooked on the middle width of the node clip.
.IP \(em 3
\fBGMIDDLE_HEIGHT\fP : link is hooked on the middle height of the node clip.
.RE 2
The default value is \fBGCENTER\fP.
.RE
.sp 1
.IP
GoMetaclass* \fBdefaultLinkType\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
Indicates the default link type used for creating links (if it is not overriden).
.br
Default value for defaultLinkType() is goLinkClass.
.RE
.sp 1
.IP
void \fBbackground\fP(GBool \fIback\fP) const;
.RS .8i
.IP \fIDescription\fP .5i
This method allows to make the background visible or unvisible.
.IP \fIback\fP .5i
If GTRUE, the background will be visible.
If GFALSE, the background will be unvisible.
.br
.RE
.sp 1
.IP
GBool \fBpositionType\fP(ushort \fIposition\fP) const;
.RS .8i
.IP \fIDescription\fP .5i
Specifies which algorithm will be used to display the tree (and only tree) object. Returns GFALSE if an error occured, otherwise returns GTRUE.
.br
.IP \fIposition\fP .5i
.br
Values are :
.RS 8
.IP \(em 3
\fBGLEFT_TO_RIGHT\fP
.IP \(em 3
\fBGRIGHT_TO_LEFT\fP
.IP \(em 3
\fBGUP_TO_BOTTOM\fP
.IP \(em 3
\fBGBOTTOM_TO_UP\fP
.IP \(em 3
\fBGAPPLICATION_DEFINE\fP : the application's algorithm will be used.
.RE 2
.RE
.sp 1
.IP
GBool \fBanchoringType\fP(ushort \fItype\fP) const;
.RS .8i
.IP \fIDescription\fP .5i
Specifies the link-node connection type. Returns GFALSE if an error occured, otherwise returns GTRUE.
.IP \fItype\fP .5i
.br
Values are :
.RS 8
.IP \(em 3
\fBGCENTER\fP
.IP \(em 3
\fBGANGLE\fP
.IP \(em 3
\fBGMIDDLE_WIDTH\fP
.IP \(em 3
\fBGMIDDLE_HEIGHT\fP
.RE 2
.RE
.sp 1
.IP
GBool \fBdefaultLinkType\fP(GoMetaclass* \fItype\fP) const;
.RS .8i
.IP \fIDescription\fP .5i
Specifies which default link class will be used to create links. Returns GFALSE if an error occured, otherwise returns GTRUE.
.IP \fItype\fP
.br
Must be a instance of link class (goLinkClass, goSimpleLinkClass ...).
.RE
.sp 1
.IP
int \fBapplicationFunction\fP(void (*)(void* \fIclos\fP, Go* \fIobject\fP, GoNode* \fIfirst_node\fP, const GPoint& \fIpoint\fP)\fIfunction\fP, void* \fIclosure\fP);
.RS .8i
.IP \fIDescription\fP .5i
Gives to the tree or graph object the application's placement algorithm.
.IP \fIfunction\fP .5i
Specifies the application's function. This function must have four parameters.
.br
Parameters are :
.RS 1.0i
.IP \(em 3
\fIclos\fP : the closure.
.IP \(em 3
\fIobject\fP : the tree or graph object.
.IP \(em 3
\fIfirst_node\fP : the first node to be placed (not necessarily the first node of the tree or graph object).
.IP \(em 3
\fIpoint\fP : the point where the \fIfirst_ node\fP have to be placed.
.RE 2
.IP \fIclosure\fP .5i
.br
Specifies which closure has to be passed as first parameter of the application's function.
.RE
.sp 1
.IP
static GoMetaclass* \fBmetaclass\fP();
.RS .8i
.IP \fIDescription\fP .5i
Returns a pointer to the metaclass object of the \fIthis\fP.
.RE
.sp1
.IP
int \fBmakePosition\fP(GoNode* \fInode\fP = NULL, const GPoint& \fIpoint\fP);
.RS .8i
.IP \fIDescription\fP .5i
Calls the algorithm to place nodes and links.
.IP \fInode\fP .5i
.br
Specifies the first node to be placed.
.br
The default value is the "firstNode()".
.IP \fIpoint\fP .5i
.br
Specifies the position of \fInode\fP.
.RE
.sp 1
.RE
.sp 2
.SH
\fBUSER INTERACTION\fP
.IP
\fISee GoGraphStructMetaclass(3Go)\fP.
.RE
.sp 2
.SH
\fBC BINDING\fP
.SS 
\fBHeader\fP
.IP
#include <Go/cGraphStr.h>
.DE
.SS 
\fBResources\fP
.IP
The following table defines a set of Go resources used by the programmer
to specify data.  The programmer can also set the resource values for the 
inherited classes to set attributes for this object.
The codes in the access column indicate if the given resource can be set by using \fBGoSetValues\fP (\fBS\fP), retrieved by using \fBGoGetValues\fP (\fBG\fP), or is not applicable (\fBN/A\fP).
.br
For superclass resources, see superclass man pages.
.br
See also Section 2.
.sp 1
.ps 8
.DS
.TS
center box;
cB sss
lB lB lB lB
l l l l.
GoGraphStruct Resource GSet
.sp
=
Name	Type	Default	Access
.sp
_
goNanchoringType	ushort	GCENTER	CSG
goNbackground	GBool	GFALSE	SG
goNbrush	GObjectId	dynamic	G
goNdefaultLinkType	GObjectId	GoLink	SG
goNfirstNode	GObjectId	dynamic	G
goNnumberLinks	int	dynamic	G
goNnumberNodes	int	dynamic	G
goNpositionType	ushort	GLEFT_TO_RIGHT	SG
.TE
.DE
.ps 10

.SS 
\fBFunctions\fP
.IP
GBool \fBGoSetGraphStructPositionType\fP(GObjectId \fIgraphstruct\fP, ushort \fIposition\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBool GoGraphStruct::positionType(ushort \fIposition\fP).
.RE
.sp 1
.IP
GBool \fBGoSetGraphStructAnchoringType\fP(GObjectId \fIgraphstruct\fP, ushort \fItype\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBool GoGraphStruct::anchoringType(ushort \fItype\fP).
.RE
.sp 1
.IP
void \fBGoSetGraphStructBackground\fP(GObjectId \fIgraphstruct\fP, GBool \fIyes\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoGraphStruct::background(GBool \fIyes\fP).
.RE
.sp 1
.IP
GBool \fBGoSetGraphStructDefaultLinkType\fP(GObjectId \fIgraphstruct\fP, GObjectId \fIlink_type\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBool GoGraphStruct::defaultLinkType(GoMetaclass* \fIlink_type\fP).
.RE
.sp 1
.IP
void \fBGoSetGraphStructApplicationFunction\fP(GObjectId \fIgraphstruct\fP, 
.br
		void(*\fIcb\fP)(GObjectId, GObjectId, GObjectId, const GPoint*), 
.br
		GObjectId \fIclosure\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoGraphStruct::applicationFunction(void(*\fIcb\fP)
.br
		(void*, Go*, GoNode*, const GPoint&), 
.br
		void* \fIclosure\fP).
.RE
.sp 1
.IP
GObjectId \fBGoGetGraphStructBrush\fP(GObjectId \fIgraphstruct\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBrush& GoGraphStruct::brush().
.RE
.sp 1
.IP
GObjectId \fBGoGetGraphStructFirstNode\fP(GObjectId \fIgraphstruct\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoNode* GoGraphStruct::firstNode().
.RE
.sp 1
.IP
ushort \fBGoGetGraphStructNumberNodes\fP(GObjectId \fIgraphstruct\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP ushort GoGraphStruct::numberNodes().
.RE
.sp 1
.IP
ushort \fBGoGetGraphStructNumberLinks\fP(GObjectId \fIgraphstruct\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP ushort GoGraphStruct::numberLinks().
.RE
.sp 1
.IP
ushort \fBGoGetGraphStructPositionType\fP(GObjectId \fIgraphstruct\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP ushort GoGraphStruct::positionType().
.RE
.sp 1
.IP
ushort \fBGoGetGraphStructAnchoringType\fP(GObjectId \fIgraphstruct\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP ushort GoGraphStruct::anchoringType().
.RE
.sp 1
.IP
GBool \fBGoGetGraphStructBackground\fP(GObjectId \fIgraphstruct\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBool GoGraphStruct::background().
.RE
.sp 1
.IP
GObjectId \fBGoGetGraphStructDefaultLinkType\fP(GObjectId \fIgraphstruct\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoMetaclass* GoGraphStruct::defaultLinkType().
.RE
.sp 1
.IP
void \fBGoGraphStructMakePosition\fP(GObjectId \fIgraphstruct\fP, GObjectId \fInode\fP, GPoint \fIpoint\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoGraphStruct::makePosition(GoNode* \fInode\fP, const GPoint& \fIpoint\fP).
.RE
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
\fIGoGraphStruct\fP instances cannot be directly created but \fIGoGraphStruct\fP subclass instances, this explains why there are not public constructors.
.sp 2
.SH
\fBSEE ALSO\fP
.IP
\fBGoTree\fP, \fBGoGraph\fP classes.
.nrPN \n%
