.\" $Id: Image.n,v 1.3 1992/12/31 15:03:05 mbikina Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991, 1992 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoImage 3Go "December 1992" "Version 1.2" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoImage\fP \(em the image object class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Image.h>\fP
.SH 
\fBCLASS\fP
.IP
\fBGoImage\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGoStdDS\fP class
.IP \(em 3
\fBGo\fP class.
.RE
.SH
\fBDESCRIPTION\fP
.IP
A \fBGoImage\fP object is one of the basic graphic objects, subclass of
\fBGoStdDS\fP. It handles a single image. The image itself is defined by a
\fIpixelArray\fP and an \fIimageBrush\fP. Load a new image is equivalent to
modify the current \fIpixelArray\fP and/or the current \fIimagebrush\fP.
The geometry is defined first by the \fIcoordsys\fP and by three values:
\fIwidth\fP, \fPheight\fP, \fPorigin\fP.
.IP
The origin of the coordinate system is the upper left corner of the image,
according to the parent coordsyst, and the edges are parallel to the axes.
.sp 1
.br
.nf
.ta .15i .25i 1.0i
class GoImage : public GoStdDS {

	public:

		static GoImageMetaclass* metaclass ();
		static GoImage* create ();
		static GoImage* create (const ShImageBrush* \fIib\fP, 
					const ShPixelArray* \fIpa\fP);

		GoImage (const ShImageBrush* \fIib\fP = NULL,
			 const ShPixelArray* \fIpa\fP = NULL);
		/*
		 * \fBget the image parameters: \fP
		 */
		GNumber       width      () const;
		GNumber       height     () const;
		const  Point& origin     () const;
		ImageBrush&   imageBrush () const;
		PixelArray&   pixelArray () const;

		/*
		 * \fBset the geometry parameter: \fP
		 */

		void   config (GNumber \fIwidth\fP = -1, GNumber \fIheight\fP = -1,
				const Point* \fIorigin\fP = NULL);

		/*
		 * \fBpre and post conditions:\fP
		 */

		void configPrecond (bool \fIproc\fP(void* \fIclosure\fP,
						const GoImage* \fIimage\fP,
						GNumber* \fInew_w\fP, GNumber* \fInew_h\fP,
						Point* \fInew_origin\fP),
				void* \fIclosure\fP, AddOrRemove  \fIadd\fP = ADD);
		void configPostcond (void \fIproc\fP(void* \fIclosure\fP,
						GoImage* \fIimage\fP),
				void* \fIclosure\fP, AddOrRemove  \fIadd\fP = ADD);

		/*
		 * \fBpre conditions calls:\fP
		 */
		GBool callConfigPrecond(GNumber*, GNumber*, GPoint*) const;

};
.fi
.SH
\fBPUBLIC METHODS\fP
.IP
\fBGoImageMetaclass\fP* \fBmetaclass\fP ()
.RS .8i
.IP \fIDescription\fP .5i
This static member function returns the \fBGoImageMetaclass\fP instance.
.RE
.sp 1
.IP
\fBGoImage\fP* \fBcreate\fP ()
.br
\fBGoImage\fP* \fBcreate\fP (const ShImageBrush* \fIib\fP, const ShPixelArray* \fIpa\fP)
.RS .8i
.IP \fIDescription\fP .5i
These static member functions are constructors with pre/postconditions.
They return a pointer on a new instance of \fBGoImage\fP if no precondition
refuses the creation, else they return NULL. The \fIcreate\fP without parameters
is equivalent to the \fIcreate\fP with two NULL parameters.
.IP \fIib\fP .5i
Specifies the image \fIimagebrush\fP. It may be NULL.
.IP \fIpa\fP .5i
Specifies the image \fIpixelarray\fP. It may be NULL.
.RE
.sp 1
.IP
\fBGoImage\fP(const ShImageBrush* \fIib\fP = NULL, const ShPixelArray* \fIpa\fP = NULL)
.RS .8i
.IP \fIDescription\fP .5i
Constructor.
.IP \fIib\fP .5i
Specifies the image \fIimagebrush\fP.
.IP \fIpa\fP .5i
Specifies the image \fIpixelarray\fP.
.RE
.sp 1
.IP
GNumber \fBwidth\fP() const;
.br
GNumber \fBheight\fP() const;
.br
const Point& \fBorigin\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
These methods return the image configuration.
.RE
.sp 1
.IP
void \fBconfig\fP(GNumber \fIw\fP = -1, GNumber \fIh\fP = -1, const Point* \fIorigin\fP = NULL)
.RS .8i
.IP \fIDescription\fP .5i
This method modifies the image geometry (but not its coordinate system).
.IP \fIw\fP .5i
Specifies the new width. -1 means that the current width will not be modified except by \fIconfigPrecond\fP if any.
.IP \fIh\fP .5i
Specifies the new height. -1 means that the current height will not be modified except by \fIconfigPrecond\fP if any.
.IP \fIorigin\fP .5i
Specifies the new origin. NULL means that the current origin will not be modified except by \fIconfigPrecond\fP if any.
.RE
.IP
.nf
ImageBrush&   \fBimageBrush\fP () const;
PixelArray&   \fBpixelArray\fP () const;
.fi
.RS .8i
.IP \fIDescription\fP .3i
These functions return a reference to the ImageBrush (resp PixelArray) of the object.
.RE
.sp 1
.IP
.nf
void \fBconfigPrecond\fP (bool \fIproc\fP(void* \fIclosure\fP, const GoImage* \fIimage\fP,
					GNumber* \fInew_w\fP,
					GNumber* \fInew_h\fP,
					Point* \fInew_origin\fP),
			void* \fIclosure\fP, AddOrRemove \fIadd\fP = ADD) const;

void \fBconfigPostcond\fP (void \fIproc\fP(void* \fIclosure\fP, GoImage* \fIimage\fP),
			void* \fIclosure\fP, AddOrRemove \fIadd\fP = ADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or remove functions to the pre/post conditions lists
triggered by \fBconfig\fP (GNumber, GNumber, const Point*) member functions.
.IP \fIproc\fP .5i
Specifies programmer's function to be added/removed.
.IP \fIclosure\fP .5i
Specifies programmer's parameter to call the function with.
.IP \fIimage\fP .5i
Specifies the \fBGoImage\fP object involved (i.e. \fIthis\fP).
.IP \fInew_w\fP .5i
Specifies the new width. May be modified by \fIproc\fP.
.IP \fInew_h\fP .5i
Specifies the new height. May be modified by \fIproc\fP.
.IP \fInew_origin\fP .5i
Specifies the new origin. May be modified by \fIproc\fP.
.IP \fIadd\fP .5i
Specifies whether to add or remove the function \fIproc\fP from the list.
.RE
.sp 1
.IP
.nf
GBool \fBcallConfigPrecond\fP(GNumber*, GNumber*, GPoint*) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method call the corresponding pre condition.
.RE
.SH
\fBC BINDING\fP
.SS
\fBHeader\fP
.IP
#include <Go/cImage.h>
.DE
.SS
\fBResources\fP
.IP
The following table defines a set of Go resources used by the programmer
to specify data.  The programmer can also set the resource values for the 
inherited classes to set attributes for this object.
The codes in the access column indicate if the given resource can be set by using \fBGoSetValues\fP (\fBS\fP), retrieved by using \fBGoGetValues\fP (\fBG\fP), or is not applicable (\fBN/A\fP).
.br
For superclass resources, see superclass man pages.
.br
.sp 1
.ps 8
.DS
.TS
center box;
cB sss
lB lB lB lB
l l l l.
GoImage Resource Set
.sp
Name	Type	Default	Access
.sp
_
goNwidth	GNumber	1	SG
goNheight	GNumber	1	SG
goNorigin	ObjectId	Point(0,0)	SG
goNpixelArray	ObjectId	DefaultPixelArray	G
goNimageBrush	ObjectId	DefaultImageBrush	G
.TE
.DE
.ps 10
.SH
\fBFunctions\fP
.IP
ObjectId GoImageInitialize();
.RS .8i
.IP \fIDescription\fP .5i
The function initializes the C interface of the GoImage.
.RE
.sp 1
.IP
ObjectId CreateGoImage (ObjectId \fIsh_ib\fP, ObjectId \fIsh_pa\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fIsee\fP GoImage::create(const ShImageBrush* \fIsh_ib\fP, const ShPixelArray* \fIsh_pa\fP);
.RE
.sp 1
.nf
	GNumber		\fBGoImageWidth\fP(ObjectId \fIgoimage\fP);
	GNumber		\fBGoImageHeight\fP(ObjectId \fIgoimage\fP);
	const Point*	\fBGoImageOrigin\fP(ObjectId \fIgoimage\fP);
	PixelArray*	\fBGoImagePixelArray\fP(ObjectId \fIgoimage\fP);
	ImageBrush*	\fBGoImageImageBrush\fP(ObjectId \fIgoimage\fP);
	void		\fBGoImageConfig\fP(ObjectId \fIgoimage\fP, GNumber \fIw\fP, GNumber \fIh\fP,
  				       Point* \fIorigin\fP);
	void		\fBGoImageConfigPrecond\fP(ObjectId \fIgoimage\fP, AddOrRemove \fIadd\fP,
					bool \fIfunc\fP(void*, ObjectId goimage,
						GNumber*, GNumber*,Point*),
					void* \fIclosure\fP);	
	void		\fBGoImageConfigPostcond\fP(ObjectId \fIgoimage\fP, AddOrRemove \fIadd\fP,
					void \fIfunc\fP(void*, ObjectId goimage),
					void* \fIclosure\fP);
.fi
.sp 1
.IP \fIDescription\fP .5i
\fIsee\fP the GoImage::\fIname\fP method.
.SH
\fBUSER INTERACTIONS\fP
.IP
The following strings may be associated with event description strings in GoUI
files to perform actions on \fBGoimage\fP objects (see \fBGoUI\fP
documentation for more information on this topic). Most of the time,
these strings refer to name-like public functions or have an obvious
signification, thus description will only be given if absolutely necessary.
.sp 1
\fBconfig\fP (GNumber, GNumber , const Point*)
.RS .8i
.IP \fIDescription\fP .5i
same as member function.
.RE
.SH
\fBUSAGE INFORMATION\fP
.IP
If willing to use pre/postconditions on object creation,
one should use \fBGoImage::create\fP instead of the public
\fBGoImage\fP constructor; this is highly recommended.
.SH
\fBSEE ALSO\fP
.IP
\fBGo\fP, \fBGoMetaclass\fP, \fBGoStdDS\fP, \fBGoStdDSMetaclass\fP,
.br
\fBGoImageMetaclass\fP, \fBImageBrush\fP, \fBPixelArray\fP.
.nrPN \n%
