.\" $Id: Link.n,v 1.1.1.1 1992/03/18 09:39:15 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoLink 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoLink\fP \(em the graph node link object class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Link.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGoLink\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGoLink\fP class
.IP \(em 3
\fBGoGraphElement\fP class
.IP \(em 3
\fBGo\fP class.
.RE
.sp 1
.SH
\fBDESCRIPTION\fP
.IP
GoLink instances allow to connect two nodes. A orientation is defined, so one of these nodes is above the other node, the first node is said the previous node and the second node is said the next node.
.br
Extremities of a link may be changed.
.br
GoLink instances do not draw anything themselves. The graphical appearance of a link is given by the Gos it contains (from Go hierarchy point of view). Thus, the graphical appearance of GoLinks can be structured graphics including geometric, textual and image objects. In addition, GoLinks can be dynamically editable by simply editing Go subtrees.
.IP
.nf
.ta .15i .25i 1.0i
class GoLink {
	public:
		// getting values;
		GoNode* nextNode();
		GoNode* previousNode();
		GPoint nextPoint();
		GPoint previousPoint();
		GPen& pen();

		// pre and post conditions;
		void attachLinkPrecond(GBool (*)\fIfunction\fP(void*, GoLink*, GoGraphNode*, GoGraphNode*), 
.br
								void* \fIclosure\fP, GAddOrRemove = GADD);
		void attachLinkPostcond(void (*)\fIfunction\fP(void*, GoLink*, GoGraphNode*, GoGraphNode*), 
.br
					void* \fIclosure\fP, GAddOrRemove = GADD);
		void anchoringPointModifyPrecond(void (*)\fIfunction\fP(void*, GoLink*, GPoint*, GPoint*), void* \fIclosure\fP, 
.br
					GAddOrRemove = GADD);
		void anchoringPointModifyPostcond(void (*)\fIfunction\fP(void*, GoLink*, GPoint*, GPoint*), void* \fIclosure\fP, 
.br
					GAddOrRemove = GADD);
		
		// others;
		GoLink();

		static GoMetaclass* metaclass();
		static GoLink* create();

		GBool attachLink(GoGraphNode* \fIprev\fP, GoGraphNode* \fInext\fP = NULL);
};
.fi
.sp 1
.SH
\fBPUBLIC MEMBERS\fP
.IP
GoNode* \fBnextNode\fP();
.RS .8i
.IP \fIDescription\fP .5i
.br
This method returns the next node attached to the link.
.RE
.sp 1
.IP
GoNode* \fBpreviousNode\fP();
.RS .8i
.IP \fIDescription\fP .5i
.br
This method returns the previous node attached to the node.
.RE
.sp 1
.IP
GPoint \fBnextPoint\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
.br
This method returns the connecting point between the link and its next node.
.RE
.sp 1
.IP
GPoint \fBpreviousPoint\fP();
.RS .8i
.IP \fIDescription\fP .5i
.br
This method returns the connecting point between the link and its next node.
.RE
.sp 1
.IP
GPen& \fBpen\fP();
.RS .8i
.IP \fIDescription\fP .5i
.br
This method returns the pen reference used to draw the link (necessary for the subclasses of GoLink class).
.RE
.sp 1
.IP
.nf
void \fBattachLinkPrecond\fP (GBool (*\fIproc\fP)(void* \fIclosure\fP, GoLink* \fIlink\fP, GoGraphNode* \fInew_prev\fP, 
.br
						GoGraphNode* \fInew_next\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBattachLinkPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GoLink* \fIlink\fP, GoGraphNode* \fInew_prev\fP, 
.br
						GoGraphNode* \fInew_next\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or to remove pre or postcondition procedures when a link is attached to a \fInew_prev\fP node and a \fInew_next\fP node.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when a link will be attached to a \fInew_prev\fP node and a \fInew_next\fP node. The precondition procedure is
called before the link is attached. It can either accept or refuse the modification.
The postcondition procedure is invoked after the link is attached.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the pre/postcondition procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the modify
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp 1
.IP
.nf
void \fBanchoringPointModifyPrecond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GoLink* \fIlink\fP, GPoint* \fIprev_point\fP,
.br
					GPoint* \fInext_point\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or to remove precondition procedures when connecting points between link and its extrem nodes are modified.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the connecting points will be modified.
The precondition procedure is invoked before connecting points are modified, and user can modify the new connecting points.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the postcondition procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the modify
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp 1
.IP
.nf
void \fBanchoringPointModifyPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GoLink* \fIlink\fP, GPoint* \fIprev_point\fP,
.br
					GPoint* \fInext_point\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or to remove postcondition procedures when connecting points between link and its extrem nodes are modified.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the connecting points will be modified.
The postcondition procedure is invoked after connecting points are modified.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the postcondition procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the modify
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp 1
.IP
\fBGoLink\fP();
.RS .8i
.IP \fIDescription\fP .5i
This method allows to create a new instance of the \fIGoLink\fP class.
.RE
.sp 1
.IP
static GoMetaclass* \fBmetaclass\fP();
.RS .8i
.IP \fIDescription\fP .5i
Returns a pointer to the metaclass object of the \fIthis\fP.
.RE
.sp1
.IP
static GoLink* \fBcreate\fP();
.RS .8i
.IP \fIDescription\fP .5i
Creates a new GoLink instance. Returns the created link.
.RE
.sp1
.IP
GBool \fBattachLink\fP(GoGraphNode* \fIprev\fP, GoGraphNode* \fInext\fP);
.RS .8i
.IP \fIDescription\fP .5i
.br
Allows to change extrem nodes of a link. Also allows to attach a link created by the GoLinkClass::create() method to a graph.
.br
This method returns GFALSE is an error occurred, otherwise it returns GTRUE.
.IP \fIprev\fP .5i
.br
Specifies the new previous node.
.IP \fInext\fP .5i
.br
Specifies the new next node.
.RE
.sp 1
.RE
.sp 2
.SH
\fBUSER INTERACTION\fP
.IP
No user interaction.
.RE
.sp 2
.SH
\fBC BINDING\fP
.SS 
\fBHeader\fP
.IP
#include <Go/cLink.h>
.DE
.SS 
\fBResources\fP
.IP
The following table defines a set of Go resources used by the programmer
to specify data.  The programmer can also set the resource values for the 
inherited classes to set attributes for this object.
The codes in the access column indicate if the given resource can be set by using \fBGoSetValues\fP (\fBS\fP), retrieved by using \fBGoGetValues\fP (\fBG\fP), or is not applicable (\fBN/A\fP).
.br
For superclass resources, see superclass man pages.
.br
See also Section 2.
.sp 1
.ps 8
.DS
.TS
center box;
cB sss
lB lB lB lB
l l l l.
GoLink Resource GSet
.sp
=
Name	Type	Default	Access
.sp
_
goNnextNode	GObjectId	dynamic	G
goNnextPoint	GPoint*	dynamic	G
goNpen	GObjectId	dynamic	G
goNpreviousNode	GObjectId	dynamic	G
goNpreviousPoint	GPoint*	dynamic	G
.TE
.DE
.ps 10

.SS 
\fBFunctions\fP
.IP
void \fBGoLinkInitialize\fP();
.RS .8i
.IP \fIDescription\fP .5i
This function must be called before any use of the GoLink C Binding.
.RE
.sp 1
.IP
GObjectId \fBGoCreateGoLink\fP();
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoLink* GoLink::create().
.RE
.sp 1
.IP
GObjectId \fBGoLinkMetaclass\fP();
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoMetaclass* GoLink::metaclass().
.RE
.sp 1
.IP
GObjectId \fBGoGetLinkPen\fP(GObjectId \fIlink\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GPen& GoLink::pen().
.RE
.sp 1
.IP
GObjectId \fBGoGetLinkPreviousNode\fP(GObjectId \fIlink\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoNode* GoLink::previousNode().
.RE
.sp 1
.IP
GObjectId \fBGoGetLinkNextNode\fP(GObjectId \fIlink\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoNode* GoLink::nextNode().
.RE
.sp 1
.IP
GPoint \fBGoGetLinkPreviousPoint\fP(GObjectId \fIlink\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GPoint GoLink::previousPoint().
.RE
.sp 1
.IP
GPoint \fBGoGetLinkNextPoint\fP(GObjectId \fIlink\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GPoint GoLink::nextPoint().
.RE
.sp 1
.IP
void \fBGoAttachLinkPrecond\fP(GObjectId \fIlink\fP, 
.br
		GBool (*\fIcb\fP)(GObjectId, GObjectId, GObjectId, GObjectId),
.br
		GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoLink::attachLinkPrecond(GBool (*\fIcb\fP)
.br
	(void*, GoLink*, GoGraphNode*, GoGraphNode*),
.br
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoAttachLinkPostcond\fP(GObjectId \fIlink\fP, 
.br
		void (*\fIcb\fP)(GObjectId, GObjectId, GObjectId, GObjectId),
.br
		GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoLink::attachLinkPostcond(void (*\fIcb\fP)
.br
	(void*, GoLink*, GoGraphNode*, GoGraphNode*),
.br
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoLinkAnchoringPointModifyPrecond\fP(GObjectId \fIlink\fP, 
.br
		void (*\fIcb\fP)(GObjectId, GObjectId, GObjectId, GObjectId),
.br
		GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoLink::anchoringPointModifyPrecond(void (*\fIcb\fP)
.br
		(void*, GoLink*, GPoint*, GPoint*),
.br
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoLinkAnchoringPointModifyPostcond\fP(GObjectId \fIlink\fP, 
.br
		void (*\fIcb\fP)(GObjectId, GObjectId, GObjectId, GObjectId),
.br
		GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoLink::anchoringPointModifyPostcond(void (*\fIcb\fP)
.br
		(void*, GoLink*, GPoint*, GPoint*),
.br
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
GBool \fBGoAttachLink\fP(GObjectId \fIlink\fP, GObjectId \fIpreviousNode\fP, GObjectId \fInextNode\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBool GoLink::attachLink(GoGraphNode* \fIpreviousNode\fP, 
.br
		GoGraphNode* \fInextNode\fP).
.RE
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBGoSimpleLink\fP, \fBGoBusLink\fP classes.
.nrPN \n%
