.\" $Id: MBForm.n,v 1.2 1992/12/28 10:33:23 andre Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH MBFormatter 3Go "December 1992" "Version 1.2" "Go Reference Manual"
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBMBFormatter\fP \(em The multi-boxes formatter class
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/MBForm.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGMBFormatter\fP inherits behavior from class \fBGFrFormatter\fP.
.RS 10
.RE
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
When linked with a \fBGMBFormatter\fP, a \fBGoText\fP is confined inside a list of boxes.
.br
The \fBGoUI\fP object provides functions to change interactively the formatter (add, remove, move or reframe a box).
.br
.sp 2
.br
.nf
.ta .15i .25i 1.50i

class GMBFormatterCtxt::public GFormatterCtxt
{
public:
    GBool	setBoxes (const GBox** boxList, int boxNumber);
    GBool	addBox (const GBox&, int boxOrder);
    GBool	removeBox (int boxOrder);
    int		boxNumber (const GPoint&) const;
    int		boxNumber (GoTextLine*) const;
    GBool	resizeBox (const GBox&, int boxOrder);
    GBool	moveBox (const GPoint& absPoint, int boxOrder);
    int		count() const;
    const GBox&	box (int i) const;
}

.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.sp 1
.IP
void \fBGMBFormatterCtxt::setBoxes\fP (const GBox** \fIboxList\fP, int \fIboxNumber\fP)
.RS .8i
.IP \fIDescription\fP .5i
This function is used to initialize the formatter with boxes.
.IP \fIboxList\fP .5i
.br
Specifies the box list to set.
.IP \boxNumber\fP .5i
.br
Specifies the box list cardinal.
.RE
.sp 1
.IP
void \fBGMBFormatterCtxt::addBox\fP (const GBox& \fIbox\fP, int \fIboxOrder\fP)
.RS .8i
.IP \fIDescription\fP .5i
This function is used to add a box.
.IP \fIbox\fP .5i
.br
Specifies the box to add.
.IP \fIboxOrder\fP .5i
.br
Specifies the box list rank.
.RE
.sp 1
.IP
void \fBGMBFormatterCtxt::removeBox\fP (int \fIboxOrder\fP)
.RS .8i
.IP \fIDescription\fP .5i
This function is used to remove a box.
.IP \fIboxOrder\fP .5i
.br
Specifies the box list rank.
.RE
.sp 1
.IP
int \fBGMBFormatterCtxt::boxNumber\fP (const GPoint& \fIabsPoint\fP)
.RS .8i
.IP \fIDescription\fP .5i
This function return the box rank which contains the given point. Returns -1 if it is not included.
.IP \fIabsPoint\fP .5i
.br
Point which is queried.
.RE
.sp 1
.IP
void \fBGMBFormatterCtxt::resizeBox\fP (const GBox& \fIbox\fP, int \fIboxOrder\fP)
.RS .8i
.IP \fIDescription\fP .5i
This function is used to resize a box. Returns TRUE if the operation is well-performed.
.IP \fIbox\fP .5i
.br
Specifies the box used to be copied.
.IP \fIboxOrder\fP .5i
.br
Specifies the box list rank of the box to be resized.
.RE
.sp 1
.IP
void \fBGMBFormatterCtxt::moveBox\fP (const GPoint& \fIabsPoint\fP, int \fIboxOrder\fP)
.RS .8i
.IP \fIDescription\fP .5i
This function is used to move a box. Returns TRUE if the operation is well-performed.
.IP \fIabsPoint\fP .5i
.br
Specifies the new box origin.
.IP \fIboxOrder\fP .5i
.br
Specifies the box list rank of the box to be moved.
.RE
.sp 1
.IP
int \fBGMBFormatterCtxt::count\fP()
.RS .8i
.IP \fIDescription\fP .5i
This function returns the box list cardinal.
.RE
.sp 1
.IP
const GBox& \fBGMBFormatterCtxt::box\fP (int \fIboxOrder\fP)
.RS .8i
.IP \fIDescription\fP .5i
This function returns the box pointed by the given rank.
.IP \fIboxOrder\fP .5i
Rank of the queried box.
.RE
.SH
\fBUSER INTERACTIONS\fP
.IP
.br
.sp1
The \fBGoUI\fP object provides two functions to resize the boxes of the 
formatter (See GoUI).
.SH
\fBC BINDING\fP
.SS
\fBHeader\fP
.IP
#include <Go/cMBForm.h>
.br
.SS
\fBFunctions\fP
.sp 1
.RE
.IP
GObjectId \fBGMBFormatterCreate\fP()
.RS .8i
.IP \fIDescription\fP .5i
This function creates an instance of the GMBFormatter class.
.sp1
.RE
.SH
\fBSEE ALSO\fP
.IP
\fBGoText\fP, \fBGMBFormatter\fP and \fBGSimpleForm\fP classes.
.nrPN \n%
