.\" $Id: Node.n,v 1.1.1.1 1992/03/18 09:39:24 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoNode 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoNode\fP \(em the graph node object abstract class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Node.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGoNode\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGoGraphElement\fP class
.IP \(em 3
\fBGo\fP class.
.RE
.sp 1
.SH
\fBDESCRIPTION\fP
.IP
The \fBGoNode\fP class is the common superclass for GoTreeNode and GoGraphNode graphic objects, so it defines common characteristics between nodes of a tree and nodes of a graph.
.br
The graphical appearance of a node is given by the Gos it contains (from Go hierarchy point of view). Thus, the graphical appearance of GoNodes can be structured graphics including geometric, textual and image objects. In addition, GoNodes can be dynamically editable by simply editing Go subtrees.
.br
Node objects may have a background.
.IP
.nf
.ta .15i .25i 1.0i
class GoNode {
	public:
		// getting values;
		GBool background() const;
		GBrush& brush() const;

		// setting values;
		void background(GBool \fIback\fP);

		// others;
		static GoMetaclass* metaclass();
};
.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
GBool \fBbackground\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
Returns GTRUE if the node object has a background, otherwise this function returns GFALSE.
.RE
.sp 1
.IP
GBrush& \fBbrush\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
Returns the brush instance used to draw the background.
.br
The brush object is created the first time the node has a background.
.RE
.sp 1
.IP
void \fBbackground\fP(GBool \fIback\fP) const;
.RS .8i
.IP \fIDescription\fP .5i
This method allows to make the background visible or unvisible. 
.br
The brush object is created the first time the node has a background.
.IP \fIback\fP .5i
If GTRUE, the background will be visible.
If GFALSE, the background will be unvisible.
.br
.RE
.sp 1
.IP
static GoMetaclass* \fBmetaclass\fP();
.RS .8i
.IP \fIDescription\fP .5i
Returns a pointer to the metaclass object of the \fIthis\fP.
.RE
.sp1
.RE
.sp 2
.SH
\fBUSER INTERACTION\fP
.IP
\fISee GoNodeMetaclass(3Go)\fP.
.RE
.sp 2
.SH
\fBC BINDING\fP
.SS 
\fBHeader\fP
.IP
#include <Go/cNode.h>
.DE
.SS 
\fBResources\fP
.IP
The following table defines a set of Go resources used by the programmer
to specify data.  The programmer can also set the resource values for the 
inherited classes to set attributes for this object.
The codes in the access column indicate if the given resource can be set by using \fBGoSetValues\fP (\fBS\fP), retrieved by using \fBGoGetValues\fP (\fBG\fP), or is not applicable (\fBN/A\fP).
.br
For superclass resources, see superclass man pages.
.br
See also Section 2.
.sp 1
.ps 8
.DS
.TS
center box;
cB sss
lB lB lB lB
l l l l.
GoNode Resource GSet
.sp
=
Name	Type	Default	Access
.sp
_
goNbackground	GBool	GFALSE	SG
goNbrush	GObjectId	dynamic	G
.TE
.DE
.ps 10

.SS 
\fBFunctions\fP
.IP
GObjectId \fBGoGetNodeBrush\fP(GObjectId \fInode\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBrush& GoNode::brush().
.RE
.sp 1
.IP
GBool \fBGoGetNodeBackground\fP(GObjectId \fInode\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBool GoNode::background().
.RE
.sp 1
.IP
void \fBGoSetNodeBackground\fP(GObjectId \fInode\fP, GBool \fIyes\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoNode::background(GBool \fIyes\fP).
.RE
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
\fIGoNode\fP instances cannot be directly created but \fIGoNode\fP subclass instances, this explains why there are not public constructors.
.sp 2
.SH
\fBSEE ALSO\fP
.IP
\fBGoTreeNode\fP, \fBGoGraphNode\fP classes.
.nrPN \n%
