.\" $Id: PointSensor.n,v 1.4 1993/01/04 17:01:15 smadja Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH PointSensor 3Go "December 1992" "Version 1.2" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoPointSensor\fP \(em the sensor object class for \fBGoPolypoint\fP objects.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/PointSensor.h>\fP
.sp 1
.SH
\fBCLASS\fP
.IP
\fBGoPointSensor\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGoStdSensor\fP class
.RE
.sp 1
.SH
\fBDESCRIPTION\fP
.IP
\fBGoPointSensor\fP is a subclass of \fBGoSensor\fP dedicated to
\fBGoPolypoint\fP subclasses instances. It allows to manipulate interactively
and individually points of a \fBGoPolypoint\fP.
.IP
A \fBGoPointSensor\fP maintains a list of small sensitive
areas, one for each point of the associated \fBGoPolypoint\fP object. These
areas are visually represented by a identical circles whose attributes are
customizable at the metaclass level (see \fBGoPointSensorMetaclass\fP member
functions \fIpen\fP (), \fIbrush\fP () and \fIradius\fP (GNumber)), thus all
\fIGoPointSensor\fP instances will look alike.
.IP
.sp 1
.br
.nf
.ta .15i .25i 1.0i

typedef void (*GPointSensorPostcond)(void* closure, GoPointSensor*);

class GoPointSensor : public GoStdSensor {

	public:
		static GoPointSensorMetaclass* metaclass();
		static GoPointSensor* create(const char* program, Go*,
				const GEvent*,
				GPointSensorPostcond, void* closure);
		static GoPointSensor* create();
    
		GoPointSensor();

	private:
		GBool m_contains(const GPoint&, GNumber maxdist); const
};

.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
GoPointSensorMetaclass* \fBmetaclass\fP ();
.RS .8i
.IP \fIDescription\fP .3i
This static member function returns the \fBGoPointSensorMetaclass\fP instance.
.RE
.sp 1
.IP
GoPointSensor* \fBcreate\fP(const char* \fIprogram\fP, Go* \fIgo\fP, const GEvent* \fIevent\fP, GPointSensorPostcond \fIprocedure\fP, void* \fIclosure\fP);
.br
GoPointSensor* \fBcreate\fP();
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to create a new instance of the \fBGoPointSensor\fP class.
They return a pointer on a new instance of GoPointSensor if no precondition
refuses the creation, else they return NULL. When using \fBcreate\fP () with no
parameter, one must know that the created instance is expected to be reparented
on a \fBGoPolypoint\fP subclass instance.
.IP \fIgo\fP .5i
.br
Specifies the parent of the \fBGoPointSensor\fP. It is assumed that it belongs
to a subclass of \fBGoPolypoint\fP. One has to make sure it is always true.
.IP \fIprogram\fP .5i
.br
Specifies the \fIprogram\fP name.
.IP \fIevent\fP .5i
.br
Specifies the first \fIevent\fP (see Sensor (3Go) constructor description).
.IP \fIprocedure,closure\fP .5i
.br
Specify the \fIprocedure\fP called when the \fPprogram\fP interactor is cancelled (see Sensor (3Go)).
.RE
.sp 1
.IP
\fBGoPointSensor\fP();
.RS .8i
.IP \fIDescription\fP .5i
Constructor. Pre/post conditions are NOT invoked if you use this public
constructor. Any such created instance is expected to be
reparented on a \fBGoPolypoint\fP subclass instance.
.br
Use the \fBGoPointSensor::create(...)\fP methods instead if you want to invoke
pre/post conditions.
.RE
.sp 1
.IP
GBool \fBm_contains\fP(const GPoint& \fIpoint\fP, GNumber \fImax_distance\fP);
.RS .8i
.IP \fIDescription\fP .5i
The method returns GTRUE is the absolute position \fIpoint\fP is insides one of the \fIcircle\fP used to highlight to points of the parent GoPolypoint.
.br
The method is called via the public \fIcontains()\fP method (see Go (3Go)).
.IP \fIpoint\fP
.br
Specifies the absolute position.
.IP \fImax_distance\fP
.br
Specifies the max distance from a \fIcircle\fP outline and the absolute position \fIpoint\fP.
.RE
.sp 1
.SH
\fBC BINDING\fP
.IP
\fITo be defined\fP
.SH
\fBUSAGE INFORMATION\fP
.IP
.fi
.RE
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBGoUI\fP, \fBGo\fP, \fBGoMetaclass\fP, \fBGoStdSensor\fP,
\fBGoSensorMetaclass\fP, \fBGoSensorMetaclass\fP, and
\fBGoPointSensorMetaclass\fP classes.
.nrPN \n%


