.\" $Id: Polyline.n,v 1.1.1.1 1992/03/18 09:39:38 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoPolyline 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoPolyline\fP \(em the polyline object class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Polyline.h>\fP
.SH 
\fBCLASS\fP
.IP
\fBGoPolyline\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGoPolypoint\fP class
.IP \(em 3
\fBGoGeometric\fP class
.IP \(em 3
\fBGoStdDS\fP class
.IP \(em 3
\fBGo\fP class.
.RE
.SH
\fBDESCRIPTION\fP
.IP
A \fBGoPolyline\fP is a set of connected lines defined by the
\fBGoPolypoint\fP array of points, starting with the first, then going through
each successive point and ending at the last one. The background of a
\fBGoPolyline\fP is drawn by filling the polygon obtained by drawing an
invisible segment between first and last point.
.IP
If the attribute \fIround\fP is set, the angles of the polyline will be drawn
rounded, according to the value of the \fIround offset\fP attribute, range 0
(minimum round) to 0.5 (maximum round effect). One may see the \fIround
offset\fP as the proportion of the round extremity in a given segment
(remember that a segment has two such extremities, except the first and the
last segment of the polyline).
.IP
The origin of its coordinate system is not related to any of the points in the
\fBGoPolypoint\fP array points(), i.e. adding or (re)moving points will not
affect the coordinate system.
.sp 1
.br
.nf
.ta .15i .25i 1.0i
class GoPolyline : public GoPolypoint {

	public:

		static GoPolylineMetaclass* metaclass ();
		static GoPolyline* create ();
		static GoPolyline* create (int, const GPoint*);

		GoPolyline ();
		GoPolyline (int, const GPoint*);
		GBool round () const;
		GNumber roundOffset () const;
		GBool round (GBool);
		GBool roundOffset (GNumber);

		/*
		 * \fBpre and post conditions:\fP
		 */

		void roundPrecond (GBool (*) (void*, const GoPolyline*, GBool*),
			void* closure, GAddOrRemove = GADD);
		void roundPostcond (void (*) (void*, GoPolyline*),
			void* closure, GAddOrRemove = GADD);
		void roundOffsetPrecond (GBool (*) (void*, const GoPolyline*, GNumber*),
			void* closure, GAddOrRemove = GADD);
		void roundOffsetPostcond (void (*) (void*, GoPolyline*),
			void* closure, GAddOrRemove = GADD);
};
.fi
.SH
\fBPUBLIC METHODS\fP
.IP
\fBGoPolylineMetaclass\fP* \fBmetaclass\fP ()
.RS .8i
.IP \fIDescription\fP .3i
This static member function returns the \fBGoPolylineMetaclass\fP instance.
.RE
.sp 1
.IP
.nf
\fBGoPolyline\fP* \fBcreate\fP ()
\fBGoPolyline\fP* \fBcreate\fP (int \fInb\fP, const GPoint* \fIpts\fP)
.fi
.RS .8i
.IP \fIDescription\fP .3i
These static member functions are constructors with pre/postconditions.
They return a pointer on a new instance of \fBGoPolyline\fP if no precondition
refuses the creation, else they return NULL;
.IP \fInb\fP .3i
Specifies the number of control point in the array \fIpts\fP
.IP \fIpts\fP .3i
Specifies the control point array.
.RE
.sp 1
.IP
.nf
\fBGoPolyline\fP ();
\fBGoPolyline\fP (int \fInb\fP,const GPoint* \fIpts\fP);
.fi
.RS .8i
.IP \fIDescription\fP .3i
Constructors. The default values of \fIround\fP and
\fIround offset\fP attribute are respectively GFALSE and 0.2.
.IP \fInb\fP .3i
Specifies the number of elements in \fIpts\fP.
.IP \fIpts\fP .3i
Specifies the array of polyline summits.
.RE
.sp 1
.IP
.nf
GBool \fBround\fP ();
GNumber \fBroundOffset\fP ();
.fi
.RS .8i
.IP \fIDescription\fP .3i
These methods return the value of the attributes "round" and "round offset".
.RE
.sp 1
.IP
.nf
GBool \fBround\fP (GBool \fIyes\fP);
GBool \fBroundOffset\fP (GNumber \fIvalue\fP);
.fi
.RS .8i
.IP \fIDescription\fP .3i
These methods set the value of the attributes "round" and "round offset".
.br
If none of the \fBroundPrecond\fP (resp. \fBroundOffsetPrecond\fP)
preconditions returned GFALSE, the action is performed with the parameter
\fIyes\fP (resp. \fIvalue\fP) possibly modify by the preconditions.
If the action succeeds, \fBroundPostcond\fP (resp. \fBroundOffsetPostcond\fP)
postconditions are called and the method returns GTRUE. Otherwise, it returns
GFALSE.
.IP \fIyes\fP .3i
Specifies the new "round" value.
.IP \fIvalue\fP .3i
Specifies the new "round offset" value.
.RE
.sp 1
.IP
.nf
void \fBroundPrecond\fP (GBool (*\fIf\fP) (void* \fIclosure\fP, const GoPolyline* \fIpolyline\fP, GBool* \fIyes\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBroundPostcond\fP (void (*\fIf\fP) (void* \fIclosure\fP, GoPolyline* \fIpolyline\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBroundOffsetPrecond\fP (GBool (*\fIf\fP) (void* \fIclosure\fP, const GoPolyline* \fIpolyline\fP, GNumber* \fInewVal\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBroundOffsetPostcond\fP (void (*\fIf\fP) (void* \fIclosure\fP, GoPolyline* \fIpolyline\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .3i
These methods allow to add or remove functions to the pre/post conditions lists
triggered by \fBround\fP (GBool) and \fBroundOffset\fP (GNumber) member functions.
.IP \fIf\fP .3i
Specifies programmer's function to be added/removed.
.IP \fIclosure\fP .3i
Specifies programmer's parameter to call the function with.
.IP \fIpolyline\fP .3i
Specifies the \fBGoPolyline\fP object involved (i.e. \fIthis\fP).
.IP \fIyes\fP
Specifies the new value for "round". May be modified by \fIf\fP.
.IP \fInewVal\fP
Specifies the new value for "round offset". May be modified by \fIf\fP.
.IP \fIadd\fP .3i
Specifies whether to add or remove the function \fIf\fP from the list.
.RE
.SH
\fBC BINDING\fP
.SS 
\fBHeader\fP
.IP
#include <Go/cPolyline.h>
.DE
.SS 
\fBResources\fP
.IP
The following table defines a set of Go resources used by the programmer
to specify data.  The programmer can also set the resource values for the 
inherited classes to set attributes for this object.
The codes in the access column indicate if the given resource can be set by
using \fBGoSetValues\fP (\fBS\fP), retrieved by using \fBGoGetValues\fP
(\fBG\fP), or is not applicable (\fBN/A\fP).
.br
For superclass resources, see superclass man pages.
.br
See also Section 2.
.sp 1
.ps 8
.DS
.TS
center box;
cB sss
lB lB lB lB
l l l l.
GoPolyline Resource GSet
.sp
=
Name	Type	Default	Access
.sp
_
goNround	GBool	GFALSE	GS
goNroundOffset	GNumber	0.2	GS
.TE
.DE
.ps 10

.SS 
\fBFunctions\fP
.IP
void \fBGoPolylineInitialize\fP ();
.RS .8i
.IP \fIDescription\fP .3i
This function must be called before any use of the GoPolyline C Binding.
.RE
.sp 1
.IP
.nf
GObjectId \fBGoPolylineCreate\fP (int \fInb\fP, const GPoint* \fIpts\fP);
GObjectId \fBGoPolylineMetaclass\fP ();
GBool \fBGoPolylineRound\fP (GObjectId \fIpolyline\fP);
GNumber \fBGoPolylineRoundOffset\fP (GObjectId \fIpolyline\fP);
GBool \fBGoPolylineSetRound\fP (GObjectId \fIpolyline\fP, GBool \fIyes\fP);
GBool \fBGoPolylineSetRoundOffset\fP (GObjectId \fIpolyline\fP, GNumber \fIvalue\fP);
.fi
.sp 1
.RS .8i
.IP \fIDescription\fP .3i
See \fBGoPolyline\fP following members :
.sp 1
.nf
GoPolyline* create (int, const GPoint*).
GoMetaclass* metaclass ().
GBool round ().
GNumber roundOffset ().
GBool round (GBool).
GBool roundOffset (GNumber).
.fi
.RE
.sp 1
.IP
.nf
void \fBGoPolylineRoundPrecond\fP (GObjectId \fIpolyline\fP, 
		GBool (*\fIf\fP) (GObjectId, GBool*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoPolylineRoundPostcond\fP (GObjectId \fIpolyline\fP, 
		void (*\fIf\fP) (GObjectId),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoPolylineRoundOffsetPrecond\fP (GObjectId \fIpolyline\fP, 
		GBool (*\fIf\fP) (GObjectId, GNumber*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoPolylineRoundOffsetPostcond\fP (GObjectId \fIpolyline\fP, 
		void (*\fIf\fP) (GObjectId, GNumber),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
.fi
.sp 1
.RS .8i
.IP \fIDescription\fP .3i
See \fBGoPolyline\fP following members :
.sp 1
.nf
void roundPrecond (GBool (*\fIf\fP) (void*, GoPolyline*, GBool*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void roundPostcond (void (*\fIf\fP) (void*, GoPolyline*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void roundOffsetPrecond (GBool (*\fIf\fP) (void*, GoPolyline*, GNumber*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void roundOffsetPostcond (void (*\fIf\fP) (void*, GoPolyline*, GNumber),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.fi
.RE
.SH
\fBUSER INTERACTIONS\fP
.IP
The following strings may be associated with event description strings in GoUI
files to perform actions on \fBGoPolyline\fP objects (see \fBGoUI\fP
documentation for more information on this topic). Most of the time,
these strings refer to name-like public functions or have an obvious
signification, thus description will only be given if absolutely necessary.
.IP
.nf
\fBround\fP (GBool)
\fBroundOffset\fP (GNumber)
.fi
.RS .8i
.IP \fIDescription\fP .3i
same as member functions.
.RE
.SH
\fBUSAGE INFORMATION\fP
.IP
If willing to use pre/postconditions on object creation,
one should use \fBGoPolyline::create\fP instead of the public
\fBGoPolyline\fP constructor; this is highly recommended.
.SH
\fBSEE ALSO\fP
.IP
\fBGo\fP, \fBGoMetaclass\fP, \fBGoStdDS\fP, \fBGoStdDSMetaclass\fP,
\fBGoGeometric\fP, \fBGoGeometricMetaclass\fP, \fBGoPolypoint\fP,
\fBGoPolypointMetaclass\fP and \fBGoPolylineMetaclass\fP classes.
.nrPN \n%

