.\" $Id: Polypoint.n,v 1.2 1992/12/28 16:48:55 mbikina Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991, 1992 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoPolypoint 3Go "December 1992" "Version 1.2" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoPolypoint\fP \(em the polypoint object class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Polypoint.h>\fP
.SH 
\fBCLASS\fP
.IP
\fBGoPolypoint\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGoGeometric\fP class
.IP \(em 3
\fBGoStdDS\fP class
.IP \(em 3
\fBGo\fP class.
.RE
.SH
\fBDESCRIPTION\fP
.IP
\fBGoPolypoint\fP object is the base class for polyline and curve families.
.br
It manages an array of points and provides common functions to manipulate this
array : reset the array, add, move or delete a point...
.IP
The origin of the coordinate system is not related to any point of the
point array, i.e. adding or (re)moving points will not affect the coordinate
system.
.sp 1
.br
.nf
.ta .15i .25i 1.0i
class GoPolypoint : public GoGeometric {

	public:

		static GoPolypointMetaclass* metaclass ();

		int nbPoint () const;
		const GPoint* points () const;
		int posToIndex (const GPoint&) const;
		GBool reset (int, const GPoint*);
		GBool addPoint (int, const GPoint&, GBool);
		GBool movePoint (int, const GPoint&, GBool);
		GBool delPoint (int);

		/*
		 * \fBpre and post conditions:\fP
		 */

		void addPointPrecond (GBool (*) (void*, const GoPolypoint*, int*, GPoint*),
			void*, GAddOrRemove = GADD);
		void addPointPostcond (void (*) (void*, GoPolypoint*, int),
			void*, GAddOrRemove = GADD);
		void delPointPrecond (GBool (*) (void*, const GoPolypoint*, int*),
			void*, GAddOrRemove = GADD);
		void delPointPostcond (void (*) (void*, GoPolypoint*, int),
			void*, GAddOrRemove = GADD);
		void movePointPrecond (GBool (*) (void*, const GoPolypoint*, int*, GPoint*),
			void*, GAddOrRemove = GADD);
		void movePointPostcond (void (*) (void*, GoPolypoint*, int),
			void*, GAddOrRemove = GADD);
		void resetPointsPrecond (GBool (*) (void*, const GoPolypoint*, int, const GPoint*),
			void*, GAddOrRemove = GADD);
		void resetPointsPostcond (void (*) (void*, GoPolypoint*),
			void*, GAddOrRemove = GADD);

		/*
		 * \fBpre conditions calls:\fP
		 */

   		GBool callAddPointPrecond(int*,   GPoint*) const;
		GBool callDelPointPrecond(int*)   const;
		GBool callMovePointPrecond(int* , GPoint*) const;
		GBool callResetPointsPrecond(int, const GPoint*) const;
};
.fi
.SH
\fBPUBLIC METHODS\fP
.IP
GoPolypointMetaclass* \fBmetaclass\fP ()
.RS .8i
.IP \fIDescription\fP .3i
This static member function returns the \fBGoPolypointMetaclass\fP instance.
.RE
.sp 1
.IP
int \fBnbPoint\fP () const
.RS .8i
.IP \fIDescription\fP .3i
Returns the number of points in the point array
.RE
.sp 1
.IP
const GPoint* \fBpoints\fP () const
.RS .8i
.IP \fIDescription\fP .3i
Returns the point array. No memory allocation is done and the array must not be
modified. All points are expressed in the object coordinate system (i.e.
relative coordinate system).
.RE
.sp 1
.IP
int \fBposToIndex\fP (const GPoint& \fIpt\fP) const
.RS .8i
.IP \fIDescription\fP .3i
Returns the index of the closest (geometrical sense) point to \fIpt\fP in
the array, -1 if the array is empty.
.IP \fIpt\fP .3i
Specifies the point.
.RE
.sp 1
.IP
GBool \fBreset\fP (int \fInb\fP, const GPoint* \fIpts\fP)
.RS .8i
.IP \fIDescription\fP .3i
Gives the GoPolypoint a new point array and delete old one (if any).
.br
This action is only performed if none of the \fIresetPrecondition\fP
conditions returns GFALSE. If the action succeeds, \fIresetPostcondition\fP
conditions are also called and the function returns GTRUE, otherwise it returns
GFALSE.
.IP \fInb\fP .3i
Specifies the number of elements in \fIpts\fP.
.IP \fIpts\fP .3i
Specifies the new point array, expressed in the object coordinate system (i.e.
relative coordinate system).
.RE
.sp 1
.IP
GBool \fBaddPoint\fP (int \fIindex\fP, const GPoint& \fIpt\fP, GBool \fIisAbsPoint\fP)
.RS .8i
.IP \fIDescription\fP .3i
Adds a new point to the point array at the specified index. The indexes 
previously greater than or equal to \fIindex\fP will be incremented by one.
.br
This action is only performed if none of the \fIaddPrecondition\fP
conditions returns GFALSE. Both \fIindex\fP and \fIpt\fP (actually a copy
 of \fIpt\fP) may be modified by
preconditions. If the action succeeds, \fIaddPostcondition\fP
conditions are also called and the function returns GTRUE, otherwise it returns
GFALSE.
.IP \fIindex\fP .3i
Specifies the position of the point in the array (starts at 0).
.IP \fIpt\fP .3i
Specifies the point to be added.
.IP \fIisAbsPoint\fP .3i
Specifies whether \fIpt\fP is expressed in the absolute coordinate
system (GTRUE), in which case its coordinates are converted in the GoPolypoint
coordinate system, otherwise \fIpt\fP is unchanged.
.RE
.sp 1
.IP
GBool \fBmovePoint\fP (int \fIindex\fP, const GPoint& \fIpt\fP, GBool \fIisAbsPoint\fP)
.RS .8i
.IP \fIDescription\fP .3i
Moves the point specified in the point array by the index to the coordinates
given by \fIpt\fP.
.br
This action is only performed if none of the \fImovePrecondition\fP
conditions returns GFALSE. Both \fIindex\fP and \fIpt\fP (actually a copy
of \fIpt\fP) may be modified by
preconditions. If the action succeeds, \fImovePostcondition\fP
conditions are also called and the function returns GTRUE, otherwise it returns
GFALSE.
.IP \fIindex\fP .3i
Specifies the position of the point in the array (starts at 0).
.IP \fIpt\fP .3i
Specifies the new coordinates.
.IP \fIisAbsPoint\fP .3i
Specifies whether \fIpt\fP is expressed in the absolute coordinate
system (GTRUE), in which case its coordinates are converted in the GoPolypoint
coordinate system, otherwise \fIpt\fP is unchanged.
.RE
.sp 1
.IP
GBool \fBdelPoint\fP (int \fIindex\fP)
.RS .8i
.IP \fIDescription\fP .3i
Removes a point from the point array. The indexes previously greater than
\fIindex\fP will be decremented by one.
.br
This action is only performed if none of the \fIdelPrecondition\fP
conditions returns GFALSE. \fIindex\fP may be modified by
preconditions. If the action succeeds, \fIdelPostcondition\fP
conditions are also called and the function returns GTRUE, otherwise it returns
GFALSE.
.IP \fIindex\fP .3i
Specifies the index of the point to be deleted in the array (starts at 0).
.RE
.sp 1
.IP
.nf
void \fBaddPointPrecond\fP (GBool (*\fIf\fP) (void* \fIclosure\fP, const GoPolypoint* \fIpolypt\fP,
			int* \fIindex\fP, GPoint* \fIpt\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD)
void \fBaddPointPostcond\fP (GBool (*\fIf\fP) (void* \fIclosure\fP, const GoPolypoint* \fIpolypt\fP, int \fIindex\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD)
void \fBmovePointPrecond\fP (GBool (*\fIf\fP) (void* \fIclosure\fP, const GoPolypoint* \fIpolypt\fP,
			int* \fIindex\fP, GPoint* \fIpt\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD)
void \fBmovePointPostcond\fP (GBool (*\fIf\fP) (void* \fIclosure\fP, const GoPolypoint* \fIpolypt\fP, int \fIindex\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD)
void \fBdelPointPrecond\fP (GBool (*\fIf\fP) (void* \fIclosure\fP, const GoPolypoint* \fIpolypt\fP, int* \fIindex\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD)
void \fBdelPointPostcond\fP (GBool (*\fIf\fP) (void* \fIclosure\fP, const GoPolypoint* \fIpolypt\fP, int \fIindex\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD)
void \fBresetPointsPrecond\fP (GBool (*\fIf\fP) (void* \fIclosure\fP, const GoPolypoint* \fIpolypt\fP,
			int \fInb\fP, const GPoint* \fIpts\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD)
void \fBresetPointsPostcond\fP (GBool (*\fIf\fP) (void* \fIclosure\fP, const GoPolypoint* \fIpolypt\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD)
.fi
.RS .8i
.IP \fIDescription\fP .3i
These methods allow to add or remove functions to the pre/post conditions lists
triggered by \fBaddPoint\fP (...), \fBmovePoint\fP (...) and \fPdelPoint\fP
(...) member functions.
.IP \fIf\fP .3i
Specifies programmer's function to be added/removed.
.IP \fIpolypt\fP .3i
Specifies the \fBGoPolypoint\fP object involved (i.e. \fIthis\fP).
.IP \fIindex\fP .3i
Specifies the index in the point array. May be modified by \fIf\fP (in
preconditions only).
.IP \fIpt\fP .3i
Pointer to the new point or new position, always expressed in the Go
coordinate system. The structure pointed to may be modified by \fIf\fP (in
preconditions only).
.IP \fInb\fP
Specifies the number of points in the array \fIpts\fP (resetPointsPrecond
only).
.IP \fIpts\fP .3i
New point array (resetPointsPrecond only). Always expressed in the Go
coordinate system.
.IP \fIadd\fP .3i
Specifies whether to add or remove the function \fIf\fP from the list.
.RE
.sp 1
.IP
.nf
GBool \fBcallAddPointPrecond\fP(int*,   GPoint*) const;
GBool \fBcallDelPointPrecond\fP(int*)   const;
GBool \fBcallMovePointPrecond\fP(int* , GPoint*) const;
GBool \fBcallResetPointsPrecond\fP(int, const GPoint*) const;
.fi
.RS .8i
.IP \fIDescription\fP .3i
These methods calls the corresponding pre conditions.
.RE
.SH
\fBC BINDING\fP
.SS 
\fBHeader\fP
.IP
#include <Go/cPolypoint.h>
.DE
.SS 
\fBResources\fP
.IP
The following table defines a set of Go resources used by the programmer
to specify data.  The programmer can also set the resource values for the 
inherited classes to set attributes for this object.
The codes in the access column indicate if the given resource can be set by
using \fBGoSetValues\fP (\fBS\fP), retrieved by using \fBGoGetValues\fP
(\fBG\fP), or is not applicable (\fBN/A\fP).
.br
For superclass resources, see superclass man pages.
.br
See also Section 2.
.sp 1
.ps 8
.DS
.TS
center box;
cB sss
lB lB lB lB
l l l l.
GoPolypoint Resource GSet
.sp
=
Name	Type	Default	Access
.sp
_
goNnbPoint	int	dynamic	G
goNpoints	GPoint*	dynamic	G
.TE
.DE
.ps 10

.SS 
\fBFunctions\fP
.IP
void \fBGoPolypointInitialize\fP ();
.RS .8i
.IP \fIDescription\fP .3i
This function must be called before any use of the GoPolypoint C Binding.
.RE
.sp 1
.IP
.nf
GObjectId \fBGoPolypointMetaclass\fP ();
int \fBGoPolypointNbPoint\fP (GObjectId \fIpolypt\fP);
const GPoint* \fBGoPolypointPoints\fP (GObjectId \fIpolypt\fP);
GBool \fBGoPolypointReset\fP (GObjectId \fIpolypt\fP, int \fInb\fP, const GPoint* \fIpts\fP);
GBool \fBGoPolypointMove\fP (GObjectId \fIpolypt\fP, int \fIindex\fP, const GPoint* \fIpt\fP, GBool \fIisAbsPoint\fP);
GBool \fBGoPolypointAdd\fP (GObjectId \fIpolypt\fP, int \fIindex\fP, const GPoint* \fIpt\fP, GBool \fIisAbsPoint\fP);
GBool \fBGoPolypointDel\fP (GObjectId \fIpolypt\fP, int \fIindex\fP);
.fi
.sp 1
.RS .8i
.IP \fIDescription\fP .3i
See \fBGoPolypoint\fP following members :
.sp 1
.nf
GoMetaclass* metaclass ().
int nbPoint ().
const GPoint* points ().
GBool reset (int, const GPoint*).
GBool move (int, const GPoint&, GBool).
GBool add (int, const GPoint&, GBool).
GBool del (int).
.fi
.RE
.sp 1
.IP
.nf
void \fBGoPolypointAddPointPrecond\fP (GObjectId \fIpolypt\fP, 
		GBool (*\fIf\fP) (GObjectId, int*, GPoint*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoPolypointAddPointPostcond\fP (GObjectId \fIpolypt\fP, 
		void (*\fIf\fP) (GObjectId, int),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoPolypointMovePointPrecond\fP (GObjectId \fIpolypt\fP, 
		GBool (*\fIf\fP) (GObjectId, int*, GPoint*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoPolypointMovePointPostcond\fP (GObjectId \fIpolypt\fP,
		void (*\fIf\fP) (GObjectId, int),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoPolypointDelPointPrecond\fP (GObjectId \fIpolypt\fP, 
		GBool (*\fIf\fP) (GObjectId, int*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoPolypointDelPointPostcond\fP (GObjectId \fIpolypt\fP, 
		void (*\fIf\fP) (GObjectId, int),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoPolypointResetPointsPrecond\fP (GObjectId \fIpolypt\fP, 
		GBool (*\fIf\fP) (GObjectId, int*, const GPoint*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoPolypointResetPointsPostcond\fP (GObjectId \fIpolypt\fP, 
		void (*\fIf\fP) (GObjectId),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
.fi
.sp 1
.RS .8i
.IP \fIDescription\fP .3i
See \fBGoPolypoint\fP following members :
.sp 1
.nf
void addPointPrecond (GBool (*\fIf\fP) (void*, GoPolypoint*, int*, GPoint*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void addPointPostcond (void (*\fIf\fP) (void*, GoPolypoint*, int),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void movePointPrecond (GBool (*\fIf\fP) (void*, GoPolypoint*, int*, GPoint*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void movePointPostcond (void (*\fIf\fP) (void*, GoPolypoint*, int),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void delPointPrecond (GBool (*\fIf\fP) (void*, GoPolypoint*, int*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void delPointPostcond (void (*\fIf\fP) (void*, GoPolypoint*, int),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void resetPointsPrecond (GBool (*\fIf\fP) (void*, GoPolypoint*, int*, const GPoint*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void resetPointsPostcond (void (*\fIf\fP) (void*, GoPolypoint*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.fi
.RE
.SH
\fBUSER INTERACTIONS\fP
.IP
The following strings may be associated with event description strings in GoUI
files to perform actions on \fBGoPolypoint\fP objects (see \fBGoUI\fP
documentation for more information on this topic).
.IP 
.nf
\fBaddPointForward\fP (GPoint* \fIposition\fP)
\fBaddPointBackward\fP (GPoint* \fIposition\fP)
.fi
.RS .8i
.IP \fIDescription\fP .3i
\fBaddPointForward\fP (resp. \fBaddPointBackward\fP) gets the closest point to
\fIposition\fP (expressed in the absolute coordinate system) from the
\fBGoPolypoint\fP point array (say at index \fIn\fP) and adds a new point next
to it, at index \fIn\fP+1 (resp. \fIn\fP) : this new point is the middle of
segment [ \fIn\fP, \fIn\fP+1 ]  (resp. [ \fIn\fP-1, \fIn\fP ]) in the original
point array.
.RE
.IP
\fBdeleteClosestPoint\fP (GPoint* \fIposition\fP)
.RS .8i
.IP \fIDescription\fP .3i
delete the closest point to \fIposition\fP (expressed in the absolute coordinate
system) from the \fBGoPolypoint\fP array.
.RE
.SH
\fBUSAGE INFORMATION\fP
.IP
\fBGoPolypoint\fP is an abstract class, thus it has no public constructor :
creation may only occur through subclasses constructors.
.SH
\fBSEE ALSO\fP
.IP
\fBGo\fP, \fBGoMetaclass\fP, \fBGoStdDS\fP, \fBGoStdDSMetaclass\fP,
\fBGoGeometric\fP, \fBGoGeometricMetaclass\fP and \fBGoPolypointMetaclass\fP
classes.
.nrPN \n%

