.\" $Id: Rectangle.n,v 1.2 1992/12/28 16:55:32 mbikina Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991, 1992 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoRectangle 3Go "December 1992" "Version 1.2" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoRectangle\fP \(em the rectangle object class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Rectangle.h>\fP
.SH 
\fBCLASS\fP
.IP
\fBGoRectangle\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGoPolygon\fP class
.IP \(em 3
\fBGoPolyline\fP class
.IP \(em 3
\fBGoPolypoint\fP class
.IP \(em 3
\fBGoGeometric\fP class
.IP \(em 3
\fBGoStdDS\fP class
.IP \(em 3
\fBGo\fP class.
.RE
.SH
\fBDESCRIPTION\fP
.IP
A \fBGoRectangle\fP object is one of the basic graphic objects, subclass of
\fBGoPolygon\fP. It is defined by two positive numbers: \fIwidth\fP and
\fIheight\fP.
.IP
The origin of the coordinate system is the upper left corner of the rectangle,
according to the parent coord syst, and the edges are parallel to the axises
i.e. seeing the rectangle as a polygon, its point array is [ (0, 0),
(\fIwidth\fP, 0), (\fIwidth\fP, \fIheight\fP). (0, \fIheight\fP) ].
.sp 1
.br
.nf
.ta .15i .25i 1.0i
class GoRectangle : public GoPolygon {

	public:

		static GoRectangleMetaclass* metaclass ();
		static GoRectangle* create ();
		static GoRectangle* create (GNumber, GNumber);

		GoRectangle (GNumber = 1, GNumber = 1);
		GNumber width () const;
		GNumber height () const;
		GBool width (GNumber);
		GBool height (GNumber);
		GBool reset (GNumber, GNumber);

		/*
		 * \fBpre and post conditions:\fP
		 */

		void widthPrecond (GBool (*) (void*, const GoRectangle*),
			void*, GAddOrRemove  = GADD);
		void widthPostcond (void (*) (void*, GoRectangle*),
			void*, GAddOrRemove  = GADD);
		void heightPrecond (GBool (*) (void*, const GoRectangle*),
			void*, GAddOrRemove  = GADD);
		void heightPostcond (void (*) (void*, GoRectangle*),
			void*, GAddOrRemove  = GADD);
		void resetPrecond (GBool (*) (void*, const GoRectangle*),
			void*, GAddOrRemove  = GADD);
		void resetPostcond (void (*) (void*, GoRectangle*),
			void*, GAddOrRemove  = GADD);

		/*
		* \fBpre conditions calls :\fP
		*/
		
		GBool callWidthPrecond(GNumber*);
		GBool callHeightPrecond(GNumber*);
		GBool callResetPrecond(GNumber* width, GNumber* height);

};
.fi
.SH
\fBPUBLIC METHODS\fP
.IP
\fBGoRectangleMetaclass\fP* \fBmetaclass\fP ()
.RS .8i
.IP \fIDescription\fP .3i
This static member function returns the \fBGoRectangleMetaclass\fP instance.
.RE
.sp 1
.IP
.nf
\fBGoRectangle\fP* \fBcreate\fP ()
\fBGoRectangle\fP* \fBcreate\fP (GNumber \fIw\fP = 1, GNumber \fIh\fP = 1)
.fi
.RS .8i
.IP \fIDescription\fP .3i
These static member functions are constructors with pre/postconditions.
They return a pointer on a new instance of \fBGoRectangle\fP if no precondition
refuses the creation, else they return NULL;
.IP \fIw\fP .3i
Specifies the rectangle width.
.IP \fIh\fP .3i
Specifies the rectangle height.
.RE
.sp 1
.IP
\fBGoRectangle\fP(GNumber \fIw\fP = 1, GNumber \fIh\fP = 1)
.RS .8i
.IP \fIDescription\fP .3i
Constructor.
.IP \fIw\fP .3i
Specifies the rectangle width.
.IP \fIh\fP .3i
Specifies the rectangle height.
.RE
.sp 1
.IP
.nf
GNumber \fBwidth\fP() const;
GNumber \fBheight\fP() const;
.fi
.RS .8i
.IP \fIDescription\fP .3i
These methods return the rectangle dimensions.
.RE
.sp 1
.IP
.nf
GBool \fBreset\fP(GNumber \fIw\fP, GNumber \fIh\fP);
GBool \fBwidth\fP(GNumber \fIw\fP);
GBool \fBheight\fP(GNumber \fIh\fP);
.fi
.RS .8i
.IP \fIDescription\fP .3i
These methods modify the rectangle width and/or height (but not its
coordinate system).
.br
If none of the \fBresetPrecond\fP (resp. \fBwidthPrecond\fP,
\fBheightPrecond\fP) preconditions returned GFALSE, the action is performed
with parameters \fIw\fP and \fIh\fP possibly modify by the preconditions.
If the action succeeds, \fBresetPostcond\fP (resp. \fBwidthPostcond\fP,
\fBheightPostcond\fP) postconditions are called and the method returns GTRUE.
Otherwise, it returns GFALSE.
.IP \fIw\fP .3i
Specifies the new width value.
.IP \fIh\fP .3i
Specifies the new height value.
.RE
.sp 1
.IP
.nf
void \fBwidthPrecond\fP (GBool (*\fIf\fP) (void* \fIclosure\fP, const GoRectangle* \fIrectangle\fP, GNumber* \fInewW\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBwidthPostcond\fP (void (*\fIf\fP) (void* \fIclosure\fP, GoRectangle* \fIrectangle\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBheightPrecond\fP (GBool (*\fIf\fP) (void* \fIclosure\fP, const GoRectangle* \fIrectangle\fP, GNumber* \fInewH\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBheightPostcond\fP (void (*\fIf\fP) (void* \fIclosure\fP, GoRectangle* \fIrectangle\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBresetPrecond\fP (GBool (*\fIf\fP) (void* \fIclosure\fP, const GoRectangle* \fIrectangle\fP,
			GNumber* \fInewW\fP, GNumber* \fInewH\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBresetPostcond\fP (void (*\fIf\fP) (void* \fIclosure\fP, GoRectangle* \fIrectangle\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .3i
These methods allow to add or remove functions to the pre/post conditions lists
triggered by \fBwidth\fP (GNumber), \fBheight\fP (GNumber) and
\fBreset\fP (GNumber, GNumber) member functions.
.IP \fIf\fP .3i
Specifies programmer's function to be added/removed.
.IP \fIclosure\fP .3i
Specifies programmer's parameter to call the fonction with.
.IP \fIrectangle\fP .3i
Specifies the \fBGoRectangle\fP object involved (i.e. \fIthis\fP).
.IP \fInewW\fP .3i
Specifies the new width. May be modified by \fIf\fP.
.IP \fInewH\fP .3i
Specifies the new height. May be modified by \fIf\fP.
.IP \fIadd\fP .3i
Specifies whether to add or remove the function \fIf\fP from the list.
.RE
.sp 1
.IP
.nf
GBool \fBcallWidthPrecond\fP (GNumber*);
GBool \fBcallHeightPrecond\fP(GNumber*);
GBool \fBcallResetPrecond\fP (GNumber* \fIwidth\fP, GNumber* \fIheight\fP);
.fi
.RS .8i
.IP \fIDescription\fP .3i
These methods calls the corresponding pre conditions.
.RE
.SH
\fBC BINDING\fP
.SS 
\fBHeader\fP
.IP
#include <Go/cRectangle.h>
.DE
.SS 
\fBResources\fP
.IP
The following table defines a set of Go resources used by the programmer
to specify data.  The programmer can also set the resource values for the 
inherited classes to set attributes for this object.
The codes in the access column indicate if the given resource can be set by
using \fBGoSetValues\fP (\fBS\fP), retrieved by using \fBGoGetValues\fP
(\fBG\fP), or is not applicable (\fBN/A\fP).
.br
For superclass resources, see superclass man pages.
.br
See also Section 2.
.sp 1
.ps 8
.DS
.TS
center box;
cB sss
lB lB lB lB
l l l l.
GoRectangle Resource GSet
.sp
=
Name	Type	Default	Access
.sp
_
goNheight	GNumber	dynamic	GS
goNwidth	GNumber	dynamic	GS
.TE
.DE
.ps 10

.SS 
\fBFunctions\fP
.IP
void \fBGoRectangleInitialize\fP ();
.RS .8i
.IP \fIDescription\fP .3i
This function must be called before any use of the GoRectangle C Binding.
.RE
.sp 1
.IP
.nf
GObjectId \fBGoRectangleCreate\fP (GNumber \fIw\fP, GNumber \fIh\fP);
GNumber \fBGoRectangleHeight\fP (GObjectId \fIrectangle\fP);
GObjectId \fBGoRectangleMetaclass\fP ();
GBool \fBGoRectangleSetHeight\fP (GObjectId \fIrectangle\fP, GNumber \fIh\fP);
GBool \fBGoRectangleSetWidth\fP (GObjectId \fIrectangle\fP, GNumber \fIw\fP);
GNumber \fBGoRectangleWidth\fP (GObjectId \fIrectangle\fP);
.fi
.sp 1
.RS .8i
.IP \fIDescription\fP .3i
See \fBGoRectangle\fP following members :
.sp 1
.nf
GoRectangle* create (GNumber, GNumber).
GNumber height ().
GoMetaclass* metaclass ().
GBool height (GNumber).
GBool width (GNumber).
GNumber width ().
.fi
.RE
.sp 1
.IP
.nf
void \fBGoRectangleWidthPrecond\fP (GObjectId \fIrectangle\fP, 
		GBool (*\fIf\fP) (GObjectId, GNumber*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoRectangleWidthPostcond\fP (GObjectId \fIrectangle\fP, 
		void (*\fIf\fP) (GObjectId),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoRectangleHeightPrecond\fP (GObjectId \fIrectangle\fP, 
		GBool (*\fIf\fP) (GObjectId, GNumber*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoRectangleHeightPostcond\fP (GObjectId \fIrectangle\fP, 
		void (*\fIf\fP) (GObjectId),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
.fi
.sp 1
.RS .8i
.IP \fIDescription\fP .3i
See \fBGoRectangle\fP following members :
.sp 1
.nf
void widthPrecond (GBool (*\fIf\fP) (void*, GoRectangle*, GNumber*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void widthPostcond (void (*\fIf\fP) (void*, GoRectangle*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void heightPrecond (GBool (*\fIf\fP) (void*, GoRectangle*, GNumber*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void heightPostcond (void (*\fIf\fP) (void*, GoRectangle*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.fi
.RE
.SH
\fBUSER INTERACTIONS\fP
.IP
The following strings may be associated with event description strings in GoUI
files to perform actions on \fBGorectangle\fP objects (see \fBGoUI\fP
documentation for more information on this topic). Most of the time,
these strings refer to name-like public functions or have an obvious
signification, thus description will only be given if absolutely necessary.
.sp 1
.IP
.nf
\fBwidth\fP (GNumber)
\fBheight\fP (GNumber)
\fBreset\fP (GNumber, GNumber)
.fi
.RS .8i
.IP \fIDescription\fP .3i
same as member functions.
.RE
.SH
\fBUSAGE INFORMATION\fP
.IP
If willing to use pre/postconditions on object creation,
one should use \fBGoRectangle::create\fP instead of the public
\fBGoRectangle\fP constructor; this is highly recommended.
.SH
\fBSEE ALSO\fP
.IP
\fBGo\fP, \fBGoMetaclass\fP, \fBGoStdDS\fP, \fBGoStdDSMetaclass\fP,
\fBGoGeometric\fP, \fBGoGeometricMetaclass\fP, \fBGoPolypoint\fP,
\fBGoPolypointMetaclass\fP, \fBGoPolyline\fP, \fBGoPolylineMetaclass\fP,
\fBGoPolygon\fP, \fBGoPolygonMetaclass\fP and \fBGoRectangleMetaclass\fP classes.
.nrPN \n%

