.\" $Id: RegPoly.n,v 1.2 1992/12/28 16:49:40 mbikina Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991, 1992 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoRegPolygon 3Go "December 1992" "Version 1.2" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoRegPolygon\fP \(em the regular polygon object class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/RegPoly.h>\fP
.SH 
\fBCLASS\fP
.IP
\fBGoRegPolygon\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGoPolygon\fP class
.IP \(em 3
\fBGoPolyline\fP class
.IP \(em 3
\fBGoPolypoint\fP class
.IP \(em 3
\fBGoGeometric\fP class
.IP \(em 3
\fBGoStdDS\fP class
.IP \(em 3
\fBGo\fP class.
.RE
.SH
\fBDESCRIPTION\fP
.IP
A \fBGoRegPolygon\fP object is one of the basic graphic objects, subclass of
\fBGoPolygon\fP. It has the following characteristics :
.RS 10
.IP \(bu 3
\fInbPoint\fP, a positive integer representing the number of summits
.IP \(bu 3
\fIradius\fP, a positive number representing the polygon radius
.IP \(bu 3
\fIangle\fP, a GNumber (possibly negative) representing the angle (OM, Ox) where
M is the first summit (first point of its GPoint array) and Ox is the X axis of
its coordinate system.
.IP \(bu 3
the origin of the coordinate system is the center of the regular polygon, thus
the first summit coordinates are (radius*cos(angle), radius*sin(angle)).
.RE
.sp 1
.br
.nf
.ta .15i .25i 1.0i
class GoRegPolygon : public GoPolygon {

	public:

		static GoRegPolygonMetaclass*  metaclass ();
		static GoRegPolygon* create ();
		static GoRegPolygon* create (int, GNumber, GNumber);

		GoRegPolygon (int = 0, GNumber = 1.0, GNumber = 0);
		GNumber radius() const;
		GNumber angle() const;

		GBool reset(int, GNumber = 1.0, GNumber = 0);
		GBool nbPoint(int);
		GBool angle(GNumber);
		GBool radius(GNumber);
    
		/*
		 * \fBpre and post conditions:\fP
		 */

		void radiusPrecond(GBool (*) (void*, const GoRegPolygon*, GNumber*),
			void*, GAddOrRemove = GADD) const;
		void radiusPostcond(void (*) (void*, GoRegPolygon*),
			void*, GAddOrRemove = GADD);
		void anglePrecond(GBool (*) (void*, const GoRegPolygon*, GNumber*),
			void*, GAddOrRemove = GADD) const;
		void anglePostcond(void (*) (void*, GoRegPolygon*),
			void*, GAddOrRemove = GADD);
		void nbPointPrecond(GBool (*) (void*, const GoRegPolygon*, int*),
			void*, GAddOrRemove = GADD) const;
		void nbPointPostcond(void (*) (void*, GoRegPolygon*),
			void*, GAddOrRemove = GADD);
		void resetPrecond(GBool (*) (void*, const GoRegPolygon*, int*, GNumber*, GNumber*),
			void*, GAddOrRemove = GADD) const;
		void resetPostcond(void (*) (void*, GoRegPolygon*),
			void*, GAddOrRemove = GADD);

		/*
		 * \fBpre conditions calls :\fP
		 /*    
		GBool callRadiusPrecond(GNumber*) const;
		GBool callAnglePrecond(GNumber*) const;
		GBool callNbPointPrecond(int*) const;
		GBool callResetPrecond(int* , GNumber*, GNumber*) const;

};
.fi
.SH
\fBPUBLIC METHODS\fP
.IP
\fBGoRegPolygonMetaclass\fP* \fBmetaclass\fP ()
.RS .8i
.IP \fIDescription\fP .3i
This static member function returns the \fBGoRegPolygonMetaclass\fP instance.
.RE
.sp 1
.IP
.nf
\fBGoRegPolygon\fP* \fBcreate\fP ();
\fBGoRegPolygon\fP* \fBcreate\fP (int \fInb\fP, GNumber \fIradius\fP, GNumber \fIangle\fP)
.fi
.RS .8i
.IP \fIDescription\fP .3i
These static member functions are constructors with pre/postconditions.
They return a pointer on a new instance of \fBGoRegPolygon\fP if no precondition
refuses the creation, else they return NULL;
.IP \fInb\fP .3i
Specifies the new number of points in the polygon.
.IP \fIradius\fP .3i
Specifies the new radius.
.IP \fIangle\fP .3i
Specifies the new angle.
.RE
.sp 1
.IP
.nf
GNumber \fBradius\fP ();
GNumber \fBangle\fP ();
.fi
.RS .8i
.IP \fIDescription\fP .3i
Return the regular polyline specific attributes.
.RE
.sp 1
.IP
.nf
GBool \fBreset\fP (int \fInb\fP, GNumber \fIradius\fP = 1.0, GNumber \fIangle\fP = 0);
GBool \fBnbPoint\fP (int \fInb\fP);
GBool \fBradius\fP (GNumber \fIradius\fP);
GBool \fBangle\fP (GNumber \fIangle\fP);
.fi
.RS .8i
.IP \fIDescription\fP .3i
GSet the regular polygon specific parameters
.br
If none of the \fBresetPrecond\fP (resp. \fBnbPointPrecond\fP,
\fBradiusPrecond\fP, \fBanglePrecond\fP) preconditions returned GFALSE, the
action is performed with parameters \fInb\fP, \fIradius\fP and \fIangle\fP
possibly modify by the preconditions. If the action succeeds,
\fBresetPostcond\fP (resp. \fBnbPointPostcond\fP, \fBradiusPostcond\fP,
\fBanglePostcond\fP) postconditions are called and the method returns GTRUE.
Otherwise, it returns GFALSE.
.IP \fInb\fP .3i
Specifies the new number of points in the polygon.
.IP \fIradius\fP .3i
Specifies the new radius.
.IP \fIangle\fP .3i
Specifies the new angle.
.RE
.sp 1
.IP
.nf
void \fBradiusPrecond\fP (GBool (*\fIf\fP) (void* \fIclosure\fP, const GoRegPolygon* \fIregpoly\fP, GNumber* \fIrad\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBradiusPostcond\fP (void (*\fIf\fP) (void* \fIclosure\fP, GoRegPolygon* \fIregpoly\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBanglePrecond\fP (GBool (*\fIf\fP) (void* \fIclosure\fP, const GoRegPolygon* \fIregpoly\fP, GNumber* \fIangle\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBanglePostcond\fP (void (*\fIf\fP) (void* \fIclosure\fP, GoRegPolygon* \fIregpoly\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBnbPointPrecond\fP (GBool (*\fIf\fP) (void* \fIclosure\fP, const GoRegPolygon* \fIregpoly\fP, int* \fInb\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBnbPointPostcond\fP (void (*\fIf\fP) (void* \fIclosure\fP, GoRegPolygon* \fIregpoly\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBresetPrecond\fP (GBool (*\fIf\fP) (void* \fIclosure\fP, const GoRegPolygon* \fIregpoly\fP,
			int* \fInb\fP, GNumber* \fIrad\fP, GNumber* \fIangle\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBresetPostcond\fP (void (*\fIf\fP) (void* \fIclosure\fP, GoRegPolygon* \fIregpoly\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.br
.RS .8i
.IP \fIDescription\fP .3i
These methods allow to add or remove functions to the pre/post conditions lists
triggered by \fBnbPoint\fP (int), \fBradius\fP (GNumber), \fBangle\fP (GNumber) and
\fBreset\fP (int, GNumber, GNumber) member functions.
.IP \fIf\fP .3i
Specifies programmer's function to be added/removed.
.IP \fIclosure\fP .3i
Specifies programmer's parameter to call the function with.
.IP \fIregpoly\fP .3i
Specifies the \fBGoRegPolygon\fP object involved (i.e. \fIthis\fP).
.IP \fIadd\fP .3i
Specifies whether to add or remove the function \fIf\fP from the list.
.RE
.sp 1
.IP
.nf
GBool \fBcallRadiusPrecond\fP(GNumber*) const;
GBool \fBcallAnglePrecond\fP (GNumber*) const;
GBool \fBcallNbPointPrecond\fP(int*) const;
GBool \fBcallResetPrecond\fP(int* , GNumber*, GNumber*) const;
.fi
.br
.RS .8i
.IP \fIDescription\fP .3i
These methods calls the corresponding pre conditions.
.RE
.SH
\fBC BINDING\fP
.SS 
\fBHeader\fP
.IP
#include <Go/cRegPolygon.h>
.DE
.SS 
\fBResources\fP
.IP
The following table defines a set of Go resources used by the programmer
to specify data.  The programmer can also set the resource values for the 
inherited classes to set attributes for this object.
The codes in the access column indicate if the given resource can be set by
using \fBGoSetValues\fP (\fBS\fP), retrieved by using \fBGoGetValues\fP
(\fBG\fP), or is not applicable (\fBN/A\fP).
.br
For superclass resources, see superclass man pages.
.br
See also Section 2.
.sp 1
.ps 8
.DS
.TS
center box;
cB sss
lB lB lB lB
l l l l.
GoRegPolygon Resource GSet
.sp
=
Name	Type	Default	Access
.sp
_
goNangle	GNumber	dynamic	GS
goNnbPoint	int	dynamic	GS
goNradius	GNumber	dynamic	GS
.TE
.DE
.ps 10

.SS 
\fBFunctions\fP
.IP
void \fBGoRegPolygonInitialize\fP ();
.RS .8i
.IP \fIDescription\fP .3i
This function must be called before any use of the GoRegPolygon C Binding.
.RE
.sp 1
.IP
.nf
GNumber \fBGoRegPolygonAngle\fP (GObjectId \fIregpoly\fP);
GObjectId \fBGoRegPolygonCreate\fP (int \fInb\fP, GNumber \fIradius\fP, GNumber \fIangle\fP);
GObjectId \fBGoRegPolygonMetaclass\fP ();
GNumber \fBGoRegPolygonRadius\fP (GObjectId \fIregpoly\fP);
GBool \fBGoRegPolygonReset\fP (GObjectId \fIregpoly\fP,
		int \fInb\fP, GNumber \fIradius\fP, GNumber \fIangle\fP);
GBool \fBGoRegPolygonSetAngle\fP (GObjectId \fIregpoly\fP, GNumber \fIangle\fP);
GBool \fBGoRegPolygonSetNbPoint\fP (GObjectId \fIregpoly\fP, GNumber \fInb\fP);
GBool \fBGoRegPolygonSetRadius\fP (GObjectId \fIregpoly\fP, GNumber \fIradius\fP);
.fi
.sp 1
.RS .8i
.IP \fIDescription\fP .3i
See \fBGoRegPolygon\fP following members :
.sp 1
.nf
GNumber angle ().
GoRegPolygon* create (int, GNumber, GNumber).
GoMetaclass* metaclass ().
GNumber radius ().
GBool reset (int, GNumber, GNumber).
GBool angle (GNumber).
GBool nbPoint (int).
GBool radius (GNumber).
.fi
.RE
.sp 1
.IP
.nf
void \fBGoRegPolygonAnglePrecond\fP (GObjectId \fIregpoly\fP, 
		GBool (*\fIf\fP) (GObjectId, GNumber*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoRegPolygonAnglePostcond\fP (GObjectId \fIregpoly\fP, 
		void (*\fIf\fP) (GObjectId),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoRegPolygonNbPointPrecond\fP (GObjectId \fIregpoly\fP, 
		GBool (*\fIf\fP) (GObjectId, int*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoRegPolygonNbPointPostcond\fP (GObjectId \fIregpoly\fP,
		void (*\fIf\fP) (GObjectId),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoRegPolygonRadiusPrecond\fP (GObjectId \fIregpoly\fP, 
		GBool (*\fIf\fP) (GObjectId, GNumber*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoRegPolygonRadiusPostcond\fP (GObjectId \fIregpoly\fP, 
		void (*\fIf\fP) (GObjectId),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoRegPolygonResetPrecond\fP (GObjectId \fIregpoly\fP, 
		GBool (*\fIf\fP) (GObjectId, int*, GNumber*, GNumber*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoRegPolygonResetPostcond\fP (GObjectId \fIregpoly\fP, 
		void (*\fIf\fP) (GObjectId),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
.fi
.sp 1
.RS .8i
.IP \fIDescription\fP .3i
See \fBGoRegPolygon\fP following members :
.sp 1
.nf
void anglePrecond (GBool (*\fIf\fP) (void*, GoRegPolygon*, GNumber*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void anglePostcond (void (*\fIf\fP) (void*, GoRegPolygon*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void nbPointPrecond (GBool (*\fIf\fP) (void*, GoRegPolygon*, int*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void nbPointPostcond (void (*\fIf\fP) (void*, GoRegPolygon*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void radiusPrecond (GBool (*\fIf\fP) (void*, GoRegPolygon*, GNumber*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void radiusPostcond (void (*\fIf\fP) (void*, GoRegPolygon*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void resetPrecond (GBool (*\fIf\fP) (void*, GoRegPolygon*, int*, GNumber*, GNumber*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void resetPostcond (void (*\fIf\fP) (void*, GoRegPolygon*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.fi
.RE
.SH
\fBUSER INTERACTIONS\fP
.IP
The following strings may be associated with event description strings in GoUI
files to perform actions on \fBGoRegPolygon\fP objects (see \fBGoUI\fP
documentation for more information on this topic). Most of the time,
these strings refer to name-like public functions or have an obvious
signification, thus description will only be given if absolutely necessary.
.sp 1
.IP
.nf
\fBangle\fP (GNumber)
\fBradius\fP (GNumber)
\fBnbPoint\fP (unsigned int)
\fBreset\fP (unsigned int, GNumber, GNumber)
.fi
.RS .8i
.IP \fIDescription\fP .3i
same as member functions.
.RE
.sp1
.IP
.nf
\fBaddEdge\fP ()
\fBdelEdge\fP ()
.fi
.RS .8i
.IP \fIDescription\fP .3i
increment/decrement the number of summits, leaving \fIangle\fP and \fIradius\fP
unchanged.
.RE
.SH
\fBUSAGE INFORMATION\fP
.IP
If willing to use pre/postconditions on object creation,
one should use \fBGoRegPolygon::create\fP instead of the public
\fBGoRegPolygon\fP constructor; this is highly recommended.
.SH
\fBSEE ALSO\fP
.IP
\fBGo\fP, \fBGoMetaclass\fP, \fBGoStdDS\fP, \fBGoStdDSMetaclass\fP,
\fBGoGeometric\fP, \fBGoGeometricMetaclass\fP, \fBGoPolypoint\fP,
\fBGoPolypointMetaclass\fP, \fBGoPolyline\fP, \fBGoPolylineMetaclass\fP,
\fBGoPolygon\fP, \fBGoPolygonMetaclass\fP and \fBGoRegPolygonMetaclass\fP
classes.
.nrPN \n%

