.\" $Id: Tau.n,v 1.1.1.1 1992/03/18 09:40:21 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoTauSpline 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoTauSpline\fP \(em the tau object class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tau.h>\fP
.SH 
\fBCLASS\fP
.IP
\fBGoTauSpline\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGoPolypoint\fP class
.IP \(em 3
\fBGoGeometric\fP class
.IP \(em 3
\fBGoStdDS\fP class
.IP \(em 3
\fBGo\fP class.
.RE
.SH
\fBDESCRIPTION\fP
.IP
\fBGoTauSpline\fP is a subclass of \fBGoCubic\fP implementing Tau splines. 
A Tau spline is an interpolating spline (i.e. passing through its control
points) with \fItension\fP and \fIbias\fP. For a discussion about
\fItension\fP, see \fBGoCubic\fP man pages. \fIBias\fP refers to the symetry of
the curve near a control point. A highly biased curve will be flatter on one
side of a knot than on the other. By the varying \fItension\fP and \fIbias\fP
suitably, curve shape can be altered considerably. Their default values are
respectively 1.0 and 0.0.
.sp 1
.br
.nf
.ta .15i .25i 1.0i
class GoTauSpline : public GoPolypoint {

	public:

		static GoTauSplineMetaclass* metaclass ();
		static GoTauSpline* create ();
		static GoTauSpline* create (int, const GPoint*);

		GoTauSpline ();
		GoTauSpline (int, const GPoint*);
		GNumber bias () const;
		GBool bias (GNumber);

		/*
		 * \fBpre and post conditions:\fP
		 */

		void biasPrecond (GBool (*) (void*, const GoTauSpline*, GNumber*),
			void* closure, GAddOrRemove = GADD);
		void biasPostcond (void (*) (void*, GoTauSpline*),
			void* closure, GAddOrRemove = GADD);
};
.fi
.SH
\fBPUBLIC METHODS\fP
.IP
\fBGoTauSplineMetaclass\fP* \fBmetaclass\fP ()
.RS .8i
.IP \fIDescription\fP .3i
This static member function returns the \fBGoTauSplineMetaclass\fP instance.
.RE
.sp 1
.IP
.nf
\fBGoTauSpline\fP* \fBcreate\fP ()
\fBGoTauSpline\fP* \fBcreate\fP (int \fInb\fP, const GPoint* \fIpts\fP)
.fi
.RS .8i
.IP \fIDescription\fP .3i
These static member functions are constructors with pre/postconditions.
They return a pointer on a new instance of \fBGoTauSpline\fP if no precondition
refuses the creation, else they return NULL;
.IP \fInb\fP .3i
Specifies the number of control points in the array \fIpts\fP
.IP \fIpts\fP .3i
Specifies the control points array.
.RE
.sp 1
.IP
.nf
\fBGoTauSpline\fP ();
\fBGoTauSpline\fP (int \fInb\fP,const GPoint* \fIpts\fP);
.fi
.RS .8i
.IP \fIDescription\fP .3i
Constructors. The default values of \fItension\fP and
\fIbias\fP attribute are respectively 1.0 and 0.
.IP \fInb\fP .3i
Specifies the number of elements in \fIpts\fP.
.IP \fIpts\fP .3i
Specifies the control points array.
.RE
.sp 1
.IP
GNumber \fBbias\fP ();
.RS .8i
.IP \fIDescription\fP .3i
This method returns the bias value.
.RE
.sp 1
.IP
GBool \fBbias\fP (GNumber \fIvalue\fP);
.RS .8i
.IP \fIDescription\fP .3i
This method sets the attribute bias to \fIvalue\fP.
.br
If none of the \fBbiasPrecond\fP preconditions returned GFALSE, the action is
performed with the parameter \fIvalue\fP possibly modify by the preconditions.
If the action succeeds, \fBbiasPostcond\fP postconditions are called and the
method returns GTRUE. Otherwise, it returns GFALSE.
.IP \fIvalue\fP .3i
Specifies the new bias value.
.RE
.sp 1
.IP
.nf
void \fBbiasPrecond\fP (GBool (*\fIf\fP) (void* \fIclosure\fP, const GoTauSpline* \fItau\fP, GNumber* \fInewVal\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBbiasPostcond\fP (void (*\fIf\fP) (void* \fIclosure\fP, GoTauSpline* \fItau\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .3i
These methods allow to add or remove functions to the pre/post conditions lists
triggered by \fBbias\fP (GNumber) member function.
.IP \fIf\fP .3i
Specifies programmer's function to be added/removed.
.IP \fIclosure\fP .3i
Specifies programmer's parameter to call the function with.
.IP \fItau\fP .3i
Specifies the \fBGoTauSpline\fP object involved (i.e. \fIthis\fP).
.IP \fInewVal\fP
Specifies the new bias value. May be modified by \fIf\fP.
.IP \fIadd\fP .3i
Specifies whether to add or remove the function \fIf\fP from the list.
.RE
.SH
\fBC BINDING\fP
.SS 
\fBHeader\fP
.IP
#include <Go/cTau.h>
.DE
.SS 
\fBResources\fP
.IP
The following table defines a set of Go resources used by the programmer
to specify data.  The programmer can also set the resource values for the 
inherited classes to set attributes for this object.
The codes in the access column indicate if the given resource can be set by
using \fBGoSetValues\fP (\fBS\fP), retrieved by using \fBGoGetValues\fP
(\fBG\fP), or is not applicable (\fBN/A\fP).
.br
For superclass resources, see superclass man pages.
.br
See also Section 2.
.sp 1
.ps 8
.DS
.TS
center box;
cB sss
lB lB lB lB
l l l l.
GoTauSpline Resource GSet
.sp
=
Name	Type	Default	Access
.sp
_
goNbias	GNumber	0.0	GS
.TE
.DE
.ps 10

.SS 
\fBFunctions\fP
.IP
void \fBGoTauSplineInitialize\fP ();
.RS .8i
.IP \fIDescription\fP .3i
This function must be called before any use of the GoTauSpline C Binding.
.RE
.sp 1
.IP
.nf
GObjectId \fBGoTauSplineCreate\fP (int \fInb\fP, const GPoint* \fIpts\fP);
GObjectId \fBGoTauSplineMetaclass\fP ();
GNumber \fBGoTauSplineBias\fP (GObjectId \fItau\fP);
GBool \fBGoTauSplineSetBias\fP (GObjectId \fItau\fP, GNumber \fIvalue\fP);
.fi
.sp 1
.RS .8i
.IP \fIDescription\fP .3i
See \fBGoTauSpline\fP following members :
.sp 1
.nf
GoTauSpline* create (int, const GPoint*).
GoMetaclass* metaclass ().
GNumber bias ().
GBool bias (GNumber).
.fi
.RE
.sp 1
.IP
.nf
void \fBGoTauSplineBiasPrecond\fP (GObjectId \fItau\fP, 
		GBool (*\fIf\fP) (GObjectId, GNumber*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoTauSplineBiasPostcond\fP (GObjectId \fItau\fP, 
		void (*\fIf\fP) (GObjectId, GNumber),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
.fi
.sp 1
.RS .8i
.IP \fIDescription\fP .3i
See \fBGoTauSpline\fP following members :
.sp 1
.nf
void biasPrecond (GBool (*\fIf\fP) (void*, GoTauSpline*, GNumber*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void biasPostcond (void (*\fIf\fP) (void*, GoTauSpline*, GNumber),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.fi
.RE
.SH
\fBUSER INTERACTIONS\fP
.IP
The following strings may be associated with event description strings in GoUI
files to perform actions on \fBGoTauSpline\fP objects (see \fBGoUI\fP
documentation for more information on this topic). Most of the time,
these strings refer to name-like public functions or have an obvious
signification, thus description will only be given if absolutely necessary.
.IP
\fBbias\fP (GNumber)
.RS .8i
.IP \fIDescription\fP .3i
same as member functions.
.RE
.SH
\fBUSAGE INFORMATION\fP
.IP
If willing to use pre/postconditions on object creation,
one should use \fBGoTauSpline::create\fP instead of the public
\fBGoTauSpline\fP constructor; this is highly recommended.
.SH
\fBSEE ALSO\fP
.IP
\fBGo\fP, \fBGoMetaclass\fP, \fBGoStdDS\fP, \fBGoStdDSMetaclass\fP,
\fBGoGeometric\fP, \fBGoGeometricMetaclass\fP, \fBGoPolypoint\fP,
\fBGoPolypointMetaclass\fP, \fBGoCurve\fP, \fBGoCurveMetaclass\fP,
\fBGoCubic\fP, \fBGoCubicMetaclass\fP and \fBGoTauSplineMetaclass\fP classes.
.nrPN \n%

