.\" $Id: Text.n,v 1.3 1992/12/30 17:02:50 andre Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoText 3Go "December 1992" "Version 1.2" "Go Reference Manual"
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoText\fP \(em The text class
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/GoText.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGoText\fP inherits behavior from class \fBGoTextual\fP.
.RS 10
.RE
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBGoText\fP is a multi-attributed block of text, ie it is built
with segments which can be can be processed separately as a \fBGoLabel\fP.
By the way, a \fBGoText\fP may use several fonts, colors, line attributes
and so on. The programming interface of a \fBGoText\fP is inherited from
the \fBGoTextual\fP class. At the creation time, the segments of a \fBGoText\fP
share the graphical attributes defined at the \fBGoTextual\fP level.
To change the attributes of a sub-string (defined by two positions
inside the string), new functions have been provided (see below).
A segment may be highlighted with a brush for its background, a pen for its underlining
and a textbrush for its string. For building mathematical formulaes or trade mrks, a segment may be exponentied or indiced by adjusting its baseline.
.br
To highlight a sub-string the user can define styles which are combination of the attributes described previously.
The function to get or set the styles are the same that those used to update the \fBGoText\fP (except that for the GoText, their name begins by the prefix \fItext\fP).
For their description, see the corresponding functions for the GoText class.


To be usable, a \fBGoText\fP must be linked with a formatter (see \fIGFormatter(3Go)\fP).
Four kinds of formatters are yet available: the \fBGSimpleFormatter\fP
(see \fIGSimpleFormatter(3Go)\fP), the \fBGMCFormatter\fP (see \fIGMCFormatter(3Go)\fP), the \fBGMBFormatter\fP (see \fIGMBFormatter(3Go)\fP and the \fBGCircleFormatter\fP (see \fIGCircleFormatter(3Go)\fP).
.br
.sp 2
.br
.nf
.ta .15i .25i 2.0i 2.50i

enum GStyleValues
{
    GBACKGROUND_SHBRUSH	= (1 << 1),
    GSTRING_SHTEXTBRUSH	= (1 << 2),
    GUNDERLINE_SHPEN	= (1 << 3),
    GMAP_UNDERLINE_SEG	= (1 << 4),
    GMAP_BACKGROUND_SEG	= (1 << 5),
    GLINE_HEIGHT	= (1 << 6),
    GUNDERLINE_POSITION	= (1 << 7),
    GEXTRA_BASELINE	= (1 << 8),
};


class GStyle{
public:
			GStyle();
			GStyle (GStyle*);
			~GStyle();

    /* get functions */
    GShTextBrush*	stringShTextBrush() const;
    GShBrush*	backgroundShBrush() const;
    GShPen*	underlineShPen() const;
    GNumber	lineHeight() const;
    GNumber	underlinePosition() const;
    GBool	mapBackgroundSeg() const;
    GBool	mapUnderlineSeg() const;
    GNumber	extraBaseline() const;
    ulong	mask() const;

    /* set functions */
    void	lineHeight (GNumber);
    void	extraBaseline (GNumber);
    void	underlinePosition (GNumber);
    void	mapBackgroundSeg (GBool);
    void	mapUnderlineSeg (GBool);
    void	backgroundShBrush (const GShBrush*);
    void	backgroundShBrush (ulong mask,const GBrushValues*);
    void	backgroundShBrush (const GBrush*);
    void	underlineShPen (const GShPen*);
    void	underlineShPen (ulong mask, const GPenValues*);
    void	underlineShPen (const GPen*);
    void	stringShTextBrush (const GShTextBrush*);
    void	stringShTextBrush (ulong mask,const GTextBrushValues*);
    void	stringShTextBrush (const GTextBrush*);
};


class GoText{
public:
			GoText();
    static GoMetaclass*	metaclass();
    static GoText*	create();

    /* formatter methods */
    void	formatter (GFormatter* form);
    GFormatter*	formatter();

    /* attributes methods */
    void	background (GBool, GPos p1, GPos p2);
    GBool	extraBaseline (GNumber, GPos p1, GPos p2);

    /* modifying shared objects methods */
    void	textUnderlinePen (ulong mask, const GPenValues*, GPos, GPos);
    void	textUnderlinePen (const GShPen* , GPos, GPos);
    void	textUnderlinePen (const GPen*, GPos, GPos);
    void	textStringTextBrush (ulong mask, const GTextBrushValues*, GPos, GPos);
    void	textStringTextBrush (const GShTextBrush*, GPos, GPos);
    void	textStringTextBrush (const GTextBrush*, GPos, GPos);
    void	textBackgroundBrush (ulong mask, const GBrushValues*, GPos, GPos);
    void	textBackgroundBrush (const GShBrush*, GPos, GPos);
    void	textBackgroundBrush (const GBrush*, GPos, GPos);
    void	highlight (const GStyle&, GPos, GPos);

    /* extra features */
    GBool	addGo (Go* go, GPos p);
    GoText*	extract (GPos p1, GPos p2);
    GBool	merge (GoText*, GPos p);
}
.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.sp 1
.IP
\fBGoText\fP()
.RS .8i
.IP \fIDescription\fP .5i
This function allows to create an instance of the \fBGoText\fP class.
.RE
.sp 1
.IP
static GoText* \fBcreate\fP();
.RS .8i
.IP \fIDescription\fP .5i
Creates a new GoText instance. Returns the created text.
.RE
.sp 1
.IP
static GoMetaclass* \fBmetaclass\fP();
.RS .8i
.IP \fIDescription\fP .5i
Returns a pointer to the metaclass object of \fIthis\fP.
.RE
.sp 1
.IP
GFormatter* \fBformatter\fP()
.br
void \fBformatter\fP (GFormatter* \fIf\fP)
.RS .8i
.IP \fIDescription\fP .5i
This function is used to get/link the text formatter.
.IP \fIf\fP .5i
.br
Specifies the formatter to be linked.
If the text is already linked with a formatter, \fIf\fP must be
of the same type than the previous one.
.RE
.sp 1
.IP
void \fBbackground\fP (GBool \fIset\fP, GPos \fIp1\fP, GPos \fIp2\fP)
.RS .8i
.IP \fIDescription\fP .5i
This function is used to set the background mapping state of the words inside the given
portion.
.IP \fIset\fP .5i
.br
Specifies the state of the background of the state.
.IP \fIp1,p2\fP .5i
.br
Specifies the boundaries of the portion.
.RE
.sp 1
.IP
void \fBextraBaseline\fP (GNumber \fIvalue\fP, GPos \fIp1\fP, GPos \fIp2\fP)
.RS .8i
.IP \fIDescription\fP .5i
This function is used to set the extrabaseline of the words inside the given
portion.
.IP \fIvalue\fP .5i
.br
Specifies the value of the extrabaseline. If \fIvalue\fP is negative the postion is indiced. If \fIvalue\fP is positive, the portion is exponentied.
.IP \fIp1,p2\fP .5i
.br
Specifies the boundaries of the portion.
.RE
.sp 1
.IP
void \fBtextStringTextBrush\fP (ulong \fImask\fP, const GTextBrushValues* \fIval\fP, GPos \fIp1\fP, GPos \fIp2\fP);
.br
void \fBtextStringTextBrush\fP (const GShTextBrush* \fIshtextbrush\fP, GPos \fIp1\fP, GPos \fIp2\fP );
.br
void \fBtextStringTextBrush\fP (const GTextBrush* \fItextbrush\fP, GPos \fIp1\fP, GPos \fIp2\fP);
.RS .8i
.IP \fIDescription\fP .5i
This function is used to modify the textBrushes (which may be named) of the given portion
of the text. Several programming interfaces are provided. When used with a mask and values
function, the TextBrushes are first unnamed.
.IP \fIp1,p2\fP .5i
.br
Specifies the boundaries of the portion.
.RE
.sp 1
.IP
void \fBtextBackgroundBrush\fP (ulong \fImask\fP, const GBrushValues* \fIval\fP, GPos \fIp1\fP, GPos \fIp2\fP);
.br
void \fBtextBackgroundBrush\fP (const GShBrush* \fIshbrush\fP, GPos \fIp1\fP, GPos \fIp2\fP );
.br
void \fBtextBackgroundBrush\fP (const GBrush* \fIbrush\fP, GPos \fIp1\fP, GPos \fIp2\fP);
.RS .8i
.IP \fIDescription\fP .5i
This function is used to modify the Brushes (which may be named) of the backgrounds of the
words between the given portion of the text. Several programming interfaces are provided.
When used with a mask and values function, the Brushes are first unnamed.
.IP \fIp1,p2\fP .5i
.br
Specifies the boundaries of the portion.
.RE
.sp 1
.IP
void \fBtextUnderlinePen\fP (ulong \fImask\fP, const GPenValues* \fIval\fP, GPos \fIp1\fP, GPos \fIp2\fP);
.br
void \fBtextUnderlinePen\fP (const GShPen* \fIshpen\fP, GPos \fIp1\fP, GPos \fIp2\fP );
.br
void \fBtextUnderlinePen\fP (const GPen* \fIpen\fP, GPos \fIp1\fP, GPos \fIp2\fP);
.RS .8i
.IP \fIDescription\fP .5i
This function is used to modify the Pens (which may be named) used to underline the
words between the given portion of the text. Several programming interfaces are provided.
When used with a mask and values function, the Pens are first unnamed.
.IP \fIp1,p2\fP .5i
.br
Specifies the boundaries of the portion.
.RE
.sp 1
.IP
void \fBhighlight\fP (const GStyle \fIstyle\fP&, GPos \fIp1\fP, GPos \fIp2\fP);
.RS .8i
.IP \fIDescription\fP .5i
This function is used to highlight the words between the given portion of the text.
.IP \fIstyle\fP .5i
.br
Specifies the style to be used.
.IP \fIp1,p2\fP .5i
.br
Specifies the boundaries of the portion.
.RE
.sp 1
.IP
void \fBaddGo\fP (Go* \fIgo\fP&, GPos \fIpos\fP);
.RS .8i
.IP \fIDescription\fP .5i
This function is used to include an object inside the text at the given position.
.IP \fIgo\fP .5i
.br
Specifies the object to include which may be a composition.
.IP \fIpos\fP .5i
.br
Specifies the position of the inclusion.
.RE
.IP
GoText* \fBextract\fP (GPos \fIp1\fP, GPos \fIp2\fP);
.RS .8i
.IP \fIDescription\fP .5i
This function is used to create a new GoText by partially copying this. The text attributes and its formatter are duplicated too. This function may be useful to copy a text chapter or paragraph in order to edit it.
.IP \fIp1,p2\fP .5i
.br
Specifies the boundaries of the extraction.
.RE
.IP
void \fBmerge\fP (GoText* \fItext\fP, GPos \fIpos\fP);
.RS .8i
.IP \fIDescription\fP .5i
This function is used to merge the given text contents. After the merge, text is automatically deleted. This function is useful to add a new chapter or a new sentence inside this.
.IP \fItext\fP .5i
.br
Specifies the text to be merged.
.IP \fIpos\fP .5i
.br
Specifies the position of the merge.
.RE
.sp 1
.SH
\fBUSER INTERACTIONS\fP
.IP
see \fIGoTextual(3Go)\fP.
.SH
\fBC BINDING\fP
.SS
\fBHeader\fP
.IP
#include <Go/cText.h>
.SS
\fBFunctions\fP
.sp 1
.IP
void \fBGoTextInitialize\fP()
.RS .8i
.IP \fIDescription\fP .5i
This function must be called before any use of the GoText C Binding.
.RE
.sp 1
.IP
GObjectId \fBGoTextMetaclass\fP()
.RS .8i
.IP \fIDescription\fP .5i
This function returns the GoText metaclass.
.RE
.sp 1
.IP
GObjectId \fBGoTextCreate\fP()
.RS .8i
.IP \fIDescription\fP .5i
This function creates an instance of the GoText class.
.RE
.sp 1
.IP
void \fBGoTextSetFormatter\fP (GGObjectId \fItext\fP, GGObjectId \fIf\fP)
.RS .8i
.IP \fIDescription\fP .5i
This function sets the formatter \fIf\fP to the text \fItext\fP.
.RE
.sp 1
.IP
GObjectId \fBGoTextGetFormatter\fP()
.RS .8i
.IP \fIDescription\fP .5i
This function returns the formatter applied to the GoText.
.RE
.sp1
.SH
\fBSEE ALSO\fP
.IP
\fBGo\fP, \fBGoUI\fP, \fBGoTextual\fP, \fBGoTextualMetaclass\fP and \fBFormatter\fP  classes.
.nrPN \n%
