.\" $Id: Textual.n,v 1.3 1992/12/28 10:33:31 andre Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoTextual 3Go "February 1992" "Version 1.1" "Go Reference Manual"
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoTextual\fP \(em The textual abstract class
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Textual.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGoTextual\fP inherits behavior from class \fBGoStdDS\fP.
.RS 10
.RE
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBGoTextual\fP class is the general class used for the text management from which
are derived the following predefined text classes: \fBGoLabel\fP, \fBGoSimpleText\fP, 
\fBGoScrolledText\fP and \fBGoText\fP. The main purpose of the \fBGoTextual\fP class is
to provide the same programming interface and a similar behaviour for all these sub-classes
(most of its functions are virtual) and to manage their common properties. In addition, the
\fBGoTextual\fP class allows the user to set some pre/post conditions.
.br
.sp 1
Any \fBGoTextual\fP is made of a text string, a cursor, a background and an underlining. Any
of these four components may be mapped or not. At the creation time, only the text string
is mapped. A \fBTextBrush\fP is provided to draw the text string, a \fBBrush\fP for the
background, a \fBBrush\fP for the text selection (highlighted sub-string), a \fBPen\fP for
the cursor and one more \fBPen\fP for the underlining. These objects may be set and
modified with the appropriates functions (see \fBBrush\fP, \fBTextBrush\fP, and \fBPen\fP).
.br
.sp 1
Unlike the \fBGoLabel\fP and the \fBGoSimpleText\fP, the \fBGoText\fP is multi-attributed
(ie compounded with segments, each one containing its own stringTextBrush, underlinePen,
backgroundBrush, and underlining position). In order to modify the apperance of a \fBGoText\fP
substring, some specific functions are given. Moreover, to be usable, a \fBGoText\fP must be
linked with a formatter (see \fBForm\fP).
.br
.sp 1
Each text object is characterized by some manipulating functions and graphical attributes
which enhance its displaying:
.RS 10
.IP \(em 3
\fBJustification\fP: 4 possibilities are availables (see below). The left and right justification
is available only for a \fBGoText\fP linked with a \fPMCFormatter\fP. The text string
is not editable with a GLR_JUSTIFICATION, it must be changed before.
.IP \(em 3
\fBUnderlining position\fP: y position of the underlining;
.IP \(em 3
\fBInterline\fP: space between two lines (available only for the \fBGoText\fP and the
\fBGoSimpleText\fP classes);
.IP \(em 3
\fBPresentation\fP: general presentation of the text obtained by playing upon lower and
upper cases, 4 possibilities are availables (see below). Unless of a GNO_PRESENTATION
presentation, it is always maintained when any modification of the text occurs,
especially when editing.
.RE
.br
.sp2
.IP
A string made of n characters begins at the position 0 and ends at the position n-1.
.br
With the exception of the \fBGoScrolledText\fP, the screen's textual data adjusts to the
application writer's needs.
.br
The provided pre/postconditions allow the programmer to be notified of the text string
modifications (char or string insertion/deletion/substitution for instance), the
attributes modifications (underlining, lineHeight change, justification, etc ...),
the cursor movement and the selection of a sub-string.
.br
Some tools functions are provided to set/get the cursor position, to search a pattern
inside the string, to map or unmap the textual components, and so on.
.br
The \fBGoUI\fP object maintains a text clipboard available for the application which
can cut/copy/paste any string from/to any \fBGoTextual\fP (see GoUI), and
provides others functions to manipulate interactively the contents (word, line and text 
selection for instance).
.br
A new and important feature of the \fBGoTextual\fP is the multiple selections management which lets the application to process simulteanously the string at several portions (underlining and color modification for instance).
.br
.sp2
.RS 10
.br
.nf
.ta .15i .25i 1.50i

/* some definitions */

/* justifications */
typedef enum	{
	GLEFT_JUSTIFICATION,
	GCENTER_JUSTIFICATION,
	GRIGHT_JUSTIFICATION,
	GLR_JUSTIFICATION
	} GJustification;

/* presentations */
typedef enum	{
	GNO_PRESENTATION,
	GLOWER_PRESENTATION,
	GUPPER_PRESENTATION,
	GTITLE_PRESENTATION
	} GPresentation;

/* searching directions */
typedef enum	{
	GTEXT_FORWARD,
	GTEXT_BACKWARD
	} GTextDirection;

/* languages used for word-hyphenation */
typedef enum	{
	GGERMAN,
	GSPANISH,
	GFRENCH,
	GENGLISH,
	GITALIAN,
	GPORTUGUESE,
	GNO_LANGUAGE} Language;

/* types used to manipulate lines and index inside the string */
typedef int	GPos;	

/* types and structures used for value changes pre/postconds */
enum GModifyValueType{
    GINSERT_CHAR_NOTIFY,
    GDELETE_CHAR_NOTIFY,
    GINSERT_STRING_NOTIFY,
    GDELETE_STRING_NOTIFY,
    GSET_STRING_NOTIFY,
    GREPLACE_CHAR_NOTIFY,
    GREPLACE_STRING_NOTIFY,
    GPRESENTATION_CHANGE_NOTIFY
};


/* structure used for GINSERT_CHAR_NOTIFY, GDELETE_CHAR_NOTIFY, GREPLACE_CHAR_NOTIFY */
typedef struct
{
    char	Char;
    GPos	pos;
} GcharStruct;


/* structure used for GREPLACE_STRING_NOTIFY, GSET_STRING_NOTIFY, GINSERT_STRING_NOTIFY,
GDELETE_STRING_NOTIFY */
typedef struct
{
    const char*	str;
    GPos	len;
    GPos	pos;   /* used for GINSERT_STRING_NOTIFY and GREPLACE_STRING_NOTIFY */
    GPos	oldStringSize;   /* used for GREPLACE_STRING_NOTIFY only */
} GstringStruct;


typedef struct
{
    GModifyValueType type;
    union
	{
	    GcharValueStruct	charValue;
	    GstringValueStruct	stringValue;
	    GPresentation	presentation;
	};
} GModifyValueStruct;


/* types and structure used for attributes changes pre/postconds */
enum GModifyAttributeType{
    GJUSTIFICATION_CHANGE_NOTIFY,
    GINTERLINE_CHANGE_NOTIFY,
    GUNDERLINE_POSITION_CHANGE_NOTIFY,
    GLINEHEIGHT_CHANGE_NOTIFY,
    GUNDERLINE_SET_NOTIFY
};

typedef struct
{
    GModifyAttributeType	type;
    GPos			firstPosition;   /* used for GUNDERLINE_SET_NOTIFY */
    GPos			lastPosition;   /* used for GUNDERLINE_SET_NOTIFY */
    union
	{
	    GJustification	justification;
	    GNumber		interline;
	    GNumber		underlinePos;
	    GNumber		lineHeight;
	    GBool		underlineSet;
	};
}GModifyAttributeStruct;


/* structure used for GMARGIN_SIDE_CHANGE_NOTIFY */

typedef struct
{
    GNumber	margin;
    GMarginSide	marginSide;
}GMarginStruct;



/**********************
*   class GoTextual
**********************/

class GoTextual: public GoStdDS {
    friend class GoTextualMetaclass;

public:

    static GoTextualMetaclass* metaclass();

    /* insertion methods */
    GBool		insertChar (char Char, GPos pos);
    GBool		insertString (const char* string, GPos length,
			GPos pos);

    /* deletion methods */
    GBool		deleteChar (GPos pos);
    GBool		deleteString (GPos stringLen, GPos pos);

    /* string methods */
    GBool		setString (const char* string, GPos length);
    const char*		getString() const; 
    GPos		length() const;
    GPos		containChar (char Char, GPos pos = 0, GTextDirection
			dir =GTEXT_FORWARD, GBool caseMatching = GFALSE) const;
    GPos		containString (char* string, GPos length, GPos pos = 0,
			GTextDirection dir = GTEXT_FORWARD,
			GBool caseMatching = GFALSE) const;
    char		operator[](GPos pos) const;
    GBool		replaceChar (char Char, GPos pos);
    GBool		replaceString (GPos pos, GPos oldStringSize,
			char* newString, GPos newStringSize);


    /* attributes methods */
    GBrush&		backgroundBrush() const;
    GBrush&		selectionBrush() const;
    GTextBrush&		stringTextBrush() const;
    GPen&		cursorPen() const;
    GPen&		underlinePen() const;
    GBool		presentation (GPresentation);
    GPresentation 	presentation() const;
    GBool		lineHeight (GNumber h, GPos pos1, GPos pos2);
    GNumber		lineHeight() const;
    GNumber		lineHeightMax() const;
    GBool		underlinePosition (GNumber u, GPos pos1, GPos pos2);
    GBool		underline (GBool set, GPos pos1, GPos pos2);
    GNumber		underlinePosition() const;
    GBool		justification (GJustification);
    GJustification	justification() const;
    GBool		interline (GNumber inter);
    GNumber		interline() const;
    GBool		margin (GNumber value, GMarginSide side);
    GNumber		margin (GMarginSide side) const;


    /* cursor methods */
    void		cursorUp();
    void		cursorDown();
    void		cursorLeft();
    void		cursorRight();
    void		cursorBegText();
    void		cursorEndText();
    void		cursorBegLine();
    void		cursorEndLine();
    GBool		currentPos (GPos pos);
    GPos		getCurrentPos() const;


    /* tools methods */
    GPos		nbLines() const;
    int			lineNumber (GPos pos) const;
    GPos		xToPos  (int line, GNumber x) const;
    GPos		xyToPos  (GPoint& relPoint) const;
    GPoint		posToXy  (GPos pos) const;
    GPos		begLinePos (int line) const;
    GPos		endLinePos (int line) const;
    void		wordBoundaries (GPos pos, GPos& wordFirstPosition,
			GPos& wordLastPosition);
    void		lineBoundaries (GPos pos, GPos& lineFirstPosition,
			GPos& lineLastPosition);
    GRegion		boundariesToRegion (GPos pos1, GPos pos2) const;
    GNumber     	width();
    GNumber     	height();
    void		resize();


    /* map methods */
    void		mapString (GBool set);
    void		mapBackground (GBool set);
    void		mapCursor (GBool set);
    void		mapUnderline (GBool set);
    GBool		stringMapped() const;
    GBool		backgroundMapped() const;
    GBool		cursorMapped() const;
    GBool		underlineMapped() const;


    /* selection operations */
    GBool		selectPortion (GPos pos1, GPos pos2, GBool set);
    GPos		firstSelected();
    GPos		lastSelected();
    char*		selectedString();
    GTextList&		selectionList() const;


    /* Pre and Post Conditions */

    /* mofify value */
    void		modifyValuePrecond (GBool (*)(void*, const GoTextual*,
			GModifyValueStruct*), void* closure,
			GAddOrRemove = GADD);
    void		modifyValuePostcond (void (*)(void*, GoTextual*,
			GModifyValueStruct*), void* closure,
			GAddOrRemove = GADD);

    /* current position change */
    void		currentPosPrecond (GBool (*)(void*, const GoTextual*,
			GPos), void* closure, GAddOrRemove = GADD);
    void		currentPosPostcond (void (*)(void*, GoTextual*, GPos),
			void* closure, GAddOrRemove = GADD);

    /* attribute */
    void		modifyAttributePrecond (GBool (*)(void*,
			const GoTextual*, GModifyAttributeStruct*),
			void* closure, GAddOrRemove = GADD);
    void		modifyAttributePostcond (void (*)(void*, GoTextual*,
			GModifyAttributeStruct*), void* closure,
			GAddOrRemove = GADD);

    /* selection */
    void		selectionPrecond (GBool (*)(void*, const GoTextual*,
			GPos, GPos), void* closure, GAddOrRemove = GADD);
    void		selectionPostcond (void (*)(void*, GoTextual*, GPos,
			GPos), void* closure, GAddOrRemove = GADD);

    /* GoStream methods */
    static int		save (const GoTextual*, GoStream*);
    static int		readParams (GoTextual*, GoStream*);
}


.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.sp
.IP
GBool \fBinsertChar\fP (char \fIChar\fP)
.br
GBool \fBinsertChar\fP (char \fIChar\fP, GPos \fIpos\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method is used to insert a character. Returns the result of the preconditions call, if any, TRUE otherwise.
.IP \fIChar\fP .5i
.br
Specifies the character to be inserted.
.IP \fIpos\fP .5i
.br
Specifies the position of the insertion. When missing, \fIChar\fP is inserted at the current position.
.RE
.sp1
.IP
GBool \fBinsertString\fP (char* \fIstr\fP, ushort \fIsize\fP)
.br
GBool \fBinsertString\fP (char* \fIstr\fP, ushort \fIsize\fP, GPos \fIpos\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method is used to insert a string. Returns the result of the preconditions call, if any, TRUE otherwise.
.IP \fIstr\fP .5i
.br
Specifies the string to be inserted.
.IP \fIsize\fP .5i
.br
Specifies the size of the string to be inserted.
.IP \fIpos\fP .5i
.br
Specifies the position of the insertion. When missing, \fIstr\fP is inserted at the current position.
.RE
.sp1
.IP
GBool \fBdeleteChar\fP()
.br
GBool \fBdeleteChar\fP (GPos \fIpos\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method is used to delete a character.
Returns the result of the preconditions call, if any, TRUE otherwise.
.IP \fIpos\fP .5i
.br
Specifies the position of the deletion. When missing, the current character is deleted.
.RE
.sp1
.IP
GBool \fBdeleteString\fP (GPos \fIsize\fP)
.br
GBool \fBdeleteString\fP (GPos \fIsize\fP, GPos \fIpos\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method is used to delete a sub-string from the text.
Returns the result of the preconditions call, if any, TRUE otherwise.
.IP \fIsize\fP .5i
.br
Specifies the size of the sub-string to be deleted.
.IP \fIpos\fP .5i
.br
Specifies the position of the deletion. When missing, the string is deleted from the current position.
.RE
.sp1
.IP
GBool \fBsetString\fP (const char* \fIstr\fP, GPos \fIsize\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method is used to set a new string.
Returns the result of the preconditions call, if any, TRUE otherwise.
.IP \fIstr\fP .5i
.br
Specifies the adress of the string to be copied.
.IP \fIsize\fP .5i
.br
Specifies the size of the string.
.RE
.sp1
.IP
const char* \fBgetString\fP()
.RS .8i
.IP \fIDescription\fP .5i
This method returns the \fBGoTextual\fP string.
.RE
.sp1
.IP
char \fBoperator[]\fP (GPos \fIpos\fp)
.RS .8i
.IP \fIDescription\fP .5i
This method returns the character pointed by the given position.
.IP \fIpos\fP .5i
.br
Specifies the position of the char to be returned.
.RE
.sp1
.IP
GPos \fBlength\fP()
.RS .8i
.IP \fIDescription\fP .5i
This method returns the length of the \fBGoTextual\fP string.
.RE
.sp 1
.IP
GPos \fBcontainChar\fP (char \fIChar\fP, GPos \fIpos\fP, GTextDirection \fIdir\fP, GBool \fIcaseMatching\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method returns the position of the first occurence of \fIChar\fP from the text, beginning the search at the position \fIpos\fP, and with the direction \fIdir\fP.
.br
-1 is returned in case of failure.
.IP \fIChar\fP .5i
.br
Specifies the character to be searched.
.IP \fIpos\fP .5i
.br
Specifies the position where begins the search. When missing, the default value is 0.
.IP \fIdir\fP .5i
.br
Specifies the direction of the search. Two possibilities are availables: FORWARD and BACKWARD. When missing, the default value is FORWARD.
.IP \fIcaseMatching\fP .5i
.br
Specifies the letter case-matching criteria. When missing, the default value is FALSE, ie this criteria is not assumed.
.RE
.sp1
.IP
GPos \fBcontainString\fP (char* \fIpattern\fP, GPos \fIpos\fP, GTextDirection \fIdir\fP, GBool \fIcaseMatching\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method returns the position of the first occurence of \fIstr\fP from the text, beginning the search at the position \fIpos\fP and with the direction \fIdir\fP.
.br
-1 is returned in case of failure.
.IP \fIpattern\fP .5i
.br
Specifies the string to be searched.
.IP \fIpos\fP .5i
.br
Specifies the position where begins the search. When missing, the default value is 0.
.IP \fIdir\fP .5i
.br
Specifies the direction of the search. Two possibilities are availables: FORWARD and BACKWARD. When missing, the default value is FORWARD.
.IP \fIcaseMatching\fP .5i
.br
Specifies the letter case-matching criteria. When missing, the default value is FALSE, ie this criteria is not assumed.
.RE
.sp1
.IP
GBool \fBreplaceChar\fP (char \fIChar\fP, GPos \fIpos\fP)
.RS .8i
.IP \fIDescription\fP .5i
Replaces the character placed at the position \fIpos\fP by \fIChar\fP.
.\fIChar\fP and the replaced character must be a printables.
.br
Returns the result of the preconditions call, if any, TRUE otherwise.
.IP \fIChar\fP .5i
.br
Specifies the new character.
.IP \fIpos\fP .5i
.br
Specifies the position of the character to be replaced. When missing, \fipos\fp is equal to the current position.
.RE
.sp1
.IP
GBool \fBreplaceString\fP (GPos \fIpos\fP, ushort \fIoldStringSize\fP, char* \fInewString\fP, ushort \fInewStringSize\fP)
.RS .8i
.IP \fIDescription\fP .5i
.br
Replaces a sub string of the text by the given one.
.br
Returns the result of the preconditions call, if any, TRUE otherwise.
.br
.IP \fIpos\fP .5i
.br
Beginning position of the sub string to replace. All the characters of this sub string must be printables.
.br
.IP \fIoldStringSize\fP .5i
.br
Length of the substring to replace.
.br
.IP \fInewString\fP .5i
.br
New string to insert inside the text. All the characters of this string must be printables.
.br
.IP \fInewStringSize\fP .5i
.br
Length of the new string.
.RE
.sp 1
.IP
const Brush& \fBselectionBrush\fP()
.RS .8i
.IP \fIDescription\fP .5i
This method returns the Brush used to draw the selection (See \fBBrush\fP).
To change the appearance of the \fBGoTextual\fP selection, the user may act on this returned value. 
.RE
.sp 1
.IP
const Brush& \fBbackgroundBrush\fP()
.RS .8i
.IP \fIDescription\fP .5i
This method returns the Brush used to draw the background (See \fBBrush\fP).
To change the appearance of the \fBGoTextual\fP background, the user may act on this returned value. 
.RE
.sp 1
.IP
const TextBrush& \fBstringTextBrush\fP()
.RS .8i
.IP \fIDescription\fP .5i
This method returns the TextBrush used to draw the string (See \fBTextBrush\fP).
To change the string drawing of the \fBGoTextual\fP, the user may act on this returned value. In the case of a \fBGoText\fP, modifying this value provokes the change of the \fBTextBrush\fPs of the selected portion of text, or of the entire string if no selection is done.
.RE
.sp 1
.IP
const Pen& \fBcursorPen\fP()
.RS .8i
.IP \fIDescription\fP .5i
This method returns the Pen used to draw the insertion point (See \fBPen\fP).
To change the pen drawing of the \fBGoTextual\fP, the user may act on this returned value. 
.RE
.sp 1
.IP
const Pen& \fBunderlinePen\fP()
.RS .8i
.IP \fIDescription\fP .5i
This method returns the Pen used to draw the underline (See \fBPen\fP).
To change the underlining drawing of the \fBGoTextual\fP, the user may act on this returned value.
In the case of a \fBGoText\fP, modifying this value provokes the change of the \fBPen\fPs of the selected portion of text, or of the entire text if no selection is done.
.RE
.sp 1
.IP
justification \fBjustification\fP()
.br
GBool \fBjustification\fP (GJustification \fIj\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method is used to get/set the justification.
Returns the result of the preconditions call, if any, TRUE otherwise.
.IP \fIj\fP .5i
.br
Value of the justification to set.
.RE
.sp 1
.IP
GNumber \fBmargin\fP (GMarginSide \fIside\fP)
.br
GBool \fBmargin\fP (GNumber \fIvalue\fP, GMarginSide \fIside\fP)
.br
.RS .8i
.IP \fIDescription\fP .
This method is used to get/set the margin value.
Returns the result of the preconditions call, if any, TRUE otherwise.
.IP \fIvalue\fP .5i
.br
Value of the justification to set.
.IP \fIside\fP .5i
.br
Side on which the modification is done.
.RE
.sp 1
.IP
GNumber \fBinterline\fP()
.br
GBool \fBinterline\fP (GNumber \fIi\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method is used to get/set the inter-line spacing.
Returns the result of the preconditions call, if any, TRUE otherwise
(useful for GoSimpleText and GoText only).
.IP \fIi\fP .5i
.br
Value of the interline spacing to set. The space between two lines is equal to the product of the height of the second one by \fIs\fP.
.RE
.sp 1
.IP
GPresentation \fBpresentation\fP()
.br
GBool \fBpresentation\fP (GPresentation \fIpresentation\fP)
.RS .8i
.IP \fIDescription\fP .5i
These method allows the user to get/set the presentation of the text.
Returns the result of the preconditions call, if any, TRUE otherwise.
.IP \fIpresentation\fP .5i
.br
Specifies the presentation value.
.RE
.sp 1
.IP
GNumber \fBlineHeight\fP()
.br
GBool \fBlineHeight\fP (GNumber \fIh\fP, GPos \fIp1\fP, GPos \fIp2\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method allows the user to get/set the height of the text lines.
Returns the result of the preconditions call, if any, TRUE otherwise.
The given parameter is the mean height, to get the effective one use the
method described below.
.IP \fIh\fP .5i
.br
Specifies the height to set.
.IP \fIp1,p2\fP .5i
.br
Specifies the boundaries of the segment (useful for GoText only).
.RE
.sp 1
.IP
GNumber \fBlineHeightMax\fP()
.RS .8i
.IP \fIDescription\fP .5i
This method allows the user to get the effective height of the text lines.
.RE
.sp 1
.IP
void \fBunderline\fP (GBool \fIset\fP, GPos \fIp1\fP, GPos \fIp2\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method is used to underline or ununderline the given segment.
In the case of a \fBGoLabel\fP (see \fIGoLabel(3Go)\fP), only the third argument
is significant because the portion represents the entire string.
.IP \fIset\fP .5i
.br
Specifies the state of underlying to apply.
.IP \fIp1,p2\fP .5i
.br
Specifies the boundaries of the segment (useful for GoText only).
.RE
.sp 1
.IP
GNumber \fBunderlinePos\fP()
.br
GBool \fBunderlinePos\fP (GNumber \fIu\fP, GPos \fIp1\fP, GPos \fIp2\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method is used to get/set the Y underlining position.
Returns the result of the preconditions call, if any, TRUE otherwise.
In the case of a \fBGoText\fP, modifying this value provokes the modification on the selected portion of text, or on the entire text if no selection is done.
.IP \fIu\fP .5i
.br
Value of the Y position underline to set. The resulting underlineing position 	
is equal to the product of the line height by \fIu\fP.
.IP \fIp1,p2\fP .5i
.br
Specifies the boundaries of the segment (useful for GoText only).
.RE
.sp 1
.IP
GPos \fBgetCurrentPos\fP()
.br
GBool \fBcurrentPos\fP (GPos \fIpos\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method allows the user to set/get the current position.
Returns the result of the preconditions call, if any, TRUE otherwise.
.IP \fIposition\fP .5i
.br
Specifies the new current position.
.RE
.sp1
.IP
int \fBnbLines\fP()
.RS .8i
.IP \fIDescription\fP .5i
This method returns the number of lines of the text.
.RE
.sp1
.IP
int \fBlineNumber\fP()
.br
int \fBlineNumber\fP (GPos \fIpos\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method returns the line number of the character of which position is given.
.IP \fIpos\fP .5i
.br
Specifies the position of the character to be queried. When missing, pos is the current position.
.RE
.sp1
.IP
GPoint \fBposToXy\fP()
.br
GPoint \fBposToXy\fP (GPos \fIpos\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method returns the absolute coordinates of the upper and left corner of the character of which the position is given.
.IP \fIpos\fP .5i
.br
Specifies the position of the character to be queried. When missing, pos is the current position.
.RE
.sp1
.IP
GPos \fBxyToPos\fP (GPoint& \fIrelPoint\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method returns the position of the character of which the given absolute coordinates of the upper and left corner is the nearest one.
.IP \fIrelPoint\fP .5i
.br
Specifies the coordinates to be queried.
.RE
.sp 1
.IP
GPos \fBbegLinePos\fP (int \fIline\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method returns the position of the first character of the given line.
.IP \fIline\fP .5i
.br
int to be querried.
.RE
.sp 1
.IP
GPos \fBendLinePos\fP (GPos \fIline\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method returns the position of the last character of the given line.
.IP \fIline\fP .5i
.br
int to be querried.
.RE
.sp 1
.IP
GRegion \fBboundariesToRegion\fP (GPos \fIp1\fP, GPos \fIp2\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method returns the \fBGRegion\fP covered by the text substring of which the boudaries are given.
.IP \fIp1,p2\fP .5i
Boundaries of the sub-string.
.RE
.sp 1
.IP
void \fBwordBoundaries\fP (GPos \fIpos\fP, GPos& \fIp1\fP, GPos& \fIp2\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method is used to get the boundaries of a word pointed by a position (in order to select it using the method \fBselectPortion\fP for instance). If pos doesn't point a word, \fIpos1\fP and \fIpos2\fP will be set to -1.
.IP \fIpos\fP .5i
Position pointing a word.
.br
.IP \fIp1,p2\fP .5i
Boundaries to be set.
.RE
.sp 1
.IP
void \fBlineBoundaries\fP (GPos \fIpos\fP, GPos& \fIp1\fP, GPos& \fIp2\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method is used to get the boundaries of a line containing a given position (in order to select it using the method \fBselectPortion\fP for instance).
.IP \fIpos\fP .5i
Position pointing a line.
.br
.IP \fIp1,p2\fP .5i
Boundaries to be set.
.RE
.sp 1
.IP
void \fBmapBackground\fP (GBool \fIset\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method is used to map/unmap the background of the text.
.IP \fIset\fP .5i
.br
The background is mapped if set is TRUE, unmapped otherwise. When missing, TRUE is the value. By default, the background is unmapped at the creation of the \fBGoTextual\fP.
.RE
.sp 1
.IP
GBool \fBbackgroundMapped\fP()
.RS .8i
.IP \fIDescription\fP .5i
This method is used to get the background mapping status.
.RE
.sp 1
.IP
void \fBmapString\fP (GBool \fIset\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method is used to map/unmap the string of the text. This method
may be used to type a password.
.IP \fIset\fP .5i
.br
The string is mapped if set is TRUE, unmapped otherwise. When missing, TRUE is the value.
By default, the string is mapped at the creation of the \fBGoTextual\fP.
.RE
.sp 1
.IP
GBool \fBstringMapped\fP()
.RS .8i
.IP \fIDescription\fP .5i
This method is used to get the string mapping status.
.RE
.sp 1
.IP
void \fBmapCursor\fP (GBool \fIset\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method is used to map/unmap the cursor of the text.
.IP \fIset\fP .5i
.br
The cursor is mapped if set is TRUE, unmapped otherwise. When missing, TRUE is the value.
By default, the cursor is unmapped at the creation of the \fBGoTextual\fP.
.RE
.sp 1
.IP
GBool \fBcursorMapped\fP()
.RS .8i
.IP \fIDescription\fP .5i
This method is used to get the cursor mapping status.
.RE
.sp 1
.IP
void \fBmapUnderline\fP (GBool \fIset\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method is used to map/unmap the underline of the text.
.IP \fIset\fP .5i
.br
The underline is mapped if set is TRUE, unmapped otherwise. When missing, TRUE is the value. By default, the underline is unmapped at the creation of the \fBGoTextual\fP.
.RE
.sp 1
.IP
GBool \fBunderlineMapped\fP()
.RS .8i
.IP \fIDescription\fP .5i
This method is used to get the underline mapping status.
.RE
.sp 1
.IP
void \fBcursorLeft\fP()
.RS .8i
.IP \fIDescription\fP .5i
This method is used to move the cursor to the previous character.
.RE
.sp 1
.IP
void \fBcursorRight\fP()
.RS .8i
.IP \fIDescription\fP .5i
This method is used to move the cursor to the next character.
.RE
.sp 1
.IP
void \fBcursorUp\fP()
.RS .8i
.IP \fIDescription\fP .5i
This method is used to move the cursor to the upper line.
.RE
.sp 1
.IP
void \fBcursorDown\fP()
.RS .8i
.IP \fIDescription\fP .5i
This method is used to move the cursor to the lower line.
.RE
.sp 1
.IP
void \fBcursorBegLine\fP()
.RS .8i
.IP \fIDescription\fP .5i
This method is used to move the cursor at the beginning of the line.
.RE
.sp 1
.IP
void \fBcursorEndLine\fP()
.RS .8i
.IP \fIDescription\fP .5i
This method is used to move the cursor at the end of the line.
.RE
.sp 1
.IP
void \fBcursorBegText\fP()
.RS .8i
.IP \fIDescription\fP .5i
This method is used to move the cursor at the beginning of the text.
.RE
.sp 1
.IP
void \fBcursorEndText\fP()
.RS .8i
.IP \fIDescription\fP .5i
This method is used to move the cursor at the end of the text.
.RE
.sp 1
.IP
void \fBselectPortion\fP (GPos \fIfirst\fP, GPos \fIlast\fP, GBool set)
.RS .8i
.IP \fIDescription\fP .5i
This method selects the given portion of text (to be underlined or deleted later, for instance). Returns the result of the preconditions call, if any, TRUE otherwise.
.IP \fIfirst,last\fP .5i
.br
Boundaries of the portion to be selected. When missing, the entire text is selected. When \fIpos1\fP and \fIpos2\fP are equal to -1, the \fBGoTextual\fP is unselected.
.IP \fIset\fP .5i
.br
This value specifies if the given portion ito be selected or unselected.
.RE
.sp 1
.IP
GPos \fBfirstSelected\fP()
.RS .8i
.IP \fIDescription\fP .5i
This method returns the position of the first selected character, -1 if no selection is done. If several selections are applied, the first position of the firts portion is returned.
.RE
.sp 1
.IP
GPos \fBlastSelected\fP()
.RS .8i
.IP \fIDescription\fP .5i
This method returns the position of the last selected character, -1 if no selection is done. If several selections are applied, the last position of the firts portion is returned.
.RE
.sp 1
.IP
char* \fBselectedString\fP()
.RS .8i
.IP \fIDescription\fP .5i
This method returns the selected string, NULL if no selection is done. The application is responsible for freeing the returned data.
.RE
.sp 1
.IP
static GoMetaclass* \fBmetaclass\fP();
.RS .8i
.IP \fIDescription\fP .5i
Returns a pointer to the metaclass object of the \fIthis\fP.
.RE
.sp1
.IP
void \fBmodifyValuePrecond\fP (GBool \fIproc\fP(*)(void* \fIclosure \fP, const GoTextual* \fIgo\fP,
.br
		GModifyValueStruct* str),
.br
		const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.br
void \fBmodifyValuePostcond\fP (void \fIproc\fP(*)(void* \fIclosure \fP, GoTextual* \fIgo\fP,
.br
		GModifyValueStruct* str),
.br
		const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add/remove pre/postcondition callbacks which will be called when a modification of the string value occurs.
.IP \fIproc\fP .5i
Specifies the pre/postcondition procedure. The precondition and the postcondition take three parameters: the closure (private application data), the GoTextual itself, a pointer to a structure of which the content depends on the type of modification (see \fIGModifyValueStruct\fP). In the case of the precondition, \fIstr\fP points to the new values. For the postcondition, \fIstr\fP points the old one. 
.RE
.sp 1
.IP
void \fBmodifyAttributePrecond\fP (GBool \fIproc\fP(*)(void* \fIclosure \fP, const GoTextual* \fIgo\fP,
.br
		GModifyAttributeStruct* str),
.br
		const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.br
void \fBmodifyAttributePostcond\fP (void \fIproc\fP(*)(void* \fIclosure \fP, GoTextual* \fIgo\fP,
.br
		GModifyAttributeStruct* str),
.br
		const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add/remove pre/postcondition callbacks which will be called when a modification of an attribute occurs.
.IP \fIproc\fP .5i
Specifies the pre/postcondition procedure. The precondition and the postconditions take three parameters: the closure (private application data), the GoTextual itself, a pointer to a structure of which the content depends on the type of modification (see \fIGModifyAttributeStruct\fP). In the case of the precondition, \fIstr\fP points to the new values. For the postcondition, \fIstr\fP points the old one.
.RE
.sp 1
.IP
void \fBcurrentPosPrecond\fP (GBool \fIproc\fP(*)(void* \fIclosure \fP, const GoTextual* \fIgo\fP, GPos \fInewPos\fP),
.br
		const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.br
void \fBcurrentPosPostcond\fP (void \fIproc\fP(*)(void* \fIclosure \fP, GoTextual* \fIgo\fP, GPos \fIoldPos\fP),
.br
		const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add/remove pre/postcondition callbacks which will be called when a change of the position of insertion point occurs.
.IP \fIproc\fP .5i
Specifies the pre/postcondition procedure. The precondition takes three parameters: the closure (private application data), the GoTextual itself, and the position to be the new one. The postcondition takes three parameters: the closure, the GoTextual, and the old position.
.RE
.sp 1
.IP
void \fBselectionPrecond\fP (GBool \fIproc\fP(*)(void* \fIclosure \fP, const GoTextual* \fIgo\fP,
.br
GPos \fIpos1fP, GPos \fIpos2\fP), const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.br
void \fBselectionPostcond\fP (void \fIproc\fP(*)(void* \fIclosure \fP, GoTextual* \fIgo\fP, GPos \fIpos1\fP, GPos \fIpos2\fP),
.br
		const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add/remove pre/postcondition callbacks which will be called when a change of the selection occurs.
.IP \fIproc\fP .5i
Specifies the pre/postcondition procedure. The precondition takes four parameters: the closure (private application data), the GoTextual itself, and the boundaries of the new selection. The postcondition takes four parameters: the closure, the GoTextual, and the boundaries of the new selection.


.SH
\fBUSER INTERACTIONS\fP
.IP
User interactions are defined by the following methods which may be
included in the customization files interpreted by the \fIGo User Interaction\fP
object \fBGoUI\fP, (see \fIGoUI(3Go)\fP).
These methods may have arguments which are defined as follows:
.sp 1
.IP
Methods availables for user interaction are:
.RS .8i
.sp 1
\fBGoTextual::insertChar(char)
.RS .8i
.IP \fIDescription\fP .5i
see \fBPUBLIC METHODS\fP
.RE
.sp 1
\fBGoTextual::deleteChar()
.RS .8i
.IP \fIDescription\fP .5i
see \fBPUBLIC METHODS\fP
.RE
.sp 1
\fBGoTextual::cursorLeft()
.RS .8i
.IP \fIDescription\fP .5i
.sp 1
see \fBPUBLIC METHODS\fP
.RE
.sp 1
\fBGoTextual::cursorRight()
.RS .8i
.IP \fIDescription\fP .5i
see \fBPUBLIC METHODS\fP
.RE
.sp1
\fBGoTextual::cursorUp()
.RS .8i
.IP \fIDescription\fP .5i
see \fBPUBLIC METHODS\fP
.RE
.sp 1
\fBGoTextual::cursorDown()
.RS .8i
.IP \fIDescription\fP .5i
see \fBPUBLIC METHODS\fP
.RE
.sp 1
\fBGoTextual::cursorBegText()
.RS .8i
.IP \fIDescription\fP .5i
see \fBPUBLIC METHODS\fP
.RE
.sp 1
\fBGoTextual::cursorBegLine()
.RS .8i
.IP \fIDescription\fP .5i
see \fBPUBLIC METHODS\fP
.RE
.sp 1
\fBGoTextual::cursorEndLine()
.RS .8i
.IP \fIDescription\fP .5i
see \fBPUBLIC METHODS\fP
.RE
.sp 1
\fBGoTextual::cursor(position)
.RS .8i
.IP \fIDescription\fP .5i
This method places the insertion point at the given position.
.RE
.sp 1
\fBGoTextual::mapCursor()
.RS .8i
.IP \fIDescription\fP .5i
see \fBPUBLIC METHODS\fP
.RE
.sp 1
\fBGoTextual::mapBackground()
.RS .8i
.IP \fIDescription\fP .5i
see \fBPUBLIC METHODS\fP
.RE
.sp 1
\fBGoTextual::mapString()
.RS .8i
.IP \fIDescription\fP .5i
see \fBPUBLIC METHODS\fP
.RE
.sp 1
\fBGoTextual::mapUnderline()
.RS .8i
.IP \fIDescription\fP .5i
see \fBPUBLIC METHODS\fP
.RE
.sp 1
\fBGoTextual::selectWord(position)
.RS .8i
.IP \fIDescription\fP .5i
This method allows to select the word placed under the cursor.
.RE
.sp 1
\fBGoTextual::selectLine(position)
.RS .8i
.IP \fIDescription\fP .5i
This method allows to select the line placed under the cursor.
.RE
.sp 1
.SH
\fBC BINDING\fP
.SS 
\fBHeader\fP
.IP
#include <Go/cTextual.h>
.DE
.SS 
\fBResources\fP
.IP
The following table defines a set of Go resources used by the programmer
to specify data.  The programmer can also set the resource values for the 
inherited classes to set attributes for this object.
The codes in the access column indicate if the given resource can be set by using \fBGoSetValues\fP (\fBS\fP), retrieved by using \fBGoGetValues\fP (\fBG\fP), or is not applicable (\fBN/A\fP).
.br
For superclass resources, see superclass man pages.
.br
See also Section 2.
.sp 1
.ps 8
.DS
.TS
center box;
cB sss
lB lB lB lB
l l l l.
GoTextual Resource Set
.sp
=
Name	Type	Default	Access
.sp
_
goNstring	char*	""	SG
goNcurrentPos	GPos	dynamic		G
goNpresentation	GPresentation	NO_P	SG
goNjustification	GJustification	LEFT_J	SG
goNinterline	GNumber	0	SG
goNlineHeight	GNumber	0	SG
goNunderlinePosition	GNumber	0	SG
goNmapBackground	GBool	TRUE	SG
goNmapCursor	GBool	TRUE	SG
goNmapString	GBool	TRUE	SG
goNmapUnderline	GBool	TRUE	SG
goNfirstSelected	GPos		G
goNlastSelected	GPos		G

.TE
.DE
.ps 10

.SS 
\fBFunctions\fP
.IP
GBool \fBGoTextualInsertChar\fP (GObjectId \fItext\fP, char \fIc\fP, GPos \fIpos\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBool GoTextual::insertChar (char \fIc\fP, GPos \fIpos\fP).
.RE
.sp 1
GBool \fBGoTextualInsertString\fP (GObjectId \fItext\fP, char* \fIstr\fP, ushort \fIsize\fP, GPos \fIpos\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBool GoTextual::insertString (char* \fIstr\fP, ushort \fIsize\fP, GPos \fIpos\fP).
.RE
.sp 1
GBool \fBGoTextualDeleteChar\fP (GObjectId \fItext\fP, GPos \fIpos\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBool GoTextual::deleteChar (GPos \fIpos\fP).
.RE
.sp 1
GBool \fBGoTextualDeleteString\fP (GObjectId \fItext\fP, ushort \fIsize\fP, GPos \fIpos\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBool GoTextual::deleteString (ushort \fIsize\fP, GPos \fIpos\fP).
.RE
.sp 1
GBool \fBGoTextualSetString\fP (GObjectId \fItext\fP, char* \fIstr\fP, ushort \fIsize\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBool GoTextual::setString (char* \fIstr\fP, ushort \fIsize\fP).
.RE
.sp 1
const char* \fBGoTextualGetString\fP (GObjectId \fItext\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP const char* GoTextual::getString().
.RE
.sp 1
char* \fBGoTextualGetSelectedString\fP (GObjectId \fItext\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP const char* GoTextual::selectedString().
.RE
.sp 1
GPos \fBGoTextualContainChar\fP (GObjectId \fItext\fP, char \fIc\fP, GPos \fIpos\fP, GTextDirection \fIdir\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GPos GoTextual::containChar(char \fIc\fP, GPos \fIpos\fP, GTextDirection \fIdir\fP).
.RE
.sp 1
GPos \fBGoTextualContainString\fP (GObjectId \fItext\fP, char* \fIstr\fP, ushort \fIsize\fP, GPos \fIpos\fP, GTextDirection \fIdir\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GPos GoTextual::containString (char* \fIstr\fP, ushort \fIsize\fP, GPos \fIpos\fP, GTextDirection \fIdir\fP).
.RE
.sp 1
short \fBGoTextualLength\fP (GObjectId \fItext\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP short GoTextual::length().
.RE
.sp 1
short \fBGoTextualNbLines\fP (GObjectId \fItext\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP short GoTextual::nbLines().
.RE
.sp 1
int \fBGoTextualLineNumber\fP (GObjectId \fItext\fP, GPos \fIpos\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP int GoTextual::lineNumber (GPos \fIpos\fP).
.RE
.sp 1
GPoint* \fBGoTextualPosToXy\fP (GObjectId \fItext\fP, GPos \fIpos\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GPoint* GoTextual::posToXy (GPos \fIpos\fP).
.RE
.sp 1
GPos \fBGoTextualXyToPos\fP (GObjectId \fItext\fP, GPoint \fIpt\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GPos GoTextual::xyToPos (GPoint& \fIpt\fP).
.RE
.sp 1
GPos \fBGoTextualBegLinePos\fP (GObjectId \fItext\fP, int \fIline\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GPos GoTextual::begLinePos (int \fIline\fP).
.RE
.sp 1
GPos \fBGoTextualEndLinePos\fP(GObjectId \fItext\fP, int \fIline\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GPos GoTextual::endLinePos (int \fIline\fP).
.RE
.sp 1
void \fBGoTextualSelectPortion\fP (GObjectId \fItext\fP, GPos \fIpos1\fP, GPos \fIpos2\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTextual::selectPortion (GPos \fIpos1\fP, GPos \fIpos2\fP).
.RE
.sp 1
void \fBGoTextualWordBoundaries\fP (GObjectId \fItext\fP, GPos \fIpos\fP, GPos* \fIpos1\fP, GPos* \fIpos2\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTextual::wordBoundaries (GPos \fIpos\fP, GPos* \fIpos1\fP, GPos* \fIpos2\fP).
.RE
.sp 1
void \fBGoTextualLineBoundaries\fP (GObjectId \fItext\fP, GPos \fIpos\fP, GPos* \fIpos1\fP, GPos* \fIpos2\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTextual::lineBoundaries (GPos \fIpos\fP, GPos* \fIpos1\fP, GPos* \fIpos2\fP).
.RE
.sp 1
void \fBGoTextualCursorRight\fP (GObjectId \fItext\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTextual::cursorRight().
.RE
.sp 1
void \fBGoTextualCursorLeft\fP (GObjectId \fItext\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTextual::cursorLeft().
.RE
.sp 1
void \fBGoTextualCursorUp\fP (GObjectId \fItext\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTextual::cursorUp().
.RE
.sp 1
void \fBGoTextualCursorDown\fP (GObjectId \fItext\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTextual::cursorDown().
.RE
.sp 1
void \fBGoTextualCursorBegLine\fP (GObjectId \fItext\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTextual::cursorBegLine().
.RE
.sp 1
void \fBGoTextualCursorBegLine\fP (GObjectId \fItext\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTextual::cursorBegLine().
.RE
.sp 1
void \fBGoTextualCursorEndLine\fP (GObjectId \fItext\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTextual::cursorEndLine().
.RE
.sp 1
void \fBGoTextualCursorBegText\fP (GObjectId \fItext\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTextual::cursorBegText().
.RE
.sp 1
void \fBGoTextualCursorEndText\fP (GObjectId \fItext\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTextual::cursorEndText().
.RE
.sp 1
GBool \fBGoTextualReplaceChar\fP (GObjectId \fItext\fP, char \fIc\fP, GPos \fIpos\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBool GoTextual::replaceChar (char \fIc\fP, GPos \fIpos\fP).
.RE
.sp 1
GBool \fBGoTextualReplaceString\fP (GObjectId \fItext\fP, GPos \fIpos\fP, ushort \fIsize1\fP, char* \fIstr\fP, ushort \fIsize2\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBool GoTextual::replaceString (GPos \fIpos\fP, ushort \fIsize1\fP, char* \fIstr\fP, ushort \fIsize2\fP);
.RE
.sp 1
GObjectId \fBGoTextualBackBrush\fP (GObjectId \fItext\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBool GoTextual::backgroundBrush();
.RE
.sp 1
GObjectId \fBGoTextualTextBrush\fP (GObjectId \fItext\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBool GoTextual::stringTextBrush();
.RE
.sp 1
GObjectId \fBGoTextualSelectionBrush\fP (GObjectId \fItext\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBool GoTextual::selectionBrush();
.RE
.sp 1
GObjectId \fBGoTextualLinePen\fP (GObjectId \fItext\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBool GoTextual::underlinePen();
.RE
.sp 1
GObjectId \fBGoTextualCursorPen\fP (GObjectId \fItext\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBool GoTextual::cursorPen();
.RE
.sp 1
void \fBGoTextualModifyValuePrecond\fP (GObjectId \fItext\fP, GBool(*\fIcb\fP)(GObjectId, const GObjectId,
.br
GModifyValueStruct*), GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTextual::modifyValuePrecond(GBool (*\fIcb\fP)
.br
	(void*, const GoTextual*, GModifyValueStruct*),
.br
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
void \fBGoTextualModifyValuePostcond\fP (GObjectId \fItext\fP, void(*\fIcb\fP)(GObjectId, GObjectId,
.br
GModifyValueStruct*), GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTextual::modifyValuePostcond (void (*\fIcb\fP)
.br
	(void*, GoTextual*, GModifyValueStruct*),
.br
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
void \fBGoTextualModifyAttributePrecond\fP (GObjectId \fItext\fP, GBool(*\fIcb\fP)(GObjectId, const GObjectId,
.br
GModifyAttributeStruct*), GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTextual::modifyAttributePrecond (GBool (*\fIcb\fP)
.br
	(void*, const GoTextual*, GModifyAttributeStruct*),
.br
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
void \fBGoTextualModifyAttributePostcond\fP (GObjectId \fItext\fP, void(*\fIcb\fP)(GObjectId, GObjectId,
.br
GModifyAttributeStruct*), GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTextual::modifyAttributePostcond (void (*\fIcb\fP)
.br
	(void*, GoTextual*, GModifyAttributeStruct*),
.br
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
void \fBGoTextualCurrentPositionPrecond\fP (GObjectId \fItext\fP, GBool(*\fIcb\fP)(GObjectId, const GObjectId,
.br
GPos), GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTextual::currentPositionPrecond (GBool (*\fIcb\fP)
.br
	(void*, const GoTextual*, GPos),
.br
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
void \fBGoTextualCurrentPositionPostcond\fP (GObjectId \fItext\fP, void(*\fIcb\fP)(GObjectId, GObjectId,
.br
GPos), GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTextual::currentPositionPostcond (void (*\fIcb\fP)
.br
	(void*, GoTextual*, GPos),
.br
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
void \fBGoTextualSelectionPrecond\fP (GObjectId \fItext\fP, GBool(*\fIcb\fP)(GObjectId, const GObjectId,
.br
GPos, GPos), GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTextual::selectionPrecond (GBool (*\fIcb\fP)
.br
	(void*, const GoTextual*, GPos, GPos),
.br
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
void \fBGoTextualSelectionPostcond\fP (GObjectId \fItext\fP, void(*\fIcb\fP)(GObjectId, GObjectId,
.br
GPos, GPos), GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTextual::selectionPostcond (void (*\fIcb\fP)
.br
	(void*, GoTextual*, GPos, GPos),
.br
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBGo\fP, \fBGoUI\fP, \fBGoTextualMetaclass\fP classes.
.nrPN \n%
