.\" $Id: Tree.n,v 1.1.1.1 1992/03/18 09:40:39 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoTree 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoTree\fP \(em the tree object class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tree.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGoTree\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGoGraphStruct\fP class
.IP \(em 3
\fBGo\fP class.
.RE
.sp 1
.SH
\fBDESCRIPTION\fP
.IP
A tree is an oriented graph where nodes have only one parent node.
.br
GoTree maintains the link-node connections. GoTree does not impose any constraints on node placement but proposes predefined algorithms.
.br
Nodes may be added or removed to the GoTree. Links are created (or removed) by the GoTree, when nodes are added (or removed).
.IP
.nf
.ta .15i .25i 1.0i
class GoTree {
	public:
		// getting values;
		GNumber distX() const;
		GNumber distY() const;
		ushort alignmentType() const;

		// setting values;
		GBool distX(GNumber \fIdist\fP);
		GBool distY(GNumber \fIdist\fP);
		GBool alignmentType(ushort \fItype\fP);

		// pre and post conditions;
		void addNodePrecond(GBool (*)\fIfunction\fP(void*, GoTree*, GoTreeNode*, GoMetaclass*, GoTreeNode*), 
.br
								void* \fIclosure\fP, GAddOrRemove = GADD);
		void addNodePostcond(void (*)\fIfunction\fP(void*, GoTree*, GoTreeNode*, GoMetaclass*, GoTreeNode*), 
.br
					void* \fIclosure\fP, GAddOrRemove = GADD);
		void removeNodePrecond(GBool (*)\fIfunction\fP(void*, GoTree*, GoTreeNode*), void* \fIclosure\fP, 
.br
					GAddOrRemove = GADD);
		void removeNodePostcond(void (*)\fIfunction\fP(void*, GoTree*, GoTreeNode*), void* \fIclosure\fP, 
.br
					GAddOrRemove = GADD);
		
		// others;
		GoTree();

		static GoMetaclass* metaclass();
		static GoTree* create();

		GoTreeNode* addNode(GoTreeNode* \fIparent\fP, GoMetaclass* \fIlinkclass\fP = NULL,
.br
		 			GoTreeNode* \fInext_brother\fP = NULL);
		GBool removeNode(GoTreeNode* \fInode\fP);
};
.fi
.sp 1
.SH
\fBPUBLIC MEMBERS\fP
.IP
GNumber \fBdistX\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
Returns a distance used by the predefined placement algorithm. If the tree is drawn from left to right or right to left, this function returns the minimum distance, on X axis, between a parent node and its children nodes. If the tree is drawn from up to bottom or bottom to up, this function returns the minimum distance, on X axis, between a node and its brother nodes.
.RE
.sp 1
.IP
GNumber \fBdistY\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
Returns a distance used by the predefined placement algorithm. If the tree is drawn from left to right or right to left, this function returns the minimum distance, on Y axis, between a node and its brother nodes. If the tree is drawn from up to bottom or bottom to up, this function returns the minimum distance, on Y axis, between a parent node and its children nodes.
.RE
.sp 1
.IP
ushort \fBalignmentType\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
Returns the node's alignment type used by the predefined placement algorithm. If it's \fBGON_CENTER\fP, every center's nodes are aligned, otherwise (\fBGON_BORDER\fP) every border's nodes are aligned.
.RE
.sp 1
.IP
GBool \fBdistX\fP(GNumber \fIdist\fP);
.RS .8i
.IP \fIDescription\fP .5i
Specifies the distX used by the predefined placement algorithm. If the tree is drawn from left to right or right to left, this function sets the minimum distance, on X axis, between a parent node and its children nodes. If the tree is drawn from up to bottom or bottom to up, this function sets the minimum distance, on X axis, between a node and its brother nodes.
.IP \fIdist\fP .5i
.br
The function returns GTRUE if \fIdist\fP is positive, otherwise it returns GFALSE.
.br
.RE
.sp 1
.IP
GBool \fBdistY\fP(GNumber \fIdist\fP);
.RS .8i
.IP \fIDescription\fP .5i
.br
Specifies the distY used by the predefined placement algorithm. If the tree is drawn from left to right or right to left, this function sets the minimum distance, on Y axis, between a node and its brother nodes. If the tree is drawn from up to bottom or bottom to up, this function sets the minimum distance, on Y axis, between a parent node and its children nodes.
.IP \fIdist\fP .5i
.br
The function returns GTRUE if \fIdist\fP is positive, otherwise it returns GFALSE.
.br
.RE
.sp 1
.IP
GBool \fBalignmentType\fP(ushort \fItype\fP);
.RS .8i
.IP \fIDescription\fP .5i
Specifies the node's alignment type used by the predefined placement algorithm. The possible values are : \fBGON_CENTER\fP and \fBGON_BORDER\fP.
.RE
.sp 1
.IP
.nf
void \fBaddNodePrecond\fP (GBool (*\fIproc\fP)(void* \fIclosure\fP, GoTree* \fItree\fP, GoTreeNode* \fIparent\fP, 
.br
						GoMetaclass* \fIlinkclass\fP, GoTreeNode* \fInext_brother\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBaddNodePostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GoTree* \fItree\fP, GoTreeNode* \fIparent\fP, 
.br
						GoMetaclass* \fIlinkclass\fP, GoTreeNode* \fInext_brother\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or to remove pre or postcondition procedures when a node is added to the \fItree\fP.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when a node will be added to the \fItree\fP. The precondition procedure is
called before the node is added. It can either accept or refuse the modification.
The postcondition procedure is invoked after the node is added.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the pre/postcondition procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the modify
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp 1
.IP
.nf
void \fBremoveNodePrecond\fP (GBool (*\fIproc\fP)(void* \fIclosure\fP, GoTree* \fItree\fP, GoTreeNode* \fInode\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBremoveNodePostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GoTree* \fItree\fP, GoTreeNode* \fInode\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or to remove pre or postcondition procedures when a node is removed from the \fItree\fP.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when a node will be removed from the \fItree\fP. The precondition procedure is
called before the node is removed. It can either accept or refuse the modification.
The postcondition procedure is invoked after the node is removed.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the pre/postcondition procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the modify
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp 1
.IP
\fBGoTree\fP();
.RS .8i
.IP \fIDescription\fP .5i
This method allows to create a new instance of the \fIGoTree\fP class.
.RE
.sp 1
.IP
static GoMetaclass* \fBmetaclass\fP();
.RS .8i
.IP \fIDescription\fP .5i
Returns a pointer to the metaclass object of the \fIthis\fP.
.RE
.sp1
.IP
static GoTree* \fBcreate\fP();
.RS .8i
.IP \fIDescription\fP .5i
Creates a new GoTree instance. Returns the created tree.
.RE
.sp1
.IP
GoTreeNode* \fBaddNode\fP(GoTreeNode* \fIparent\fP, GoMetaclass* \fIlinkclass\fP, 
.br
				GoTreeNode* \fInext_brother\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method adds a node to the tree. It consists in creating a new node, attaching it to its \fIparent\fP node with a new link. This method returns the created node Id.
.IP \fIparent\fP .5i
.br
Specifies the parent node of the created node. If the created node is the root node, \fIparent\fP must be NULL.
.br
.IP \fIlinkclass\fP .5i
.br
Specifies the class of the link created to connect the new node to its parent node. The default value is NULL. In this case the \fIlinkclass\fP is the class returned by the \fIdefaultLinkType()\fP method of GoGraphStruct class.
.br
.IP \fInext_brother\fP .5i
Specifies the next brother node of the new node. It may be NULL. In this case, the new node will be the last child node of its parent.
.RE
.sp 1
.IP
GBool \fBremoveNode\fP(GoTreeNode* \fInode\fP);
.RS .8i
.IP \fIDescription\fP .5i
Removes the \fInode\fP and all its subtree. Returns GFALSE if an error occurred, otherwise returns GTRUE.
.IP \fInode\fP .5i
.br
Specifies the node to remove.
.RE
.sp 1
.RE
.sp 2
.SH
\fBUSER INTERACTION\fP
.IP
\fISee GoTreeMetaclass(3Go)\fP.
.RE
.sp 2
.SH
\fBC BINDING\fP
.SS 
\fBHeader\fP
.IP
#include <Go/cTree.h>
.DE
.SS 
\fBResources\fP
.IP
The following table defines a set of Go resources used by the programmer
to specify data.  The programmer can also set the resource values for the 
inherited classes to set attributes for this object.
The codes in the access column indicate if the given resource can be set by using \fBGoSetValues\fP (\fBS\fP), retrieved by using \fBGoGetValues\fP (\fBG\fP), or is not applicable (\fBN/A\fP).
.br
For superclass resources, see superclass man pages.
.br
See also Section 2.
.sp 1
.ps 8
.DS
.TS
center box;
cB sss
lB lB lB lB
l l l l.
GoTree Resource GSet
.sp
=
Name	Type	Default	Access
.sp
_
goNdistX	GNumber*	10	SG
goNdistY	GNumber*	10	SG
goNalignmentType	ushort*	GON_BORDER	SG
.TE
.DE
.ps 10

.SS 
\fBFunctions\fP
.IP
void \fBGoTreeInitialize\fP();
.RS .8i
.IP \fIDescription\fP .5i
This function must be called before any use of the GoTree C Binding.
.RE
.sp 1
.IP
GObjectId \fBGoCreateGoTree\fP();
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoTree* GoTree::create().
.RE
.sp 1
.IP
GObjectId \fBGoTreeMetaclass\fP();
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoMetaclass* GoTree::metaclass().
.RE
.sp 1
.IP
GBool \fBGoSetTreeDistX\fP(GObjectId \fItree\fP, GNumber \fIdist\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBool GoTree::distX(GNumber \fIdist\fP).
.RE
.sp 1
.IP
GBool \fBGoSetTreeDistY\fP(GObjectId \fItree\fP, GNumber \fIdist\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBool GoTree::distY(GNumber \fIdist\fP).
.RE
.sp 1
.IP
GBool \fBGoSetTreeAlignmentType\fP(GObjectId \fItree\fP, ushort \fItype\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBool GoTree::alignmentType(ushort \fItype\fP).
.RE
.sp 1
.IP
GNumber \fBGoGetTreeDistX\fP(GObjectId \fItree\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GNumber GoTree::distX().
.RE
.sp 1
.IP
GNumber \fBGoGetTreeDistY\fP(GObjectId \fItree\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GNumber GoTree::distY().
.RE
.sp 1
.IP
ushort \fBGoGetTreeAlignmentType\fP(GObjectId \fItree\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP ushort GoTree::alignmentType().
.RE
.sp 1
.IP
void \fBGoAddTreeNodePrecond\fP(GObjectId \fItree\fP, 
.br
		GBool(*\fIcb\fP)(GObjectId, GObjectId, GObjectId, GObjectId,
.br
		GObjectId), GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTree::addNodePrecond(GBool (*\fIcb\fP)
.br
		(void*, GoTree*, GoTreeNode*, GoMetaclass*, 
.br
		GoTreeNode*), void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoAddTreeNodePostcond\fP(GObjectId \fItree\fP, 
.br
		void(*\fIcb\fP)(GObjectId, GObjectId, GObjectId, GObjectId,
.br
		GObjectId), GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTree::addNodePostcond(void (*\fIcb\fP)
.br
		(void*, GoTree*, GoTreeNode*, GoMetaclass*,
.br
		 GoTreeNode*), void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoRemoveTreeNodePrecond\fP(GObjectId \fItree\fP, 
.br
		GBool(*\fIcb\fP)(GObjectId, GObjectId, GObjectId),
.br
		GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTree::removeNodePrecond(GBool (*\fIcb\fP)
.br
		(void*, GoTree*, GoTreeNode*),
.br
		 void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoRemoveTreeNodePostcond\fP(GObjectId \fItree\fP, 
.br
		void(*\fIcb\fP)(GObjectId, GObjectId, GObjectId),
.br
		GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTree::removeNodePostcond(void (*\fIcb\fP)
.br
		(void*, GoTree*, GoTreeNode*),
.br
		 void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
GObjectId \fBGoAddTreeNode\fP(GObjectId \fItree\fP, GObjectId \fIparent\fP, GObjectId \fIlinkclass\fP,
.br
			GObjectId \fInext\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoTreeNode* GoTree::addNode(GoTreeNode* \fIparent\fP, 
.br
		GoMetaclass* \fIlinkclass\fP, GoTreeNode* \fInext\fP); 
.RE
.sp 1
.IP
GBool \fBGoRemoveTreeNode\fP(GObjectId \fItree\fP, GObjectId \fInode\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBool GoTree::removeNode(GoTreeNode* \fInode\fP); 
.RE
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBGoGraphStruct\fP, \fBGoTreeNode\fP, \fBGoLink\fP classes.
.nrPN \n%
