.\" $Id: TreeNode.n,v 1.1.1.1 1992/03/18 09:40:44 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoTreeNode 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoTreeNode\fP \(em the tree node object class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/TreeNode.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGoTreeNode\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGoNode\fP class
.IP \(em 3
\fBGoGraphElement\fP class
.IP \(em 3
\fBGo\fP class.
.RE
.sp 1
.SH
\fBDESCRIPTION\fP
.IP
A GoTreeNode instance has a parent node, a first child node, a next brother node and a previous brother node. Nodes are connected together by links.
.br
Each node may be closed or opened, i.e each subtree may be unvisible or visible.
.br
Each node may be detach from a node and reattach to another node. Each node may be moved from a tree to another tree.
.IP
.nf
.ta .15i .25i 1.0i
class GoTreeNode {
	public:
		// getting values;
		GoTreeNode* nextNode() const;
		GoTreeNode* previousNode() const;
		GoTreeNode* parentNode() const;
		GoTreeNode* childNode() const;
		GoLink* parentLink() const;
		GBool isOpen() const;

		// pre and post conditions;
		void attachNodePrecond(GBool (*)\fIfunction\fP(void*, GoTreeNode*, GoTreeNode*, GoMetaclass*, 
.br
								GoTreeNode*, GoTree*), void* \fIclosure\fP, GAddOrRemove = GADD);
		void attachNodePostcond(void (*)\fIfunction\fP(void*, GoTreeNode*, GoTreeNode*, GoMetaclass*, 
.br
					GoTreeNode*, GoTree*), void* \fIclosure\fP, GAddOrRemove = GADD);
		void shiftNodePrecond(GBool (*)\fIfunction\fP(void*, GoTreeNode*, GoTreeNode*), void* \fIclosure\fP, 
.br
					GAddOrRemove = GADD);
		void shiftNodePostcond(void (*)\fIfunction\fP(void*, GoTreeNode*, GoTreeNode*), void* \fIclosure\fP, 
.br
					GAddOrRemove = GADD);
		
		// others;
		GoTreeNode();

		static GoMetaclass* metaclass();
		static GoTreeNode* create();

		void openNode();
		void closeNode();
		GBool attachNode(const GoTreeNode* \fInew_parent\fP, GoMetaclass* \fIlinkclass\fP = NULL,
.br
		 			GoTreeNode* \fInew_next\fP, GoTree* \fInew_tree\fP = NULL);
		GBool shiftNode(GoTreeNode* \fInext_brother\fP = NULL);
};
.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
GoTreeNode* \fBnextNode\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
.br
This method returns the next brother node of the node.
.RE
.sp 1
.IP
GoTreeNode* \fBpreviousNode\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
.br
This method returns the previous brother node of the node.
.RE
.sp 1
.IP
GoTreeNode* \fBparentNode\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
.br
This method returns the parent node of the node.
.RE
.sp 1
.IP
GoTreeNode* \fBchildNode\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
.br
This method returns the first child node of the node.
.RE
.sp 1
.IP
GoLink* \fBparentLink\fP();
.RS .8i
.IP \fIDescription\fP .5i
.br
This method returns the link connecting the node to its parent node.
.br
With the returned link Id, the programmer can get the link's pen to change its attributes, or reparent gos on the link. But deleting link, reparenting link on another Go (and so on ...) are strictely FORBIDDEN.
.RE
.sp 1
.IP
GBool \fBisOpened\fP();
.RS .8i
.IP \fIDescription\fP .5i
.br
Returns GTRUE if the node is opened, otherwise it returns GFALSE.
.RE
.sp 1
.IP
.nf
void \fBattachNodePrecond\fP (GBool (*\fIproc\fP)(void* \fIclosure\fP, GoTreeNode* \fInode\fP, GoTreeNode* \fInew_parent\fP, 
.br
						GoMetaclass* \fIlinkclass\fP, GoTreeNode* \fInew_next\fP, GoTree* \fInew_tree\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBattachNodePostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GoTreeNode* \fInode\fP, GoTreeNode* \fInew_parent\fP, 
.br
						GoMetaclass* \fIlinkclass\fP, GoTreeNode* \fInew_next\fP, GoTree* \fInew_tree\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or to remove pre or postcondition procedures when a node is attached to a \fInew_parent\fP node or a \fInew_tree\fP.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when a node will be attached to a \fInew_parent\fP or a \fInew_tree\fP. The precondition procedure is
called before the node is attached. It can either accept or refuse the modification.
The postcondition procedure is invoked after the node is attached.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the pre/postcondition procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the modify
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp 1
.IP
.nf
void \fBshiftNodePrecond\fP (GBool (*\fIproc\fP)(void* \fIclosure\fP, GoTreeNode* \fInode\fP, GoTreeNode* \fInext_brother\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBshiftNodePostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GoTreeNode* \fInode\fP, GoTreeNode* \fInext_brother\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or to remove pre or postcondition procedures when a node is shifted.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when a node will be shifted. The precondition procedure is
called before the node is shifted. It can either accept or refuse the modification.
The postcondition procedure is invoked after the node is shifted.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the pre/postcondition procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the modify
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp 1
.IP
\fBGoTreeNode\fP();
.RS .8i
.IP \fIDescription\fP .5i
This method allows to create a new instance of the \fIGoTreeNode\fP class.
.RE
.sp 1
.IP
static GoMetaclass* \fBmetaclass\fP();
.RS .8i
.IP \fIDescription\fP .5i
Returns a pointer to the metaclass object of the \fIthis\fP.
.RE
.sp1
.IP
static GoTreeNode* \fBcreate\fP();
.RS .8i
.IP \fIDescription\fP .5i
Creates a new GoTreeNode instance. Returns the created node.
.RE
.sp1
.IP
void \fBopenNode\fP();
.RS .8i
.IP \fIDescription\fP .5i
.br
Opens the node, i.e makes visible the node's subtree.
.RE
.sp1
.IP
void \fBcloseNode\fP();
.RS .8i
.IP \fIDescription\fP .5i
.br
Closes the node, i.e makes unvisible the node's subtree. 
.RE
.sp1
.IP
GBool \fBattachNode\fP(const GoTreeNode* \fInew_parent\fP, GoMetaclass* \fIlinkclass\fP, 
.br
			GoTreeNode* \fInew_next\fP, GoTree* \fInew_tree\fP);
.RS .8i
.IP \fIDescription\fP .5i
.br
Allows to change the node's parent node or to "reparent" the node to another tree. Also allows to attach a node created by the GoTreeNodeClass::create() method to a tree.
.br
The node's subtree stays connected to the node, so if the node is reparented to another tree, all its subtree will be reparented to the new tree.
.br
This method returns GFALSE is an error occurred, otherwise it returns GTRUE.
.IP \fInew_parent\fP .5i
.br
Specifies the new parent node. If \fInew_parent\fP is NULL, \fInew_tree\fP must be specified.
.IP \fIlinkclass\fP .5i
.br
Specifies the class of the link created to connect the node to its new parent node. The default value is NULL. In this case the \fIlinkclass\fP is the class returned by the \fIdefaultLinkType()\fP method of GoGraphStruct class.
.IP \fInew_next\fP .5i
.br
Specifies the new next brother of this node. It may be NULL. In this case, the node will be the last child of its new parent node.
.IP \fInew_tree\fP .5i
.br
Specifies the new tree to attach node. This parameter is only checked if \fInew_parent\fP is NULL. In this case the node will have no parent node and no link will be created.
.RE
.sp 1
.IP
GBool \fBshiftNode\fP(GoTreeNode* \fInext_brother\fP);
.RS .8i
.IP \fIDescription\fP .5i
.br
This method shifts the node just before \fInext_brother\fP in the GoTree.
.br
The method returns GFALSE if an error occurred, otherwise it returns GTRUE.
.IP \fInext_brother\fP .5i
.br
The new next brother of this node. It may be NULL. In this case, the node will be the last child of its parent node.
.br
Default value is NULL.
.RE
.sp 1
.RE
.sp 2
.SH
\fBUSER INTERACTION\fP
.IP
\fISee GoTreeNodeMetaclass(3Go)\fP.
.RE
.sp 2
.SH
\fBC BINDING\fP
.SS 
\fBHeader\fP
.IP
#include <Go/cTreeNode.h>
.DE
.SS 
\fBResources\fP
.IP
The following table defines a set of Go resources used by the programmer
to specify data.  The programmer can also set the resource values for the 
inherited classes to set attributes for this object.
The codes in the access column indicate if the given resource can be set by using \fBGoSetValues\fP (\fBS\fP), retrieved by using \fBGoGetValues\fP (\fBG\fP), or is not applicable (\fBN/A\fP).
.br
For superclass resources, see superclass man pages.
.br
See also Section 2.
.sp 1
.ps 8
.DS
.TS
center box;
cB sss
lB lB lB lB
l l l l.
GoTreeNode Resource GSet
.sp
=
Name	Type	Default	Access
.sp
_
goNchildNode	GObjectId	dynamic	G
goNisOpened	GBool	GTRUE	SG
goNnextNode	GObjectId	dynamic	G
goNparentLink	GObjectId	dynamic	G
goNparentNode	GObjectId	dynamic	G
goNpreviousNode	GObjectId	dynamic	G
.TE
.DE
.ps 10

.SS 
\fBFunctions\fP
.IP
void \fBGoTreeNodeInitialize\fP();
.RS .8i
.IP \fIDescription\fP .5i
This function must be called before any use of the GoTreeNode C Binding.
.RE
.sp 1
.IP
GObjectId \fBGoCreateGoTreeNode\fP();
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoTreeNode* GoTreeNode::create().
.RE
.sp 1
.IP
GObjectId \fBGoTreeNodeMetaclass\fP();
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoMetaclass* GoTreeNode::metaclass().
.RE
.sp 1
.IP
GObjectId \fBGoGetNextTreeNode\fP(GObjectId \fInode\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoTreeNode* GoTreeNode::nextNode().
.RE
.sp 1
.IP
GObjectId \fBGoGetPreviousTreeNode\fP(GObjectId \fInode\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoTreeNode* GoTreeNode::previousNode().
.RE
.sp 1
.IP
GObjectId \fBGoGetParentTreeNode\fP(GObjectId \fInode\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoTreeNode* GoTreeNode::parentNode().
.RE
.sp 1
.IP
GObjectId \fBGoGetChildTreeNode\fP(GObjectId \fInode\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoTreeNode* GoTreeNode::childNode().
.RE
.sp 1
.IP
GObjectId \fBGoGetTreeNodeParentLink\fP(GObjectId \fInode\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GoTreeNode* GoTreeNode::parentLink().
.RE
.sp 1
.IP
GBool \fBGoTreeNodeIsOpened\fP(GObjectId \fInode\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBool GoTreeNode::isOpened().
.RE
.sp 1
.IP
void \fBGoAttachTreeNodePrecond\fP(GObjectId \fInode\fP, 
.br
	GBool(*\fIcb\fP)(GObjectId, GObjectId, GObjectId, GObjectId, GObjectId,
.br
	GObjectId), GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTreeNode::attachNodePrecond(GBool (*\fIcb\fP)
.br
	(void*, GoTreeNode*, GoTreeNode*, GoMetaclass*, GoTreeNode*,
.br
	GoTree*), void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoAttachTreeNodePostcond\fP(GObjectId \fInode\fP, 
.br
	void(*\fIcb\fP)(GObjectId, GObjectId, GObjectId, GObjectId, GObjectId,
.br
	GObjectId), GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTreeNode::attachNodePostcond(void (*\fIcb\fP)
.br
	(void*, GoTreeNode*, GoTreeNode*, GoMetaclass*, GoTreeNode*, 
.br
	GoTree*), void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoShiftTreeNodePrecond\fP(GObjectId \fInode\fP, 
.br
		GBool(*\fIcb\fP)(GObjectId, GObjectId, GObjectId), 
.br
		GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTreeNode::shiftNodePrecond(GBool (*\fIcb\fP)
.br
	(void*, GoTreeNode*, GoTreeNode**),
.br
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoShiftTreeNodePostcond\fP(GObjectId \fInode\fP, 
.br
		void(*\fIcb\fP)(GObjectId, GObjectId, GObjectId), 
.br
		GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTreeNode::shiftNodePostcond(void (*\fIcb\fP)
.br
	(void*, GoTreeNode*, GoTreeNode*),
.br
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoCloseTreeNode\fP(GObjectId \fInode\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTreeNode::closeNode().
.RE
.sp 1
.IP
void \fBGoOpenTreeNode\fP(GObjectId \fInode\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTreeNode::openNode().
.RE
.sp 1.
.IP
GBool \fBGoShiftTreeNode\fP(GObjectId \fInode\fP, GObjectId \fInext\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBool GoTreeNode::shiftNode(GoTreeNode* \fInext\fP).
.RE
.sp 1
.IP
GBool \fBGoAttachTreeNode\fP(GObjectId \fInode\fP, GObjectId \fIparent\fP, GObjectId \fIlinkclass\fP, GObjectId \fInext\fP, GObjectId \fItree\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP GBool GoTreeNode::attachNode(GoTreeNode* \fIparent\fP, GoMetaclass* \fIlinkclass\fP, GoTreeNode* \fInext\fP, GoTree* \fItree\fP).
.RE
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBGoTree\fP, \fBGoNode\fP and \fBGoLink\fP classes.
.nrPN \n%
