.\" $Id: mBeta.n,v 1.1.1.1 1992/03/18 09:40:54 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoBetaSplineMetaclass 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoBetaSplineMetaclass\fP \(em the Meta Class object for the \fBGoBetaSpline\fP
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/mBeta.h>\fP
.SH 
\fBCLASS\fP
.IP
\fBGoBetaSplineMetaclass\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGoPolypointMetaclass\fP class
.IP \(em 3
\fBGoGeometricMetaclass\fP class
.IP \(em 3
\fBGoStdDSMetaclass\fP class
.IP \(em 3
\fBGoMetaclass\fP class.
.RE
.SH
\fBDESCRIPTION\fP
.IP
The \fBGoBetaSplineMetaclass\fP class is the common superclass for all
\fBGoBetaSpline\fP objects.
.br
As for other "Metaclasses", there is only one static instance of
\fBGoBetaSplineMetaclass\fP: this instance is returned by
\fBGoBetaSpline::metaclass ()\fP static method.
.IP
Such object is meant to provide methods on \fBGoBetaSpline\fP at
the class level; in particular this allows the programmer to set some
pre/postconditions at the class level.
.IP
.nf
.ta .15i .25i 1.0i
class GoBetaSplineMetaclass {

	public:

		/*
		 * \fBpre and post conditions:\fP
		 */

		void biasPrecond (GBool (*) (void*, const GoBetaSpline*, GNumber*),
			void*, GAddOrRemove = GADD);
		void biasPostcond (void (*) (void*, GoBetaSpline*),
			void*, GAddOrRemove = GADD);
};
.fi
.SH
\fBPUBLIC MEMBERS\fP
.IP
.nf
void \fBbiasPrecond\fP (GBool (*\fIf\fP) (void* \fIclosure\fP, const GoBetaSpline* \fIbeta\fP, GNumber* \fInewVal\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBbiasPostcond\fP (void (*\fIf\fP) (void* \fIclosure\fP, GoBetaSpline* \fIbeta\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or remove functions to the pre/post conditions lists
triggered by \fBbias\fP (GNumber) member function.
.IP \fIf\fP .5i
Specifies programmer's function to be added/removed.
.IP \fIclosure\fP .5i
Specifies programmer's parameter to call the function with.
.IP \fIbeta\fP .5i
Specifies the GoBetaSpline object involved.
.IP \fInewVal\fP
Specifies the new bias value. May be modified by \fIf\fP.
.IP \fIadd\fP .5i
Specifies whether to add or remove the function \fIf\fP from the list.
.RE
.SH
\fBC BINDING\fP
.SS 
\fBHeader\fP
.IP
#include <Go/cBeta.h>
.SS 
\fBFunctions\fP
.IP
.nf
void \fBGoBetaSplineMetaclassBiasPrecond\fP (GObjectId \fIbetaMclass\fP, 
			GBool (*\fIf\fP) (void*, const GObjectId, GNumber*),
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoBetaSplineMetaclassBiasPostcond\fP (GObjectId \fIbetaMclass\fP, 
			void (*\fIf\fP) (void*, GObjectId),
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.fi
.sp 1
.RS .3i
.IP \fIDescription\fP .3i
See \fBGoBetaSplineMetaclass\fP following members :
.sp 1
.nf
void biasPrecond (GBool (*\fIf\fP) (void*, const GoBetaSpline*, GNumber),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void biasPostcond (void (*\fIf\fP) (void*, GoBetaSpline*),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.fi
.RE
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBGo\fP, \fBGoMetaclass\fP, \fBGoStdDS\fP, \fBGoStdDSMetaclass\fP,
\fBGoGeometric\fP, \fBGoGeometricMetaclass\fP, \fBGoPolypoint\fP,
\fBGoPolypointMetaclass\fP, \fBGoCurve\fP, \fBGoCurveMetaclass\fP,
\fBGoCubic\fP, \fBGoCubicMetaclass\fP and \fBGoBetaSpline\fP classes.
.nrPN \n%
