.\" $Id: mCubic.n,v 1.1.1.1 1992/03/18 09:40:58 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoCubicMetaclass 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoCubicMetaclass\fP \(em the Meta Class object for the \fBGoCubic\fP
class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/mCubic.h>\fP
.SH 
\fBCLASS\fP
.IP
\fBGoCubicMetaclass\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGoCurveMetaclass\fP class.
.IP \(em 3
\fBGoPolypointMetaclass\fP class.
.IP \(em 3
\fBGoGeometricMetaclass\fP class.
.IP \(em 3
\fBGoStdDSMetaclass\fP class
.IP \(em 3
\fBGoMetaclass\fP class.
.RE
.SH
\fBDESCRIPTION\fP
.IP
The \fBGoCubicMetaclass\fP class is the common superclass for all
\fBGoCubic\fP objects.
.br
As for other "Metaclasses", there is only one static instance of
\fBGoCubicMetaclass\fP : this instance is returned by
\fBGoCubic::metaclass ()\fP static method.
.IP
Such object is meant to provide methods on \fBGoCubic\fP at
the class level; in particular this allows the programmer to set some
pre/postconditions at the class level.
.IP
.nf
.ta .15i .25i 1.0i
class GoCubicMetaclass {

	public:
		/*
		 * \fBpre and post conditions:\fP
		 */

		void tensionPrecond (GBool (*) (void*, const GoCubic*, GNumber*),
			void*, GAddOrRemove = GADD) const;
		void tensionPostcond (GBool (*) (void*, GoCubic*),
			void*, GAddOrRemove = GADD) const;
};
.fi
.SH
\fBPUBLIC MEMBERS\fP
.IP
.nf
void \fBtensionPrecond\fP (GBool (*\fIf\fP) (void* \fIclosure\fP, GoCubic* \fIcubic\fP, GNumber* \fInew\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBtensionPostcond\fP (void (*\fIf\fP) (void* \fIclosure\fP, GoCubic* \fIcubic\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or remove functions to the pre/post conditions lists
triggered by \fBtension\fP (GNumber) member function of \fBGoCubic\fP class.
.IP \fIf\fP .5i
Specifies the programmer's function to add/remove from the list.
.IP \fIclosure\fP .5i
Specifies the programmer's parameter to call the function with.
.IP \fIcubic\fP .5i
Specifies the \fBGoCubic\fP object involved.
.IP \fInew\fP .3i
Specifies a pointer to the value intended to be set (precondition only); the
value pointed to may be modify by \fIf\fP.
.RE
.SH
\fBC BINDING\fP
.SS 
\fBHeader\fP
.IP
#include <Go/cCubic.h>
.SS 
\fBFunctions\fP
.IP
.nf
void \fBGoCubicMetaclassTensionPrecond\fP(GObjectId \fICubicMclass\fP, 
			GBool (*\fIf\fP) (void*, const GObjectId, GNumber*),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoCubicMetaclassTensionPostcond\fP(GObjectId \fICubicMclass\fP, 
			void (*\fIf\fP) (void*, GObjectId),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
.fi
.sp 1
.RS .3i
.IP \fIDescription\fP .3i
See \fBGoCubicMetaclass\fP following members :
.sp 1
.nf
void tensionPrecond(GBool (*\fIf\fP) (void*, const GoCubic*, GNumber*),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void tensionPostcond(void (*\fIf\fP) (void*, GoCubic*),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.fi
.RE
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBGo\fP, \fBGoMetaclass\fP, \fBGoStdDS\fP, \fBGoStdDSMetaclass\fP,
\fBGoGeometrric\fP, \fBGoGeometricMetaclass\fP, \fBGoPolypoint\fP,
\fBGoPolypointMetaclass\fP, \fBGoCurve\fP, \fBGoCurveMetaclass\fP and
\fBGoCubic\fP classes.
.nrPN \n%
