.\" $Id: mGraph.n,v 1.1.1.1 1992/03/18 09:41:07 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoGraphMetaclass 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoGraphMetaclass\fP \(em the graph class object class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/mGraph.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGoGraphMetaclass\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGoGraphStructMetaclass\fP class
.IP \(em 3
\fBGoMetaclass\fP class.
.RE
.sp 1
.SH
\fBDESCRIPTION\fP
.IP
The \fBGoGraphMetaclass\fP class is the class for \fIGoGraph\fP objects.
There is only one static instance of the class: it is returned by \fIGoGraph::metaclass()\fP method.
.IP
This instance is defined to provide methods on \fIGoGraph\fP at the class level and its main purpose is to allow the programmer to set some pre/postconditions at the class level.
.IP
.nf
.ta .15i .25i 1.0i
class GoGraphMetaclass {
	public:
		// pre and post conditions;
		void addNodePrecond(GBool (*)\fIfunction\fP(void*, GoGraph*, GoGraphNode*, GBool*, GoMetaclass*), 
.br
					void* \fIclosure\fP, GAddOrRemove = GADD);
		void addNodePostcond(void (*)\fIfunction\fP(void*, GoGraph*, GoGraphNode*, GBool*, GoMetaclass*), 
.br
					void* \fIclosure\fP, GAddOrRemove = GADD);
		void removeNodePrecond(GBool (*)\fIfunction\fP(void*, GoGraph*, GoGraphNode*), 
.br	
					void* \fIclosure\fP, GAddOrRemove = GADD);
		void removeNodePostcond(void (*)\fIfunction\fP(void*, GoGraph*, GoGraphNode*), 
.br
					void* \fIclosure\fP, GAddOrRemove = GADD);
		void addLinkPrecond(GBool (*)\fIfunction\fP(void*, GoGraph*, GoGraphNode*, GoGraphNode*, 
.br
					GoMetaclass*), void* \fIclosure\fP, GAddOrRemove = GADD);
		void addLinkPostcond(void (*)\fIfunction\fP(void*, GoGraph*, GoGraphNode*, GoGraphNode*, 
.br
					GoMetaclass*), void* \fIclosure\fP, GAddOrRemove = GADD);
		void removeLinkPrecond(GBool (*)\fIfunction\fP(void*, GoGraph*, GoLink*), 
.br
					void* \fIclosure\fP, GAddOrRemove = GADD);
		void removeLinkPostcond(void (*)\fIfunction\fP(void*, GoGraph*, GoLink*), 
.br
					void* \fIclosure\fP, GAddOrRemove = GADD);
		
};
.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
.nf
void \fBaddNodePrecond\fP (GBool (*\fIproc\fP)(void* \fIclosure\fP, GoGraph* \fIgraph\fP, GoGraphNode* \fIextrem\fP, 
.br
				GBool* \fIis_previous\fP, GoMetaclass* \fIlinkclass\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBaddNodePostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GoGraph* \fIgraph\fP, GoGraphNode* \fIextrem\fP, 
.br
				GBool* \fIis_previous\fP, GoMetaclass* \fIlinkclass\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or to remove pre or postcondition procedures when a node is added to the \fIgraph\fP.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when a node will be added to the \fIgraph\fP. The precondition procedure is
called before the node is added. It can either accept or refuse the modification.
The postcondition procedure is invoked after the node is added.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the pre/postcondition procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the modify
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp 1
.IP
.nf
void \fBremoveNodePrecond\fP (GBool (*\fIproc\fP)(void* \fIclosure\fP, GoGraph* \fIgraph\fP, GoGraphNode* \fInode\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBremoveNodePostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GoGraph* \fIgraph\fP, GoGraphNode* \fInode\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or to remove pre or postcondition procedures when a node is removed from the \fIgraph\fP.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when a node will be removed from the \fIgraph\fP. The precondition procedure is
called before the node is removed. It can either accept or refuse the modification.
The postcondition procedure is invoked after the node is removed.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the pre/postcondition procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the modify
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp 1
.IP
.nf
void \fBaddLinkPrecond\fP (GBool (*\fIproc\fP)(void* \fIclosure\fP, GoGraph* \fIgraph\fP, GoGraphNode* \fIprev\fP, 
.br
				GoGraphNode* \fInext\fP, GoMetaclass* \fIlinkclass\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBaddLinkPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GoGraph* \fIgraph\fP, GoGraphNode* \fIprev\fP, 
.br
				GoGraphNode* \fInext\fP, GoMetaclass* \fIlinkclass\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or to remove pre or postcondition procedures when a link is added to the \fIgraph\fP.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when a link will be added to the \fIgraph\fP. The precondition procedure is
called before the link is added. It can either accept or refuse the modification.
The postcondition procedure is invoked after the link is added.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the pre/postcondition procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the modify
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp 1
.IP
.nf
void \fBremoveLinkPrecond\fP (GBool (*\fIproc\fP)(void* \fIclosure\fP, GoGraph* \fIgraph\fP, GoLink* \fIlink\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBremoveLinkPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GoGraph* \fIgraph\fP, GoLink* \fIlink\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or to remove pre or postcondition procedures when a link is removed from the \fIgraph\fP.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when a link will be removed from the \fIgraph\fP. The precondition procedure is
called before the link is removed. It can either accept or refuse the modification.
The postcondition procedure is invoked after the link is removed.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the pre/postcondition procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the modify
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp 1
.RE
.sp 2
.SH
\fBUSER INTERACTION\fP
.IP
User interactions are defined by the following functions which may be included in the customization files to be interpreted by the \fIGo\fP \fIUser\fP \fIInteraction\fP object \fBGoUI\fP (see \fIGoUI(3Go)\fP).
.sp1
.IP
Functions availables for user interaction are:
.br
GoGraph::rotateGraph(\fINumber\fP, \fIPoint&=*(GPoint*)NULL\fP)
.RS .8i
.IP \fIDescription\fP .5i
See the public method rotateGraph(\fINumber\fP, \fIPoint&=*(GPoint*)NULL\fP).
.RE
.SH
\fBC BINDING\fP
.SS 
\fBHeader\fP
.IP
#include <Go/cGraph.h>
.SS 
\fBFunctions\fP
.IP
void \fBGoAddGraphNodeMetaclassPrecond\fP(GObjectId \fImetaclass\fP, 
.br
			GBool(*\fIcb\fP)(GObjectId, GObjectId, GObjectId, GBool*, GObjectId), 
.br
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoGraphMetaclass::addNodePrecond(GBool(*\fIcb\fP)
.br
		(void*, GoGraph*, GoGraphNode*, GBool*, GoMetaclass*), 
.br
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).	
.RE
.sp 1
.IP
void \fBGoAddGraphNodeMetaclassPostcond\fP(GObjectId \fImetaclass\fP, 
.br
			void(*\fIcb\fP)(GObjectId, GObjectId, GObjectId, GBool*, GObjectId), 
.br
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoGraph::addNodePostcond(void(*\fIcb\fP)
.br
		(void*, GoGraph*, GoGraphNode*, GBool*, GoMetaclass*), 
.br
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.Sp 1
.IP
void \fBGoRemoveGraphNodeMetaclassPrecond\fP(GObjectId \fImetaclass\fP, 
.br
			GBool(*\fIcb\fP)(GObjectId, GObjectId, GObjectId), 
.br
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoGraph::removeNodePrecond(void(*\fIcb\fP)
.br
			(void*, GoGraph*, GoGraphNode*), 
.br
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoRemoveGraphNodeMetaclassPostcond\fP(GObjectId \fImetaclass\fP, 
.br
			void(*\fIcb\fP)(GObjectId, GObjectId, GObjectId), 
.br
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoGraph::removeNodePostcond(void(*\fIcb\fP)
.br
			(void*, GoGraph*, GoGraphNode*), 
.br	
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoAddGraphLinkMetaclassPrecond\fP(GObjectId \fImetaclass\fP, 
.br
			GBool(*\fIcb\fP)(GObjectId, GObjectId, GObjectId, GObjectId, GObjectId), 
.br
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoGraph::addLinkPrecond(GBool(*\fIcb\fP)
.br
	(void*, GoGraph*, GoGraphNode*, GoGraphNode*, GoMetaclass*), 
.br
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoAddGraphLinkMetaclassPostcond\fP(GObjectId \fImetaclass\fP, 
.br
			void(*\fIcb\fP)(GObjectId, GObjectId, GObjectId, GObjectId, GObjectId), 
.br
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoGraph::addLinkPostcond(void(*\fIcb\fP)
.br
	(void*, GoGraph*, GoGraphNode*, GoGraphNode*, GoMetaclass*), 
.br
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoRemoveGraphLinkMetaclassPrecond\fP(GObjectId \fImetaclass\fP, 
.br
			GBool(*\fIcb\fP)(GObjectId, GObjectId, GObjectId), 
.br
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoGraph::removeLinkPrecond(GBool(*\fIcb\fP)
.br
			(void*, GoGraph*, GoLink*), 
.br
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoRemoveGraphLinkMetaclassPostcond\fP(GObjectId \fImetaclass\fP, 
.br
			void(*\fIcb\fP)(GObjectId, GObjectId, GObjectId), 
.br
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoGraph::removeLinkPostcond(void(*\fIcb\fP)
.br
			(void*, GoGraph*, GoLink*), 
.br
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBGoGraph\fP class.
.nrPN \n%
