.\" $Id: mImage.n,v 1.1.1.1 1992/03/18 09:41:21 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoImageMetaclass 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoImageMetaclass\fP \(em the MetaClass object for the \fBGoImage\fP
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/mImage.h>\fP
.SH 
\fBCLASS\fP
.IP
\fBGoImageMetaclass\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGoStdDSMetaclass\fP class
.IP \(em 3
\fBGoMetaclass\fP class.
.RE
.SH
\fBDESCRIPTION\fP
.IP
The \fBGoImageMetaclass\fP class is the common superclass for all
\fBGoImage\fP objects.
.br
As for other "Metaclasses", there is only one static instance of
\fBGoImageMetaclass\fP: this instance is returned by
\fBGoImage::metaclass ()\fP static method.
.IP
Such object is meant to provide methods on \fBGoImage\fP at
the class level; in particular this allows the programmer to set some
pre/postconditions at the class level.
.IP
.nf
.ta .15i .25i 1.0i
class GoImageMetaclass {

	public:

		/*
		 * \fBpre and post conditions:\fP
		 */

		void configPrecond (bool \fIproc\fP(void* \fIclosure\fP,
					const GoImage* \fIimage\fP,
					Number* \fInew_w\fP, Number* \fInew_h\fP,
					Point* \fInew_origin\fP),
			void* \fIclosure\fP, AddOrRemove  \fIadd\fP = ADD);
		void configPostcond (void \fIproc\fP(void* \fIclosure\fP, GoImage* \fIimage\fP),
			void* \fIclosure\fP, AddOrRemove  \fIadd\fP = ADD);
};
.fi
.SH
\fBPUBLIC MEMBERS\fP
.IP
.nf
void \fBconfigPrecond\fP (bool \fIproc\fP(void* \fIclosure\fP, const GoImage* \fIimage\fP,
	Number* \fInew_w\fP, Number* \fInew_h\fP, Point* \fInew_origin\fP),
	void* \fIclosure\fP, AddOrRemove \fIadd\fP = ADD) const;
void \fBresetPostcond\fP (void \fIproc\fP(void* \fIclosure\fP, GoImage* \fIimage\fP),
	void* \fIclosure\fP, AddOrRemove \fIadd\fP = ADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or remove functions to the pre/post conditions lists
triggered by \fBconfig\fP (Number, Number, const Point*) member functions of \fBGoImage\fP.
.IP \fIproc\fP .5i
Specifies programmer's function to be added/removed.
.IP \fIclosure\fP .5i
Specifies programmer's parameter to call the function with.
.IP \fIimage\fP .5i
Specifies the \fIGoImage\fP object involved.
.IP \fInew_w\fP .5i
Specifies the new width. May be modified by \fIproc\fP.
.IP \fInew_h\fP .5i
Specifies the new height. May be modified by \fIproc\fP.
.IP \fInew_origin\fP .5i
Specifies the new origin. May be modified by \fIproc\fP.
.IP \fIadd\fP .5i
Specifies whether to add or remove the function \fIproc\fP from the list.
.RE
.SH
\fBC BINDING\fP
.IP
.SS
\fBFunctions\fP
.nf
	void	\fBGoImageClassConfigPrecond\fP(ObjectId* \fIgoimage\fP, AddOrRemove \fIadd\fP,
				    	  bool \fIfunc\fP(void*, ObjectId goimage,
						 Number*, Number*,Point*),
			      	void* \fIclosure\fP);

	void	\fBGoImageClassConfigPostcond\fP(ObjectId \fIgoimage\fP, AddOrRemove \fIadd\fP,
				       	void \fIfunc\fP(void*, ObjectId goimage),
			       		void* \fIclosure\fP);
.fi
.sp 1
.IP \fIDescription\fP .5i
\fIsee\fP the GoImageMetaclass::\fIname\fP method.
.SS
\fBResources\fP
.IP
No resources.
.SH
\fBSEE ALSO\fP
.IP
\fBGo\fP, \fBGoMetaclass\fP, \fBGoStdDS\fP, \fBGoStdDSMetaclass\fP,
\fBGoImage\fP classes.
.nrPN \n%
