.\" $Id: mLink.n,v 1.1.1.1 1992/03/18 09:41:26 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoLinkMetaclass 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoLinkMetaclass\fP \(em the graph node link class object class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/mLink.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGoLinkMetaclass\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGoGraphElementMetaclass\fP class
.IP \(em 3
\fBGoMetaclass\fP class.
.RE
.sp 1
.SH
\fBDESCRIPTION\fP
.IP
The \fBGoLinkMetaclass\fP class is the common superclass for all \fIGoLink class\fP objects.
There is only one static instance of the class: it is returned by \fIGoLink::metaclass()\fP method.
.IP
This instance is defined to provide methods on \fIGoLink\fP at
the class level.  Such class objects exist for every \fIGoLink\fP class.
The main purpose of this object is to allow the programmer to set some pre/postconditions at the class level.
.IP
.nf
.ta .15i .25i 1.0i
class GoLinkMetaclass {
	public:
		// pre and post conditions;
		void attachLinkPrecond(GBool (*)\fIfunction\fP(void*, GoLink*, GoGraphNode*, GoGraphNode*), 
.br
								void* \fIclosure\fP, GAddOrRemove = GADD);
		void attachLinkPostcond(void (*)\fIfunction\fP(void*, GoLink*, GoGraphNode*, GoGraphNode*), 
.br
					void* \fIclosure\fP, GAddOrRemove = GADD);
		void anchoringPointModifyPrecond(void (*)\fIfunction\fP(void*, GoLink*, GPoint*, GPoint*), 
.br
					void* \fIclosure\fP, GAddOrRemove = GADD);
		void anchoringPointModifyPostcond(void (*)\fIfunction\fP(void*, GoLink*, GPoint*, GPoint*), 
.br
					void* \fIclosure\fP, GAddOrRemove = GADD);
		
};
.fi
.sp 1
.SH
\fBPUBLIC MEMBERS\fP
.IP
.nf
void \fBattachLinkPrecond\fP (GBool (*\fIproc\fP)(void* \fIclosure\fP, GoLink* \fIlink\fP, GoGraphNode* \fInew_prev\fP, 
.br
						GoGraphNode* \fInew_next\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBattachLinkPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GoLink* \fIlink\fP, GoGraphNode* \fInew_prev\fP, 
.br
						GoGraphNode* \fInew_next\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or to remove pre or postcondition procedures when a link is attached to a \fInew_prev\fP node and a \fInew_next\fP node.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when a link will be attached to a \fInew_prev\fP node and a \fInew_next\fP node. The precondition procedure is
called before the link is attached. It can either accept or refuse the modification.
The postcondition procedure is invoked after the link is attached.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the pre/postcondition procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the modify
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp 1
.IP
.nf
void \fBanchoringPointModifyPrecond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GoLink* \fIlink\fP, 
.br
					GPoint* \fIprev_point\fP, GPoint* \fInext_point\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or to remove precondition procedures when connecting points between link and its extrem nodes are modified.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the connecting points will be modified.
The precondition procedure is invoked before connecting points are modified, and user can modify the new connecting points.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the postcondition procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the modify
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp 1
.IP
.nf
void \fBanchoringPointModifyPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GoLink* \fIlink\fP,
.br
					GPoint* \fIprev_point\fP, GPoint* \fInext_point\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or to remove postcondition procedures when connecting points between link and its extrem nodes are modified.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the connecting points will be modified.
The postcondition procedure is invoked after connecting points are modified.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the postcondition procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the modify
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp 1
.RE
.sp 2
.SH
\fBC BINDING\fP
.SS 
\fBHeader\fP
.IP
#include <Go/cLink.h>
.SS 
\fBFunctions\fP
.IP
void \fBGoAttachLinkMetaclassPrecond\fP(GObjectId \fImetaclass\fP, 
.br
			GBool (*\fIcb\fP)(GObjectId, GObjectId, GObjectId, GObjectId),
.br
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoLinkMetaclass::attachLinkPrecond(GBool (*\fIcb\fP)
.br
			(void*, GoLink*, GoGraphNode*, GoGraphNode*),
.br
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoAttachLinkMetaclassPostcond\fP(GObjectId \fImetaclass\fP, 
.br
			void (*\fIcb\fP)(GObjectId, GObjectId, GObjectId, GObjectId),
.br
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoLinkMetaclass::attachLinkPostcond(void (*\fIcb\fP)
.br
			(void*, GoLink*, GoGraphNode*, GoGraphNode*),
.br
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoLinkMetaclassAnchoringPointModifyPrecond\fP(GObjectId \fImetaclass\fP, 
.br
			void (*\fIcb\fP)(GObjectId, GObjectId, GObjectId, GObjectId),
.br
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoLinkMetaclass::anchoringPointModifyPrecond(void (*\fIcb\fP)
.br
			(void*, GoLink*, GPoint*, GPoint*),
.br
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoLinkMetaclassAnchoringPointModifyPostcond\fP(GObjectId \fImetaclass\fP, 
.br
			void (*\fIcb\fP)(GObjectId, GObjectId, GObjectId, GObjectId),
.br
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoLinkMetaclass::anchoringPointModifyPostcond(void (*\fIcb\fP)
.br
			(void*, GoLink*, GPoint*, GPoint*),
.br
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBGoLink\fP class.
.nrPN \n%

