.\" $Id: mPointSensor.n,v 1.1.1.1 1992/03/18 09:41:34 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoPointSensorMetaclass 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoPointSensorMetaclass\fP \(em the GoPointSensor metaclass object class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/PointSensor.h>\fP
.sp 1
.SH
\fBCLASS\fP
.IP
\fBGoPointSensorMetaclass\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGoSensorMetaclass\fP class
.IP \(em 3
\fBGoAbsDSMetaclass\fP class
.IP \(em 3
\fBGoMetaclass\fP class
.RE
.sp 1
.SH
\fBDESCRIPTION\fP
.IP
The \fBGoPointSensorMetaclass\fP class defines the \fBGoPointSensor\fP
metaclass object. It implements a common behavior for all \fBGoPointSensor\fP
instances (See \fBGoPointSensor\fP). There is only one instance of
\fBGoPointSensorMetaclass\fP. It can be accessed with
\fBGoPointSensor::metaclass()\fP.
.IP
\fIWarning:\fP As for \fBGoUI\fP, the current implementation is a temporary
implementation.
.sp 1
.br
.nf
.ta .15i .25i 1.0i
class GoPointSensorMetaclass : public GoSensorMetaclass {

	public:

		GoPointSensorMetaclass();
		virtual ~GoPointSensorMetaclass();
		virtual GBool radius(GNumber);

		GPen&   pen()    const;
		GBrush& brush()  const;
		GNumber radius() const;

		/*
		 * \fBpre and post conditions :\fP
		 */

		void radiusPrecond(GBool (*) (void*, const Go*,
			const GoPointSensorMetaclass*, GNumber*),
			void* closure, GAddOrRemove = GADD);
		void radiusPostcond(void (*) (void*, Go*, GoPointSensorMetaclass*),
			void* closure, GAddOrRemove = GADD);
};

.fi
.sp 1
.SH
\fBPUBLIC FUNCTIONS\fP
.IP
.nf
GPen& \fBpen\fP () const;
GBrush& \fBbrush\fP () const;
.fi
.RS .8i
.IP \fIDescription\fP .3i
These functions return a reference to the GPen (resp GBrush) used by all
\fBGoPointSensor\fP instances.
.RE
.IP
GNumber \fBradius\fP ();
.RS .8i
.IP \fIDescription\fP .3i
Returns the radius value used by all \fBGoPointSensor\fP instances to display
their circular sensitive areas.
.RE
.IP
GBool \fBradius\fP (GNumber \fIvalue\fP);
.RS .8i
.IP \fIDescription\fP .3i
This method sets to new value the radius used by all \fBGoPointSensor\fP
instances to display their circular sensitive areas.
.br
If none of the \fBradiusPrecond\fP preconditions returned GFALSE, the
action is performed with parameter \fIvalue\fP possibly modify by the
preconditions. If the action succeeds, \fBradiusPostcond\fP postconditions
are called and the method returns GTRUE. Otherwise, it returns GFALSE.
.IP \fIvalue\fP .3i
Specifies the new radius value.
.RE
.IP
.nf
void \fBradiusPrecond\fP(GBool (*\fIf\fP) (void* \fIclosure\fP, const Go* \fInull\fP,
	const GoPointSensorMetaclass* \fIptSensorMclass\fP, GNumber* \fIvalue\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBradiusPostcond\fP(void (*\fIf\fP) (void* \fIclosure\fP, Go* \fInull\fP,
	GoPointSensorMetaclass* \fIptSensorMclass\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or remove functions to the pre/post conditions lists
triggered by \fBradius\fP (GNumber) member function.
.IP \fIf\fP .5i
Specifies programmer's function to be added/removed.
.IP \fIclosure\fP .5i
Specifies programmer's parameter to call the function with.
.IP \fInull\fP .5i
This parameter is not used.
.IP \fIvalue\fP .5i
Specifies the new radius value. May be modified by \fIf\fP.
.IP  \fIptSensorMclass\fP .5i
Specifies the GoPointSensorMetaclass involved (i.e. \fIthis\fP).
.IP \fIadd\fP .5i
Specifies whether to add or remove the function \fIf\fP from the list.
.RE
.SH
\fBC BINDING\fP
.SS 
\fBHeader\fP
.IP
#include <Go/cPointSensor.h>
.DE
.SS 
\fBFunctions\fP
.IP
.nf
GNumber \fBGoPointSensorMetaclassRadius\fP(GObjectId \fIptSensorMclass\fP);
void \fBGoPointSensorMetaclassSetRadius\fP(GObjectId \fIptSensorMclass\fP, GNumber \fIvalue\fP);
void \fBGoPointSensorMetaclassRadiusPrecond\fP(GObjectId \fIptSensorMclass\fP,
		GBool (*\fIf\fP) (void*, const GObjectId, const GObjectId, GNumber*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoPointSensorMetaclassRadiusPostcond\fP(GObjectId \fIptSensorMclass\fP,
		void (*\fIf\fP) (void*, GObjectId, GObjectId),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
.fi
.sp 1
.RS .8i
.IP \fIDescription\fP .3i
See \fBGoPolyline\fP following members :
.sp 1
.nf
GNumber \fBradius\fP ();
GBool \fBradius\fP (GNumber \fIvalue\fP);
void \fBradiusPrecond\fP(GBool (*\fIf\fP) (void*, const Go*, const GoPointSensorMetaclass*, GNumber*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBradiusPostcond\fP(void (*\fIf\fP) (void*, Go*, GoPointSensorMetaclass*),
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
.fi
.RE
.SH
\fBUSAGE INFORMATION\fP
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBGoUI\fP, \fBGo\fP, \fBGoMetaclass\fP, \fBGoAbsDS\fP, \fBGoAbsDSMetaclass\fP,
\fBGoSensor\fP, \fBGoSensorMetaclass\fP and \fBGoPointSensor\fP classes.
.nrPN \n%
