.\" $Id: mPolyline.n,v 1.1.1.1 1992/03/18 09:41:39 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoPolylineMetaclass 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoPolylineMetaclass\fP \(em the Meta Class object for the \fBGoPolyline\fP
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/mPolyline.h>\fP
.SH 
\fBCLASS\fP
.IP
\fBGoPolylineMetaclass\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGoPolypointMetaclass\fP class
.IP \(em 3
\fBGoGeometricMetaclass\fP class
.IP \(em 3
\fBGoStdDSMetaclass\fP class
.IP \(em 3
\fBGoMetaclass\fP class.
.RE
.SH
\fBDESCRIPTION\fP
.IP
The \fBGoPolylineMetaclass\fP class is the common superclass for all
\fBGoPolyline\fP objects.
.br
As for other "Metaclasses", there is only one static instance of
\fBGoPolylineMetaclass\fP: this instance is returned by
\fBGoPolyline::metaclass ()\fP static method.
.IP
Such object is meant to provide methods on \fBGoPolyline\fP at
the class level; in particular this allows the programmer to set some
pre/postconditions at the class level.
.IP
.nf
.ta .15i .25i 1.0i
class GoPolylineMetaclass {

	public:

		/*
		 * \fBpre and post conditions:\fP
		 */

		void roundPrecond (GBool (*) (void*, const GoPolyline*, GBool*),
			void*, GAddOrRemove = GADD);
		void roundPostcond (void (*) (void*, GoPolyline*),
			void*, GAddOrRemove = GADD);
		void roundOffsetPrecond (GBool (*) (void*, const GoPolyline*, GNumber*),
			void*, GAddOrRemove = GADD);
		void roundOffsetPostcond (void (*) (void*, GoPolyline*),
			void*, GAddOrRemove = GADD);
};
.fi
.SH
\fBPUBLIC MEMBERS\fP
.IP
.nf
void \fBroundPrecond\fP (GBool (*\fIf\fP) (void* \fIclosure\fP, const GoPolyline* \fIpolyline\fP, GBool* \fIyes\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBroundPostcond\fP (void (*\fIf\fP) (void* \fIclosure\fP, GoPolyline* \fIpolyline\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBroundOffsetPrecond\fP (GBool (*\fIf\fP) (void* \fIclosure\fP, const GoPolyline* \fIpolyline\fP, GNumber* \fInewVal\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBroundOffsetPostcond\fP (void (*\fIf\fP) (void* \fIclosure\fP, GoPolyline* \fIpolyline\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or remove functions to the pre/post conditions lists
triggered by \fBround\fP (GBool) and \fBroundOffset\fP (GNumber) member functions.
.IP \fIf\fP .5i
Specifies programmer's function to be added/removed.
.IP \fIclosure\fP .5i
Specifies programmer's parameter to call the function with.
.IP \fIpolyline\fP .5i
Specifies the GoPolyline object involved.
.IP \fIyes\fP
Specifies the new value for "round". May be modified by \fIf\fP.
.IP \fInewVal\fP
Specifies the new value for "round offset". May be modified by \fIf\fP.
.IP \fIadd\fP .5i
Specifies whether to add or remove the function \fIf\fP from the list.
.RE
.SH
\fBC BINDING\fP
.SS 
\fBHeader\fP
.IP
#include <Go/cPolyline.h>
.SS 
\fBFunctions\fP
.IP
.nf
void \fBGoPolylineMetaclassRoundPrecond\fP (GObjectId \fIpolylineMclass\fP, 
			GBool (*\fIf\fP) (void*, const GObjectId, GBool*),
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoPolylineMetaclassRoundPostcond\fP (GObjectId \fIpolylineMclass\fP, 
			void (*\fIf\fP) (void*, GObjectId),
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoPolylineMetaclassRoundOffsetPrecond\fP (GObjectId \fIpolylineMclass\fP, 
			GBool (*\fIf\fP) (void*, const GObjectId, GNumber*),
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
void \fBGoPolylineMetaclassRoundOffsetPostcond\fP (GObjectId \fIpolylineMclass\fP, 
			void (*\fIf\fP) (void*, GObjectId),
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.fi
.sp 1
.RS .3i
.IP \fIDescription\fP .3i
See \fBGoPolylineMetaclass\fP following members :
.sp 1
.nf
void roundPrecond (GBool (*\fIf\fP) (void*, const GoPolyline*, GBool*),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void roundPostcond (void (*\fIf\fP) (void*, GoPolyline*),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void roundOffsetPrecond (GBool (*\fIf\fP) (void*, const GoPolyline*, GNumber),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
void roundOffsetPostcond (void (*\fIf\fP) (void*, GoPolyline*),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.fi
.RE
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBGo\fP, \fBGoMetaclass\fP, \fBGoStdDS\fP, \fBGoStdDSMetaclass\fP,
\fBGoGeometric\fP, \fBGoGeometricMetaclass\fP, \fBGoPolypoint\fP,
\fBGoPolypointMetaclass\fP and \fBGoPolyline\fP classes.
.nrPN \n%
