.\" $Id: mScText.n,v 1.2 1992/12/16 12:31:09 andre Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoScrolledTextMetaclass 3Go "February 1992" "Version 1.1" "Go Reference Manual"
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoScrolledTextMetaclass\fP \(em The scrolled text class object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/mScText.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGoScrolledTextMetaclass\fP inherits behavior from class \fBGoSimpleTextMetaclass\fP.
.RS 10
.RE
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBGoScrolledTextMetaclass\fP class is the class for \fIGoScrolledText\fP objects.
There is only one static instance of the class: it is returned by \fIGoScrolledText::metaclass()\fP method.
This instance is defined to provide methods on \fIGoScrolledText\fP at the class level and its main purpose is to allow the programmer to set some pre/postconditions at the class level.
.IP
.nf
.ta .15i .25i 1.50i


class GoScrolledTextMetaclass: public GoSimpleTextMetaclass
{
public:
    /* Pre/Postconds on firstLineToShow value */
    void	firstLineToShowPrecond (GBool (*)(void*, const GoScrolledText*, int),
.br
				void* closure, GAddOrRemove = GADD);
    void	firstLineToShowPostcond (void (*)(void*, GoScrolledText*, int),
.br
				void* closure, GAddOrRemove = GADD);

    /* Pre/Postconds on nbLinesToShow value */
    void	nbLinesToShowPrecond (GBool (*)(void*, const GoScrolledText*, ushort)
.br
				,void* closure, GAddOrRemove = GADD);
    void	nbLinesToShowPostcond (void (*)(void*, GoScrolledText*, ushort),
.br
				void* closure, GAddOrRemove = GADD);

    /* Pre/Postconds on horizontal scroll */
    void	hScrollPrecond (GBool (*)(void*, const GoScrolledText*, GNumber*)
.br
				,void* closure, GAddOrRemove = GADD);
    void	hScrollPostcond (void (*)(void*, GoScrolledText*, GNumber*),
.br
				void* closure, GAddOrRemove = GADD);
}


.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.sp
.IP
void \fBfirstLineToShowPrecond\fP (GBool \fIproc\fP(*)(void* \fIclosure \fP, const GoScrolledText* \fIgo\fP,
.br
		int \fIline\fP),
.br
		const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.br
void \fBfirstLineToShowPostcond\fP (void \fIproc\fP(*)(void* \fIclosure \fP, GoScrolledText* \fIgo\fP,
.br
		int \fIline\fP),
.br
		const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.IP \fIDescription\fP .5i
These methods allow to add/remove pre/postcondition callbacks which will be called when a change of the first line to be chown occurs.
.IP \fIproc\fP .5i
Specifies the pre/postcondition procedure. The precondition and the postcondition take three parameters: the closure (private application data), the GoScrolledText itself, and a line number. In the case of the precondition, \fIline\fP is the new line to be chown, and the old one for a postcondtion.
.RE
.sp 1
.IP
void \fBnbLinesToShowPrecond\fP (GBool \fIproc\fP(*)(void* \fIclosure \fP, const GoScrolledText* \fIgo\fP,
.br
		ushort \fInb\fP),
.br
		const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.br
void \fBnbLinesToShowPostcond\fP (void \fIproc\fP(*)(void* \fIclosure \fP, GoScrolledText* \fIgo\fP,
.br
		ushort \fInb\fP),
.br
		const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.IP \fIDescription\fP .5i
These methods allow to add/remove pre/postcondition callbacks which will be called when the number of lines to show changes.
.IP \fIproc\fP .5i
Specifies the pre/postcondition procedure. The precondition and the postcondition take three parameters: the closure (private application data), the GoScrolledText itself, and a number of lines. In the case of the precondition, \fInb\fP is the new number of lines to show, and the old one for a postcondtion.
.br
.RE
.sp 1
.IP
void \fBhScrollPrecond\fP (GBool \fIproc\fP(*)(void* \fIclosure \fP, const GoScrolledText* \fIgo\fP,
.br
		GNumber* \fIx\fP),
.br
		const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.br
void \fBhScrollPostcond\fP (void \fIproc\fP(*)(void* \fIclosure \fP, GoScrolledText* \fIgo\fP,
.br
		GNumber* \fIx\fP),
.br
		const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.IP \fIDescription\fP .5i
These methods allow to add/remove pre/postcondition callbacks which will be called when the horizontal scroll changes.
.IP \fIproc\fP .5i
Specifies the pre/postcondition procedure. The precondition and the postcondition take three parameters: the closure (private application data), the GoScrolledText itself, and a scroll value. In the case of a precondition, \fIx\fP is the new horizontal scrolling value, and the old one for a postcondtion.
.br
.RE
.SH
\fBUSER INTERACTIONS\fP
.IP
User interactions are defined by the following functions which may be
included in the customization files interpreted by the \fIGo User Interaction\fP
object \fBGoUI\fP, (see \fIGoUI(3Go)\fP).
.sp 1
.IP
Functions availables for user interaction are:
.RS .8i
.sp 1
\fBGoScrolledText::scrollUp()
.RS .8i
.IP \fIDescription\fP .5i
This method allows, if possible, to scroll one line upper the displayed text.
.RE
.sp 1
\fBGoScrolledText::scrollDown()
.RS .8i
.IP \fIDescription\fP .5i
This method allows, if possible, to scroll one line downer the displayed text.
.RE
.sp 1
\fBGoScrolledText::addLineToShow()
.RS .8i
.IP \fIDescription\fP .5i
This method allows, if possible, to add one line at the bottom of the window.
.RE
.sp 1
\fBGoScrolledText::removeLineToShow()
.RS .8i
.IP \fIDescription\fP .5i
This method allows, if possible, to remove one line from the bottom of the window.
.sp 1
.SH
\fBC BINDING\fP
.SS
\fBHeader\fP
.IP
#include <Go/cScText.h>
.SS
\fBFunctions\fP
.sp 1
.IP
void \fBGoScrolledTextMetaclassNbLinesToShowPrecond\fP (GObjectId \fItext\fP,
.br
        , GBool(*\fIcb\fP)(GObjectId, const GObjectId, ushort),
.br
        GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoScrolledTextMetaclass::nbLinesToShowPrecond (GBool (*\fIcb\fP)
.br
        (void*, const GoScrolledText*, ushort),
.br
        void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoScrolledTextMetaclassNbLinesToShowPostcond\fP (GObjectId \fItext\fP,
.br
        , void(*\fIcb\fP)(GObjectId, GObjectId, ushort),
.br
        GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoScrolledTextMetaclass::nbLinesToShowPostcond (void (*\fIcb\fP)
.br
        (void*, GoScrolledText*, ushort),
.br
        void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoScrolledTextMetaclassFirstLineToShowPrecond\fP (GObjectId \fItext\fP,
.br
        , GBool(*\fIcb\fP)(GObjectId, const GObjectId, int),
.br
        GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoScrolledTextMetaclass::firstLineToShowPrecond (GBool (*\fIcb\fP)
        (void*, const GoScrolledText*, int),
.br
        void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoScrolledTextMetaclassFirstLineToShowPostcond\fP (GObjectId \fItext\fP,
.br
        , void(*\fIcb\fP)(GObjectId, GObjectId, int),
.br
        GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoScrolledTextMetaclass::firstLineToShowPostcond (void (*\fIcb\fP)
.br
        (void*, GoScrolledText*, int),
.br
        void* \fIclosure\fP, GAddOrRemove \fIadd\fP).

.RE
.sp 1
.IP
void \fBGoScrolledTextMetaclassHscrollPrecond\fP (GObjectId \fItext\fP,
.br
        , GBool(*\fIcb\fP)(GObjectId, const GObjectId, GNumber*),
.br
        GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoScrolledTextMetaclass::hScrollPrecond (GBool (*\fIcb\fP)
.br
        (void*, const GoScrolledText*, GNumber*),
.br
        void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoScrolledTextMetaclassHscrollPostcond\fP (GObjectId \fItext\fP,
.br
        , void(*\fIcb\fP)(GObjectId, GObjectId, GNumber*),
.br
        GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoScrolledTextMetaclass::hScrollPostcond (void (*\fIcb\fP)
.br
        (void*, GoScrolledText*, GNumber*),
.br
        void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.SH
\fBSEE ALSO\fP
.IP
\fBGo\fP, \fBGoUI\fP, \fBGoTextual\fP, \fBGoTextualMetaclass\fP, \fBGoSimpleText\fP and \fBGoSimpleTextMetaclass\fP classes.
.nrPN \n%
