.\" $Id: mTextual.n,v 1.2 1992/12/16 12:31:11 andre Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoTextualMetaclass 3Go "February 1992" "Version 1.1" "Go Reference Manual"
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoTextualMetaclass\fP \(em The textual class object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/mTextual.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGoTextualMetaclass\fP inherits behavior from class \fBGoStdDSMetaclass\fP.
.RS 10
.RE
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBGoTextualMetaclass\fP class is the class for \fIGoTextual\fP objects.
There is only one static instance of the class: it is returned by \fIGoTextual::metaclass()\fP method.
This instance is defined to provide methods on \fIGoTextual\fP at the class level and its main purpose is to allow the programmer to set some pre/postconditions at the class level.
.IP
.nf
.ta .15i .25i 1.50i


class GoTextualMetaclass: public GoStdDSMetaclass
{
public:
    // Pre/Postconditions functions

    /* modify value */
    void		modifyValuePrecond (GBool (*)(void*, const GoTextual*, GmodifyValueStruct*),
.br
				void* closure, GAddOrRemove = GADD);
    void		modifyValuePostcond (void (*)(void*, GoTextual*, GmodifyValueStruct*),
.br
				void* closure, GAddOrRemove = GADD);

    /* current position change */
    void		currentPosPrecond (GBool (*)(void*, const GoTextual*, GPos),
.br
				void* closure, GAddOrRemove = GADD);
    void		currentPosPostcond (void (*)(void*, GoTextual*, GPos),
.br
				void* closure, GAddOrRemove = GADD);

    /* modify attribute */
    void		modifyAttributePrecond (GBool (*)(void*, const GoTextual*, GmodifyAttributeStruct*),
.br
				void* closure, GAddOrRemove = GADD);
    void		modifyAttributePostcond (void (*)(void*, GoTextual*, GmodifyAttributeStruct*),
.br
				void* closure, GAddOrRemove = GADD);

    /* selection */
    void		selectionPrecond (GBool (*)(void*, const GoTextual*, GPos, GPos),
.br
				void* closure, GAddOrRemove = GADD);
    void		selectionPostcond (void (*)(void*, GoTextual*, GPos, GPos),
.br
				void* closure, GAddOrRemove = GADD);
}


.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.sp
.IP
void \fBmodifyValuePrecond\fP (GBool \fIproc\fP(*)(void* \fIclosure \fP, const GoTextual* \fIgo\fP,
.br
		GmodifyValueStruct* str),
.br
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.br
void \fBmodifyValuePostcond\fP (void \fIproc\fP(*)(void* \fIclosure \fP, GoTextual* \fIgo\fP,
.br
		GmodifyValueStruct* str),
.br
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add/remove pre/postcondition callbacks which will be called when a modification of the string value occurs.
.IP \fIproc\fP .5i
Specifies the pre/postcondition procedure. The precondition and the postcondition take three parameters: the closure (private application data), the GoTextual itself, a pointer to a structure of which the content depends on the type of modification (see \fIGoTextual(3Go)\fP). In the case of the precondition, \fIstr\fP points to the new values. For the postcondition, \fIstr\fP points the old one. 
.RE
.sp 1
.IP
void \fBmodifyAttributePrecond\fP (GBool \fIproc\fP(*)(void* \fIclosure \fP, const GoTextual* \fIgo\fP,
.br
		GmodifyAttributeStruct* str),
.br
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.br
void \fBmodifyAttributePostcond\fP (void \fIproc\fP(*)(void* \fIclosure \fP, GoTextual* \fIgo\fP,
.br
		GmodifyAttributeStruct* str),
.br
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add/remove pre/postcondition callbacks which will be called when a modification of an attribute occurs.
.IP \fIproc\fP .5i
Specifies the pre/postcondition procedure. The precondition and the postconditions take three parameters: the closure (private application data), the GoTextual itself, a pointer to a structure of which the content depends on the type of modification (see \fIGoTextual(3Go)\fP). In the case of the precondition, \fIstr\fP points to the new values. For the postcondition, \fIstr\fP points the old one.
.RE
.sp 1
.IP
void \fBcurrentPosPrecond\fP (GBool \fIproc\fP(*)(void* \fIclosure \fP, const GoTextual* \fIgo\fP, GPos \fInewPos\fP),
.br
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.br
void \fBcurrentPosPostcond\fP (void \fIproc\fP(*)(void* \fIclosure \fP, GoTextual* \fIgo\fP, GPos \fIoldPos\fP),
.br
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add/remove pre/postcondition callbacks which will be called when a change of the position of insertion point occurs.
.IP \fIproc\fP .5i
Specifies the pre/postcondition procedure. The precondition takes three parameters: the closure (private application data), the GoTextual itself, and the position to be the new one. The postcondition takes three parameters: the closure, the GoTextual, and the old position.
.RE
.sp 1
.IP
void \fBselectionPrecond\fP (GBool \fIproc\fP(*)(void* \fIclosure \fP, const GoTextual* \fIgo\fP, GPos \fIpos1fP, GPos \fIpos2\fP),
.br
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.br
void \fBselectionPostcond\fP (void \fIproc\fP(*)(void* \fIclosure \fP, GoTextual* \fIgo\fP, GPos \fIpos1\fP, GPos \fIpos2\fP),
.br
		void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add/remove pre/postcondition callbacks which will be called when a change of the selection occurs.
.IP \fIproc\fP .5i
Specifies the pre/postcondition procedure. The precondition takes four parameters: the closure (private application data), the GoTextual itself, and the boundaries of the new selection. The postcondition takes four parameters: the closure, the GoTextual, and the boundaries of the new selection.


.SH
\fBUSER INTERACTIONS\fP
.IP
User interactions are defined by the following functions which may be
included in the customization files interpreted by the \fIGo User Interaction\fP
object \fBGoUI\fP, (see \fIGoUI(3Go)\fP).
These functions may have arguments which are defined as follows:
.IP
.RS .4i
\fIposition\fP: Point obtained by pressing a mouse button.
.br
\fIchar\fP: Character obtained by pressing a key.
.RE

.sp 1
.IP
Functions availables for user interaction are:
.RS .8i
.sp 1
\fBGoTextual::insertChar(char)
.RS .8i
.IP \fIDescription\fP .5i
see the public method \fIinsertChar\fP.
.RE
.sp 1
\fBGoTextual::deleteChar()
.RS .8i
.IP \fIDescription\fP .5i
see the public method \fIdeleteChar\fP.
.RE
.sp 1
\fBGoTextual::cursorLeft()
.RS .8i
.IP \fIDescription\fP .5i
see the public method \fIcursorLeft\fP.
.RE
.sp 1
\fBGoTextual::cursorRight()
.RS .8i
.IP \fIDescription\fP .5i
see the public method \fIcursorRight\fP.
.RE
.sp1
\fBGoTextual::cursorUp()
.RS .8i
.IP \fIDescription\fP .5i
see the public method \fIcursorUp\fP.
.RE
.sp 1
\fBGoTextual::cursorDown()
.RS .8i
.IP \fIDescription\fP .5i
see the public method \fIcursorDown\fP.
.RE
.sp 1
\fBGoTextual::cursorBegText()
.RS .8i
.IP \fIDescription\fP .5i
see the public method \fIcursorBegText\fP.
.RE
.sp 1
\fBGoTextual::cursorEndText()
.RS .8i
.IP \fIDescription\fP .5i
see the public method \fIcursorEndText\fP.
.RE
.sp 1
\fBGoTextual::cursorBegLine()
.RS .8i
.IP \fIDescription\fP .5i
see the public method \fIcursorBegLine\fP.
.RE
.sp 1
\fBGoTextual::cursorEndLine()
.RS .8i
.IP \fIDescription\fP .5i
see the public method \fIcursorEndLine\fP.
.RE
.sp 1
\fBGoTextual::cursor(position)
.RS .8i
.IP \fIDescription\fP .5i
This function places the insertion point at the given position.
.RE
.sp 1
\fBGoTextual::underline(GBool)
.RS .8i
.IP \fIDescription\fP .5i
This function draws or undraws an underline inside the selected portion of text.
.RE
.sp 1
\fBGoTextual::mapString(GBool)
.RS .8i
.IP \fIDescription\fP .5i
see the public method \fImapString\fP.
.RE
.sp 1
\fBGoTextual::mapCursor(GBool)
.RS .8i
.IP \fIDescription\fP .5i
see the public method \fImapCursor\fP.
.RE
.sp 1
\fBGoTextual::mapUnderline(GBool)
.RS .8i
.IP \fIDescription\fP .5i
see the public method \fImapUnderline\fP.
.RE
.sp 1
\fBGoTextual::mapBackground(GBool)
.RS .8i
.IP \fIDescription\fP .5i
see the public method \fImapBackground\fP.
.RE
.sp 1
\fBGoTextual::justification()
.RS .8i
.IP \fIDescription\fP .5i
This method changes (by turning the value) the current justification.
.RE
.sp 1
\fBGoTextual::presentation()
.RS .8i
.IP \fIDescription\fP .5i
This method changes (by turning the value) the current presentation.
.RE
.sp 1
\fBGoTextual::interline()
.RS .8i
.IP \fIDescription\fP .5i
This method changes (by turning the value) the current interline.
.RE
.sp 1
\fBGoTextual::updateCharCase()
.RS .8i
.IP \fIDescription\fP .5i
This method changes the character case at the current position.
The cursor is moved to the next position.
.RE
.sp 1
.SH
\fBC BINDING\fP
.SS
\fBHeader\fP
.IP
#include <Go/cTextual.h>
.SS
\fBFunctions\fP
.sp 1
.IP
void \fBGoTextualMetaclassModifyValuePrecond\fP (GObjectId \fItext\fP, GBool(*\fIcb\fP)(GObjectId, const GObjectId,
.br
GmodifyValueStruct*), GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void modifyValuePrecond(GBool (*\fIcb\fP)
.br
	(GObjectId, const GObjectId, GmodifyValueStruct*),
.br
	GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
void \fBGoTextualMetaclassModifyValuePostcond\fP (GObjectId \fItext\fP, void(*\fIcb\fP)(GObjectId, GObjectId,
.br
GmodifyValueStruct*),GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void modifyValuePostcond (void (*\fIcb\fP)
.br
	(GObjectId, GObjectId, GmodifyValueStruct*),
.br
	GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
void \fBGoTextualMetaclassModifyAttributePrecond\fP (GObjectId \fItext\fP, GBool(*\fIcb\fP)(GObjectId, const GObjectId,
.br
GmodifyAttributeStruct*), GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void modifyAttributePrecond (GBool (*\fIcb\fP)
.br
	(GObjectId, const GObjectId, GmodifyAttributeStruct*),
.br
	GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
void \fBGoTextualMetaclassModifyAttributePostcond\fP (GObjectId \fItext\fP, void(*\fIcb\fP)(GObjectId, GObjectId,
.br
GmodifyAttributeStruct*), GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void modifyAttributePostcond (void (*\fIcb\fP)
.br
	(GObjectId, GObjectId, GmodifyAttributeStruct*),
.br
	GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
void \fBGoTextualMetaclassCurrentPositionPrecond\fP (GObjectId \fItext\fP, GBool(*\fIcb\fP)(GObjectId, const GObjectId,
.br
 GPos),	GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void currentPositionPrecond (GBool (*\fIcb\fP)
.br
	(GObjectId, const GObjectId, GPos),
.br
	GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
void \fBGoTextualMetaclassCurrentPositionPostcond\fP (GObjectId \fItext\fP, void(*\fIcb\fP)(GObjectId, GObjectId,
.br
GPos), GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void currentPositionPostcond (void (*\fIcb\fP)
.br
	(GObjectId, GObjectId, GPos),
.br
	GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
void \fBGoTextualMetaclassSelectionPrecond\fP (GObjectId \fItext\fP, GBool(*\fIcb\fP)(GObjectId, const GObjectId,
.br
GPos, GPos), GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void selectionPrecond (GBool (*\fIcb\fP)
.br
	(GObjectId, const GObjectId, GPos, GPos),
.br
	GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
void \fBGoTextualMetaclassSelectionPostcond\fP (GObjectId \fItext\fP, void(*\fIcb\fP)(GObjectId, GObjectId,
.br
GPos, GPos), GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void selectionPostcond (void (*\fIcb\fP)
.br
	(GObjectId, GObjectId, GPos, GPos),
.br
	GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBGo\fP, \fBGoUI\fP, \fBGoTextual\fP classes.
.nrPN \n%
