.\" $Id: mTree.n,v 1.1.1.1 1992/03/18 09:42:14 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoTreeMetaclass 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoTreeMetaclass\fP \(em the tree class object class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/mTree.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGoTreeMetaclass\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGoGraphStructMetaclass\fP class
.IP \(em 3
\fBGoMetaclass\fP class.
.RE
.sp 1
.SH
\fBDESCRIPTION\fP
.IP
The \fBGoTreeMetaclass\fP class is the class for \fIGoTree\fP objects.
There is only one static instance of the class: it is returned by \fIGoTree::metaclass()\fP method.
.IP
This instance is defined to provide methods on \fIGoTree\fP at
the class level and its main purpose is to allow the programmer to set some pre/postconditions at the class level.
.IP
.nf
.ta .15i .25i 1.0i
class GoTree {
	public:
		// pre and post conditions;
		void addNodePrecond(GBool (*)\fIfunction\fP(void*, const GoTree*, GoTreeNode*, GoMetaclass*, 
.br
					GoTreeNode*), void* \fIclosure\fP, GAddOrRemove = GADD);
		void addNodePostcond(void (*)\fIfunction\fP(void*, GoTree*, GoTreeNode*, GoMetaclass*, 
.br
					GoTreeNode*), void* \fIclosure\fP, GAddOrRemove = GADD);
		void removeNodePrecond(GBool (*)\fIfunction\fP(void*, const GoTree*, GoTreeNode*), void* \fIclosure\fP, 
.br
					GAddOrRemove = GADD);
		void removeNodePostcond(void (*)\fIfunction\fP(void*, GoTree*, GoTreeNode*), void* \fIclosure\fP, 
.br
					GAddOrRemove = GADD);
};
.fi
.sp 1
.SH
\fBPUBLIC MEMBERS\fP
.IP
.nf
void \fBaddNodePrecond\fP (GBool (*\fIproc\fP)(void* \fIclosure\fP, const GoTree* \fItree\fP, GoTreeNode* \fIparent\fP, 
.br
						GoMetaclass* \fIlinkclass\fP, GoTreeNode* \fInext_brother\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBaddNodePostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GoTree* \fItree\fP, GoTreeNode* \fIparent\fP, 
.br
						GoMetaclass* \fIlinkclass\fP, GoTreeNode* \fInext_brother\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or to remove pre or postcondition procedures when a node is added to the \fItree\fP.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when a node will be added to the \fItree\fP. The precondition procedure is
called before the node is added. It can either accept or refuse the modification.
The postcondition procedure is invoked after the node is added.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the pre/postcondition procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the modify
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp 1
.IP
.nf
void \fBremoveNodePrecond\fP (GBool (*\fIproc\fP)(void* \fIclosure\fP, const GoTree* \fItree\fP, GoTreeNode* \fInode\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBremoveNodePostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GoTree* \fItree\fP, GoTreeNode* \fInode\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or to remove pre or postcondition procedures when a node is removed from the \fItree\fP.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when a node will be removed from the \fItree\fP. The precondition procedure is
called before the node is removed. It can either accept or refuse the modification.
The postcondition procedure is invoked after the node is removed.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the pre/postcondition procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the modify
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp 1
.RE
.sp 2
.SH
\fBUSER INTERACTION\fP
.IP
User interactions are defined by the following functions which may be included in the customization files to be interpreted by the \fIGo\fP \fIUser\fP \fIInteraction\fP object \fBGoUI\fP (see \fIGoUI(3Go)\fP).
.sp1
.IP
Functions availables for user interaction are:
.br
GoTree::setDistX(\fIGNumber\fP)
.RS .8i
.IP \fIDescription\fP .5i
See the public method distX(\fIGNumber\fP).
.RE
.sp1
.IP
GoTree::setDistY(\fINumber\fP)
.RS .8i
.IP \fIDescription\fP .5i
See the public method distY(\fIGNumber\fP).
.RE
.sp1
.SH
\fBC BINDING\fP
.SS 
\fBHeader\fP
.IP
#include <Go/cTree.h>
.SS 
\fBFunctions\fP
.IP
void \fBGoAddTreeNodeMetaclassPrecond\fP(GObjectId \fImetaclass\fP, 
.br
			GBool(*\fIcb\fP)(GObjectId, const GObjectId, GObjectId, GObjectId, GObjectId),
.br
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTreeMetaclass::addNodePrecond(GBool (*\fIcb\fP)
.br
	(void*, const GoTree*, GoTreeNode*, GoMetaclass*, GoTreeNode*),
.br
	 void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoAddTreeNodeMetaclassPostcond\fP(GObjectId \fImetaclass\fP, 
.br
			void(*\fIcb\fP)(GObjectId, GObjectId, GObjectId, GObjectId, GObjectId),
.br
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTreeMetaclass::addNodePostcond(void (*\fIcb\fP)
.br
	(void*, GoTree*, GoTreeNode*, GoMetaclass*, GoTreeNode*),
.br
	 void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoRemoveTreeNodeMetaclassPrecond\fP(GObjectId \fImetaclass\fP, 
.br
			GBool(*\fIcb\fP)(GObjectId, const GObjectId, GObjectId),
.br
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTreeMetaclass::removeNodePrecond(GBool (*\fIcb\fP)
.br
			(void*, const GoTree*, GoTreeNode*),
.br
			 void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoRemoveTreeNodeMetaclassPostcond\fP(GObjectId \fImetaclass\fP, 
.br
			void(*\fIcb\fP)(GObjectId, GObjectId, GObjectId),
.br
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTreeMetaclass::removeNodePostcond(void (*\fIcb\fP)
.br
			(void*, GoTree*, GoTreeNode*),
.br
			 void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBGoTree\fP class.
.nrPN \n%
