.\" $Id: mTreeNode.n,v 1.1.1.1 1992/03/18 09:42:19 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoTreeNodeMetaclass 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoTreeNodeMetaclass\fP \(em the tree node class object class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/mTreeNode.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGoTreeNodeMetaclass\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGoNodeMetaclass\fP class
.IP \(em 3
\fBGoGraphElementMetaclass\fP class
.IP \(em 3
\fBGoMetaclass\fP class.
.RE
.sp 1
.SH
\fBDESCRIPTION\fP
.IP
The \fBGoTreeNodeMetaclass\fP class is the class for \fIGoTreeNode\fP objects.
There is only one static instance of the class: it is returned by \fIGoTreeNode::metaclass()\fP method.
.IP
This instance is defined to provide methods on \fIGoTreeNode\fP at
the class level and its main purpose is to allow the programmer to set some pre/postconditions at the class level.
.IP
.nf
.ta .15i .25i 1.0i
class GoTreeNodeMetaclass {
	public:
		// pre and post conditions;
		void attachNodePrecond(GBool (*)\fIfunction\fP(void*, GoTreeNode*, GoTreeNode*, GoMetaclass*, 
.br
					GoTreeNode*, GoTree*), void* \fIclosure\fP, GAddOrRemove = GADD);
		void attachNodePostcond(void (*)\fIfunction\fP(void*, GoTreeNode*, GoTreeNode*, GoMetaclass*, 
.br
					GoTreeNode*, GoTree*), void* \fIclosure\fP, GAddOrRemove = GADD);
		void shiftNodePrecond(GBool (*)\fIfunction\fP(void*, GoTreeNode*, GoTreeNode*), 
.br
					void* \fIclosure\fP, GAddOrRemove = GADD);
		void shiftNodePostcond(void (*)\fIfunction\fP(void*, GoTreeNode*, GoTreeNode*), 
.br
					void* \fIclosure\fP, GAddOrRemove = GADD);
		
};
.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
.nf
void \fBattachNodePrecond\fP (GBool (*\fIproc\fP)(void* \fIclosure\fP, GoTreeNode* \fInode\fP, GoTreeNode* \fInew_parent\fP, 
.br
						GoMetaclass* \fIlinkclass\fP, GoTreeNode* \fInew_next\fP, GoTree* \fInew_tree\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBattachNodePostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GoTreeNode* \fInode\fP, GoTreeNode* \fInew_parent\fP, 
.br
						GoMetaclass* \fIlinkclass\fP, GoTreeNode* \fInew_next\fP, GoTree* \fInew_tree\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or to remove pre or postcondition procedures when a node is attached to a \fInew_parent\fP node or a \fInew_tree\fP.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when a node will be attached to a \fInew_parent\fP or a \fInew_tree\fP. The precondition procedure is
called before the node is attached. It can either accept or refuse the modification.
The postcondition procedure is invoked after the node is attached.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the pre/postcondition procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the modify
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp 1
.IP
.nf
void \fBshiftNodePrecond\fP (GBool (*\fIproc\fP)(void* \fIclosure\fP, GoTreeNode* \fInode\fP, GoTreeNode* \fInext_brother\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBshiftNodePostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GoTreeNode* \fInode\fP, GoTreeNode* \fInext_brother\fP),
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or to remove pre or postcondition procedures when a node is shifted.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when a node will be shifted. The precondition procedure is
called before the node is shifted. It can either accept or refuse the modification.
The postcondition procedure is invoked after the node is shifted.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the pre/postcondition procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the modify
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp 1
.RE
.sp 2
.SH
\fBUSER INTERACTION\fP
.IP
User interactions are defined by the following functions which may be included in the customization files to be interpreted by the \fIGo\fP \fIUser\fP \fIInteraction\fP object \fBGoUI\fP (see \fIGoUI(3Go)\fP).
.sp1
.IP
Functions availables for user interaction are:
.br
GoTreeNode::openNode()
.RS .8i
.IP \fIDescription\fP .5i
See the public method openNode().
.RE
.sp1
.IP
GoTreeNode::closeNode()
.RS .8i
.IP \fIDescription\fP .5i
See the public method closeNode().
.RE
.sp1
.IP
GoTreeNode::shiftNode(\fIGoTreeNode*=NULL\fP)
.RS .8i
.IP \fIDescription\fP .5i
See the public method shiftNode(\fIGoTreeNode*=NULL\fP).
.RE
.sp1
.SH
\fBC BINDING\fP
.SS 
\fBHeader\fP
.IP
#include <Go/cTreeNode.h>
.SS 
\fBFunctions\fP
.IP
void \fBGoAttachTreeNodeMetaclassPrecond\fP(GObjectId \fImetaclass\fP, 
.br
			GBool(*\fIcb\fP)(GObjectId, GObjectId, GObjectId, GObjectId, GObjectId, 
.br
			GObjectId), GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTreeNodeMetaclass::attachNodePrecond(GBool (*\fIcb\fP)
.br
	(void*, GoTreeNode*, GoTreeNode*, GoMetaclass*, GoTreeNode*, GoTree*),
.br
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoAttachTreeNodeMetaclassPostcond\fP(GObjectId \fImetaclass\fP, 
.br
			void(*\fIcb\fP)(GObjectId, GObjectId, GObjectId, GObjectId, GObjectId, 
.br
			GObjectId), GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTreeNodeMetaclass::attachNodePostcond(void (*\fIcb\fP)
.br
	(void*, GoTreeNode*, GoTreeNode*, GoMetaclass*, GoTreeNode*, GoTree*),
.br
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoShiftTreeNodeMetaclassPrecond\fP(GObjectId \fImetaclass\fP, 
.br
			GBool(*\fIcb\fP)(GObjectId, GObjectId, GObjectId), 
.br
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTreeNodeMetaclass::shiftNodePrecond(GBool (*\fIcb\fP)
.br
			(void*, GoTreeNode*, GoTreeNode*),
.br
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.IP
void \fBGoShiftTreeNodeMetaclassPostcond\fP(GObjectId \fImetaclass\fP, 
.br
			void(*\fIcb\fP)(GObjectId, GObjectId, GObjectId), 
.br
			GObjectId \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void GoTreeNodeMetaclass::shiftNodePostcond(void (*\fIcb\fP)
.br
			(void*, GoTreeNode*, GoTreeNode*),
.br
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP).
.RE
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBGoTreeNode\fP class.
.nrPN \n%
