.\" $Id: CBInterf.n,v 1.2 1992/12/17 15:33:01 jacomet Exp $
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH ClipboardInterf 3Go "December 1992" "Version 1.2" "Go Reference Manual"
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBClipboardInterf\fP \(em the copy/paste interface class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Ext/CBInterf.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGClipboardInterf\fP does not inherit behavior from any class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBGClipboardInterf\fP class is an interface for interclient copy/paste. The \fIGClipboardInterf\fP is the super class for other classes implementing specific interfaces for existing graphic systems (e.g. \fIGXtClipboardInterf\fP class
for the X Window System).
.sp 1
.nf
.ta .15i .25i 1.0i
typedef void (*GLoseCopyProc)(void* \fIclient_data\fP, GoInterf* \fIinterf\fP, GClipboardDataFormat \fItype\fP);
typedef void (*GGetDataProc)(void* \fIclient_data\fP, GoInterf* \fIinterf\fP, GClipboardDataFormat \fItype\fP,
				void* \fIdata\fP, ulong \fIlength\fP, GClipboardError \fIerror\fP);

class GClipboardInterf
{
	public:
	virtual GBool copy(GoInterf* \fIinterf\fP, GTimeStamp \fItime\fP, GClipboardDataFormat \fItype\fP,
			void* \fIdatas\fP, ulong \fIlength\fP, GBool \fIcopy\fP, GLoseCopyProc \fIcallback\fP,
			void* \fIclient_data\fP) = 0;
	virtual void paste(GoInterf* \fIinterf\fP, GTimeStamp \fItime\fP, GClipboardDataFormat \fItype\fP,
			GGetDataProc \fIcallback\fP, void* \fIclient_data\fP) = 0;
	virtual GBool isThereClipboard(GoInterf* \fIinterf\fP) = 0;
};
.fi
.sp 1
.SH
\fBFORMAT AND ERROR DEFINITIONS\fP
.IP
The \fItype\fP parameter of the methods specifies the format of the copied or pasted datas.
.sp 1
.nf
.ta .25i 1.0i 2.0i 3.0i
typedef enum {
    GGOSTREAM,
    GGOSTREAM_FILENAME,
    GGO,
    GSHARED_OBJECT,
    GTEXT,
    GPOSTSCRIPT,
    GPOSTSCRIPT_FILENAME,
    GNO_DATA_FORMAT
} GClipboardDataFormat;
.bp
The \fIerror\fP parameter of the GetDataProc function specifies the error type.
typedef enum {
    GCONVERSION_ERROR = 5,
    GCOMMUNICATION_ERROR,
    GFORMAT_ERROR,
    GNO_ERROR
} GClipboardError;
.fi
.RE
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
.nf
virtual GBool \fBcopy\fP(GoInterf* \fIinterf\fP, GTimeStamp \fItime\fP, GClipboardDataFormat \fItype\fP, void* \fIdatas\fP, 
		ulong \fIlength\fP, GBool \fIcopy\fP, GLoseCopyProc \fIcallback\fP, void* \fIclient_data\fP) = 0;
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method allows to copy datas. For more details see subclasses man pages.
.RE
.sp 1
.IP
.nf
virtual void \fBpaste\fP(GoInterf* \fIinterf\fP, GTimeStamp \fItime\fP, GClipboardDataFormat \fItype\fP, GGetDataProc \fIcallback\fP, 
		void* \fIclient_data\fP) = 0;
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method allows to paste datas. For more details see subclasses man pages.
.RE
.sp 1
.IP
.nf
virtual GBool \fBisThereClipboard\fP(GoInterf* \fIinterf\fP) = 0;
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method returns GTRUE if a clipboard application is running, otherwise it returns GFALSE.
.IP \fIinterf\fP .5i
.br
Specifies the GoInterface using to retrieve the Display Id.
.RE
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
\fIGClipboardInterf\fP instances cannot be directly created but \fIGClipboardInterf\fP subclass instances, this explains why there are not public constructors.
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBXtClipboardInterf(3Go)\fP.
.nrPN \n%
