.\" $Id: ConvertSh.n,v 1.1 1992/12/28 11:55:10 jacomet Exp $
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH ConvertShared 3Go "November 1992" "Version 1.2" "Go Reference Manual"
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBConvertShared\fP \(em the converter class of SharedObject.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Ext/ConvertSh.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGConvertShared\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGConverter\fP class
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBGConvertShared\fP class implements conversion functions from GoStream to Shared Objects (ShColor, ShDash, ShPattern). The \fBGConvertShared\fP is the super class for other classes implementing specific conversions in existing graphic system formats (e.g. \fIXmConvertShared\fP class for the OSF/Motif Window System). 
.sp 1
.nf
.ta .15i .25i 1.0i

class GConvertShared 
{
	public:
	GConvertShared();
	~GConvertShared();
    
	GBool gostreamFileToShColor  (const char* \fIfileName\fP, int& \fInb_color\fP,
					GShColor**& \fIcolor\fP, char**& \fIname\fP);
    
	GBool gostreamFileToShDash    (const char* \fIfileName\fP, int& \fInb_dash\fP,
					GShDash**& \fIdash\fP, char**& \fIname\fP);
    
	GBool gostreamFileToShPattern (const char* \fIfileName\fP, int& \fInb_pattern\fP,
					GShPattern**& \fIpattern\fP, char**& \fIname\fP);
};
.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
.nf
\fBGConvertShared\fP ();
.fi
.RS .8i
.IP \fIDescription\fP .5i
This is the class constructor.
.RE
.sp 1
.IP
.nf
\fB~GConvertShared\fP ();
.fi
.RS .8i
.IP \fIDescription\fP .5i
This is the class destructor.
.RE
.sp 1
.IP
.nf
GBool \fBgostreamFileToShColor\fP (const char* \fIfileName\fP, int& \fInb_color\fP, 
					GShColor**& \fIcolor\fP, char**& \fIname\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method allows to restore shared colors from a gostream. If no error occured, it returns GTRUE, otherwise it returns GFALSE.
.IP \fIfilename\fP .5i
.br
Specifies the gostream.
.IP \fInb_color\fP .5i
.br
Returns the number of shared color found in the gostream. 
.IP \fIcolor\fP .5i
.br
Returns the created array of the GShColor*. The GConvertShared class allocates memory for this array of GShColor*. So the application is responsible for freeing this array of GShColor*.
.IP \fIname\fP .5i
.br
Returns the created array of the GShColor's name. The GConvertShared class allocates memory for this array of name (char*). So the application is responsible for freeing this array of char*.
.RE
.sp 1
.IP
.nf
GBool \fBgostreamFileToShDash\fP (const char* \fIfileName\fP, int& \fInb_dash\fP, 
					GShDash**& \fIdash\fP, char**& \fIname\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method allows to restore shared dashes from a gostream. If no error occured, it returns GTRUE, otherwise it returns GFALSE.
.IP \fIfilename\fP .5i
.br
Specifies the gostream.
.IP \fInb_dash\fP .5i
.br
Returns the number of shared dash found in the gostream. 
.IP \fIdash\fP .5i
.br
Returns the created array of the GShDash*. The GConvertShared class allocates memory for this array of GShDash*. So the application is responsible for freeing this array of GShDash*. 
.IP \fIname\fP .5i
.br
Returns the created array of the GShDash's name. The GConvertShared class allocates memory for this array of name (char*). So the application is responsible for freeing this array of char*.
.RE
.sp 1
.IP
.nf
GBool \fBgostreamFileToShPattern\fP (const char* \fIfileName\fP, int& \fInb_pattern\fP, 
					GShPattern**& \fIpattern\fP, char**& \fIname\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method allows to restore shared patterns from a gostream. If no error occured, it returns GTRUE, otherwise it returns GFALSE.
.IP \fIfilename\fP .5i
.br
Specifies the gostream.
.IP \fInb_pattern\fP .5i
.br
Returns the number of shared pattern found in the gostream. 
.IP \fIpattern\fP .5i
.br
Returns the created array of the GShPattern*. The GConvertShared class allocates memory for this array of GShPattern*. So the application is responsible for freeing this array of GShPattern*. 
.IP \fIname\fP .5i
.br
Returns the created array of the GShPattern's name. The GConvertShared class allocates memory for this array of name (char*). So the application is responsible for freeing this array of char*.
.RE
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBConverter(3Go), Stream(3Go), SharedObject(3Go), ShColor(3Go), ShDash(3Go), ShPattern(3Go), Ascii(3Go), Binary(3Go)\fP.
.nrPN \n%
