.\" $Id: Converter.n,v 1.2 1992/12/17 15:33:03 jacomet Exp $
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH Converter 3Go "December 1992" "Version 1.2" "Go Reference Manual"
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBConverter\fP \(em the converter class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Ext/Converter.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGConverter\fP does not inherit behavior from any class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBGConverter\fP class implements conversion functions from Go formats (Go Id, GoStream ...) to Go formats. The \fBGConverter\fP is the super class for other classes implementing specific conversions in existing graphic system formats (e.g. \fIGXConverter\fP class for the X Window System). 

.sp 1
.nf
.ta .15i .25i 1.0i
typedef enum {
    GBINARY_STREAM,
    GASCII_STREAM
} GStreamType;

class GConverter {
	public:
	GConverter();
	~GConverter();
    
	char* goToGostream(const GSet* \fIgo\fP, ulong& \fIsize\fP, GStreamType \fItype\fP, char* \fIheader\fP=NULL) const;
	ushort goToGostreamFile(const GSet* \fIgo\fP, const char* \fIfilename\fP, GStreamType \fItype\fP, 
				char* \fIheader\fP=NULL) const;
	char* sharedToGostream(const GSet* \fIsh\fP, ulong& \fIsize\fP, GStreamType \fItype\fP, char* \fIheader\fP=NULL) const;
	ushort sharedToGostreamFile(const GSet* \fIsh\fP, const char* \fIfilename\fP, GStreamType \fItype\fP, 
				char* \fIheader\fP=NULL) const;
	ushort gostreamToGo(const char* \fIstream\fP, ulong \fIsize\fP, GSet* \fIgos\fP, 
				uint& \fInb_gos\fP, GSet* \fIshared\fP, uint& \fInb_shared\fP, char** \fIheader\fP=NULL) const;
	ushort gostreamFileToGo(const char* \fIfilename\fP, GSet* \fIgos\fP, uint& nb_\fIgos\fP,
				GSet* \fIshared\fP, uint& nb_\fIshared\fP, char** \fIheader\fP=NULL) const;
	ushort streamToFile(const char* \fIstream\fP, const ulong \fIsize\fP, const char* \fIfilename\fP) const;
	char* fileToStream(const char* \fIfilename\fP, ulong& \fIsize\fP) const;
};
.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
.nf
\fBGConverter\fP ();
.fi
.RS .8i
.IP \fIDescription\fP .5i
This is the class constructor.
.RE
.sp 1
.IP
.nf
\fB~GConverter\fP ();
.fi
.RS .8i
.IP \fIDescription\fP .5i
This is the class destructor.
.RE
.sp 1
.IP
.nf
char* \fBgoToGostream\fP (const GSet* \fIgo\fP, ulong& \fIsize\fP, GStreamType \fItype\fP, char* \fIheader\fP) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method allows to create an ascii or binary gostream containing Go trees. If no error occured, it returns the created gostream, otherwise it returns NULL.
.IP \fIgo\fP .5i
.br
Contains the Go trees.
.IP \fIsize\fP .5i
.br
Returns the created gostream size.
.IP \fItype\fP .5i
.br
Specifies the gostream type (GASCII_STREAM or GBINARY_STREAM).
.IP \fIheader\fP .5i
.br
If this string is not NULL, it will be written at the stream beginning.
.RE
.sp 1
.IP
.nf
ushort \fBgoToGostreamFile\fP (const GSet* \fIgo\fP, const char* \fIfilename\fP, GStreamType \fItype\fP, 
				char* \fIheader\fP) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method allows to create a gostream file containing Go trees. If no error occured, it returns GOK, otherwise it returns one of the following values: GIS_NOT_REG_FILE, GFILE_ACCESS_ERROR or GSAVE_STREAM_ERROR.
.IP \fIgo\fP .5i
.br
Contains the Go trees.
.IP \fIfilename\fP .5i
.br
Specifies the created gostream filename.
.IP \fItype\fP .5i
.br
Specifies the gostream type (GASCII_STREAM or GBINARY_STREAM).
.IP \fIheader\fP .5i
.br
If this string is not NULL, it will be written at the stream beginning.
.RE
.sp 1
.IP
.nf
char* \fBsharedToGostream\fP (const GSet* \fIsh\fP, ulong& \fIsize\fP, GStreamType \fItype\fP, char* \fIheader\fP) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method allows to create a gostream containing shared objects (see \fISharedObject (3Go)\fP). If no error occured, it returns the created gostream, otherwise it returns NULL.
.IP \fIsh\fP .5i
.br
Contains the shared objects.
.IP \fIsize\fP .5i
.br
Returns the created gostream size. 
.IP \fItype\fP .5i
.br
Specifies the gostream type (GASCII_STREAM or GBINARY_STREAM).
.IP \fIheader\fP .5i
.br
If this string is not NULL, it will be written at the stream beginning.
.RE
.sp 1
.IP
.nf
ushort \fBsharedToGostreamFile\fP (const GSet* \fIsh\fP, const char* \fIfilename\fP, GStreamType \fItype\fP, 
				char* \fIheader\fP) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method allows to create a gostream file containing shared objects (see \fISharedObject (3Go)\fP). If no error occured, it returns GOK, otherwise it returns one of the following values: GIS_NOT_REG_FILE, GFILE_ACCESS_ERROR or GSAVE_STREAM_ERROR.
.IP \fIsh\fP .5i
.br
Contains the shared objects.
.IP \fIfilename\fP .5i
.br
Specifies the created gostream filename.
.IP \fItype\fP .5i
.br
Specifies the gostream type (GASCII_STREAM or GBINARY_STREAM).
.IP \fIheader\fP .5i
.br
If this string is not NULL, it will be written at the stream beginning.
.RE
.sp 1
.IP
.nf
ushort \fBgostreamToGo\fP (const char* \fIstream\fP, ulong \fIsize\fP, GSet* \fIgos\fP, 
			   uint& \fInb_gos\fP, GSet* \fIshared\fP, uint& \fInb_shared\fP, char** \fIheader\fP=NULL) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method allows to create Go trees and shared objects from a gostream. In fact it creates a stream file and uses the gostreamFileToGo() method. If no error occured, it returns GOK, otherwise it returns one of the following values: GERROR, GIS_NOT_REG_FILE, GFILE_ACCESS_ERROR, GNO_FILE or GLOAD_STREAM_ERROR.
.IP \fIstream\fP .5i
.br
Specifies the gostream.
.IP \fIsize\fP .5i
.br
Specifies the gostream size.
.IP \fIgos\fP .5i
.br
Returns the created Go trees.
.IP \fInb_gos\fP .5i
.br
Returns the number of created Go trees.
.IP \fIshared\fP .5i
.br
Returns the created shared objects.
.IP \fInb_shared\fP .5i
.br
Returns the number of created shared objects.
.IP \fIheader\fP .5i
.br
If \fIheader\fP is not NULL, this method returns the header written in the \fIstream\fP. The application is responsible for freeing the storage associated with the string.
.RE
.sp 1
.IP
.nf
ushort \fBgostreamFileToGo\fP (const char* \fIfilename\fP, GSet* \fIgos\fP, 
			   uint& \fInb_gos\fP, GSet* \fIshared\fP, uint& \fInb_shared\fP, char** \fIheader\fP=NULL) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method allows to create Go trees and shared objects from a gostream file. If no error occured, it returns GOK, otherwise it returns one of the following values: GIS_NOT_REG_FILE, GFILE_ACCESS_ERROR, GNO_FILE or GLOAD_STREAM_ERROR.
.IP \fIfilename\fP .5i
.br
Specifies the gostream filename.
.IP \fIgos\fP .5i
.br
Returns the created Go trees.
.IP \fInb_gos\fP .5i
.br
Returns the number of created Go trees.
.IP \fIshared\fP .5i
.br
Returns the created shared objects.
.IP \fInb_shared\fP .5i
.br
Returns the number of created shared objects.
.IP \fIheader\fP .5i
.br
If \fIheader\fP is not NULL, this method returns the header written in the Gostream. The application is responsible for freeing the storage associated with the string.
.RE
.sp 1
.IP
.nf
ushort \fBstreamToFile\fP (const char* \fIstream\fP, const ulong \fIsize\fP, const char* \fIfilename\fP) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method allows to create a file from a character stream. If no error occured, it returns GOK, otherwise it returns one of the following values: GIS_NOT_REG_FILE, GFILE_ACCESS_ERROR or GERROR.
.IP \fIstream\fP .5i
.br
Specifies the stream.
.IP \fIsize\fP .5i
.br
Specifies the stream size.
.IP \fIfilename\fP .5i
.br
Specifies the created filename.
.RE
.sp 1
.IP
.nf
char* \fBfileToStream\fP (const char* \fIfilename\fP, ulong& \fIsize\fP) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method allows to create a character stream from a file. If no error occured, it returns the character stream, otherwise it returns NULL.
.IP \fIfilename\fP .5i
.br
Specifies the file to read.
.IP \fIsize\fP .5i
.br
Returns the character stream size.
.RE
.sp 1
.SH
\fBC BINDING\fP
.SS 
\fBHeader file\fP
.IP
#include <Go/Ext/cConverter.h>
.SS 
\fBC Functions\fP
.IP
GObjectId \fBGCreateConverter\fP ();
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GConverter::GConverter().
.RE
.sp 1
.IP
void \fBGDestroyConverter\fP (GObjectId \fIconv\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GConverter::~GConverter().
.RE
.sp 1
.IP
char* \fBGConverterGoToGostream\fP(GObjectId \fIconv\fP, const GObjectId \fIgo\fP, ulong* \fIsize\fP, 
			GStreamFile \fItype\fP, char* \fIheader\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GConverter::goToGostream().
.RE
.sp 1
.IP
GBool \fBGConverterGoToGostreamFile\fP(GObjectId \fIconv\fP, const GObjectId \fIgo\fP, 
			const char* \fIfilename\fP, GStreamFile \fItype\fP, char* \fIheader\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GConverter::goToGostreamFile().
.RE
.sp 1
.IP
char* \fBGConverterSharedToGostream\fP(GObjectId \fIconv\fP, const GObjectId \fIsh\fP, ulong* \fIsize\fP,
			GStreamFile \fItype\fP, char* \fIheader\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GConverter::sharedToGostream().
.RE
.sp 1
.IP
GBool \fBGConverterSharedToGostreamFile\fP(GObjectId \fIconv\fP, const GObjectId \fIsh\fP, 
			const char* \fIfilename\fP, GStreamFile \fItype\fP, char* \fIheader\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GConverter::sharedToGostreamFile().
.RE
.sp 1
.IP
GBool \fBGConverterGostreamToGo\fP(GObjectId \fIconv\fP, const char* \fIstream\fP, ulong \fIsize\fP, 
			GObjectId \fIgos\fP, uint* \fInb_gos\fP, GObjectId \fIshared\fP, uint* \fInb_shared\fP, 
			char** \fIheader\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GConverter::gostreamToGo().
.RE
.sp 1
.IP
GBool \fBGConverterGostreamFileToGo\fP(GObjectId \fIconv\fP, const char* \fIfilename\fP, GObjectId \fIgos\fP, 
			uint* \fInb_gos\fP, GObjectId \fIshared\fP, uint* \fInb_shared\fP, char** \fIheader\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GConverter::gostreamFileToGo().
.RE
.sp 1
.IP
GBool \fBGConverterStreamToFile\fP(GObjectId \fIconv\fP, const char* \fIstream\fP, const ulong \fIsize\fP, 
			const char* \fIfilename\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GConverter::streamToFile().
.RE
.sp 1
.IP
char* \fBGConverterFileToStream\fP(GObjectId \fIconv\fP, const char* \fIfilename\fP, ulong* \fIsize\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GConverter::fileToStream().
.RE
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBXConverter(3Go), XmConverter(3Go), PSConverter(3Go), GoStream(3Go), GoAscii(3Go), GoBinary(3Go)\fP.
.nrPN \n%
