.\" $Id: Editor.n,v 1.2 1992/12/17 15:33:05 jacomet Exp $
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH Editor 3Go "December 1992" "Version 1.2" "Go Reference Manual"
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBEditor\fP \(em the GoCompanion common class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Ext/Editor.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGEditor\fP inherits behavior from GShell class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBGEditor\fP class is a one window - one page editor. It is the superclass of all GoCompanion editors as gohyper, gowrite and so on ... All common functionnalities are implemented in this class. GEditor class manages the undo/redo, the coordinate system modifications, the file input/output, the structure modidifcations, the cut/copy/paste ...
.br
Each GEditor instance is associated to a GWindow instance. This GWindow is used to display Graphic Objects.
.br
Each GEditor instance may be associated to a specific dialog management instance. A specific dialog class implemented on OSF/Motif exists. The same class for
Windows is in process. These classes allow all GoCompanions to have the same user interface.
.sp 1
.nf
.ta .15i .25i 1.0i
class GEditor : public GShell
{
	public:
	GEditor(GWindow* \fIwindow\fP);
	~GEditor();

	void dialog(void* \fIdial\fP);
	void* dialog();

	/* undo */
	GUndoManager* undoManager();
	void useNoUndo();
	void useCSModificationUndo(GBool \fIyes\fP);
	GBool useCSModificationUndo();
	void useSelectionUndo(GBool \fIyes\fP);
	GBool useSelectionUndo();
	void useStructureUndo(GBool \fIyes\fP);
	GBool useStructureUndo();
	void useNewObjectsUndo(GBool \fIyes\fP);
	GBool useNewObjectsUndo();
	void useDestroyObjectsUndo(GBool \fIyes\fP);
	GBool useDestroyObjectsUndo();

	/* coordinate system modification */
	ushort move(Go* \fIgo\fP);
	ushort rescale(Go* \fIgo\fP);
	ushort rotate(Go* \fIgo\fP, const GPoint* \fIcenter\fP);
	ushort deform(Go* \fIgo\fP);
	ushort moveThis(Go* \fIgo\fP);
	ushort rescaleThis(Go* \fIgo\fP);
	ushort moveSelectedObjects();
	ushort rescaleSelectedObjects();
	ushort rotateSelectedObjects();
	ushort deformSelectedObjects();
    
	/* file management */
	void destroyAllObjects();
	ushort loadGostream(const char* \fIfilename\fP, Go* \fIreparent_on_this_go\fP, char** \fIheader\fP=NULL);
	ushort saveGostream(const char* \fIfilename\fP, GBool \fIall_objects\fP = GTRUE,
			GStreamType \fIformat\fP=GASCII_STREAM, char* \fIheader\fP=NULL);
	ushort savePostscript(const char* \fIfilename\fP, GBool \fIall_objects\fP = GTRUE);
	ushort print(const char* \fIlpr\fP, GBool \fIall_objects\fP = GTRUE,
			GLayoutMode \fImode\fP=GLANDSCAPE);
    
	/* selection management */
	void selectOneObject(Go* \fIgo\fP);
	void unselectOneObject(Go* \fIgo\fP);
	void selectLowerLevel();
	void selectUpperLevel();
	void selectSomeObjects();
	void unselectSomeObjects();
	void selectAll();
	void unselectAll();
	void getSelectedObjects(GSet& \fIobj\fP);
	uint nbSelectedObjects();
	
	/* structure management */
	ushort currentParentSelectedObject();
	void currentParent(Go* \fIgo\fP);
	Go* currentParent();
	ushort reparentSelectedObjects(Go* \fIon_this_go\fP);
	ushort groupSelectedObjects();
	ushort ungroupSelectedObjects();
	ushort leafSelectedObjects();
	ushort unleafSelectedObjects();
	void reparentObjects(GSet* \fIgos\fP, Go* \fIon_this_go\fP);
	ushort groupObjects(GSet* \fIgos\fP);
	void ungroupObjects(GSet* \fIgos\fP);
	void leafObjects(GSet* \fIgos\fP);
	void unleafObjects(GSet* \fIgos\fP);
	void raiseLower();
    
	/* cut/copy/paste management */
	void paste(GTimeStamp \fItime\fP, GGetDataProc \fIcallback\fP, void* \fIdata\fP);
	ushort cutSelectedObjects(GTimeStamp \fItime\fP);
	void cutObjects(GSet* \fIgos\fP, GTimeStamp \fItime\fP);
	ushort copySelectedObjects(GTimeStamp \fItime\fP);

	/* named object management */
	static GStringAssoc& namedPenList();
	static GStringAssoc& namedBrushList();
	static GStringAssoc& namedTextBrushList();
	static GStringAssoc& namedColorList();
	static GStringAssoc& namedDashList();
	static GStringAssoc& namedPatternList();
	static GStringAssoc& namedFontList();

	/* autosave management */
	void autoSaveActive(char* \fIfilename\fP, int \fIinter\fP);
	void autoSaveDisactive();
	GBool isAutoSaveActive();

	/* others */
	uint nbObjects();
	void overviewOnGo(GoRoot* \fIroot\fP, uint \fIpage\fP=0);
};
.fi
.sp 1
.SH
\fBFORMAT GOSTREAM DEFINITIONS\fP
.IP
.sp 1
.nf
.ta .25i 1.0i 2.0i 3.0i
typedef enum {
    GASCII_STREAM,
    GBINARY_STREAM,
} GStreamType;
.fi
.sp 1
.SH
\fBRETURNED VALUE DEFINITIONS\fP
.IP
Some methods return a ushort value. In this case this value is one of the following values :
.sp 1
.nf
.ta .25i 1.0i 2.0i 3.0i
GOK
GERROR
GONE_OR_MORE_OBJECT
GTWO_OR_MORE_OBJECT
GNONE_OR_ONE_OBJECT
GNO_OBJECT
GNO_PRINTER     
.fi
.RE
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
.nf
\fBGEditor\fP(GWindow* \fIwindow\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
Constructor method. A GEditor is always associated with a GWindow instance.
.IP \fIwindow\fP .5i
.br
Specifies the GWindow instance. This GWindow instance must contain a BGoUIEditor instance (See Window(3Go) man pages).
.RE
.IP
.nf
\fB~GEditor\fP();
.fi
.RS .8i
.IP \fIDescription\fP .5i
Destructor method.
.RE
.IP
.nf
void \fBdialog\fP(void* \fIdial\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
Indicates the associated dialog instance.
.IP \fIdial\fP .5i
.br
Specifies the dialog instance.
.RE
.IP
.nf
void* \fBdialog\fP();
.fi
.RS .8i
.IP \fIDescription\fP .5i
Returns the associated dialog instance.
.RE
.IP
.nf
GUndoManager* \fBundoManager\fP();
.fi
.RS .8i
.IP \fIDescription\fP .5i
Returns the used undo manager.
.RE
.IP
.nf
void \fBuseNoUndo\fP();
.fi
.RS .8i
.IP \fIDescription\fP .5i
Indicates that no undo will be saved.
.RE
.IP
.nf
void \fBuseCSModificationUndo\fP(GBool \fIyes\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
Indicates if undo may be saved when a coordinate system modification is made.
.IP \fIyes\fP .5i
.br
Specifies if undo is saved.
.RE
.IP
.nf
GBool \fBuseCSModificationUndo\fP();
.fi
.RS .8i
.IP \fIDescription\fP .5i
Returns GTRUE if undo is saved when a coordinate system modification is made, otherwise GFALSE.
.RE
.IP
.nf
void \fBuseSelectionUndo\fP(GBool \fIyes\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
Indicates if undo may be saved when object selection is modified.
.IP \fIyes\fP .5i
.br
Specifies if undo is saved.
.RE
.IP
.nf
GBool \fBuseSelectionUndo\fP();
.fi
.RS .8i
.IP \fIDescription\fP .5i
Returns GTRUE if undo is saved when object selection is modified, otherwise GFALSE.
.RE
.IP
.nf
void \fBuseStructureUndo\fP(GBool \fIyes\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
Indicates if undo may be saved when the structure of Go trees is changed.
.IP \fIyes\fP .5i
.br
Specifies if undo is saved.
.RE
.IP
.nf
GBool \fBuseStructureUndo\fP();
.fi
.RS .8i
.IP \fIDescription\fP .5i
Returns GTRUE if undo is saved when the structure of Go trees is changed, otherwise GFALSE.
.RE
.IP
.nf
void \fBuseNewObjectsUndo\fP(GBool \fIyes\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
Indicates if undo may be saved when objects are created or pasted.
.IP \fIyes\fP .5i
.br
Specifies if undo is saved.
.RE
.IP
.nf
GBool \fBuseNewObjectsUndo\fP();
.fi
.RS .8i
.IP \fIDescription\fP .5i
Returns GTRUE if undo is saved when objects are created or pasted, otherwise GFALSE.
.RE
.IP
.nf
void \fBuseDestroyUndo\fP(GBool \fIyes\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
Indicates if undo may be saved when objects are destroyed or cut.
.IP \fIyes\fP .5i
.br
Specifies if undo is saved.
.RE
.IP
.nf
GBool \fBuseDestroyUndo\fP();
.fi
.RS .8i
.IP \fIDescription\fP .5i
Returns GTRUE if undo is saved when objects are destroyed or cut, otherwise GFALSE.
.RE
.IP
.nf
ushort \fBmove\fP(Go* \fIgo\fP);
ushort \fBrescale\fP(Go* \fIgo\fP);
ushort \fBrotate\fP(Go* \fIgo\fP, const GPoint* \fIcenter\fP);
ushort \fBdeform\fP(Go* \fIgo\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods change interactively the coordinate system of the object \fIgo\fP. The modification is either a moving or a rescaling or a rotation or a deformation. A BGoUIEditor is used to interact with the user. Undo may be recorded (see functions above).
.br
The returned value is one of the following: GOK or GNO_OBJECT if \fIgo\fP is NULL.
.IP \fIgo\fP .5i
.br
Specifies the object on which the modification will be made.
.IP \fIcenter\fP .5i
.br
Specifies the rotation center.
.RE
.IP
.nf
ushort \fBmoveThis\fP(Go* \fIgo\fP);
ushort \fBrescaleThis\fP(Go* \fIgo\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods change interactively the coordinate system of the object \fIgo\fP without modifying the children coordinate system. The modification is either a moving or a rescaling. A BGoUIEditor is used to interact with the user. Undo may be recorded (see functions above).
.br
The returned value is one of the following: GOK or GNO_OBJECT if \fIgo\fP is NULL.
.IP \fIgo\fP .5i
.br
Specifies the object on which the modification will be made.
.RE
.IP
.nf
ushort \fBmoveSelectedObjects\fP();
ushort \fBrescaleSelectedObjects\fP();
ushort \fBrotateSelectedObjects\fP();
ushort \fBdeformSelectedObjects\fP();
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods change interactively the coordinate system of all selected objects. The modification is either a moving or a rescaling or a rotation or a deformation. The rotation center is choosed by the user. A BGoUIEditor is used to interact with the user. Undo may be recorded (see functions above).
.br
The returned value is one of the following: GOK or GONE_OR_MORE_OBJECT that indicates that at least one object must be selected.
.RE
.IP
.nf
void \fBdestroyAllObjects\fP();
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method destroys all Graphic Objects. Undo may be recorded (see functions above).
.RE
.IP
.nf
ushort \fBloadGostream\fP(const char* \fIfilename\fP, Go* \fIreparent_on_this_go\fP, char** \fIheader\fP=NULL);
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method loads the Gostream named \fIfilename\fP and reparents all loaded Go subtrees on the \fIreparent_on_this_go\fP object. Undo may be recorded (see functions above).
.br
The returned value is one of the following: GOK or GIS_NOT_REG_FILE, GFILE_ACCESS_ERROR, GNO_FILE or GLOAD_STREAM_ERROR.
.IP \fIfilename\fP .5i
.br
Specifies the stream name.
.IP \fIreparent_on_this_go\fP .5i
.br
Specifies the object on which restored objects will be reparented.
.IP \fIheader\fP .5i
.br
If \fIheader\fP is not NULL, this method returns the header written in the Gostream. The application is responsible for freeing the storage associated with the string.
.RE
.IP
.nf
ushort \fBsaveGostream\fP(const char* \fIfilename\fP, GBool \fIall_objects\fP=GTRUE, 
		GStreamType \fIformat\fP=GASCII_STREAM, char* \fIheader\fP=NULL);
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method saves all objects or all selected objects in the Gostream named \fIfilename\fP. The Gostream format can be either ascii or binary.
.br
The returned value is one of the following: GNO_OBJECT is there is no objects or no selected objects and GOK or GIS_NOT_REG_FILE, GFILE_ACCESS_ERROR, GSAVE_STREAM_ERROR.
.IP \fIfilename\fP .5i
.br
Specifies the stream name.
.IP \fIall_objects\fP .5i
.br
Specifies if all objects will be saved or only the selected objects.
.IP \fIformat\fP .5i
.br
Specifies the Gostream format.
.IP \fIheader\fP .5i
.br
If this string is not NULL, it will be written at the Gostream beginning.
.RE
.IP
.nf
ushort \fBsavePostscript\fP(const char* \fIfilename\fP, GBool \fIall_objects\fP=GTRUE);
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method saves all objects or all selected objects in a Postscript file named \fIfilename\fP.
.br
The returned value is one of the following: GNO_OBJECT is there is no objects or no selected objects and GOK or GIS_NOT_REG_FILE, GFILE_ACCESS_ERROR.
.IP \fIfilename\fP .5i
.br
Specifies the postscript filename.
.IP \fIall_objects\fP .5i
.br
Specifies if all objects will be saved or only the selected objects.
.RE
.IP
.nf
ushort \fBprint\fP(const char* \fIlpr\fP, GBool \fIall_objects\fP=GTRUE, GLayoutMode \fImode\fP=GLANDSCAPE);
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method prints all objects or all selected objects.
.br
The returned value is one of the following: GOK or GNO_PRINTER
.IP \fIlpr\fP .5i
.br
Specifies the print command.
.IP \fIall_objects\fP .5i
.br
Specifies if all objects will be printed or only the selected objects.
.IP \fImode\fP .5i
.br
Specifies the layout on the printer. \fImode\fP can be one of the following values: GLANDSCAPE or GPORTRAIT
.RE
.IP
.nf
void \fBselectOneObject\fP(Go* \fIgo\fP);
void \fBunselectOneObject\fP(Go* \fIgo\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to respectively select or unselect one object. Undo may be recorded (see functions above).
.IP \fIgo\fP .5i
.br
Specifies the object to (un)select.
.RE
.IP
.nf
void \fBselectLowerLevel\fP();
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method unselects all selected objects and selects their children. If there is no child, nothing is done. Undo may be recorded (see functions above).
.RE
.IP
.nf
void \fBselectUpperLevel\fP();
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method unselects all selected objects and selects their parent. If there is no parent, nothing is done. Undo may be recorded (see functions above).
.RE
.IP
.nf
void \fBselectSomeObjects\fP();
void \fBunselectSomeObjects\fP();
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods respectively select or unselect some objects. Objects are interactively choosed with a rubber band. Undo may be recorded (see functions above).
.RE
.IP
.nf
void \fBselectAll\fP();
void \fBunselectAll\fP();
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods respectively select or unselect all objects. Undo may be recorded (see functions above).
.RE
.IP
.nf
void \fBgetSelectedObjects\fP(GSet& \fIobj\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method adds all selected objects in the \fIobj\fP set. The \fIobj\fP set is not reseted by this method.
.IP \fIobj\fP .5i
.br
Specifies the GSet used to return selected objects.
.RE
.IP
.nf
uint \fBnbSelectedObjects\fP();
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method returns the number of selected objects.
.IP \fIobj\fP .5i
.br
Specifies the GSet used to return selected objects.
.RE
.IP
.nf
ushort \fBcurrentParentSelectedObject\fP();
.fi
.RS .8i
.IP \fIDescription\fP .5i
With this method, the selected object becomes the current parent. The returned value can be one of the following: GOK or GNONE_OR_ONE_OBJECT that means that at most one object must be selected.
.RE
.IP
.nf
void \fBcurrentParent\fP(Go* \fIgo\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
With this method, the \fIgo\fP object becomes the current parent.
.RE
.IP
.nf
Go* \fBcurrentParent\fP();
.fi
.RS .8i
.IP \fIDescription\fP .5i
Returns the current parent.
.RE
.IP
.nf
ushort \fBreparentSelectedObjects\fP(Go* \fIon_this_go\fP);
ushort \fBgroupSelectedObjects\fP();
ushort \fBungroupSelectedObjects\fP();
ushort \fBleafSelectedObjects\fP();
ushort \fBunleafSelectedObjects\fP();
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods respectively reparents all selected objects on the \fIon_this_go\fP object or group, ungroup, leaf, unleaf all selected objects. The returned value can be one of the following: GOK, GONE_OR_MORE_OBJECT (that means that at least one object must be selected) or GTWO_OR_MORE_OBJECT (for the groupSelectedObjects() method that means that at least two objects must be selected).
.IP \fIon_this_go\fP .5i
.br
Specifies the object on which all selected objects will be reparented.
.RE
.IP
.nf
void \fBreparentObjects\fP(GSet* \fIgos\fP, Go* \fIon_this_go\fP);
ushort \fBgroupObjects\fP(GSet* \fIgos\fP);
void \fBungroupObjects\fP(GSet* \fIgos\fP);
void \fBleafObjects\fP(GSet* \fIgos\fP);
void \fBunleafObjects\fP(GSet* \fIgos\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods reparent all objects specified in the \fIgos\fP set on the \fIon_this_go\fP object or group, ungroup, leaf, unleaf all objects specified in the \fIgos\fP set. The returned value can be one of the following: GOK or GERROR.
.IP \fIgos\fP .5i
.br
This is the GSet which contains all objects to modify.
.IP \fIon_this_go\fP .5i
.br
Specifies the object on which objects will be reparented.
.RE
.IP
.nf
void \fBraiseLower\fP();
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method allows the user to interactively change the stack order of all displayed objects.
.RE
.IP
.nf
void \fBpaste\fP(GTimeStamp \fItime\fP, GGetDataProc \fIcallback\fP, void* \fIdata\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method allows to paste Go objects in the GWindow instance associated to
the GEditor instance.
.IP \fItime\fP .5i
.br
Specifies the time indicated in the GEvent structure.
.IP \fIcallback\fP .5i
.br
Specifies the application callback that will be called when Gos have been obtained. Note that this is how the datas are communicated back to the application. Callback parameters are (see \fIClipboardInterf (3Go)\fP):
.RS 8
.IP \(em 3
a closure.
.IP \(em 3
the GoInterface that has asked the datas.
.IP \(em 3
the pasted data type.
.IP \(em 3
the pasted datas. The datas are a pointer to a \fBGSet\fP containing the Go trees.
.IP \(em 3
the size of the pasted datas which indicates how many objects are contained in the \fBGSet\fP.
.IP \(em 3
the error type, if an error occured. See \fIClipboardInterf (3Go)\fP.
.RE 2
.IP \fIdata\fP .5i
.br
Specifies the closure that will be passed to the GGetDataProc callback.
.RE
.IP
.nf
ushort \fBcutSelectedObjects\fP(GTimeStamp \fItime\fP);
ushort \fBcopySelectedObjects\fP(GTimeStamp \fItime\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to respectively cut or copy all selected objects. The returned value can be one of the following: GOK or GONE_OR_MORE_OBJECT that means that at least one object must be selected.
.IP \fItime\fP .5i
.br
Specifies the time indicated in the GEvent structure.
.RE
.IP
.nf
void \fBcutObjects\fP(GSet* \fIgos\fP, GTimeStamp \fItime\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method allows to cut objects specified in the \fIgos\fP set.
.IP \fIgos\fP .5i
.br
This is the GSet containing the objects to cut.
.IP \fItime\fP .5i
.br
Specifies the time indicated in the GEvent structure.
.RE
.IP
.nf
GStringAssoc& \fBnamedPenList\fP();
GStringAssoc& \fBnamedBrushList\fP();
GStringAssoc& \fBnamedTextBrushList\fP();
GStringAssoc& \fBnamedColorList\fP();
GStringAssoc& \fBnamedDashList\fP();
GStringAssoc& \fBnamedPatternList\fP();
GStringAssoc& \fBnamedFontList\fP();
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods return the GStringAssoc composed of all associations key-value for each type of named shared object. The key is the shared object name and the value is its Id. All named shared objects used in the application are referenced in the GStringAssocs.
.RE
.IP
.nf
void \fBautoSaveActive\fP(char* \fIfilename\fP, int \fIinter\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method sets the autosave on. All objects will be saved in a Gostream named \fIfilename\fP. The saving period is \fIinter\fP minutes.
.IP \fIfilename\fP .5i
.br
Specifies the Gostream name.
.IP \fIinter\fP .5i
.br
Specifies the saving period.
.RE
.IP
.nf
void \fBautoSaveDisactive\fP();
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method sets the autosave off.
.RE
.IP
.nf
GBool \fBisAutoSaveActive\fP();
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method returns GTRUE if the autosave is on, otherwise it returns GFALSE.
.RE
.IP
.nf
int \fBnbObjects\fP();
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method returns the number of displayed objects.
.RE
.IP
.nf
void \fBoverviewOnGo\fP(GoRoot* \fIroot\fP, uint \fIpage\fP=0);
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method is called by the Help used by the GoCompanions. It gives informations on the displayed objects by modifying the \fIroot\fP children.
.RE
.SH
\fBSEE ALSO\fP
.IP
\fB Shell(3Go) Window(3Go)\fP
.nrPN \n%
