.\" $Id: Help.n,v 1.3 1992/12/21 16:52:54 jacomet Exp $
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH Help 3Go "December 1992" "Version 1.2" "Go Reference Manual"
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBHelp\fP \(em the class used to implement application help.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Ext/Help.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGHelp\fP inherits behavior from;
.RS 10
.IP \(em 3
GMultiPageEditor class.
.IP \(em 3
GEditor class.
.IP \(em 3
GShell class.
.RE
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBGHelp\fP class is a one window - several pages editor. This class allows to load help files. Four types of help files are defined: the contents files, the index files, the overview files and the other files. The contents, index and overview files must be respectively named "contents", "index" and "overview". The other filenames are free. At the initialization, all contents and index files are loaded. 
.sp
Each help file is defined by a chapter number, a subchapter number and a page number. Some informations must be set by associations (key <--> value) in the file named "contents.0". They are the following:
.br
\fBhelpNbChapter\fP indicates the number of chapters.
.br
\fBhelpChapterFilenames\fP indicates the help filenames. The format is "nameOfChapter0\\nameOfChapter1\\...\\nameOfChapterX".
.br
\fBhelpNbSubchapter\fP indicates the subchapter number of each chapter. The format is "subchapterNumberOfChapter0\\subchapterNumberOfChapter1\\...\\subchapterNumberOfChapterX".
.br
\fBhelpChapter0NbFiles\fP, \fBhelpChapter1NbFiles\fP, ..., \fBhelpChapterXNbFiles\fP indicate the number of pages for each chapter and subchapter. For example, if the chapter 0 has no subchapter and three pages, the association will be : "helpChapter0NbFiles <--> 3". If the chapter 1 has two subchapters and subchapters respectively have two and one pages, the association will be "helpChapter1NbFiles <--> 2\\1".
.br
The help filenames have the following syntax: 
.br
filename.x.y if chapter has subchapter. 'x' if the subchapter number and 'y' the page number.
.br
or
.br
filename.x if chapter has no subchapter. 'x' if the page number.
.sp
This class depends on the GXmHelp class. The GXmHelp class defines the Motif dialog used to display help files.
.sp 1
.nf
.ta .15i .25i 1.0i
typedef struct infoFileStruct {
	unsigned short chapter;
	unsigned short subchapter;
	unsigned short page;
} GInfoFileStruct;

class GHelp : public GMultiPageEditor
{
	public:
	GHelp(GWindow* \fIwindow\fP, char* \fIsubpath\fP, GXmHelp* \fIdialog\fP);
	~GHelp();
	ushort loadHelpFile(ushort \fIch\fP, ushort \fIsub\fP, ushort \fIpage\fP);
	GInfoFileStruct* loadPreviousHelpFile(ushort \fIch\fP, ushort \fIsub\fP, ushort \fIpage\fP);
	GInfoFileStruct* loadNextHelpFile(ushort \fIch\fP, ushort \fIsub\fP, ushort \fIpage\fP);
	ushort searchPattern(char* \fItxt\fP, GBool \fIfirst\fP);
};

extern void LoadHelpFile(Go* \fIgo\fP, const GPoint* \fIpoint\fP);
.fi
.sp 1
.SH
\fBRETURNED VALUE DEFINITIONS\fP
.IP
Some methods return a ushort value. In this case this value is one of the following values :
.sp 1
.nf
.ta .25i 1.0i 2.0i 3.0i
GERROR
GOK
GNO_INDICATED_PAGE
.fi
.RE
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
.nf
\fBGHelp\fP(GWindow* \fIwindow\fP, char* \fIsubpath\fP, GXmHelp* \fIdialog\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
Constructor method. A GHelp is always associated with a GWindow instance.
.IP \fIwindow\fP .5i
.br
Specifies the GWindow instance. This GWindow instance must contain either no GoUI instance or a BGoUIEditor instance.
.IP \fIsub_path\fP .5i
.br
Specifies the path used to find the help files.
.IP \fIdialog\fP .5i
.br
Specifies the GXmHelp instance.
.RE
.IP
.nf
\fB~GHelp\fP();
.fi
.RS .8i
.IP \fIDescription\fP .5i
Destructor method.
.RE
.IP
.nf
ushort \fBloadHelpFile\fP(ushort \fIch\fP, ushort \fIsub\fP, ushort \fIpage\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
Loads and maps the specified help file. 
.br
The returned value may be GOK, GNO_INDICATED_PAGE or GERROR.
.IP \fIch\fP .5i
.br
Specifies chapter number.
.IP \fIsub\fP .5i
.br
Specifies subchapter number.
.IP \fIpage\fP .5i
.br
Specifies page number.
.RE
.IP
.nf
GInfoFileStruct* \fBloadPreviousHelpFile\fP(ushort \fIch\fP, ushort \fIsub\fP, ushort \fIpage\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
Loads and maps the previous file of the specified help file.
.br
If an error occured NULL is returned, otherwise the loaded file characteristics are returned.
.IP \fIch\fP .5i
.br
Specifies chapter number.
.IP \fIsub\fP .5i
.br
Specifies subchapter number.
.IP \fIpage\fP .5i
.br
Specifies page number.
.RE
.IP
.nf
GInfoFileStruct* \fBloadNextHelpFile\fP(ushort \fIch\fP, ushort \fIsub\fP, ushort \fIpage\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
Loads and maps the next file of the specified help file.
.br
If an error occured NULL is returned, otherwise the loaded file characteristics are returned.
.IP \fIch\fP .5i
.br
Specifies chapter number.
.IP \fIsub\fP .5i
.br
Specifies subchapter number.
.IP \fIpage\fP .5i
.br
Specifies page number.
.RE
.IP
.nf
ushort \fBsearchPattern\fP(char* \fItxt\fP, GBool \fIfirst\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
If the loaded help file contains a GoTextual object, the method can be used to search a pattern. If the pattern matches a part of the GoTextual object, GOK is
returned, otherwise GERROR is returned. 
.IP \fItxt\fP .5i
.br
Specifies the pattern to search.
.IP \fIfirst\fP .5i
.br
If \fIfirst\fP is GTRUE the research begins from the cursor position in the GoTextual object. Otherwise the research begins from the cursor position in the GoTextual object plus the pattern length.
.RE
.IP
.nf
void \fBLoadHelpFile\fP(Go* \fIgo\fP, const GPoint* \fIpoint\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
This function can be used in a goui file. To use it, write in the goui file the following string: "Go.sensorName  event	 LoadHelpFile(go, pos)". The sensor named "sensorName" must be a GoHyperSensor instance (or a subclass of GoHyperSensor).
.br
This function gets the sensor in which the mouse pointer is. It reads some associations on this sensor and loads the help file defined by the associations.
.br
Only one association is needed. This is "chapter <--> chapter number". Two other associations may be specified if needed: "subchapter <--> subchapter number" and "page <--> page number". Default values for these associations are 0.
.IP \fIgo\fP .5i
.br
Specifies the Graphic Object in which the mouse pointer is.
.IP \fIposition\fP .5i
.br
Specifies the pointer mouse location.
.RE
.SH
\fBSEE ALSO\fP
.IP
\fB MultiPageEditor(3Go) Editor(3Go) Shell(3Go)\fP
.nrPN \n%
