.\" $Id: GEvent.n,v 1.2 1992/12/28 13:07:59 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH Event 3Go "December 1992" "Version 1.2" "Go Reference Manual"
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBEvent\fP \(em the Go event object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Event.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGEvent\fP does not inherit behavior from any super class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBGEvent\fP object is the object passed by a \fBGoInterf\fP instance
when calling the \fIeventPostcond\fP procedure (see \fIGoInterf(3Go)\fP) but
events are not necessary generated by a \fIGoInterf\fP instance.
.IP
The \fBGEvent\fP class is used as the super class of a collection of
subclasses depending on the event type (see \fIGFunctionKeyEvent\fP,
\fIGCharEvent\fP, \fIGStringEvent\fP, \fIGButtonEvent\fP,
\fIGButtonPressEvent\fP, \fIGButtonReleaseEvent\fP, \fIGDoubleClicEvent\fP,
\fIGTripleClicEvent\fP, \fIGExposeEvent\fP, \fIGMotionEvent\fP,
\fIGEnterSensorEvent\fP, \fIGLeaveSensorEvent\fP). These two last events
cannot be generated by a \fIGoInterf\fP instance.
.sp 1 
.br
.nf
.ta .15i .25i 1.i
class GEvent {
	public:
		GEventType type() const;
		GoInterf* origin() const;

		virtual char character() const;
		virtual const char* string() const;
		virtual GButton button() const;
		virtual GFunctionKey functionKey() const;
		virtual ulong modifiers() const;
		virtual GPoint position() const;
		virtual const GRegion& region() const;
		virtual const GoSensor* sensor() const;
};
.fi
.sp 1
.SH
\fBPUBLIC FUNCTIONS\fP
.sp 1
.IP
GEventType \fBtype\fP () const;
.RS .8i
.IP \fIDescription:\fP .5i
This method returns the event type. Possible values are:
.nf
.ta .15i .25i 1.i
	GBUTTON_PRESS_EVENT,
	GBUTTON_RELEASE_EVENT,
	GDOUBLE_CLICK_EVENT,
	GTRIPLE_CLICK_EVENT,
	GCHAR_EVENT,
	GSTRING_EVENT,
	GFUNCTION_KEY_EVENT,
	GEXPOSE_EVENT,
	GMOTION_EVENT,
	GENTER_SENSOR_EVENT,
	GLEAVE_SENSOR_EVENT.
.fi
.sp 1
Associated with the event types, event masks are defined. These masks are
used to modify the input mask of a \fIGoInterf\fP instance.
The following masks are used:
.sp 1
.nf
.ta .15i 2.5i
	#define  GBUTTON_PRESS_MASK_INDEX 	0
	#define  GBUTTON_RELEASE_MASK_INDEX 	1
	#define  GDOUBLE_CLICK_MASK_INDEX 	2
	#define  GTRIPLE_CLICK_MASK_INDEX 	3
	#define  GCHAR_MASK_INDEX 	4
	#define  GSTRING_MASK_INDEX 	5
	#define  GFUNCTION_KEY_MASK_INDEX 	6
	#define  GEXPOSE_MASK_INDEX 	7
	#define  GMOTION_MASK_INDEX 	8
	#define  GENTER_SENSOR_MASK_INDEX 	9
	#define  GLEAVE_SENSOR_MASK_INDEX 	10
	#define  GCOMPRESS_MOTION_MASK_INDEX 	11
	/** the last one gives the number of mask **/
	#define  GN_EVENT_MASK	12

	typedef unsigned int GEventMask;

	#define GBUTTON_PRESS_MASK 	(1 << GBUTTON_PRESS_MASK_INDEX)
	#define GBUTTON_RELEASE_MASK 	(1 << GBUTTON_RELEASE_MASK_INDEX)
	#define GDOUBLE_CLICK_MASK 	(1 << GDOUBLE_CLICK_MASK_INDEX)
	#define GTRIPLE_CLICK_MASK 	(1 << GTRIPLE_CLICK_MASK_INDEX)
	#define GCHAR_MASK 	(1 << GCHAR_MASK_INDEX)
	#define GSTRING_MASK 	(1 << GSTRING_MASK_INDEX)
	#define GFUNCTION_KEY_MASK 	(1 << GFUNCTION_KEY_MASK_INDEX)
	#define GEXPOSE_MASK 	(1 << GEXPOSE_MASK_INDEX)
	#define GMOTION_MASK 	(1 << GMOTION_MASK_INDEX)
	#define GENTER_SENSOR_MASK 	(1 << GENTER_SENSOR_MASK_INDEX)
	#define GLEAVE_SENSOR_MASK 	(1 << GLEAVE_SENSOR_MASK_INDEX)
	#define GCOMPRESS_MOTION_MASK 	(1 << GCOMPRESS_MOTION_MASK_INDEX)
	#define GALL_MASK 	(~0)
.fi
.RE
.sp 1
.IP
GoInterf* \fBorigin\fP () const;
.RS .8i
.IP \fIDescription:\fP .5i
This method returns the \fIGoInterf\fP instance which has generated the event.
.RE
.sp 1
.IP
char \fBcharacter\fP () const;
.RS .8i
.IP \fIDescription:\fP .5i
This method returns the character of the event. This method is only valid
for \fIGCharEvent\fP class.
.RE
.sp 1
.IP
const char* \fBstring\fP () const;
.RS .8i
.IP \fIDescription:\fP .5i
This method returns a pointer to a string containing in the event. This method
is only valid for \fIGCharEvent\fP and \fIGStringEvent\fP.
.RE
.sp 1
.IP
GButton \fBbutton\fP () const;
.RS .8i
.IP \fIDescription:\fP .5i
This method returns the button which is responsible of the event. The method
is only valid for \fIGButtonPress\fP, \fIGButtonRelease\fP,
\fIGDoubleClic\fP and \fIGTripleClic\fP. Possible values are:
.nf
.ta .15i .25i 1.i
	GBUTTON1,
	GBUTTON2,
	GBUTTON3,
	GBUTTON4,
	GBUTTON5,
	GBUTTON6,
	GBUTTON7,
	GBUTTON8.
.fi
.RE
.sp 1
.IP
GFunctionKey \fBfunctionKey\fP () const;
.RS .8i
.IP \fIDescription:\fP .5i
This method returns the function key responsible of the event. This method
is only valid for \fIGFunctionKeyEvent\fP class.
.nf
.ta .15i .25i 1.i
	GKEY_LEFT,
	GKEY_RIGHT,
	GKEY_UP,
	GKEY_DOWN,
	GKEY_INSERT,
	GKEY_DELETE,
	GKEY_BACKSPACE,
	GKEY_HOME,
	GKEY_END,
	GKEY_PAGE_UP,
	GKEY_PAGE_DOWN,
	GKEY_TAB,
	GKEY_BACKTAB,
	GKEY_HELP,
	GKEY_F1,
	GKEY_F2,
	GKEY_F3,
	GKEY_F4,
	GKEY_F5,
	GKEY_F6,
	GKEY_F7,
	GKEY_F8,
	GKEY_F9,
	GKEY_F10,
	GKEY_F11,
	GKEY_F12,
	GKEY_ESC.
.fi
.RE
.sp 1
.IP
ulong \fBmodifiers\fP () const;
.RS .8i
.IP \fIDescription:\fP .5i
This method returns the modifiers associated with the event. This method is
only valid for \fIGButtonPressEvent\fP, \fIGButtonReleaseEvent\fP,
\fIGDoubleClicEvent\fP, \fIGTripleClicEvent\fP, \fIGCharEvent\fP,
\fIGStringEvent\fP, \fIGFunctionKeyEvent\fP classes. Possible values
are:
.nf
.ta .15i .25i 1.i
	GNONE 	= 0,
	GSHIFT 	= (1 << 0),
	GCONTROL 	= (1 << 2),
	GALTERNATE 	= (1 << 3)
.fi
.RE
.sp 1
.IP
GPoint \fBposition\fP () const;
.RS .8i
.IP \fIDescription:\fP .5i
This method returns in the pointer position (in the absolute coordinate
system) when the event occured. This method is always valid.
.RE
.sp 1
.IP
const GRegion& \fBregion\fP () const;
.RS .8i
.IP \fIDescription:\fP .5i
This method is only valid for the \fIGExposeEvent\fP class and returns
the region which has to be exposed.
.RE
.sp 1
.IP
const GoSensor* sensor() const;
.RS .8i
.IP \fIDescription:\fP .5i
This method is only valid for the \fIGEnterSensorEvent\fP and
\fIGLeaveSensorEvent\fP classes. It returns a pointer to the concerned
\fIGoSensor\fP instance.
.RE
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
The \fIGEvent\fP class is an abstract class, thus it is not directly used,
instead the application developper has to use subclasses.
.sp 1
.SH
\fBC BINDING\fP
.IP
\fITo be defined.\fP
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBGoInterf\fP, \fBFunctionKeyEvent\fP,
\fBStringEvent\fP, \fBButtonEvent\fP, \fBButtonPressEvent\fP,
\fBButtonReleaseEvent\fP, \fBExposeEvent\fP, \fBMotionEvent\fP,
\fBRegion\fP and \fBGoSensor\fP classes.
.nrPN \n%
