.\" $Id: Go.n,v 1.2 1993/01/04 17:51:53 jojic Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH Go 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGo\fP \(em the graphic object class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Go.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGo\fP does not inherit behavior from any class.
.sp 1
.SH
\fBDESCRIPTION\fP
.IP
The \fBGo\fP class is the common superclass for all graphic objects. The
\fBGo\fP class defines all the basic methods available on the graphic object
instances.
.IP
\fIGo's\fP are organized in a tree, methods exist to manage the place of a
\fIGo\fP instance in this tree (see \fIPUBLIC TREE MANAGEMENT METHODS\fP section).
The place in the tree determines the stacking order of the \fIGo\fP: a \fIGo\fP
is on top of its parent and under its next brother.
.IP
To be displayed on an output device, \fIGo's\fP have to be reparented on an instance
of \fIGoRoot\fP (see \fIGoRoot(3Go)\fP) which has to be linked to an instance of
a subclass of \fIGoInterf\fP (see \fIGoInterf(3Go)\fP). Methods allows to control
this attachment. Other methods allows to map/unmap a \fIGo\fP (sub)tree on the
\fIGoInterf\fP.
.IP
A \fIGo\fP is mostly defined by its coordinate system. The coordinate system
is defined by its origin point \fI(O)\fP and two vectors \fI(I, J)\fP (see \fICoodSys(3Go)\fP).
The coordinate system may be expressed in the absolute coordinate
system  (in millimeters with along the origin at the upper left corner) or
relatively to its parent coordinate system.
.IP
\fIGo's\fP (and the \fIGo\fP tree) may exported/imported to/from the external
world independently of the format, the methods \fIsave()\fP and \fIrestore()\fP
are provided to perform this function.
.IP
Precondition and postcondition callbacks may be set for most of the available
operations. Preconditions allow to accept, to refuse and in some case to force
an operation (i.e. coordinate system modification), they are called just before
the action processing. Postconditions are called just after the action processing.
It is possible, instead having conditions at the instance level, to have
conditions at the class level by using the class objects
(see \fIGoMetaclass(3Go)\fP).
In that case, preconditions on instance creation/restoring and postconditions
on instance deletion are possible: the \fIcreate()\fP, \fIrestore()\fP and
\fIdestroy()\fP methods of the object have to be used
instead of \fInew\fP and \fIdelete\fP.
.IP
\fIImportant\fP: instance pre/postconditions are called
\fIbefore\fP class pre/postconditions.
.IP
\fIWarning:\fP Methods which name starts with an upper case letter require some
\fIGo\fP expertise, they should be ignored by \fIbeginners\fP and they may
be used carefully by \fIGo experts\fP.
.bp
.nf
.ta .15i .25i 1.0i
class Go {
	public:
		/*
		 * \fBgo creation and destruction:\fP
		 */

		Go* dup();
		static Go* create(const char* \fIgo_class_name\fP);

		GBool destroy();


		// preconditions:

		void dupPrecond(GBool \fIproc\fP(void* closure, const Go*),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void destroyPrecond(GBool \fIproc\fP(void* closure, const Go*),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);

		// postconditions:

		void dupPostcond(void \fIproc\fP(void* closure, Go*),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void destroyPostcond(void \fIproc\fP(void* closure, const Go*),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);



		/*
		 * \fBtree structure:\fP
		 */

		// get:

		Go* parent() const;
		Go* previous() const;
		Go* next() const;
		Go* child() const;
		Go* lastChild() const;
		int childIndex(const Go*) const;

		GBool leaf() const;
		Go* goAt(const GPoint& \fIabs_point\fP, GNumber \fImaxDistance\fP) const;
		GoRoot* root() const;
		GBool isAncestor(const Go* \fIgo\fP) const;
		GBool isUpper (const Go* \fIgo\fP) const;
		GBool isLower (const Go* \fIgo\fP) const;

		friend Go* commonAncestor(const Go* \fIgo1\fP, const Go* \fIgo2\fP);
		GCrossType crossType() const;

		Go* Previous(int \fIthis_index\fP = GUNKNOWN_INDEX) const;
		Go* Next(int \fIthis_index\fP = GUNKNOWN_INDEX) const;
		Go* Child(int \fIindex\fP = 0) const;
		Go* LastChild() const;
		Go* GoAt(const GPoint&, GNumber \fImaxDistance\fP) const;
		Go* Root() const;

		void* forEveryGo(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP), void* \fIclosure\fP);
		void* forEveryMappedGo(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP), void* \fIclosure\fP);
		void* forEverySelectedGo(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP), void* \fIclosure\fP);
		void* forEverySelectedSubtree(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP), void* \fIclosure\fP);
		void* forEveryGoContainingPoint (void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP),
			void* \fIclosure\fP, const GPoint& \fIabspoint\fP, GNumber \fImax_dist\fP = 0);
		void* forEverySelectedGoContainingPoint (void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP),
			void* \fIclosure\fP, const GPoint& \fIabspoint\fP, GNumber \fImax_dist\fP = 0);
		void* forEverySelectedSubtreeContainingPoint (void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP),
			void* \fIclosure\fP, const GPoint& \fIabspoint\fP, GNumber \fImax_dist\fP = 0);

		void stopRecursion(void* \fIreturn_value\fP);

		void* ForEveryGo(void \fIproc\fP(void*, Go*), void* \fIclosure\fP);
		void* ForEveryMappedGo(void \fIproc\fP(void*, Go*), void* \fIclosure\fP);
		void* ForEverySelectedGo(void \fIproc\fP(void*, Go*), void* \fIclosure\fP);
		void* ForEverySelectedSubtree(void \fIproc\fP(void*, Go*), void* \fIclosure\fP);
		void* ForEverySensor(void \fIproc\fP(void*, Sensor*), void* \fIclosure\fP);
		void* ForEveryGoContainingPoint(void \fIproc\fP(void*, Go*),
			void*, const GPoint&, GNumber \fImaxDistance\fP);

		// set:

		GBool reparent(Go* \fInew_parent\fP, Go* \fInext_brother\fP = NULL);
		GBool parentRelativeReparent(Go* \fInew_parent\fP, Go* \fInext_brother\fP = NULL);
		GBool shift(Go* \fInext_brother\fP);
		GBool raise();
		GBool lower();
		GBool leaf(GBool);
		GBool crossType(GCrossType \fInew_cross_type\fP);


		// preconditions:

		void shiftPrecond(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP, const Go* (*\fInext_brother\fP)),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void removeChildPrecond(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP, const Go* \fIchild_to_remove\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void addChildPrecond(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP,
			const Go* \fIchild_to_add\fP, const Go* (*\fInext_brother\fP)),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void reparentPrecond(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP,
			const Go* \fInew_parent\fP, const Go* (*\fInext_brother\fP)),
			void* closure, GAddOrRemove \fIadd\fP = GADD);
		void rootPrecond(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP, const GoRoot* \fIgoroot\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void interfPrecond(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP, const GoInterf* \fIgointerf\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void crossTypePrecond(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP, GCrossType* \fIcross_type\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);

		// postconditions:

		void shiftPostcond(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, Go* \fIold_next_brother\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void removeChildPostcond(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, Go* \fIrem_child\fP,
			Go* \fIold_next_brother\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void addChildPostcond(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, Go* \fIadded_child\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void reparentPostcond(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, Go* \fIold_parent\fP, Go* \fIold_next_brother\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void rootPostcond(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, Go* \fIold_root\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void interfPostcond(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, GoInterf* \fIold_interf\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void crossTypePostcond(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, GCrossType \fIold_cross_type\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);


		/*
		 * \fBcoordinate systems:\fP
		 */

		// get:

		GCoordSys coordsys(const Go* \fIrelative_to\fP = NULL) const;
		GPoint origin(const Go* \fIrelative_to\fP = NULL) const;
		GMatrix matrix(const Go* \fIrelative_to\fP = NULL) const;
		GCoordSys parentCoordsys() const;

		GCoordSys Abscs(const GCoordSys& \fIparabs\fP = *((GCoordSys*)NULL)) const;
		GCoordSys Relcs(const GCoordSys& \fIparabs\fP = *((GCoordSys*)NULL)) const;

		// set:

		GBool setCoordsys(const GCoordSys& \fIcs\fP, Go* \fIrelative_to\fP = NULL);
		GBool move(const GPoint& \fIo\fP, Go* \fIrelative_to\fP = NULL);
		GBool setMatrix(const GMatrix& \fImatrix\fP, Go* \fIrelative_to\fP = NULL);
		GBool rescale(GNumber xsize, GNumber ysize, Go* \fIrelto\fP = NULL);
		GBool rotate(GNumber angle, const GPoint& center, Go* \fIrelto\fP = NULL);

		GBool SetThisAbscs(const GCoordSys& \fIabs_cs\fP);

		// preconditions:

		void relcsPrecond(GBool \fIproc\fP(void* \fIclosure\fP, const Go*\fIgo\fP, GCoordSys* \fInew_relcs\fP,
			const GCoordSys* \fIoldparabs\fP, const GCoordSys* \fInewparabs\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void abscsPrecond(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP, GCoordSys* \fInew_abscs\fP,
			const GCoordSys* \fIoldparabs\fP, const GCoordSys* \fInewparabs\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);

		// postconditions:

		void relcsPostcond(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, const GCoordSys* \fIparabs\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void abscsPostcond(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, const GCoordSys* \fIparabs\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);


		/*
		 * \fBabout drawings:\fP
		 */

		// get:

		GBool mapped() const;
		GBool mappable() const;
		GBool selected() const;

		GBool contains(const GPoint& \fIabsolute_point\fP, GNumber \fImax_distance\fP = 0) const;
		GBool subtreeContains(const GPoint& \fIabsolute_point\fP, GNumber \fImax_distance\fP = 0) const;

		GRegion myClip() const;
		GRegion myOpaqueClip() const;
		GRegion clip() const;
		GRegion opaqueClip() const;
		void addMyClip(GRegion&) const;
		void addMyOpaqueClip(GRegion&) const;
		void addClip(GRegion&) const;

		void wiredDraw (const GCoordSys& \fIcs\fP, const GPen&,
				GQuality = GMAX_QUALITY) const;

		// set:

		GBool map();
		GBool unmap();
		GBool select();
		GBool unselect();


		// preconditions:

		void mapPrecond(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void selectPrecond(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);

		// postconditions:

		void mapPostcond(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void selectPostcond(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void myClipPostcond(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void clipPostcond(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);

		/*
		 * \fBsaving:\fP
		 */


		// preconditions and postconditions:

		void savePrecond(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP, const GoStream* \fIstream\fP),
			void* \fIclosure\fP, GAddOrRemove \fIgo\fP = GADD);
		void savePostcond(void proc(void* \fIclosure\fP, Go* \fIstream\fP, GoStream* \fIstream\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);

		/*
		 * \fBmiscellianeous:\fP
		 */

		static GoMetaclass* metaclass();
		static GoMetaclass* metaclass(const char* \fIclassname\fP);
		GoMetaclass* getMetaclass() const;
		void check() const;
		GAssoc* assoc() const;
		GoInterf* interf() const;
		GBool isSensor() const;
		GBool isToBeDestroyed() const;
};
.fi
.sp 1
.SH
\fBPUBLIC CREATION AND DESTRUCTION METHODS\fP
.IP
Go* \fBdup\fP();
.RS .8i
.IP \fIDescription\fP .5i
This method returns a \fIGo\fP which is a copy of \fIthis\fP and the \fIGo\fP (sub)tree which has \fIthis\fP
as root. Neither pre/postconditions nor associations are duplicated, but pre/postconditions at the class
level are obviously kept. \fIGoSensors\fP (see \fISensor(3Go)\fP) are not duplicated.
.RE
.sp 1
.IP
.nf
void \fBdupPrecond\fP(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBdupPostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIsource\fP, Go* \fIcopy\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add/remove pre/postcondition callback routines in order to be notified
when a duplication of a \fIGo\fP (\fIthis\fP)
is requested/done. Preconditions allow to refuse the copy of the \fIGo\fP.
.IP \fIproc\fP .5i
.br
Specifies the pre/postcondition callback function to be called when a
\fIGo\fP is duplicated.
Preconditions take two paramaters: the closure (private application data) anf the \fIGo\fP itself.
Postconditions take three parameters: the closure, the \fIGo\fP (\fIsource\fP) and the new copy.
.IP \fIclosure\fP .5i
.br
Specifies the private application data which is passed to the pre/post
condition callback \fIproc\fP as the first parameter.
.IP \fIadd\fP .5i
.br
Specifies if the pre/post condition callback \fIproc\fP has to be added
(default) or removed (GREMOVE).
.RE
.IP
static Go* \fBcreate\fP(const char* \fIgo_class_name\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to create a \fIGo\fP instance from a Go class name.
It takes in account pre and postconditions.
.IP
This method calls the create method of the GoMetaclass corresponding
to \fIgo_class_name\fP.
.sp 1
This method will return NULL if some precondition refuses the creation
(you can use metaclasses to set create preconditions).
.sp 1
This method will fail (and a error message will be printed) and return NULL
if it is used for a class which cannot be instancied
(a class defined to be subclassed).
For example: \fIGo::create("Go")\fP will fail because the \fIGo\fP class has
no public constructor (see \fIGo(3Go)\fP), \fIGo::create("GoPolyline")\fP
will succeed.
.sp 1
Of course, this is a convenient method to create a graphic object from a name,
but you can use directly: \fIGoPolyline::create()\fP.
.RE
.sp 1
.IP
.nf
GBool \fBdestroy\fP();
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method allows to destroy \fIthis\fP and the \fIGo\fP (sub)tree which has
\fIthis\fP as root. The \fIdestroy()\fP method manages pre/postconditions.
.RE
.sp 1
.IP
.nf
void \fBdestroyPrecond\fP(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBdestroyPostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add/remove pre/postcondition on destroying \fIthis\fP.
If all precondition callbacks return GTRUE, \fIthis\fP will be destroyed. Just before the destruction,
\fIthis\fP is removed from the \fIGo\fP tree (reparented to NULL) and the postcondition callbacks,
if any, are called. Then the \fIthis\fP destructor is called.
.IP \fIproc\fP .5i
.br
Specifies the callback procedure which is called as either precondtion (boolean function) or
postcondition (void function). It takes two parameters which are the closure (application private
data) and the \fIGo\fP to be destroyed. It cannot be modified (const).
.IP \fIclosure\fP .5i
.br
Specifies the private application data which is passed to the pre/post condition callback \fIproc\fP
as the first parameter.
.IP \fIadd\fP .5i
.br
Specifies if the pre/post condition callback \fIproc\fP has to added (default) or removed (GREMOVE).
.RE
.sp 2
.SH
\fBPUBLIC TREE MANAGEMENT METHODS\fP
.IP
.nf
Go* \fBparent\fP() const;
Go* \fBprevious\fP() const;
Go* \fBnext\fP() const;
Go* \fBchild\fP() const;
Go* \fBlastChild\fP() const;
int \fBchildIndex\fP(const Go*) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods return the parent, previous brother, next brother
first child and the last child of the \fIGo\fP or \fINULL\fP.
.br
\fIthis->childIndex(go)\fP returns the child index of \fIgo\fP
(which must be a child of \fIthis\fP).
.RE
.sp 1
.IP
GBool \fBleaf\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns GTRUE if this go has a cross type: \fIGCROSS_AS_LEAF\fP.
That means, even if this \fIgo\fP has children, methods dealing with children
(as child, forEveryGo, ...) will considerate that it has no child.
.br
This is valid for lower case methods. With upper case methods you can
always access the full go tree (Child, ForEveryGo, ...).
.RE
.sp 1
.IP
Go* \fBgoAt\fP(const GPoint& \fIabs_position\fP, GNumber \fImax_distance\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fIthis->goAt(abs_position, max_distance)\fP returns the \fIGo\fP (which must
be a (sub)child of \fIthis\fP) at the given position (with an uncertainty of
\fImax_distance\fP).
.RE
.sp 1
.IP
GoRoot* \fBroot\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the \fIGoRoot\fP (see \fIGoRoot(3Go)\fP) instance of the graphic object tree or NULL.
.RE
.sp 1
.IP
GBool \fBisAncestor\fP(const Go* \fIgo\fP) const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns GTRUE if the \fIGo\fP is an ancestor of
\fIgo\fP or \fIgo\fP itself, else it returns GFLASE.
.IP \fIgo\fP .5i
.br
The \fIGo\fP we want to check for ancestors. It may be \fINULL\fP, in that case
the method returns \fIGFLASE\fP.
.RE
.sp 1
.IP
.nf
GBool \fBisUpper\fP (const Go* \fIgo\fP) const;
GBool \fBisLower\fP (const Go* \fIgo\fP) const;
.fi
.RS .8i
.IP \fIDescription\fP
These two methods returns GTRUE if \fIgo\fP is upper (resp. lower) than \fIthis\fP
in the drawing stack order. This does not means \fIgo\fP overlaps (resp. is overlapped)
by \fIthis\fP; \fIgo\fP will be drawn after (resp. before) \fIthis\fP.
.IP \fIgo\fP .5i
.br
The \fIGo\fP concerned by the tests.
.RE
.sp 1
.IP
friend Go* \fBcommonAncestor\fP(const Go* \fIgo1\fP, const Go* \fIgo2\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method returns the first common ancestor of \fIgo1\fP and \fIgo2\fP in the
\fIGo\fP tree. It returns NULL if \fIgo1\fP and \fIgo2\fP have no common ancestor.
.IP "\fIgo1, go2\fP" .5i
Specify the two \fIGo\fPs.
.RE
.sp 1
.IP
GCrossType \fBcrossType\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the \fIGCrossType\fP of the \fIGo\fP. The \fIGCrossType\fP determines
the external visibility of the \fIGo\fP in the \fIGo\fP tree. Possible values
are:
.br
.nf
.ta .25i 1.5i 2.5i
	GCROSS_AS_NODE		\fIRegular Go: default value\fP
	GCROSS_AS_LEAF		\fIThe children of the Go cannot be accessed by
		regular tree navigation methods\fP
	GCROSS_AS_NOTHING	\fIThis Go cannot be accessed by regular tree
		navigation methods\fP
.fi
.RE
.sp 1
.IP
.nf
void* \fBforEveryGo\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP), void* \fIclosure\fP);
.br
void* \fBforEveryMappedGo\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP), void* \fIclosure\fP);
void* \fBforEverySelectedGo\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP), void* \fIclosure\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to execute the procedure \fIproc\fP for every \fIGo\fP
(or selected \fIGo\fP, or mapped \fIGo\fP) in the subtree which has \fIthis\fP
as \fIroot\fP. \fIProc\fP is called for the current \fIGo\fP first.
The subtree navigation is recursive and top-down/left-right and it takes care
of the \fIGCrossType\fP. The returned value is the value passed to \fIstopRecursion()\fP.
.IP \fIproc\fP .5i
.br
Specify the procedure to be called for every \fIGo\fP or selected \fIGo\fP in the subtree.
It takes two parameters:
\fIclosure\fP which is an application data and the concerned \fIGo\fP.
.IP \fIclosure\fP .5i
.br
Specifies the \fIclosure\fP parameter passed to the procedure \fIproc\P.
.RE
.sp 1
.IP
void* \fBforEverySelectedSubtree\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP), void* \fIclosure\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to execute the procedure \fIproc\fP for every selected \fIGo\fP in the subtree
which has the \fIGo\fP as \fIroot\fP. This method is recusive but if a selected \fIGo\fP is found,
the recusivity is stopped for this \fIGo\fP subtree. The subtree navigation is
top-down/left-right and it takes care of the \fIGCrossType\fP.
.IP \fIproc\fP .5i
.br
Specify the procedure to be called for every selected \fIGo\fP in the subtree. It takes to parameters:
\fIclosure\fP which is an application data and the concerned \fIGo\fP.
.IP \fIclosure\fP .5i
.br
Specifies the \fIclosure\fP parameter passed to the procedure \fIproc\fP.
.RE
.sp 1
.IP
.nf
void* \fBforEveryGoContainingPoint\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP),
	void* \fIclosure\fP, const GPoint& \fIabspoint\fP, GNumber \fImax_dist\fP = 0);
void* \fBforEverySelectedGoContainingPoint\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP),
	void* \fIclosure\fP, const GPoint& \fIabspoint\fP, GNumber \fImax_dist\fP = 0);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to call the procedure \fIproc\fP for every \fIGo\fP or selected \fIGo\fP
containing the \fIGPoint\fP \fIabspoint\fP
in the subtree which has \fIthis\fP as \fIroot\fP.
The subtree navigation is recursive and top-down/left-right
and it takes care of the \fIGCrossType\fP.
The returned value is the value passed to \fIstopRecursion()\fP.
.IP \fIproc\fP .5i
.br
Specifies the procedure to be called for every \fIGo\fP or selected \fIGo\fP
constaining the given \fIGPoint\fP. It takes to parameters:
\fIclosure\fP which is an application data and the concerned \fIGo\fP.
.IP \fIclosure\fP .5i
.br
Specifies the \fIclosure\fP parameter passed to the procedure \fIproc\fP.
.IP \fIabspoint\fP .5i
.br
Specifies the \fIGPoint\fP which must be contained by the \fIGo\fP. This point is expressed in
the absolute coordinate system.
.IP \fImax_dist\fP .5i
.br
Specifies the tolerance.
.RE
.sp 1
.IP
.nf
void* \fBforEverySelectedSubtreeContainingPoint\fP (void \fIproc\fP(void* \fIproc\fP, Go* \fIp\fP),
	void* \fIclosure\fP, const GPoint& \fIabspoint\fP, GNumber \fImax_dist\fP = 0);
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method is a combination of \fIforEverySelectedSubtree\fP and \fIforEveryGoContainingPoint\fP.
See these methods.
.RE
.sp 1
.IP
void \fBstopRecursion\fP(void* \fIreturn_value\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to stop the recursion started by the last \fIforEvery...\fP
or \fIForEvery...\fP (notice the upper case) method.
.IP \fIreturn_value\fP .5i
.br
Specifies the value which will be returned by the \fIforEvery...\fP or
\fIForEvery...\fP method.
.RE
.sp 1
.IP
GBool \fBreparent\fP (Go* \fInewParent\fP, Go* \fInextBrother\fP = NULL)
.RS .8i
.IP \fIDescription\fP .5i
This method reparents this \fIGo\fP such as its new parent will be
\fInewParent\fP and its next brother will be \fInextBrother\fP.
The absolute coordinate system of this \fIGo\fP is not changed (and therefore
the parent relative coordinate system of this \fIGo\fP may change).
See the \fIparentRelativeReparent()\fP method.
.br
The method returns GTRUE if all preconditions have returned GTRUE and the
method has been performed.
.IP \fInewParent\fP .5i
.br
The new parent of this go. It may be \fINULL\fP. In that case this \fIGo\fP
becomes the root of a new subtree.
.IP \fInextBrother\fP .5i
The new next brother of this \fIGo\fP. It may be \fINULL\fP. In that case
the \fIGo\fP will be the last child of its new parent.
.RE
.sp 1
.IP
GBool \fBparentRelativeReparent\fP(Go* \fInew_parent\fP, Go* \fInext_brother\fP = NULL);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to reparent \fIGo\fP but the relative coordinate system
is keeped and the absolute coordinate system may change (see the
\fIreparent\fP method).
.br
The method returns GTRUE if all preconditions have returned GTRUE and the
method has been performed.
.RE
.sp 1
.IP
GBool \fBshift\fP (Go* \fInext_brother\fP = NULL)
.br
GBool \fBraise\fP();
.br
GBool \fBlower\fP();
.RS .8i
.IP \fIDescription\fP .5i
The \fIshift\fP method shifts the \fIGo\fP just before \fInext_brother\fP in
the \fIGo\fP tree.
.br
The \fIraise\fP method shifts this go as last child (then it will be desplayed on
top of its brothers). It is equivalent to \fIshift(NULL)\fP.
.br
The \fIlower\fP method shifts this go as first child (then it will be desplayed at
bottom of its brothers).
.IP \fInext_brother\fP .5i
.br
The new next brother of this \fIGo\fP. It may be \fINULL\fP. In that case
this \fIGo\fP will be the last child of its parent.
.br
The methods return GTRUE if all preconditions have returned GTRUE and the
actions have been performed.
.RE
.sp 1
.IP
GBool \fBleaf\fP(GBool set_leaf);
.br
GBool \fBsetCrossType\fP(GCrossType \fIcross_type\fP);
.RS .8i
.IP \fIDescription\fP .5i
These methods allows to define the external visibility of the \fIGo\fP
in the \fIGo\fP tree.
.br
The methods return GTRUE if all preconditions have returned GTRUE and the
actions have been performed.
.IP \fIset_leaf\fP .5i
.br
If it is GTRUE equivalent to \fIsetCrossType(GCROSS_AS_LEAF)\fP.
.br
If it is GFLASE equivalent to \fIsetCrossType(GCROSS_AS_NODE)\fP.
.IP \fIcross_type\fP .5i
.br
Specifies the crossing mode in the tree: \fIGCROSS_AS_NODE\fP, \fIGCROSS_AS_LEAF\fP,
\fIGCROSS_AS_NOTHING\fP.
.RE
.sp 1
.IP
Go* \fBPrevious\fP(int \fIthis_index\fP = GUNKNOWN_CHILD_INDEX) const;
.br
Go* \fBNext\fP(int \fIthis_index\fP = GUNKNOWN_CHILD_INDEX) const;
.br
Go* \fBChild\fP(int \fIindex\fP = 0) const;
.br
Go* \fBLastChild\fP() const;
.br
Go* \fBGoAt\fP(const GPoint& \fIabs_position\fP, GNumber \fPmax_distance\fP) const;
.br
int \fBChildIndex\fP(const Go* \fIchild\fP) const;
.RS .8i
.IP \fIDescription\fP .5i
These methods act like corresponding lower case methods but without
taking in account the \fIcross type\fP.
.br
For example, \fIChild\fP will return the first child of this, even if this
has a cross type of \fIGCROSS_AS_LEAF\fP. \fIPrevious\fP will return the previous
brother of this, even if the previous brother has a cross type of
\fIGCROSS_AS_NOTHING\fP.
.RE
.sp 1
.IP
Go* \fBRoot\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the root \fIGo\fP of the \fIGo\fP (sub)tree containing \fIthis\fP.
This root may not be a \fIGoRoot\fP (in that case, \fIroot()\fP method returns NULL).
.RE
.sp 1
.IP
.nf
void* \fBForEveryGo\fP(void \fIproc\fP(void*, Go*), void* \fIclosure\fP);
void* \fBForEveryMappedGo\fP(void \fIproc\fP(void*, Go*), void* \fIclosure\fP);
void* \fBForEverySelectedGo\fP(void \fIproc\fP(void*, Go*), void* \fIclosure\fP);
void* \fBForEverySelectedSubtree\fP(void \fIproc\fP(void*, Go*), void* \fIclosure\fP);
void* \fBForEverySensor\fP(void \fIproc\fP(void*, GoSensor*), void* \fIclosure\fP);
void* \fBForEveryGoContainingPoint\fP(void \fIproc\fP(void*, Go*),
		void*, const GPoint&, GNumber \fImaxDistance\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
See the corresponding lower case methods (forEvery...).
.br
The difference is that these methods do not care with the cross type.
.RE
.sp 1
.IP
.nf
void \fBshiftPrecond\fP(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP, const Go* (*\fInext_brother\fP)),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBshiftPostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, Go* \fIold_next_brother\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBremoveChildPrecond\fP(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP, const Go* \fIchild_to_remove\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBremoveChildPostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP,
	Go* \fIrem_child\fP, Go* \fIold_next_brother\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBaddChildPrecond\fP(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP,
	const Go* \fIchild_to_add\fP, const Go* (*\fInext_brother\fP)),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBaddChildPostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, Go* \fIadded_child\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBreparentPrecond\fP(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP,
	const Go* \fInew_parent\fP, const Go* (*\fInext_brother\fP)),
	void* closure, GAddOrRemove \fIadd\fP= GADD);
void \fBreparentPostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP,
	Go* \fIold_parent\fP, Go* \fIold_next_brother\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.fi
.RS .8i
.IP \fIDescription\fP .5i
This set of methods allows to add/remove pre/postconditions when modifying the \fIGo\fP
tree structure around \fIthis\fP (i.e. change brothers, parent, remove child). Preconditions allow
to refuse the modification (return GFLASE), but they cannot modify the request. Postconditions are
called after the modification of the \fIGo\fP structure.
.IP \fIproc\fP .5i
.br
Specifies the pre/postcondition callback which is called when the \fIGo\fP environment in the
\fIGo\fP tree is changed. It takes up to four paramaters (depending on the modification type).
The two first parameters are the closure (private application data) and \fIthis\fP itself.
The other parameters are \fIthis\fP brothers (\fInext_brother, old_next_brother\fP
or concerned children or parents (\fIchild_to_remove, child_to_add, rem(oved)_child, added_child,
new_parent, old_parent\fP). 
.IP \fIclosure\fP .5i
.br
Specifies the private application data which is passed to the pre/post condition callback \fIproc\fP
as the first parameter.
.IP \fIadd\fP .5i
.br
Specifies if the pre/post condition callback \fIproc\fP has to added (default) or removed (GREMOVE).
.RE
.sp 1
.IP
.nf
void \fBrootPrecond\fP(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP, const GoRoot* \fIgoroot\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBrootPostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, Go* \fIold_root\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add/remove pre/postcondition callbacks on \fIGoRoot\fP
changing. Preconditions may refuse the modification. Postconditions are called
after the \fIGoRoot\fP change.
.IP \fIproc\fP .5i
.br
Specifies the pre/postcondition callback procedure which is called when the \fIGoRoot\fP is
changed. It takes three parameters: the closure (private application data), the \fIGo\fP instance
itself (\fIthis\fP) and the new/old \fIGoRoot\fP.
.IP \fIclosure\fP .5i
.br
Specifies the private application data which is passed to the pre/post condition callback \fIproc\fP
as the first parameter.
.IP \fIadd\fP .5i
.br
Specifies if the pre/post condition callback \fIproc\fP has to added (default) or removed (GREMOVE).
.RE
.sp 1
.IP
.nf
void \fBinterfPrecond\fP(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP, const GoInterf* \fIgointerf\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBinterfPostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, Go* \fIold_interf\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add/remove pre/postcondition callbacks on \fIGoInterf\fP changing. Preconditions
may refuse the modification. Postconditions are called after the
\fIGoInterf\fP change.
.IP \fIproc\fP .5i
.br
Specifies the pre/postcondition callback procedure which is called when the \fIGoInterf\fP is
changed. It takes three parameters: the closure (private application data), the \fIGo\fP instance
itself (\fIthis\fP) and the new/old \fIGoInterf\fP.
.IP \fIclosure\fP .5i
.br
Specifies the private application data which is passed to the pre/post condition callback \fIproc\fP
as the first parameter.
.IP \fIadd\fP .5i
.br
Specifies if the pre/post condition callback \fIproc\fP has to added (default) or removed (GREMOVE).
.RE
.sp 1
.IP
.nf
void \fBcrossTypePrecond\fP(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP, GCrossType* \fIcross_type\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBcrossTypePostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, GCrossType \fIold_cross_type\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add/remove pre/postconditions on \fIcross type\fP modification of the \fIGo\fP.
The precondition may accept the new cross type, modify it or refuse the modification. In the last case, it
has to return GFLASE, else it returns GTRUE.
.IP \fIproc\fP .5i
.br
Specifies the pre/postcondition which is called when the \fIGo\fP cross type is modified. It takes three parameters:
the closure (private application data), the \fIGo\fP that the cross type is going to be (or has been) modified
and a pointer to the new cross type (or the old cross type).
.IP \fIclosure\fP .5i
.br
Specifies the private application data which is passed to the pre/post condition callback \fIproc\fP
as the first parameter.
.IP \fIadd\fP .5i
.br
Specifies if the pre/post condition callback \fIproc\fP has to added (default) or removed (GREMOVE).
.RE
.sp 1
.SH
\fBPUBLIC COORDINATE SYSTEM METHODS\fP
.IP
.nf
GCoordSys \fBcoordsys\fP(const Go* \fIrelative_to\fP = NULL) const;
GPoint \fBorigin\fP(const Go* \fIrelative_to\fP = NULL) const;
GMatrix \fBmatrix\fP(const Go* \fIrelative_to\fP = NULL) const;
.fi
.RS .8i
.IP \fIDescription\fP
These methods allows to get values of the coordinate system.
.IP \fIrelative_to\fP .5i
If \fIrelative_to\fP is NULL (the default value), the absolute coordinate
system of this is returned.
Else the coordinate system of this relatively to the coordinate system of
\fIrelative_to\fP is returned.
.RE
.sp 1
.IP
.nf
GCoordSys \fBAbscs\fP(const GCoordSys& \fIabscs\fP = *((GCoordSys*)NULL)) const;
GCoordSys \fBRelcs\fP(const GCoordSys& \fIrelcs\fP = *((GCoordSys*)NULL)) const;
.fi
.RS .8i
.IP \fIDescription\fP
These methods return the \fIGo\fP absolute coordinate system (\fIAbscs\fP),
the parent relative coordinate system (\fIRelcs\fP).
.IP \fIabscs\fP .5i
.br
Specifies the absolute coordinate system of the parent of this go.
If it is NULL (the default value) the method uses the actual parent absolute
coordinate system.
.br
Using \fIabscs\fP you will be able to get information like "which would be
the coordinate system of this if its parent had \fIabscs\fP as absolute
coordinate system ?".
.IP \fIrelcs\fP .5i
.br
.RE
.sp 1
.IP
.nf
GBool \fBsetCoordsys\fP(const GCoordSys& \fIcs\fP, Go* \fIrelative_to\fP = NULL);
GBool \fBmove\fP(const GPoint& \fIo\fP, Go* \fIrelative_to\fP = NULL);
GBool \fBsetMatrix\fP(const GMatrix& \fImatrix\fP, Go* \fIrelative_to\fP = NULL);
GBool \fBrescale\fP(GNumber \fIxsize\fP, \fIysize\fP, Go* \fIrelative_to\fP = NULL);
GBool \fBrotate\fP(GNumber \fIangle\fP, const GPoint& \fIcenter\fP, Go* \fIrelative_to\fP = NULL);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to modify the coordinate system of \fIthis\fP. Before modifying
the coordinate system, \fIcoodsysPrecond\fP callbacks are called, this callbacks may
accept, refuse or force another modification. After the coordinate system modification
is performed, the \fICoordsysPostcond\fP callbacks are called.
.br
These methods return GTRUE if all the preconditions return GTRUE and the actions
are performed.
.IP \fIrelative_to\fP .5i
If \fIrelative_to\fP is not NULL, \fIcs\fP, \fIo\fP, \fImatrix\fP, \fIxsize\fP,
\fIysize\fP and \fIcenter\fP are expressed relatively to the coordinate system
of \fIrelative_to\fP.
.IP "\fIcs, o, matrix\fP" .5i
Specify the new values requested for the \fIGo\fP coordinate system.
.IP "\fIxsize\fP, \fIysize\fP" .5i
Specify sizes of the X vector and of the Y vector of the coordinate system.
.IP \fIcenter\fP .5i
Specifies the center of rotation.
.RE
.sp 1
.IP
.nf
GBool \fBSetThisAbscs\fP(const GCoordSys& \fIabs_cs\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method allows you to update the coordinate system of \fIthis\fP, while
absolute coordinate systems of its children are kept.
.RE
.sp 1
.IP
.nf
void \fBrelcsPrecond\fP(GBool \fIproc\fP(void* \fIclosure\fP, const Go*\fIgo\fP, GCoordSys* \fInew_relcs\fP,
	const GCoordSys* \fIoldparabs\fP, const GCoordSys* \fInewparabs\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBrelcsPostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, const GCoordSys* \fIparabs\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBabscsPrecond\fP(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP, GCoordSys* \fInew_abscs\fP,
	const GCoordSys* \fIoldparabs\fP, const GCoordSys* \fInewparabs\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBabscsPostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, const GCoordSys* \fIparabs\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add/remove pre/postconditions on relative coordinate system (\fIrelcs\fP)
or absolute coordinate system (\fIabscs\fP) changing. Preconditions allow to refuse the coordinate
system change but they are able to force other modifications.
.sp 1
\fIWarning:\fP Preconditions on coordinate system modifications are called recursively in the
\fIGo\fP subtree before any modification, but a precondition callback in a child receives
the old (\fIcurrent\fP) and the new (\fIfuture\fP)
coordinate systems of its parent in order to allow to decide if the
modification is either acceptable or has to be forced or has to be refused.
.IP \fIproc\fP .5i
.br
Specifies the pre/postcondition callback routine which is called when the relative/absolute
coordinate system is changed. Preconditions take five parameters: the closure (private
application data), the \fIGo\fP itself, the new relative/absolute coordinate system, the old
parent asolute coordinate system (before the coordinate system modification) and the new parent
absolute coordinate system (after the modification).
Postconditions take three parameters: the closure, the \fIGo\fP with the new coordinate system
and and the new parent coordinate system.
.IP \fIclosure\fP .5i
.br
Specifies the private application data which is passed to the pre/post condition callback \fIproc\fP
as the first parameter.
.IP \fIadd\fP .5i
.br
Specifies if the pre/post condition callback \fIproc\fP has to added (default) or removed (GREMOVE).
.RE
.sp 2
.SH
\fBPUBLIC DISPLAYING MANAGEMENT METHODS\fP
.IP
.nf
GBool \fBmap\fP()
GBool \fBunmap\fP()
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods map and unmap this \fIGo\fP. A \fIGo\fP is visible only if it
is mapped and if its parent is visible. The \fImapPrecond\fP and \fImapPostcond\fP
callbacks are called.
.br
These methods return GTRUE, if all preconditions return GTRUE and the actions
are performed.
.RE
.sp 1
.IP
GBool \fBmapped\fP()
.RS .8i
.IP \fIDescription\fP .5i
This method returns GTRUE only if this object \fIis\fP visible, i.e.
\fIthis\fP and all its ancestors are mapped.
.RE
.sp 1
.IP
GBool \fBmappable\fP()
.RS .8i
.IP \fIDescription\fP .5i
This method returns GTRUE if this object \fImay be\fP visible,
if all its ancestors are mapped. The method \fImap()\fP has been
performed for \fIthis\fP.
.RE
.sp 1
.IP
.nf
void \fBmapPrecond\fP(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBmapPostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add/remove pre/postcondition callbacks which will be called when \fIthis\fP
becomes mapped (visible) or unmapped (unvisible). Preconditions allow to refuse or accept the (un)mapping.
.IP \fIproc\fP .5i
.br
Specifies the pre/postcondition callback routine which is called when a mapping modification
occurs for \fIthis\fP. It takes two parameters: the closure (private application data) and
the \fIGo\fP itself.
.IP \fIclosure\fP .5i
.br
Specifies the private application data which is passed to the pre/post condition callback \fIproc\fP
as the first parameter.
.IP \fIadd\fP .5i
.br
Specifies if the pre/post condition callback \fIproc\fP has to added (default) or removed (GREMOVE).
.RE
.sp 1
.IP
.nf
GBool \fBselect\fP()
GBool \fBunselect\fP()
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to select/unselect \fIthis\fP. The methods call first \fIpreconditions\fP; if they accept the internal select flag is set for \fIselect\fP and unset for \fIunselect\fP. If the action is performed they call \fIpostconditions\fP.
.br
Methods return GTRUE if all \fIpreconditions\fP returns GTRUE else it returns GFALSE.
.RE
.sp 1
.IP
GBool \fBselected\fP()
.RS .8i
.IP \fIDescription\fP .5i
This method returns \fIGTRUE\fP if this \fBGo\fP is selected.
.RE
.sp 1
.IP
.nf
void \fBselectPrecond\fP(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBselectPostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add/remove pre/postcondition callbacks which will be called when \fIthis\fP
will become selected or deselected. Preconditions
may refuse or accept the (de)selection of the \fIGo\fP.
.IP \fIproc\fP .5i
.br
Specifies the pre/postcondition callback routine which is called when a (de)selection
occurs. It takes two parameters: the closure (private application data) and the \fIGo\fP itself.
.IP \fIclosure\fP .5i
.br
Specifies the private application data which is passed to the pre/post condition callback \fIproc\fP
as the first parameter.
.IP \fIadd\fP .5i
.br
Specifies if the pre/post condition callback \fIproc\fP has to added (default) or removed (GREMOVE).
.RE
.sp 1
.IP
.nf
GBool \fBcontains\fP(const GPoint& \fIabsolute_point\fP, GNumber \fImax_distance\fP = 0) const;
GBool \fBsubtreeContains\fP(const GPoint& \fIabsolute_point\fP, GNumber \fImax_distance\fP = 0) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to know if a point (see \fIGPoint(3Go)\fP) is belongs to the clipping region
of\fIthis\fP (\fIcontains()\fP) or of the subtree which has \fIthis\fP as root.
.IP \fIabsolute_point\fP .5i
Specifies the point expressed in the absolute coordinate system.
.IP \fImax_distance\fP .5i
Specifies the accepted tolerance expressed in millimeters.
.RE
.sp 1
.IP
.nf
GRegion \fBclip\fP() const;
void \fBaddClip\fP(GRegion& \fIregion\fP) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods return the clip of this go and its subtree.
The clip means a region that contains all drawings of this go and its
subtree.
.br
The \fIclip\fP method returns that clip region.
The \fIaddClip\fP method add that clip region to \fIregion\fP.
.RE
.sp 1
.IP
.nf
GRegion \fBmyClip\fP() const;
void \fBaddMyClip\fP(GRegion& \fIregion\fP) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods give you the clip of this go (and not of its children).
The clip means a region that contains all drawings of this go.
.br
The \fImyClip\fP method returns that clip region.
The \fIaddMyClip\fP method adds that clip region to \fIregion\fP.
.RE
.sp 1
.IP
GRegion \fBopaqueClip\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the opaque clip of this go and its subtree.
.br
The opaque clip means a region which is fully inside the drawings of this
go and its subtree.
.RE
.sp 1
.IP
.nf
GRegion \fBmyOpaqueClip\fP() const;
void \fBaddMyOpaqueClip\fP(GRegion& \fIregion\fP) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods give you the opaque clip of this go (and not of its subtree).
The opaque clip means a region which is fully inside the drawings of this go.
.br
The \fImyOpaqueClip\fP method returns that opaque clip region.
The \fIaddMyOpaqueClip\fP method adds that opaque clip region to \fIregion\fP.
.RE
.sp 1
.IP
.nf
void \fBmyClipPostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBclipPostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add/remove postcondition functions in order to be notified when
the absolute clipping region (overall dimensions) of \fIthis\fP is changed.
\fIMyClipPostcond\fP allows to be notified when the clipping region of the \fIGo\fP is
changed, \fIclipPostcond\fP allows to be notified when the clipping region of the \fIGo\fP
and all its children is changed.
.IP \fIproc\fI .5i
.br
Specifies the postcondition callback function which is called when the \fIGo\fP clipping region
is changed. It takes two parameters: the closure (private application data) and the \fIGo\fP itself.
.IP \fIclosure\fP .5i
.br
Specifies the private application data which is passed to the pre/post condition callback \fIproc\fP
as the first parameter.
.IP \fIadd\fP .5i
.br
Specifies if the pre/post condition callback \fIproc\fP has to added (default) or removed (GREMOVE).
.RE
.sp 1
.IP
.nf
void \fBwiredDraw\fP(const GCoordSys& \fIcs\fP, const GPen& pen, GQuality q = GMAX_QUALITY) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method allows to draw the \fIGo\fP using a fast algorithm
in the given absolute coordinate system. The original drawing of the \fIGo\fP is not
changed.
.IP \fIcs\fP .5i
.br
Specifies the absolute coordinate system in which the \fIGo\fP has to be drawn.
.RE
.sp 2
.SH
\fBPUBLIC SAVE MANAGEMENT METHODS\fP
.sp 1
.IP
.nf
void \fBsavePrecond\fP(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP, const GoStream* \fIstream\fP),
	void* \fIclosure\fP, GAddOrRemove \fIgo\fP = GADD);
void \fBsavePostcond\fP(void proc(void* \fIclosure\fP, Go* \fIgo\fP, GoStream* \fIstream\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add/remove pre/postconditions on \fIGo\fP saving. Preconditions may refuse the
saving (return GFLASE). Postconditions may be used by the application to save its own data
(associations, conditions, private structure, ...) which will
be retrievable when restoring (see \fIrestore()\fP).
.IP \fIproc\fP .5i
.br
Specifies the pre/postcondition callback which is called when a \fIGo\fP is saved. It takes
three parameters: the closure (private application data), the \fIGo\fP to be saved and the stream
that can be used by the application to save its own data.
.IP \fIclosure\fP .5i
.br
Specifies the private application data which is passed to the pre/post condition callback \fIproc\fP
as the first parameter.
.IP \fIadd\fP .5i
.br
Specifies if the pre/post condition callback \fIproc\fP has to added (default) or removed (GREMOVE).
.RE
.sp 2
.SH
\fBOTHER PUBLIC METHODS\fP
.IP
static GoMetaclass* \fBmetaclass\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the metaclass of "class Go".
.RE
.sp 1
.IP
static GoMetaclass* \fBmetaclass\fP (const char* \fIclass_name\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method returns the metaclass which name is \fIclass_name\fP.
For example, "GoEllipse::metaclass()" is similar to
"Go::metaclass("GoEllipse")".
.RE
.sp 1
.IP
GoMetaclass* \fBgetMetaclass\fP() const;
.RS .8i
.IP \fIDescription .5i
This method returns the metaclass of \fIthis\fP.
.br
If \fIGo* go\fP is realy a GoRectangle, \fIgo->getMetaclass()\fP will return
the metaclass of GoRectangle (which can also be accessed by
\fIGoRectangle::metaclass()\fP).
.RE
.sp 1
.IP
void \fBcheck\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method checks the validity of \fIthis\fP. This method returns nothing,
but it will print a warning message if something is wrong, and eventually
stop the program if an uncoverable error is detected.
.RE
.sp 1
.IP
GAssoc* \fBassoc\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns a pointer to the \fIGAssoc\fP object associated
with the \fIGo\fP (See \fIAssoc(3Go)\fP). It may be NULL for light weight Gos.
.RE
.sp 2
.SH
\fBUSER INTERACTION\fP
.IP
\fISee mGo(3Go)\fP.
.sp 2
.SH
\fBC BINDING\fP
.SS
\fBHeader\fP
.IP
#include <Go/cGo.h>
.SS
\fBGeneral Informations\fP
.IP
Almost all C++ classes become GObjectId's with a set of related functions and
attributes.
.sp
To get an attribute you have to initialize a GArg structure with the attribute name
and the location to store the returned value. If \fINULL\fP is passed, the value
is stored in in \fIarg.value\fP.
.IP
.nf
.ta .15i 1.0i
	typedef struct _GArg
	{
		char* attribute;
		void* value;
	} GArg;
.fi
.IP
You can use the macro `GOSET_ARG' to set a GArg structure:
.nf
.ta .15i
	void \fBGOSET_ARG\fP (GArg \fIarg\fP, const char* \fIattribute\fP, void* \fIvalue\fP);
.fi
.IP
To get the value of an attribute you must use the following function:
.nf
.ta .15i
	void \fBGoGetValues\fP (GObjectId \fIgo\fP, GArg* \fIargs\fP, int \fIargCount\fP);
.fi
.IP
Example:
.nf
.ta .15i
	GArg args[2];
	GNumber radius;
	GOSET_ARG(args[0], goNparent, NULL);
	GOSET_ARG(args[1], goNradius, &radius);
	GoGetValues(aGoCircle, args, 2);
.fi
.IP
After this sequence of instructions you can get the parent of \fIaGoCircle\fP
in \fIargs[0].value\fP, and the radius in \fIradius\fP.
.IP
To set an attribute you must set up a GArg with the attribute name
and the value, and call the following function:
.nf
.ta .15i
	void \fBGoSetValues\fP (GObjectId \fIgo\fP, GArg* \fIargs\fP, int \fIargCount\fP);
.fi
.IP
Example:
.nf
.ta .15i
	GArg arg;
	GOSET_ARG(arg, goNradius, 10.0);
	GoSetValues(aGoCircle, &arg, 1);
.fi
.SS
\fBGo Attributes\fP
.IP
You can get or set following attributes at Go level:
.nf
.ta .15i
	goNparent
	goNprevious
	goNnext
	goNfirstChild
	goNroot
	goNcrossType

	goNcoordsys
	goNparentRelativeCoordsys

	goNmapped
	goNselected
.fi
.SS
\fBC Functions\fP
.IP
You will find below the list of C functions at Go level, with their
corresponding C++ methods. Booleans (\fIGBool\fP) are passed as integer
(\fIint\fP) in the C interface (for portability reasons).
.IP
.nf
.ta .15i 1.0i
	\fIC function\fP
		corresponding C++ method

\fIGo Creation and Destruction:\fP
	GObjectId \fBGoCreateFromName\fP (const char* \fIname\fP)
		static Go* Go::create (const char* \fIname\fP);
	GObjectId \fBGoDup\fP (GObjectId \fIgo\fP)
		Go* Go::dup ();

	int \fBGoDestroy\fP (GObjectId \fIgo\fP)
		GBool Go::destroy ();

\fIGo Tree Management:\fP
	GObjectId \fBGoParent\fP (GObjectId \fIgo\fP)
		Go* Go::parent () const;
	GObjectId \fBGoPrevious\fP (GObjectId \fIgo\fP)
		Go* Go::previous () const;
	GObjectId \fBGoNext\fP (GObjectId \fIgo\fP)
		Go* Go::next () const;
	GObjectId \fBGoFirstChild\fP (GObjectId \fIgo\fP)
		Go* Go::firstChild () const;
	GObjectId \fBGoAtPosition\fP (GObjectId \fIgo\fP, GPoint \fIpos\fP, GNumber \fImax_distance\fP)
		Go* Go::goAt (const GPoint& \fIpos\fP, GNumber \fImax_distance\fP) const;
	GObjectId \fBGoRoot\fP (GObjectId \fIgo\fP)
		GoRoot* Go::root () const;
	int \fBGoIsAncestor\fP (GObjectId \fIgo\fP, GObjectId \fIsubchild\fP)
		GBool Go::isAncestor (const Go* \fIsubchild\fP);
	GObjectId \fBGoCommonAncestor\fP (GObjectId \fIgo1\fP, GObjectId \fIgo2\fP)
		Go* commonAncestor (const Go* \fIgo1\fP, const Go* \fIgo2\fP);
	GCrossType \fBGoCrossType\fP (GObjectId \fIgo\fP)
		GCrossType Go::crossType () const;

	int \fBGoReparent\fP (GObjectId \fIgo\fP, GObjectId \fInewParent\fP, GObjectId \fInewNextBrother\fP)
		GBool Go::reparent (Go* \fInewParent\fP, Go* \fInewNextBrother\fP);
	int \fBGoParentRelativeReparent\fP (GObjectId \fIgo\fP, GObjectId \fInewParent\fP, GObjectId \fInewNextBrother\fP)
		GBool Go::parentRelativeReparent (Go* go, Go* \fInewParent\fP, Go* \fnewNextBrother\fP);
	int \fBGoShift\fP (GObjectId \fIgo\fP, GObjectId \fInewNextBrother\fP)
		GBool Go::shift (Go* \fInewNextBrother\fP);
	int \fBGoRaise\fP (GObjectId \fIgo\fP)
		GBool Go::raise ();
	int \fBGoLower\fP (GObjectId \fIgo\fP)
		GBool Go::lower ();
	int \fBGoSetCrossType\fP (GObjectId \fIgo\fP, GCrossType \fIctype\fP)
		void Go::crossType (GCrossType \fIctype\fP);

\fIGo Coordinate System Management:\fP
	GCoordSys \fBGoCoordSys\fP (GObjectId \fIgo\fP)
		GCoordSys Go::coordsys ((const Go*)NULL) const;
	GCoordSys \fBGoRelativeCoordSys\fP (GObjectId \fIgo\fP, GObjectId \fIrelativeToThisGo\fP)
		GCoordSys Go::coordsys (const Go* \fIrelativeToThisGo\fP);
	int \fBGoSetCoordSys\fP (GObjectId \fIgo\fP, GCoordSys* \fIcs\fP)
		void Go::setCoordsys (const GCoordSys& \fIcs\fP, (Go*) NULL);
	int \fBGoSetRelativeCoordSys\fP (GObjectId \fIgo\fP, GCoordSys* \fIcs\fP, GObjectId \fIreltogo\fP)
		void Go::setCoordsys (const GCoordSys& \fIcs\fP, Go* \fIreltogo\fP);

\fIGo Drawing Management:\fP
	int \fBGoMapped\fP (GObjectId \fIgo\fP)
		GBool Go::mapped () const;
	int \fBGoMappable\fP (GObjectId \fIgo\fP)
		GBool Go::mappable () const;
	int \fBGoSelected\fP (GObjectId \fIgo\fP)
		GBool Go::selected () const;
	int \fBGoContains\fP (GObjectId \fIgo\fP, GPoint \fIposition\fP, GNumber \fImaxDistance\fP)
		GBool Go::contains (const GPoint& \fIposition\fP, GNumber \fImaxDistance\fP);
	void \fBGoWiredDraw\fP (GObjectId \fIgo\fP, GCoordSys* \fIcs\fP)
		void Go::wiredDraw (const GCoordSys& \fIcs\fP);

	int \fBGoMap\fP (GObjectId \fIgo\fP)
		GBool Go::map ();
	int \fBGoUnmap\fP (GObjectId \fIgo\fP)
		GBool Go::unmap ();
	int \fBGoSelect\fP (GObjectId \fIgo\fP)
		GBool Go::select ();
	int \fBGoUnselect\fP (GObjectId \fIgo\fP)
		void Go::unselect ();

\fIGo Metaclass Management:\fP
	GObjectId \fBMetaclass\fP (GObjectId \fIgo\fP)
		GoMetaclass* Go::getMetaclass () const;
	GObjectId \fBGoMetaclassFromName\fP (const char* \fImetaclass_name\fP)\fP
		static GoMetaclass* Go::metaclass (const char* \fImetaclass_name\fP);
	GObjectId \fBGoGetMetaclass\fP ()
		static GoMetaclass* Go::metaclass ();
.fi
.IP
Functions to add (or remove) pre and postconditions are very similar to the
corresponding C++ methods.
.IP
.nf
.ta .15i 1.0i
	void \fBGoDestroyPrecond\fP (
		GObjectId \fIgo\fP, GAddOrRemove \fIadd\fP,
		int (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP),
		void* \fIclosure\fP);
	void \fBGoDestroyPostcond\fP (
		GObjectId \fIgo\fP, GAddOrRemove \fIadd\fP,
		void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP),
		void* \fIclosure\fP);

	void \fBGoDupPrecond\fP (
		GObjectId \fIgo\fP, GAddOrRemove \fIadd\fP,
		int (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIgo\fP),
		void* \fIclosure\fP);
	void \fBGoDupPostcond\fP (
		GObjectId \fIgo\fP, GAddOrRemove \fIadd\fP,
		void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP),
		void* \fIclosure\fP);

	void \fBGoShiftPrecond\fP (
		GObjectId \fIgo\fP, GAddOrRemove \fIadd\fP,
		int (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIgo\fP, GObjectId* \fIp_next_brother\fP),
		void* \fIclosure\fP);
	void \fBGoShiftPostcond\fP (
		GObjectId \fIgo\fP, GAddOrRemove \fIadd\fP,
		void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP, GObjectId* \fIp_next_brother\fP),
		void* \fIclosure\fP);

	void \fBGoRemoveChildPrecond\fP (
		GObjectId \fIgo\fP, GAddOrRemove \fIadd\fP,
		int (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIgo\fP, GObjectId \fIchild_to_remove\fP),
		void* \fIclosure\fP);
	void \fBGoRemoveChildPostcond\fP (
		GObjectId \fIgo\fP, GAddOrRemove \fIadd\fP,
		void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP, GObjectId \fIremoved_child\fP),
		void* \fIclosure\fP);

	void \fBGoAddChildPrecond\fP (
		GObjectId \fIgo\fP, GAddOrRemove \fIadd\fP,
		int (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIgo\fP,
		                 GObjectId \fIchild_to_add\fP, GObjectId* \fIp_next_brother\fP),
		void* \fIclosure\fP);
	void \fBGoAddChildPostcond\fP (
		GObjectId \fIgo\fP, GAddOrRemove \fIadd\fP,
		void (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIgo\fP, GObjectId \fIadded_child\fP),
		void* \fIclosure\fP);

	void \fBGoReparentPrecond\fP (
		GObjectId \fIgo\fP, GAddOrRemove \fIadd\fP,
		int (*\fIfunction\fP)(void* \fIclosure\fP,const  GObjectId \fIgo\fP,
		                 GObjectId \fInew_parent\fP, GObjectId* \fIp_next_brother\fP),
		void* \fIclosure\fP);
	void \fBGoReparentPostcond\fP (
		GObjectId \fIgo\fP, GAddOrRemove \fIadd\fP,
		void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP,
		                 GObjectId \fIold_parent\fP, GObjectId \fIold_next_brother\fP),
		void* \fIclosure\fP);

	void \fBGoRootPrecond\fP (
		GObjectId \fIgo\fP, GAddOrRemove \fIadd\fP,
		int (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIgo\fP, GObjectId \fInew_goroot\fP),
		void* \fIclosure\fP);
	void \fBGoRootPostcond\fP (
		GObjectId \fIgo\fP, GAddOrRemove \fIadd\fP,
		void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP, GObjectId \fIold_goroot\fP),
		void* \fIclosure\fP);

	void \fBGoCrossTypePrecond\fP (
		GObjectId \fIgo\fP, GAddOrRemove \fIadd\fP,
		int (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIgo\fP, GCrossType* \fIp_new_cross_type\fP),
		void* \fIclosure\fP);
	void \fBGoCrossTypePostcond\fP (
		GObjectId \fIgo\fP, GAddOrRemove \fIadd\fP,
		void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP, GCrossType \fIold_cross_type\fP),
		void* \fIclosure\fP);

	void \fBGoRelcsPrecond\fP (
		GObjectId \fIgo\fP, GAddOrRemove \fIadd\fP,
		int (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIgo\fP, GCoordSys* \fIp_new_relcs\fP),
		void* \fIclosure\fP);
	void \fBGoRelcsPostcond\fP (
		GObjectId \fIgo\fP, GAddOrRemove \fIadd\fP,
		void (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIgo\fP),
		void* \fIclosure\fP);

	void \fBGoAbscsPrecond\fP (
		GObjectId \fIgo\fP, GAddOrRemove \fIadd\fP,
		int (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIgo\fP, GCoordSys* \fIp_new_abscs\fP),
		void* \fIclosure\fP);
	void \fBGoAbscsPostcond\fP (
		GObjectId \fIgo\fP, GAddOrRemove \fIadd\fP,
		void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP),
		void* \fIclosure\fP);

	void \fBGoMapPrecond\fP (
		GObjectId \fIgo\fP, GAddOrRemove \fIadd\fP,
		int (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIgo\fP),
		void* \fIclosure\fP);
	void \fBGoMapPostcond\fP (
		GObjectId \fIgo\fP, GAddOrRemove \fIadd\fP,
		void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP),
		void* \fIclosure\fP);

	void \fBGoSelectPrecond\fP (
		GObjectId \fIgo\fP, GAddOrRemove \fIadd\fP,
		int (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIgo\fP),
		void* \fIclosure\fP);
	void \fBGoSelectPostcond\fP (
		GObjectId \fIgo\fP, GAddOrRemove \fIadd\fP,
		void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP),
		void* \fIclosure\fP);

	void \fBGoMyClipPostcond\fP (
		GObjectId \fIgo\fP, GAddOrRemove \fIadd\fP,
		void (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIgo\fP),
		void* \fIclosure\fP);
	void \fBGoClipPostcond\fP (
		GObjectId \fIgo\fP, GAddOrRemove \fIadd\fP,
		void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP),
		void* \fIclosure\fP);

	void \fBGoInterfPrecond\fP (
		GObjectId \fIgo\fP, GAddOrRemove \fIadd\fP,
		int (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIgo\fP, GObjectId \fInew_gointerf\fP),
		void* \fIclosure\fP);
	void \fBGoInterfPostcond\fP (
		GObjectId \fIgo\fP, GAddOrRemove \fIadd\fP,
		int (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP, GObjectId \fIold_gointerf\fP),
		void* \fIclosure\fP);
.fi
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
\fIGo\fP instances cannot be directly created this explains why there are no
public constructors (you must create real gos: GoBezier, GoText, ...).
.sp 2
.SH
\fBSEE ALSO\fP
.IP
\fBGAssoc\fP, \fBCons\fP, \fBGCoordSys\fP, \fBGoClass\fP, \fBGoInterf\fP, \fBGoRoot\fP, \fBGoStream\fP, \fBGoUI\fP,
\fBGNumber\fP, \fBGMatrix\fP, \fBGPoint\fP, \fBGRegion\fP, \fBGoSensors\fP, and \fBVector\fP classes.
.nrPN \n%
