.\" $Id: GoBinary.n,v 1.2 1992/12/30 18:00:12 mbikina Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any adve rtising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoBinary 3Go "September 1992" "Version 1.2" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoBinary\fP \(em the binary file GoStream object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/GoBinary.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGoBinary\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGoStream\fP class.
.RE
.sp 1
.SH 
\fBDESCRIPTION\fP
.sp 1
.IP
\fBGoBinary\fP is a \fBGoStream\fP which uses a binary representation to describe
objects. As \fBGoStream\fP, \fBGoBinary\fP needs a \fBMedium\fP to write on or
read from. The device used depends on the \fBMedium\fP subclass. 
.IP
.nf
.ta .15i .25i 1.0i
class GoBinary : public GoStream {

	public:

		GoBinary(GMedium* medium = NULL);
		~GoBinary();
};
.fi
.SH
\fBPUBLIC METHODS\fP
.sp 1
.IP
\fBGoBinary\fP (GMedium* \fImedium\fP = NULL)
.RS .8i
.IP \fIDescription\fP .3i
Class constructor.
.IP \fImedium\fP .3i
.br
Specifies a \fBMedium\fP for the new \fBGoBinary\fP instance.
.RE
.sp 1
.IP
\fB~GoBinary\fP()
.RS .8i
.IP \fIDescription\fP .3i
Class destructor. Does not affect the \fBMedium\fP attached to the
\fBGoBinary\fP instance (if any).
.RE
.sp 1
.SH
\fBC BINDING\fP
.SS
\fBHeader\fP
.IP
\fI#include <Go/cGoBinary.h>\fP
.SS
\fBC Functions\fP
.IP
.nf
GObjectId \fBNewGoBinary\fP (GObjectId \fImedium\fP);
.fi
.sp 1
.RS .8i
.IP \fIDescription\fP .3i
C interface to \fBnew GoBinary\fP (\fImedium\fP).
.br
Use the function \fBDeleteGoStream\fP to delete the object create by
\fBNewGoBinary\fP.
.RE
.sp 1
.SH
\fBGOBINARY DESCRIPTION FILE\fP
.sp 1
\fBOverview of File Structure\fP
.sp 1
The GoStream binary has a sequential organization. GoBinary has
components that appear in a fixed order. 
.IP \(bu 2
A GoBinary file begin with a file header containing a magic number that 
identifies the GoStream as a GoStream Binary, the version of the GoBinary,
the byte order use in the GoStream, a user header, and a reference of a GoBinary directory.
.IP \(bu 2
The GoBinary directory contains two tables : a class table and an index table. 
The class table make the correspondance between a class name and a
class identifier. The index table is a list of objects references in the medium.
.IP \(bu 2
The Data block is a list of description of each object, identifier and data.
.sp 2
.PP
\fBFormat Details\fP
.sp 1
.IP "\fIThe Go Stream Header\fP" 
This block is not subject to a particular version of GoBinary.
This block must appear at the beginning of every GoBinary.
.sp 1
.IP "\fIThe Magic Number\fP"
This field indicating that this GoStream is a GoBinary. It contains an arbitrary 
but carefully chosen values. Legal values is the list of bytes 0x4d 0x4e 0x47 0x4f "MNGO".
.sp 1
.IP "\fIThe Byte  Ordering\fP"
This field indicate the order use for muti-byte numeric types.
Byte order can either be least-significant-byte (LSB) first or
most-significant-byte (MSB) first.
.sp 1
.IP "\fIThe GoBinary version\fP"
Identifies the minimum set of capabilities necessary to a decoder
to fully process the GoBinary.
.sp 1
.IP "\fIThe Encoding\fP"
This field indicates the compression algorithm use in the GoBinary.
.sp 1
.IP "\fIThe References of Tables\fP"
This field contains the location of the class table and index table
in the medium.This value is a byte offset with respect to the beginning of 
the medium.The first byte of the medium has an offset of 0.
.sp 1
.IP "\fIThe user Header\fP"
This block contains application specific data. This is a set of bytes ;
the lenght is not limited.
.sp 1
.IP "\fIThe Data\fP"
The representation of an objet consists of an object identifier, a class 
identifier and a sequence of attributes. Each attributes has the following
format  : a control fied that identifies  the type, and a value. The lenght of
the value depend of his type.The decoder use this control field to determine the 
lenght of value. (see annexe for description of each type of attributes).
.sp 1
.IP "\fIThe Class Table\fP"
The class table is a data structure who describes the classes used
by the objects saved in the GoBinary stream. Each object has in his description
a class identifier.
The class table make the correspondance between a class name and a
class identifier (class Id).
.sp 1
.IP "\fIThe Index Table\fP"
The Index table is a list of objects references in the medium. 
The index table permits a direct access for each object in the GoBinary.
.sp 1
.IP "\fIThe Trailer\fP"
This block is a single-field block indicating the end of the
GoStream Binary. It contains the value of the location of the class table.
.sp 2
.PP
\fBLimits, restrictions and recommendations\fP
.sp 1
.PP
There are no comments in GoBinary Stream.
.PP
The GoBinary makes the following assumptions :
.IP \(bu 2
byte are portable, where a byte is defined to be 8 bits of data
The types and theirs sizes are : integer defined to be 32 bits, short defined to be 16 bits, long defined to be 32 bits, char defined to be 8  bits.
.IP \(bu 2
The representation of floating-point data type "float" used is the IEEE standard, where a single-precision floating-point numbers is defined to be 32 bits, and double-precision floating point data is defined to be 64 bits.
.sp 1
.PP
The encoder is the program used to create the GoBinary. The encoder produces the necessary control and data to restore data. The encoder has the following responsabilities : 
.IP \(bu 2
Insure that a GoBinary is labeled with the earliest possible
version number.
.IP \(bu 2
Encoding data and indicating the method employed in the header
.sp 1
.PP
The Decoder is the program used to process the GoBinary Stream. The Decoder  parsing the various blocks, using the contol information (header,tables) to interpret and access to data. The Decoder has the following responsabilities :
.IP \(bu 2
uses default values when header is not complete (Byte Order,Version)
.IP \(bu 
control that lenght of data types are compatibles with the lenghts of types defined by the GoBinary specifications.
.sp 1
.bp
.IP \fBANNEXE\fP
.sp 1
.IP "\fIGOBinary Grammar\fP"
.sp 1
The following legend defines the symbols used to describe the GoBinary
grammar.
.RS
.IP "\fILegend\fP" 
.IP "<>" 
grammar word
.IP "::" 
defines symbol
.IP "*"  
zero or more occurences
.IP "|"  
alternate element
.IP "[]" 
optional elememt
.RE

.IP "\fIThe grammar :\fP"
.IP  
<GoBinary>	:: <GoHeader> <Data> <Class Table> <Index Table> <trailer>
.IP  
<GoHeader>	:: <MagicNumber> <Byte Order> <Version> <Encoding> [<UserHeader>]
.IP  
<Data>		:: <Object>   | <Data>
.IP  
<Object>	:: <Object Id> <Class Id>    <Attributes>
.IP  
<Attributes>	:: <Type Id>   <TypeValue> | <Attributes>
.IP  
<Class Table>	:: <Class Id>  <ClassName> | <Class Table>
.IP  
<Index Table>	:: <Reference of an object in the medium> | <Index Table>
.IP 
<TypeValue>	:: BUFFER | STRING | INT | BOOL | SHORT | LONG | CHAR | NUMBER | DOUBLE | VECTOR | POINT | BOX | RGB | COORDSYS | REGION | OBJECT  
.ps

The GoStream Header
.sp 1
.TS
allbox, tab(@);
lB lB lB lB
l l l l.
#bytes @Type @Variables @Valeur		
0-3 @byte @GoStream MagicNumber @0x44d474f
4 @uchar @Byte Order MSB, LSB @-
5-8 @ulong @GoStream Version @-
9 @uchar @Encoding @-
9-n @User Header @Optional @-
n+1-n+3 @ulong @Reference of class table on the medium @-
n+4-n+7 @ulong @Reference of index table on the medium @-
.TE


The user header
.sp 1
.TS
allbox, tab(@);
lB lB lB lB
l l l l.
#bytes @Type @Variables @Valeur		
0-4 @byte @Start Header @0x5548474f
4-7 @ulong @length Header @-	
8-n @byte @data @-
.TE

.bp
Data
.sp 1
The representation of each object is as follow :
.sp 1
.TS
allbox, tab(@);
lB lB lB
l l l.
#bytes @Type @Description
0-3 @ulong @Objet Id
4-7 @ulong @Class Id
8-n @- @Object attributes
.TE


The representation of each attribute is as follow :
.sp 1
.TS
allbox, tab(@);
lB lB lB
l l l.
#bytes @Type @Description
0 @uchar @Type Id
n @- @Type Value
.TE

.sp 1
The following sections describe structures/values datas for each predefined GoBinary type.
  
OBJECT
.sp 1
.TS
allbox, tab(@);
lB lB lB
l l l.
#bytes @Type @Description
0-3 @ulong @Object id 
.TE


BUFFER
.sp 1
.TS
allbox, tab(@);
lB lB lB
l l l.
#bytes @Type @Description
0-3 @ulong @lenght
4-n @char @data
.TE

   
STRING
.sp 1
.TS
allbox, tab(@);
lB lB lB
l l l.
#bytes @Type @Description
0-3 @ulong @lenght of string
4-n @char @-		
.TE


INT
.sp 1
.TS
allbox, tab(@);
lB lB lB
l l l.
#bytes @Type @Description
0-3 @int @-
.TE

.bp
BOOL
.sp 1
.TS
allbox, tab(@);
lB lB lB
l l l.
#bytes @Type @Description
0 @char @-
.TE


SHORT
.sp 1
.TS
allbox, tab(@);
lB lB lB
l l l.
#bytes @Type @Description
0-1 @short @-
.TE


LONG
.sp 1
.TS
allbox, tab(@);
lB lB lB
l l l.
#bytes @Type @Description
0-3 @long @-
.TE


CHAR
.sp 1
.TS
allbox, tab(@);
lB lB lB
l l l.
#bytes @Type @Description
0 @char @-
.TE


NUMBER
.sp 1
.TS
allbox, tab(@);
lB lB lB
l l l.
#bytes @Type @Description
0 @float @-
.TE


DOUBLE
.sp 1
.TS
allbox, tab(@);
lB lB lB
l l l.
#bytes @Type @Description
0-7 @double @-
.TE 


VECTOR
.sp 1
.TS
allbox, tab(@);
lB lB lB
l l l.
#bytes @Type @Description
0-3 @float @x
4-7 @float @y
.TE


POINT
.sp 1
.TS
allbox, tab(@);
lB lB lB
l l l.
#bytes @Type @Description
0-3 @float @coord x
4-7 @float @coord y
.TE
.bp

BOX
.sp 1
.TS
allbox, tab(@);
lB lB lB
l l l.
#bytes @Type @Description
0-3 @float @box xmin
3-6 @float @box ymin
7-10 @float @box xmax
11-14 @float @box ymax
.TE


RGB
.sp 1
.TS
allbox, tab(@);
lB lB lB
l l l.
#bytes @Type @Description
0-1 @unsigned short @first  color
2-3 @unsigned short @second color
4-5 @unsigned short @last   color
.TE


COORDSYS
.sp 1
.TS
allbox, tab(@);
lB lB lB
l l l.
#bytes @Type @Description
0 -3 @float @origin  x
4 -6 @float @origin  y
7 -10 @float @x point I
11-14 @float @y point I
15-18 @float @x point J
19-22 @float @y point J
.TE


ClASS TABLE
.sp 1
The class table is a list of structure as follow :
.sp 1
.TS
allbox, tab(@);
lB lB lB
l l l.
#bytes @Type @Variables
0-3 @ulong @Class Id
4 @uchar @lenght Class Name
n-n' @char @Class name		
.TE


INDEX TABLE
.sp 1
The index table is a list of references :
.sp 1 
.TS
allbox, tab(@);
lB lB lB
l l l.
#bytes @Type @Variables
0-3 @ulong @Reference	
.. @ulong @.....		
n-n+3 @ulong @Reference of last object
n+4-n+7 @ulong @Reference of Class table
.TE
.RE
.bp
.SH
\fBUSAGE INFORMATION\fP
.IP
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBGoStream\fP, \fBMedium\fP classes.
.nrPN \n%
