.\" $Id: GoInDisp.n,v 1.1 1992/07/20 07:33:05 smadja Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH InputDispatcher 3Go "June 1992" "Version 1.2" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBInputDispatcher\fP \(em the input dispatcher object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/GoInDisp.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBInputDispatcher\fP does not inherit behavior from any class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBInputDispatcher\fP object allows to distribute \fIevents\fP. The definition of incoming events is the role of a sub class of \fBInputDispatcher\fP. It allows also to set \fItimer\fP and \fIprocedure\fP to call if there is no incoming \fIevents\fP left in the input queue.
.br
The \fBInputDispatcher\fP must be subclasses. It is an abstract class.
.sp 1
\fBGoInputDispatcher\fP is the C++ type for the \fIInputDispatcher\fP object class.
.sp 1
.nf
.ta .15i .25i 1.0i

typedef enum { GIDLE_AGAIN, GIDLE_AFTER_NEXTEVENT, GIDLE_REMOVE } GIdle;

typedef GIdle (*GInDispIdleProc)(void* \fIclosure\fP);
typedef void  (*GInDispTimerProc)(void* \fIclosure\fP);
typedef GBool (*GInDispFilterProc)(void* \fIclosure\fP, void* \fIevent\fP);

class GoInputDispatcher {
	public:
		~GoInputDispatcher();

		void idleProc(GInDispIdleProc \fIproc\fP, void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) = 0;
		void timerProc(GInDispTimerProc \fIproc\fP, void* \fIclosure\fP, ulong \fIinterval\fP, GAddOrRemove \fIadd\fP = GADD) = 0;
		void filterProc(GInDispFilterProc \fIproc\fP, void* \fIclosure\fP, GAddOrRemove \fIadd\fP); = 0;

		GBool eventReady() = 0;
		void  handleNextEvent() = 0;
		void* runEventLoop() = 0;
		void  stopEventLoop(void* \fIreturn_value\fP);
};

extern GoInputDispatcher* goInputDispatcher;
.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
\fBGoInputDispatcher\fP();
.RS .8i
.IP \fIDescription\fP .5i
The constructor is not provided in public because GoInputDispatcher is an abstract class.
.RE
.sp 1
.IP
\fB~GoInputDispatcher\fP();
.RS .8i
.IP \fIDescription\fP .5i
This method is called when an \fIInputDispatcher\fP instance is deleted.
.RE
.sp 1
.IP
void \fBidleProc\fP(GInDispIdleProc \fIproc\fP, void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) = 0;
.RS .8i
.IP \fIDescription\fP .5i
The method \fIadds\fP or \fIremoves\fP the couple (\fIproc,closure\fP) to the input dispatcher idle procedure list. An \fIidleProc\fP is called if there is no  incoming \fIevents\fP left in the input queue. see \fBrunEventLoop\fP for idle explanations.
.IP \fIproc\fP .5i
Specifies the procedure to be called.
.IP \fIclosure\fP .5i
Specifies the first parameter when \fIproc\fP is called.
.IP \fIadd\fP .5i
Specifies if you want to add or remove the couple (\fIproc,closure\fP) to list of the idle procedures.
.IP
.RE
.sp 1
.IP
void \fBtimerProc\fP(GInDispTimerProc \fIproc\fP, void* \fIclosure\fP, ulong \fIinterval\fP, GAddOrRemove \fIadd\fP = GADD) = 0;
.RS .8i
.IP \fIDescription\fP .5i
The method \fIadds\fP or \fIremoves\fP the couple (\fIproc,closure\fP) to the input dispatcher timer procedure list. An \fItimerProc\fP is called (only if \fIrunEventLoop\fP is running) when \fIinterval\fP elapses. After calling the \fItimer\fP is removed.
.IP \fIproc\fP .5i
Specifies the procedure to be called.
.IP \fIclosure\fP .5i
Specifies the first parameter when \fIproc\fP is called.
.IP \fIinterval\fP .5i
Specifies the time interval in milliseconds.
.IP \fIadd\fP .5i
Specifies if you want to add or remove the couple (\fIproc,closure\fP) to list of the timer procedures.
.IP
.RE
.sp 1
.IP
void \fBfilterProc\fP(GInDispFilterProc \fIproc\fP, void* \fIclosure\fP, GAddOrRemove \fIadd\fP);
.RS .8i
.IP \fIDescription\fP .5i
The method adds or removes the couple (\fIproc,closure\fP) to the list of filter event of the input dispatcher. A \fIfilter\fP is called on each received \fIevent\fP. See \fIrunEventLoop\fP explanations. The type of \fIproc\fP is GInDispFilterProc. The first parameter is \fIclosure\fP, the second one is an void*. The type of this void* is determined by the subclass.
.IP \fIproc\fP .5i
Specifies the procedure to be called.
.IP \fIclosure\fP .5i
Specifies the first parameter when \fIproc\fP is called.
.IP \fIadd\fP .5i
Specifies if you want to add or remove the couple (\fIproc,closure\fP) to list of the filters.
.RE
.sp 1
.IP
GBool \fBeventReady()\fP() = 0;
.RS .8i
.IP \fIDescription\fP .5i
The method returns true if an event or a timer is pending; otherwise it returns false.  Remember that event is a subclass definition.
.RE
.sp 1
.IP
void \fBhandleNextEvent()\fP = 0;
.RS .8i
.IP \fIDescription\fP .5i
The method handles the next event or timer. If no event or timer is pending it waits until an event is ready. Remember that event is a subclass definition.
.RE
.sp 1
.IP
void* \fBrunEventLoop\fP() = 0;
.RS .8i
.IP \fIDescription\fP .5i
The role of \fIrunEventLoop\fP is to handler \fItimers\fP and to dispatch incoming \fIevents\fP to event handlers. The way to define \fIevent\fP and event \fIhandlers\fP is subclass dependent. \fIrunEventLoop\fP will return the parameter of \fIstopEventLoop\fP if  \fIstopEventLoop\fP is called; otherwise it does not returns.
.br
\fIidleProc(s)\fP are called when there is no event left in the input queue. If an \fIidleProc\fP returns GIDLE_AGAIN \fIrunEventLoop\fP calls the other \fIidleProc\fP of the list and  if there is no event left in the input queue \fIrunEventLoop\fP continues to call the \fIidleProc\fP. If an \fIidleProc\fP returns GIDLE_AFTER_NEXTEVENT \fIrunEventLoop\fP waits for another available event to recall \fIidleProc\fP (when  there will be no events left in the input queue). If an \fIidleProc\fP returns GIDLE_REMOVE the function is removed from the list.
.br
\fItimerProc(s)\fP are called when \fIinterval\fP elapses. Note that the InputDispatcher class does not provide real time.
.br
\fIfilterProc(s)\fP are called on each reveived \fIevent\fP before dispatching it. If a \fIfilter\fP returns GFALSE, the corresponding \fIevent\fP will be discarded (so \fIevent\fP will not be handled); otherwise the \fIevent\fP will be dispatched. Note that \fIevent\fI is not const so it can be modified by \fIfilter\fP.
.RE
.sp 1
.IP
void \fBstopEventLoop\fP(void* \fIreturn_value\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method stops the current \fIrunEventLoop\fP if any. \fIreturn_value\fP will be returned by the \fIrunEventLoop\fP method. If \fIrunEventLoop\fP is not running, \fIstopEventLoop\fP has no effect.
.RE
.bp
.SH
\fBC BINDING\fP
.IP
.sp 1
.nf
.ta .15i .25i 1.5i
	\fI#include <Go/cGoIndisp.h>\fP

		void GoInputDispatcherIdleProc(GObjectId \fPinput_dispatcher\fP,
			GInDispIdleProc \fIprocedure\fP,
			void*           \fIclosure\fP,
			GAddOrRemove    \fIadd\fP);

		void GoInputDispatcherFilterProc(GObjectId \fPinput_dispatcher\fP,
			GInDispFilterProc \fIprocedure\fP,
			void*           \fIclosure\fP,
			GAddOrRemove    \fIadd\fP);

		void GoInputDispatcherTimerProc(GObjectId \fPinput_dispatcher\fP,
			GInDispTimerProc \fIprocedure\fP,
			void*           \fIclosure\fP,
			ulong           \fIinterval\fP,
			GAddOrRemove    \fIadd\fP);

		GBool GoInputDispatcherEventReady(GObjectId \fIinput_dispatcher\fP);

		void  GoInputDispatcherHandleNextEvent(GobjectId \fIinput_dispatcher\fP);

		void* GoInputDispatcherRunEventLoop(GObjectId \fIinput_dispatcher\fP);

		void  GoInputDispatcherStopEventLoop(GObjectId \fIinput_dispatcher\fP,
			void* \fIreturn_value\fP);

		void GoInputDispatcherDelete(GObjectId \fIinput_dispatcher\fP);
.fi
.IP \fIDescription\fP .5i
See above the corresponding C++ method.
.SH
\fBUSAGE INFORMATION\fP
.IP
.sp 1
\fIrunEventLoop\fP method has to be seen as an \fIevent_main_loop\fP, but it may returns if an event handler calls the \fIstopEventLoop\fP method.
.br
In general there is only one instance of an \fIinput dispatcher\fP inside an application.
.br
The object defines an external GLOBAL pointer \fIgoInputDispatcher\fP which can be initialized by application. If application uses object which uses \fIgoInputDispatcher\fP (see Object Documentation) application has to instancied \fIgoInputDispatcher\fP with a not abstract class (e.g XtInputDispatcher).
.sp 1
.SH
\fBSEE ALSO\fP
.IP
InputDispatcher subclasses.
.nrPN \n%
