.\" $Id: GoInterf.n,v 1.4 1993/01/05 09:35:20 smadja Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoInterf 3Go "July 1992" "Version 1.2" "Go Reference Manual"
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoInterf\fP \(em the graphic system interface class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/GoInterf.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGoInterf\fP does not inherit behavior from any class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBGoInterf\fP class is an interface for any input/output
system. The \fBGoInterf\fP is the super class for other classes implementing
specific interfaces for existing graphic systems (e.g. \fIXGoInterf\fP class
for the X Window System). The \fBGoInterf\fP class in independent of \fBGo\fP,
it can be used in an other environment.

In the following text, we will use the term \fIoutput\fP in order to speak
about the device (e.g. a window, a screen, a file, ...).

A \fBGoInterf\fP instance receives events from the user. In order to
deliver these events to the appropriate object, it has to know to function
pointer called \fIEvent Handler\fP and \fIExpose Handler\fP (events are
not necessary delivered to a \fBGoUI\fP instance).

The \fBGoInterf\fP class provides a set of \fIquery\fP methods to help
\fBGo\fP instances or other kind of objects in their clip and contains computation.

It also is possible to get a \fBShPixelArray\fP corresponding to a rectangular
area of the \fIoutput\fP. The rectangular area may be masked.
.sp 1
.nf
.ta .15i .25i 1.0i
Class GoInterf {
	public:
		~GoInterf ();
    
		virtual void map();
		virtual void unmap();
		virtual void flush();
		virtual void synchronize (GBool \fIdiscard\fP);

		void    setClip (const GRegion& region);
		void    resetClip ();

		// \fBOutput methods:\fP

		virtual void clear (const GRegion& \fIregion\fP) =0;

		virtual void line (const GShPen* \fIshpen\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIp1\fP, const GPoint& \fIp2\fP, GQuality \fIquality\fP = GMAX_QUALITY);
		void line (const GPen* \fIpen\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIp1\fP, const GPoint& \fIp2\fP, GQuality \fIquality\fP = GMAX_QUALITY);

		virtual void polyline (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
			int \fInpoint\fP, const GPoint* \fIpoints\fP, GQuality \fIquality\fP = GMAX_QUALITY) =0;
		void polyline (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			int \fInpoint\fP, const GPoint* \fIpoints\fP, GQuality \fIquality\fP = GMAX_QUALITY);

		virtual void polygon (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
			int \fInpoint\fP, const GPoint* \fIpoints\fP, GQuality \fIquality\fP = GMAX_QUALITY) =0;
		void polygon (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			int \fInpoint\fP, const GPoint* \fIpoints\fP, GQuality \fIquality\fP = GMAX_QUALITY);

		virtual void rectangle (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIposition\fP, GNumber \fIwidth\fP, GNumber \fIheight\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);
		void rectangle (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIposition\fP, GNumber \fIwidth\fP, GNumber \fIheight\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);

		virtual void ellipse (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
			GNumber \fIangle1\fP = 0, GNumber \fIangle2\fP = 2*PI, GQuality \fIquality\fP = GMAX_QUALITY);
		void ellipse (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
			GNumber \fIangle1\fP = 0, GNumber \fIangle2\fP = 2*PI, GQuality \fIquality\fP = GMAX_QUALITY);

		virtual void ellipseChord (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
			GNumber \fIangle1\fP, GNumber \fIangle2\fP, GQuality \fIquality\fP = GMAX_QUALITY);
		void ellipseChord (const Pen* \fIpen\fP, const Brush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
			GNumber \fIangle1\fP, GNumber \fIangle2\fP, GQuality \fIquality\fP = GMAX_QUALITY);

		virtual void ellipsePie (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
			GNumber \fIangle1\fP, GNumber \fIangle2\fP, GQuality \fIquality\fP = GMAX_QUALITY);
		void ellipsePie (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
			GNumber \fIangle1\fP, GNumber \fIangle2\fP, GQuality \fIquality\fP = GMAX_QUALITY);

		virtual void circle (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& center, GNumber \fIradius\fP,
			GNumber \fIangle1\fP = 0, GNumber \fIangle2\fP = 2*PI, GQuality \fIquality\fP = GMAX_QUALITY);
		void circle (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& center, GNumber \fIradius\fP,
			GNumber \fIangle1\fP = 0, GNumber \fIangle2\fP = 2*PI, GQuality \fIquality\fP = GMAX_QUALITY);

		virtual void circleChord (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& center, GNumber \fIradius\fP,
			GNumber \fIangle1\fP, GNumber \fIangle2\fP, GQuality \fIquality\fP = GMAX_QUALITY);
		void circleChord (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& center, GNumber \fIradius\fP,
			GNumber \fIangle1\fP, GNumber \fIangle2\fP, GQuality \fIquality\fP = GMAX_QUALITY);

		virtual void circlePie (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& center, GNumber \fIradius\fP,
			GNumber \fIangle1\fP, GNumber \fIangle2\fP, GQuality \fIquality\fP = GMAX_QUALITY);
		void circlePie (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& center, GNumber \fIradius\fP,
			GNumber \fIangle1\fP, GNumber \fIangle2\fP, GQuality \fIquality\fP = GMAX_QUALITY);

		virtual void bezier (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
			int \fInpoint\fP, const GPoint* \fIpoints\fP, GQuality \fIquality\fP = GMAX_QUALITY);
		void bezier (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			int \fInpoint\fP, const GPoint* \fIpoints\fP, GQuality \fIquality\fP = GMAX_QUALITY);

		virtual void cubicCurve (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
			int \fInpoint\fP, const GPoint* \fIpoints\fP,
			GNumber \fIbasisMatrix\fP[4][4], int \fIeval_shift\fP = 1, GQuality \fIquality\fP = GMAX_QUALITY);
		void cubicCurve (const PPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			int \fInpoint\fP, const GPoint* \fIpoints\fP,
			GNumber \fIbasisMatrix\fP[4][4], int \fIeval_shift\fP = 1, GQuality \fIquality\fP = GMAX_QUALITY);


		virtual void string (const GShTextBrush* \fIshtbrush\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIposition\fP, GNumber \fIheight\fP,
			int \fInchar\fP, const char* \fIstring\fP, GQuality \fIquality\fP = GMAX_QUALITY) =0;
		void string (const GTextBrush* \fItbrush\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIposition\fP, GNumber \fIheight\fP,
			int \fInchar\fP, const char* \fIstring\fP, GQuality \fIquality\fP = GMAX_QUALITY);

		virtual void image (const GShImageBrush* \fIshibrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIposition\fP, GNumber \fIwidth\fP, GNumber \fIheight\fP,
			const GShPixelArray* \fIshpixel_array\fP, GQuality \fIquality\fP = GMAX_QUALITY) =0;
		void image (const GImageBrush* \fIibrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIposition\fP, GNumber \fIwidth\fP, GNumber \fIheight\fP,
			const GPixelArray* \fIpixel_array\fP, GQuality \fIquality\fP = GMAX_QUALITY);


		// \fBPostcond management:\fP
		void exposePostcond (void \fIproc\fP(void*, GoInterf*, const GExposeEvent*),
			const void* \fIclosure\fP, GAddOrremove \fIadd\fP= GADD) const;
		void eventPostcond (void \fIproc\fP(void*, GoInterf*, const GEvent*),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void destroyPostcond (void \fIproc\fP(void*, GoInterf*), const void* \fIclosure\fP,
			GAddOrRemove \fIadd\fP = GADD) const;
		void resizePostcond (void \fIproc\fP(void*, GoInterf*), const void* \fIclosure\fP,
			GAddOrRemove \fIadd\fP = GADD) const;

		// \fBInput Methods:\fP

		virtual GPoint getPointer (const GCoordSys* \fIcs\fP = NULL) const =0;
		virtual void setPointer (const GPoint& \fIposition\fP, const GCoordSys* \fIcs\fP = NULL) =0;

		void* grab (GGrabProc \fIprocedure\fP, void* \fIclosure\fP, GEventMask \fIinput_mask\fP =
			GBUTTON_PRESS_MASK | GBUTTON_RELEASE_MASK | GCHAR_MASK |
			GFUNCTION_KEY_MASK | GCOMPRESS_MOTION_MASK);
		GBool stopGrab (void* \fIgrab_value\fP);

		virtual void addInputMask (GEventMask \fImask\fP);
		virtual void removeInputMask (GEventMask \fImask\fP);

		GBool   captureEvent(GEventMask \fIinput_mask\fP, GBool \fIconfined\fP,
			GTimeStamp \fIreference\fP = GCURRENT_TIME) = 0;
		void    unCaptureEvent(GTimeStamp \fIreference\fP) = 0;

                GEventMask inputMask () const;
		virtual ulong inputFd() =0;

		virtual void handle (GEvent* \fIevent\fP);

		// \fBDevice Query Methods:\fP

		GNumber width () const;
		GNumber height () const;
		virtual GNumber  pixelWidth () const =0;
		virtual GNumber  pixelHeight () const =0;
		int toPixelWidth (GNumber \fImm\fP) const;
		int toPixelHeight (GNumber \fImm\fP) const;
		ushort depth () const;
		const GColor* background () const;
		virtual GShColor* colorFromName(const char* color_name) const =0;

		// \fBDevice Setting Methods:\fP

		virtual void resize (GNumber \fIwidth\fP, GNumber \fIheight\fP);
		virtual void background (const class GShColor* \fIshcolor\fP);
		void background (const class GColor* \fIcolor\fP);

		// \fBQuery on clip, opaque_clip of drawing:\fP
	
		virtual void polylineClips (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
			int \fInpoint\fP, const GPoint* \fIpoints\fP,
			GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
			GQuality \fIquality\fP = GmaxGQuality) =0;
		void polylineClips (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			int \fInpoint\fP, const GPoint* \fIpoints\fP,
			GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
			GQuality \fIquality\fP = GmaxGQuality);

		virtual void polygonClips (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
			int \fInpoint\fP, const GPoint* \fIpoints\fP,
			GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
			GQuality \fIquality\fP = GMAX_QUALITY) =0;
		void polygonClips (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			int \fInpoint\fP, const GPoint* \fIpoints\fP,
			GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);

		virtual void rectangleClips (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIposition\fP, GNumber \fIwidth\fP, GNumber \fIheight\fP,
			GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);
		void rectangleClips (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIposition\fP, GNumber \fIwidth\fP, GNumber \fIheight\fP,
			GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);

		virtual void ellipseClips (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
			GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
			GNumber \fIangle1\fP = 0, GNumber \fIangle2\fP = 2*PI,
			GQuality \fIquality\fP = GMAX_QUALITY);
		void ellipseClips (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
			GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
			GNumber \fIangle1\fP = 0, GNumber \fIangle2\fP = 2*PI,
			GQuality \fIquality\fP = GMAX_QUALITY);
	
		virtual void ellipseChordClips (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
			GNumber \fIangle1\fP, GNumber \fIangle2\fP,
			GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);
		void ellipseChordClips (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
			GNumber \fIangle1\fP, GNumber \fIangle2\fP,
			GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);

		virtual void ellipsePieClips (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
			GNumber \fIangle1\fP, GNumber \fIangle2\fP,
			GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);
		void ellipsePieClips (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
			GNumber \fIangle1\fP, GNumber \fIangle2\fP,
			GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);

		virtual void circleClips (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& center, GNumber \fIradius\fP,
			GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
			GNumber \fIangle1\fP = 0, GNumber \fIangle2\fP = 2*PI,
			GQuality \fIquality\fP = GMAX_QUALITY);

		void circleClips (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& center, GNumber \fIradius\fP,
			GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
			GNumber \fIangle1\fP = 0, GNumber \fIangle2\fP = 2*PI,
			GQuality \fIquality\fP = GMAX_QUALITY);
	
		virtual void circleChordClips (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& center, GNumber \fIradius\fP,
			GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
			GNumber \fIangle1\fP, GNumber \fIangle2\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);
		void circleChordClips (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& center, GNumber \fIradius\fP,
			GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
			GNumber \fIangle1\fP, GNumber \fIangle2\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);

		virtual void circlePieClips (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& center, GNumber \fIradius\fP,
			GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
			GNumber \fIangle1\fP, GNumber \fIangle2\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);
		void circlePieClips (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& center, GNumber \fIradius\fP,
			GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
			GNumber \fIangle1\fP, GNumber \fIangle2\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);

		virtual void bezierClips (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
			int \fInpoint\fP, const GPoint* \fIpoints\fP,
			GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);
		void bezierClips (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			int \fInpoint\fP, const GPoint* \fIpoints\fP,
			GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);

		virtual void cubicCurveClips (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
			int \fInpoint\fP, const GPoint* \fIpoints\fP,
			GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
 			GNumber \fIbasisMatrix\fP[4][4], int \fIeval_shift\fP = 1,
 			GQuality \fIquality\fP = GMAX_QUALITY);
		void cubicCurveClips (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			int \fInpoint\fP, const GPoint* \fIpoints\fP,
			GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
 			GNumber \fIbasisMatrix\fP[4][4], int \fIeval_shift\fP = 1,
 			GQuality \fIquality\fP = GMAX_QUALITY);


		virtual void stringClips (const GShTextBrush* \fIshtbrush\fP, const GShBrush* \fIshbrush\fP,
			const GCoordSys& \fIcs\fP, const GPoint& \fIposition\fP, GNumber \fIheight\fP,
			int \fInchar\fP, const char* \fIstring\fP,
			GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
			GQuality \fIquality\fP = GMAX_QUALITY) =0;
		void stringClips (const GTextBrush* \fItbrush\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIposition\fP, GNumber \fIheight\fP,
			int \fInchar\fP, const char* \fIstring\fP,
			GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);

		virtual void imageClips (const GShImageBrush* \fIshibrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIposition\fP, GNumber \fIwidth\fP, GNumber \fIheight\fP,
			GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
			GQuality \fIquality\fP = GMAX_QUALITY) =0;
		void imageClips (const GImageBrush* \fIibrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIposition\fP, GNumber \fIwidth\fP, GNumber \fIheight\fP,
			GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
			GQuality \fIquality\fP = GMAX_QUALITY) =0;

	
		// \fBQuery contains information:\fP
	
		virtual GBool polylineContains (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP,
			const GCoordSys& \fIcs\fP, int \fInpoint\fP, const GPoint* \fIpoints\fP,
			const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
			GQuality \fIquality\fP = GMAX_QUALITY) =0;
		GBool polylineContains (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP,
			const GCoordSys& \fIcs\fP, int \fInpoint\fP, const GPoint* \fIpoints\fP,
			const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);

		virtual GBool polygonContains (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP,
			const GCoordSys& \fIcs\fP, int \fInpoint\fP, const GPoint* \fIpoints\fP,
			const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
			GQuality \fIquality\fP = GMAX_QUALITY) =0;
		GBool polygonContains (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP,
			const GCoordSys& \fIcs\fP, int \fInpoint\fP, const GPoint* \fIpoints\fP,
			const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);

		virtual GBool rectangleContains (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP,
			const GCoordSys& \fIcs\fP, const GPoint& \fIposition\fP,
			GNumber \fIwidth\fP, GNumber \fIheight\fP, const GPoint& \fIabsolute_pos\fP,
			GNumber \fImax_distance\fP, GQuality \fIquality\fP = GMAX_QUALITY);
		GBool rectangleContains (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP,
			const GCoordSys& \fIcs\fP, const GPoint& \fIposition\fP, GNumber \fIwidth\fP,
			GNumber \fIheight\fP, const GPoint& \fIabsolute_pos\fP,
			GNumber \fImax_distance\fP, GQuality \fIquality\fP = GMAX_QUALITY);

		virtual GBool ellipseContains (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
			const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
			GNumber \fIangle1\fP = 0, GNumber \fIangle2\fP = 2*PI,
			GQuality \fIquality\fP = GMAX_QUALITY);
		GBool ellipseContains (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
			const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
			GNumber \fIangle1\fP = 0, GNumber \fIangle2\fP = 2*PI,
			GQuality \fIquality\fP = GMAX_QUALITY);
	
		virtual GBool ellipseChordContains (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP,
			const GCoordSys& \fIcs\fP,
			const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP,
			GNumber \fIradiusY\fP, GNumber \fIangle1\fP, GNumber \fIangle2\fP,
			const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);
		GBool ellipseChordContains (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
			GNumber \fIangle1\fP, GNumber \fIangle2\fP,
			const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);

		virtual GBool ellipsePieContains (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP,
			const GCoordSys& \fIcs\fP,
			const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
			GNumber \fIangle1\fP, GNumber \fIangle2\fP,
			const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);
		GBool ellipsePieContains (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
			GNumber \fIangle1\fP, GNumber \fIangle2\fP,
			const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);

		virtual GBool circleContains (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& center, GNumber \fIradius\fP,
			GNumber \fIangle1\fP = 0, GNumber \fIangle2\fP = 2*PI,
			const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);
		GBool circleContains (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& center, GNumber \fIradius\fP,
			GNumber \fIangle1\fP = 0, GNumber \fIangle2\fP = 2*PI,
			const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);
	
		virtual GBool circleChordContains (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP,
			const GCoordSys& \fIcs\fP,
			const GPoint& center, GNumber \fIradius\fP,
			const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
			GNumber \fIangle1\fP, GNumber \fIangle2\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);
		GBool circleChordContains (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& center, GNumber \fIradius\fP,
			const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
			GNumber \fIangle1\fP, GNumber \fIangle2\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);

		virtual GBool circlePieContains (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP,
			const GCoordSys& \fIcs\fP,
			const GPoint& center, GNumber \fIradius\fP,
			const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
			GNumber \fIangle1\fP, GNumber \fIangle2\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);
		GBool circlePieContains (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& center, GNumber \fIradius\fP,
			const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
			GNumber \fIangle1\fP, GNumber \fIangle2\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);

		virtual GBool bezierContains (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP,
			const GCoordSys& \fIcs\fP,
			int \fInpoint\fP, const GPoint* \fIpoints\fP,
			const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);
		GBool bezierContains (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			int \fInpoint\fP, const GPoint* \fIpoints\fP,
			const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);

		virtual GBool cubicCurveContains (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP,
			const GCoordSys& \fIcs\fP,
			int \fInpoint\fP, const GPoint* \fIpoints\fP,
			const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
			GNumber \fIbasisMatrix\fP[4][4], int \fIeval_shift\fP = 1,
			GQuality \fIquality\fP = GMAX_QUALITY);
		GBool cubicCurveContains (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			int \fInpoint\fP, const GPoint* \fIpoints\fP,
			const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
			GNumber \fIbasisMatrix\fP[4][4], int \fIeval_shift\fP = 1,
			GQuality \fIquality\fP = GMAX_QUALITY);


		virtual GBool stringContains (const GShTextBrush* \fIshtbrush\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIposition\fP, GNumber \fIheight\fP,
			int \fInchar\fP, const char* \fIstring\fP,
			const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
			GQuality \fIquality\fP = GMAX_QUALITY) =0;
		GBool stringContains (const GTextBrush* \fItbrush\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIposition\fP, GNumber \fIheight\fP,
			int \fInchar\fP, const char* \fIstring\fP,
			const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);

		virtual GBool imageContains (const GShImageBrush* \fIibrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIposition\fP, GNumber \fIwidth\fP, GNumber \fIheight\fP,
			const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
			GQuality \fIquality\fP = GMAX_QUALITY) =0;
		GBool imageContains (const GImageBrush* \fIibrush\fP, const GCoordSys& \fIcs\fP,
			const GPoint& \fIposition\fP, GNumber \fIwidth\fP, GNumber \fIheight\fP,
			const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
			GQuality \fIquality\fP = GMAX_QUALITY);

	
		// \fBQuery on Font objects:\fP

		virtual GNumber stringLeftBearing (const char* \fIstring\fP, int \fInchar\fP,
			GNumber \fIheight\fP, const GShFont* \fIshfont\fP) =0;	
		GNumber stringLeftBearing (const char* \fIstring\fP, int \fInchar\fP,
			GNumber \fIheight\fP, const GFont* \fIfont\fP);

		virtual GNumber stringRightBearing (const char* \fIstring\fP, int \fInchar\fP,
			GNumber \fIheight\fP, const GShFont* \fIshfont\fP) =0;
		GNumber  stringRightBearing (const char* \fIstring\fP, int \fInchar\fP,
 			GNumber \fIheight\fP, const GFont* \fIfont\fP);

		virtual GNumber stringAscent (const char* \fIstring\fP, int \fInchar\fP,
			GNumber \fIheight\fP, const GShFont* \fIshfont\fP) =0;
		GNumber stringAscent (const char* \fIstring\fP, int \fInchar\fP,
			GNumber \fIheight\fP, const GFont* \fIfont\fP);

		virtual GNumber stringDescent (const char* \fIstring\fP, int \fInchar\fP,
 			GNumber \fIheight\fP, const GShFont* \fIshfont\fP) =0;
		GNumber stringDescent (const char* \fIstring\fP, int \fInchar\fP,
			GNumber \fIheight\fP, const GFont* \fIfont\fP);

		virtual GNumber stringWidth (const char* \fIstring\fP, int \fInchar\fP,
			GNumber \fIheight\fP, const GShFont* \fIshfont\fP) =0;
		GNumber stringWidth (const char* \fIstring\fP, int \fInchar\fP,
			GNumber \fIheight\fP, const GFont* \fIfont\fP);

		virtual GNumber fontAscent (GNumber \fIheight\fP, GShFont* \fIshfont\fP) =0;
		GNumber fontAscent (GNumber \fIheight\fP, const GFont* \fIfont\fP);

		virtual GNumber fontDescent (GNumber \fIheight\fP, const GShFont* \fIshfont\fP) =0;
		GNumber fontDescent (GNumber \fIheight\fP, const GFont* \fIfont\fP);

		virtual GNumber fontUnderlineThickness (GNumber \fIheight\fP, const GShFont* \fIshfont\fP) =0;
		GNumber fontUnderlineThickness (GNumber \fIheight\fP, const GFont* \fIfont\fP);

		virtual GNumber fontUnderlinePosition (GNumber \fIheight\fP, const GShFont* \fIshfont\fP) =0;
		GNumber fontUnderlinePosition (GNumber \fIheight\fP, const GFont* \fIfont\fP);

		virtual GNumber fontItalicAngle (GNumber \fIheight\fP, const GShFont* \fIshfont\fP) =0;
		GNumber fontItalicAngle (GNumber \fIheight\fP, const GFont* \fIfont\fP);

		virtual GNumber fontStrikeoutAscent (GNumber \fIheight\fP, GShFont* \fIshfont\fP) =0;
		GNumber fontStrikeoutAscent (GNumber \fIheight\fP, const GFont* \fIfont\fP);

		virtual GNumber fontStrikeoutDescent (GNumber \fIheight\fP, const GShFont* \fIshfont\fP) =0;
		GNumber fontStrikeoutDescent (GNumber \fIheight\fP, const GFont* \fIfont\fP);

		virtual GNumber fontMinSpace (GNumber \fIheight\fP, const GShFont* \fIshfont\fP) =0;
		GNumber fontMinSpace (GNumber \fIheight\fP, const GFont* \fIfont\fP);

		virtual GNumber fontMaxSpace (GNumber \fIheight\fP, const GShFont* \fIshfont\fP) =0;
		GNumber fontMaxSpace (GNumber \fIheight\fP, const GFont* \fIfont\fP);

		virtual GNumber fontNormSpace (GNumber \fIheight\fP, const GShFont* \fIshfont\fP) =0;
		GNumber fontNormSpace (GNumber \fIheight\fP, const GFont* \fIfont\fP);

		virtual GNumber fontEndSpace (GNumber \fIheight\fP, const GShFont* \fIshfont\fP) =0;
		GNumber fontEndSpace (GNumber \fIheight\fP, const GFont* \fIfont\fP);

		virtual const char* fontName (const GCoordSys& \fIcs\fP, GNumber \fIheight\fP,
			const GShFont* \fIshfont\fP) =0;
		const char* fontName (const GCoordSys& \fIcs\fP, GNumber \fIheight\fP,
			const GFont* \fIfont\fP);



		// \fBImage:\fP

		virtual void getImage (GImageBrushValues& \fIimagebrush_result\fP,
			GPixelArrayValues& \fIpixelarray_result\fP,
			const GCoordSys& \fIcs\fP, const GPoint& \fIorigin\fP,
			GNumber \fIwidth\fP, GNumber \fIheight\fP,
			ushort \fIdepth\fP = 0, GBool \fIcompress_colormap\fP = GTRUE,
			ushort \fIx_resolution\fP = 0, ushort \fIy_resolution\fP = 0,
			GQuality \fIquality\fP = GMAX_QUALITY) =0;

		// \fBCursors:\fP
	    
		virtual void pushCursor(long \fIcursorIdent\fP);
		virtual void pushCursor(const GCursor* \fIcursor\fP);
		virtual void pushCursor(const GShCursor* \fIshcursor\fP);
		virtual void popCursor();

		// \fBBell:\fP;
		virtual void bell(int \fIpercent\fP);
};
\fR

typedef void (*GrabProc)(void* closure, const GEvent&, const GPoint& first,
		const GPoint& prev, const GPoint& current);

.fi
.sp 1
.SH
\fBQUALITY DEFINITIONS\fP
.IP
The \fIquality\fP parameter of the drawing functions
specifies what should be the quality of the graphic request result.
.sp 1
Quality is \fIsubjective\fP, only the \fIGMIN_QUALITY\fP is defined.
.sp 1
.nf
.ta .25i 1.0i 2.0i 3.0i
	typedef	uchar	GQuality;

	#define	GMIN_QUALITY	0
	#define	GBAD_QUALITY	1
	#define	GMEDIUM_QUALITY	2
	#define	GGOOD_QUALITY	3
	#define	GMAX_QUALITY	4
	#define	GN_QUALITY	5
.fi
.sp 1
.RS .8i
.IP \fBGMIN_QUALITY\fP .5i
Specifies that \fIfilling\fP, \fIpatterning\fP and \fIdashing\fP should be ignored. The
line width should be the thinest line that can be rendered on the device. For
texts and images only the outer box should be drawn.
.RE
.sp 1
.SH
\fBCURSOR DEFINITIONS\fP
.IP
The set of cursor shapes are predefined:
.sp 1
.nf
.ta .25i 1.0i 2.0i 3.0i
	#define GCURSOR_DEFAULT		0
	#define GCURSOR_CROSS		1
	#define GCURSOR_CROSSHAIR	2
	#define GCURSOR_ARROW		3
	#define GCURSOR_ARROW_NS	4
	#define GCURSOR_ARROW_WE	5
	#define GCURSOR_WAIT		6
.fi
.sp 1
.SH
\fBGLOBAL DECLARATION\fP
.IP \fBinputDispatcher\fP .5i
.br
The GoInterf library declares an external \fBinputDispatcher\fP object. This object
may be used by application if it needs it. Note that the \fBInputDispatcher\fP object
needs an operating system dependent function \fIWaitEventProc\fP.
See \fIInDisp(3Go)\fP for details.
.RE
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
\fB~GoInterf\fP ();
.RS .8i
.IP \fIDescription:\fP .5i
This method is called when an instance of the \fBGoInterf\fP class is deleted.
.RE
.sp 1
.IP
void \fBmap\fP ();
.RS .8i
.IP \fIDescription:\fP .5i
This method allows to enable output/input functions.
.RE
.sp1
.IP
void \fBunmap\fP ();
.RS .8i
.IP \fIDescription:\fP .5i
This method allows to disable output/input functions. Query methods are
still usable. When created, a \fBGoInterf\fP instance is unmapped.
.RE
.sp1
.IP
void \fBflush\fP ();
.RS .8i
.IP \fIDescription:\fP .5i
This method allows to flush the output buffers of the \fBGoInterf\fP.
This function may be unuseful on some output devices.
.RE
.sp1
.IP
void \fBsynchronize\fP (GBool \fIdiscard\fP);
.RS .8i
.IP \fIDescription:\fP .5i
This method flushes all requests of the interface, then waits until all events resulting from previous calls have been received and processed by the interface. Events are paced on the input queue.
.IP \fIdiscard\fP .5i
.br
If GTRUE, \fIdiscards all events on the input queue (including those events that were on the input queue before \fIsynchronize\fP is called).
.RE
.sp 1
.IP
void \fBsetClip\fP (const GRegion& \fIregion\fP);
.br
void \fBresetClip\fP ();
.RS .8i
.IP \fIDescription:\fP .5i
This method allows to define the current output clip region. If \fIresetClip\fP
method is used, the clip region becomes the output size (ie. the window
size in a window system).
.IP \fIregion\fP .5i
.br
Specifies the region used as a clipping region in the \fBGoInterf\fP object.
.RE
.sp 1
.IP
void \fBclear\fP (const GRegion& \fIregion\fP);
.RS .8i
.IP \fIDescription:\fP .5i
This method allows to fill a region of the output (which is the intersection
of \fIregion\fP and the current clipping region) with the background color
of the output.
.IP \fIregion\fP .5i
.br
Specifies the region of the output which is going to be filled. The region
is expressed in the absolute coordinate system.
.RE
.sp 1
.IP
.nf
void \fBline\fP (const GShPen* \fIshpen\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIp1\fP, const GPoint& \fIp2\fP, GQuality \fIquality\fP = GMAX_QUALITY);
void \fBline\fP (const GPen* \fIpen\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIp1\fP, const GPoint& \fIp2\fP, GQuality \fIquality\fP = GMAX_QUALITY);
.fi
.RS .8i
.IP \fIDescription:\fP .5i
This method allows to draw a line.
.IP "\fIshpen, pen\fP" .5i
.br
Specifies the output attributes which will be used to draw the line (see \fIShPen(3Go), Pen(3Go)\fP).
.IP \fIcs\fP .5i
.br
Specifies the coordinate system in which line ends (points) are expressed.
.IP "\fIp1, p2\fP" .5i
.br
Specify the line ends.
.IP \fIquality\fP .5i
Specifies the drawing quality. Possible values are \fIGMIN_QUALITY, GBAD_QUALITY, GMEDIUM_QUALITY,
GGOOD_QUALITY, GMAX_QUALITY\fP (see also \fIGoInterf\fP subclasses).
.RE
.sp 1
.IP
.nf
void \fBpolyline\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	int \fInpoint\fP, const GPoint* \fIpoints\fP, GQuality \fIquality\fP = GMAX_QUALITY);
void \fBpolyline\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	int \fInpoint\fP, const GPoint* \fIpoints\fP, GQuality \fIquality\fP = GMAX_QUALITY);
.fi
.RS .8i
.IP \fIDescription:\fP .5i
This method allows to draw a polyline.
.IP "\fIshpen, pen\fP" .5i
.br
If non NULL \fIshpen\fP or \fIpen\fP specify the output attributes which will be used to draw
the polyline (see \fIShPen(3Go)\fP or\fIPen(3Go)\fP), Else the outline is not drawn.
.IP "\fIshbrush, brush\fP" .5i
.br
if non NULL, \fIshbrush\fP or \fIbrush\fP specifiy the output attributes which will be used
to draw the filled polygon (see \fIShBrush(3Go)\fP or \fIBrush(3Go)\fP) else the polyline will
not be filled.
.IP \fIcs\fP .5i
.br
Specifies the coordinate system in which the control points are expressed.
.IP \fInpoint\fP .5i
Specifies the control point number of the polyline.
.IP \fIpoints\fP .5i
.br
Specifies the control points of the polyline.
.IP \fIquality\fP .5i
Specifies the drawing quality. Possible values are \fIGMIN_QUALITY, GBAD_QUALITY, GMEDIUM_QUALITY,
GGOOD_QUALITY, GMAX_QUALITY\fP (see also \fIGoInterf\fP subclasses).
.RE
.sp 1
.IP
.nf
void \fBpolygon\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	int \fInpoint\fP, const GPoint* \fIpoints\fP, GQuality \fIquality\fP = GMAX_QUALITY);
void \fBpolygon\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	int \fInpoint\fP, const GPoint* \fIpoints\fP, GQuality \fIquality\fP = GMAX_QUALITY);
.fi
.RS .8i
.IP \fIDescription:\fP
This method allows to draw a polygon (closed polygon).
.IP "\fIshpen, pen\fP" .5i
.br
If non NULL, \fIshpen\fP or \fIpen\fP specify the output attributes which will be used to draw
the polygon outline (see \fIShPen(3Go)\fP or \fIPen(3Go)\fP); else no outline will be displayed.
.IP "\fIshbrush, brush\fP" .5i
.br
if non NULL, \fIshbrush\fP or \fIbrush\fP specify the output attributes which will be used
to draw the filled polygon (see \fIShBrush(3Go)\fP or \fIBrush(3Go)\fP);
else the polygon will not be filled.
.IP \fIcs\fP .5i
.br
Specifies the coordinate system in which the control points are expressed.
.IP \fInpoint\fP .5i
Specifies the control point number of the polygon.
.IP \fIpoints\fP .5i
.br
Specifies the control points of the polygon (the first and the last point
are different).
.IP \fIquality\fP .5i
Specifies the drawing quality. Possible values are \fIGMIN_QUALITY, GBAD_QUALITY, GMEDIUM_QUALITY,
GGOOD_QUALITY, GMAX_QUALITY\fP (see also \fIGoInterf\fP subclasses).
.RE
.sp 1
.IP
.nf
void \fBrectangle\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIposition\fP, GNumber \fIwidth\fP, GNumber \fIheight\fP, GQuality \fIquality\fP = GMAX_QUALITY);
void \fBrectangle\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIposition\fP, GNumber \fIwidth\fP, GNumber \fIheight\fP, GQuality \fIquality\fP = GMAX_QUALITY);
.fi
.RS .8i
.IP \fIDescription:\fP .5i
This method allows to draw a rectangle.
.IP "\fIshpen, pen\fP" .5i
If non NULL, \fIshpen\fP or \fIpen\fP specify the output attributes which will be used to
draw the rectangle outline (see \fIShPen(3Go)\fP or \fIPen(3Go)\fP); else no outline will be displayed.
.IP "\fIshbrush, brush\fP" .5i
.br
If non NULL, \Ishbrush\fP or \fIbrush\fP specify the output attributes which will be
used to draw the filled rectangle (see \fIShBrush(3Go)\fP or \fIBrush(3Go)\fP);
else the rectangle will not be filled.
.IP \fIcs\fP .5i
.br
Specifies the coordinate system in which the position, the width and the
height are expressed.
.IP \fIposition\fP .5i
.br
Specifies the rectangle origin.
.IP "\fIwidth, height\fP" .5i
.br
Specify the rectangle size.
.IP \fIquality\fP .5i
Specifies the drawing quality. Possible values are \fIGMIN_QUALITY, GBAD_QUALITY, GMEDIUM_QUALITY,
GGOOD_QUALITY, GMAX_QUALITY\fP (see also \fIGoInterf\fP subclasses).
.RE
.sp 1
.IP
.nf
void \fBellipse\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
	GNumber \fIangle1\fP = 0, GNumber \fIangle2\fP = 2*PI, GQuality \fIquality\fP = GMAX_QUALITY);
void \fBellipse\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
	GNumber \fIangle1\fP = 0, GNumber \fIangle2\fP = 2*PI, GQuality \fIquality\fP = GMAX_QUALITY);

void \fBellipseChord\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
	GNumber \fIangle1\fP, GNumber \fIangle2\fP, GQuality \fIquality\fP = GMAX_QUALITY);
void \fBellipseChord\fP (const Pen* \fIpen\fP, const Brush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
	GNumber \fIangle1\fP, GNumber \fIangle2\fP, GQuality \fIquality\fP = GMAX_QUALITY);

void \fBellipsePie\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
	GNumber \fIangle1\fP, GNumber \fIangle2\fP, GQuality \fIquality\fP = GMAX_QUALITY);
void \fBellipsePie\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
	GNumber \fIangle1\fP, GNumber \fIangle2\fP, GQuality \fIquality\fP = GMAX_QUALITY);
.fi
.RS .8i
.IP \fIDescription:\fP .5i
This method allows to draw a general ellipse arc. The arc ends may be joined by using
\fIellipseChord\fP or \fIellipsePie\fP methods.
.IP "\fIshpen, pen\fP" .5i
.br
If non NULL, \fIshpen\fP or \fIpen\fP specify the output attributes which will be used to draw
the ellipse outline (see \fIShPen(3Go)\fP or \fIPen(3Go)\fP); else no outline will be displayed.
.IP "\fIshbrush, brush\fP" .5i
.br
If non NULL, \fIshbrush\fP or \fIbrush\fP specify the output attributes which will be used
to draw the filled ellipse (see \fIShBrush(3Go)\fP or \fIBrush(3Go)\fP);
else the ellipse will not be filled.
.IP \fIcs\fP .5i
.br
Specifies the coordinate system in which the position and dimensions are
expressed.
.IP \fIcenter\fP .5i
.br
Specifies the origin the X and Y vectors (the ellipse center).
.IP "\fIradiusX, radiusY\fP" .5i
.br
Specify the two radius of the full ellipse.
.IP "\fIangle1, angle2\fP"
.br
Specify which part of the ellipse is going to be drawn (the part
between angle1 and angle2). Angles are expressed in radians.
.IP \fIquality\fP .5i
Specifies the drawing quality. Possible values are \fIGMIN_QUALITY, GBAD_QUALITY, GMEDIUM_QUALITY,
GGOOD_QUALITY, GMAX_QUALITY\fP (see also \fIGoInterf\fP subclasses).
.RE
.sp 1
.IP
.nf
void \fBcircle\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& center, GNumber \fIradius\fP,
	GNumber \fIangle1\fP = 0, GNumber \fIangle2\fP = 2*PI, GQuality \fIquality\fP = GMAX_QUALITY);
void \fBcircle\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& center, GNumber \fIradius\fP,
	GNumber \fIangle1\fP = 0, GNumber \fIangle2\fP = 2*PI, GQuality \fIquality\fP = GMAX_QUALITY);

void \fBcircleChord\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& center, GNumber \fIradius\fP,
	GNumber \fIangle1\fP, GNumber \fIangle2\fP, GQuality \fIquality\fP = GMAX_QUALITY);
void \fBcircleChord\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& center, GNumber \fIradius\fP,
	GNumber \fIangle1\fP, GNumber \fIangle2\fP, GQuality \fIquality\fP = GMAX_QUALITY);

void \fBcirclePie\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& center, GNumber \fIradius\fP,
	GNumber \fIangle1\fP, GNumber \fIangle2\fP, GQuality \fIquality\fP = GMAX_QUALITY);
void \fBcirclePie\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& center, GNumber \fIradius\fP,
	GNumber \fIangle1\fP, GNumber \fIangle2\fP, GQuality \fIquality\fP = GMAX_QUALITY);
.fi
.RS .8i
.IP \fIDescription:\fP .5i
This method allows to draw a circle. The chord or the pie may drawn by using
\fIcircleChord\fP and \fIcirclePie\fP.
.IP "\fIshpen, pen\fP" .5i
.br
If non NULL, \fIshpen\fP or \fIpen\fP specify the output attributes which will be used to
draw the circle outline (see \fIShPen(3Go)\fP or \fIPen(3Go)\fP);
else no outline will be displayed.
.IP "\fIshbrush, brush\fP" .5i
.br
If non NULL, \fIshbrush\fP or \fIbrush\fP specify the output attributes which will be used
to draw the filled circle (see \fIShBrush(3Go)\fP or \fIBrush(3Go)\fP);
else the circle will not be filled.
.IP \fIcs\fP .5i
.br
Specifies the coordinate system in which the position and the size of the
circle.
.IP \fIcenter\fP .5i
.br
Specify the center position of the circle.
.IP \fIradius\fP .5i
.br
Specifies the radius size of the circle.
.IP "\fIangle1, angle2\fP" .5i
Specify which part of the circle is going to be drawn. Angles are expressed in
Radians.
.IP \fIquality\fP .5i
Specifies the drawing quality. Possible values are \fIGMIN_QUALITY, GBAD_QUALITY, GMEDIUM_QUALITY,
GGOOD_QUALITY, GMAX_QUALITY\fP (see also \fIGoInterf\fP subclasses).
.RE
.sp 1
.IP
.nf
void \fBbezier\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	int \fInpoint\fP, const GPoint* \fIpoints\fP, GQuality \fIquality\fP = GMAX_QUALITY);
void \fBbezier\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	int \fInpoint\fP, const GPoint* \fIpoints\fP, GQuality \fIquality\fP = GMAX_QUALITY);
.fi
.RS .8i
.IP \fIDescription:\fP .5i
This method allows to draw a bezier curve.
.IP \fIpen\fP .5i
.br
If non NULL, \fIshpen\fP or \fIpen\fP specify the output attributes which will be used to
draw the bezier outline (see \fIShPen(3Go)\fP or \fIPen(3Go)\fP); else no outline will be displayed.
.IP "\fIshbrush, brush\fP" .5i
.br
If non NULL, \fIshbrush\fP or \fIbrush\fP specify the output attributes which will be used to
draw the filled bezier (see \fIShBrush(3Go)\fP or \fIBrush(3Go)\fP);
else the bezier will not be filled.
.IP \fIcs\fP .5i
.br
Specifies the coordinate system in which the control points are expressed.
.IP \fInpoint\fP .5i
Specifies the control point number of the bezier curve.
.IP \fIpoints\fP .5i
.br
Specifies the control points of the bezier curve (the first and the last point
are different).
.IP \fIquality\fP .5i
Specifies the drawing quality. Possible values are \fIGMIN_QUALITY, GBAD_QUALITY, GMEDIUM_QUALITY,
GGOOD_QUALITY, GMAX_QUALITY\fP (see also \fIGoInterf\fP subclasses).
.RE
.sp 1
.IP
.nf
void \fBcubicCurve\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	int \fInpoint\fP, const GPoint* \fIpoints\fP,
	GNumber \fIbasisMatrix\fP[4][4], int \fIeval_shift\fP = 1, GQuality \fIquality\fP = GMAX_QUALITY);
void \fBcubicCurve\fP (const PPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	int \fInpoint\fP, const GPoint* \fIpoints\fP,
	GNumber \fIbasisMatrix\fP[4][4], int \fIeval_shift\fP = 1, GQuality \fIquality\fP = GMAX_QUALITY);
.fi
.RS .8i
.IP \fIDescription:\fP .5i
This method allows to draw a cubic curve (spline, beta, cardinal, tau).
.IP "\fIshpen, pen\fP" .5i
.br
If non NULL, \fIshpen\fP or \fIpen\fP specify the output attributes which will be used to
draw the cubicCurve outline (see \fIShPen(3Go)\fP or \fIPen(3Go)\fP); else no outline will be displayed.
.IP "\fIshbrush, brush\fP" .5i
.br
If non NULL, \fIshbrush\fP or \fIbrush\fP specify the output attributes which will be used to draw
the filled cubicCurve (see \fIShBrush(3Go)fP or \fIBrush(3Go)\fP);
else the cubicCurve will not be filled.
.IP \fIcs\fP .5i
.br
Specifies the coordinate system in which the control points are expressed.
.IP \fInpoint\fP .5i
Specifies the control point number of the curve.
.IP \fIpoints\fP .5i
.br
Specifies the control points of the curve (the first and the last point
are different).
.IP "\fIbasicMatrix, eval_shift\fP" .5i
Specify the curve type (spline, beta, cardinal, tau). \fIToo long to explain here\fP.
.IP \fIquality\fP .5i
Specifies the drawing quality. Possible values are \fIGMIN_QUALITY, GBAD_QUALITY, GMEDIUM_QUALITY,
GGOOD_QUALITY, GMAX_QUALITY\fP (see also \fIGoInterf\fP subclasses).
.RE
.sp 1
.IP
.nf
void \fBstring\fP (const GShTextBrush* \fIshtbrush\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIposition\fP, GNumber \fIheight\fP,
	int \fInchar\fP, const char* \fIstring\fP, GQuality \fIquality\fP = GMAX_QUALITY);
void \fBstring\fP (const GTextBrush* \fItbrush\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIposition\fP, GNumber \fIheight\fP,
	int \fInchar\fP, const char* \fIstring\fP, GQuality \fIquality\fP = GMAX_QUALITY);
.fi
.RS .8i
.IP \fIDescription:\fP .5i
This method allows to draw a character string.
.IP "\fIshtbrush, tbrush\fP" .5i
.br
Specify the output attributes which will be used to draw the string (see \fIShTextBrush(3Go)\fP
or \fITextBrush(3Go)\fP).
.IP "\fIshbrush, brush\fP" .5i
.br
If non NULL, \fIshbrush\fP or \fIbrush\fP specify the output attributes which will be used to
draw the background of the text. The background size is the clipping region  of the string
(see \fIShBrush(3Go)\fP or \fIBrush(3Go)\fP); else no background will be drawn.
.IP \fIcs\fP .5i
.br
Specifies the coordinate system in which the position and the height of the
string.
.IP \fIposition\fP .5i
.br
Specifies the position of the upper left corner of the string.
.IP \fIheight\fP .5i
.br
Specifies the height of the font.
.IP \fInchar\fP .5i
.br
Specifies the character number of the string \fIstring\fP.
.IP \fIstring\fP .5i
.br
Specifies the text itself. Special characters (new_line, tab, ...) are not
handled.
.IP \fIquality\fP .5i
Specifies the drawing quality. Possible values are \fIGMIN_QUALITY, GBAD_QUALITY, GMEDIUM_QUALITY,
GGOOD_QUALITY, GMAX_QUALITY\fP (see also \fIGoInterf\fP subclasses).
.RE
.sp 1
.IP
.nf
void \fBimage\fP (const GShImageBrush* \fIshibrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIposition\fP, GNumber \fIwidth\fP, GNumber \fIheight\fP,
	const GShPixelArray* \fIshpixel_array\fP, GQuality \fIquality\fP = GMAX_QUALITY);
void \fBimage\fP (const GImageBrush* \fIibrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIposition\fP, GNumber \fIwidth\fP, GNumber \fIheight\fP,
	const GPixelArray* \fIpixel_array\fP, GQuality \fIquality\fP = GMAX_QUALITY);
.fi
.RS .8i
.IP \fIDescription:\fP .5i
This method allows to draw an image.
.IP "\fIshibrush, ibrush\fP" .5i
.br
Specify the output attributes which will be used to draw the image (see \fIShImageBrush(3Go)\fP
or \fIImageBrush(3Go)\fP).
.IP \fIcs\fP .5i
.br
Specifies the coordinate system in which the position and the size of the
image are expressed.
.IP \fIposition\fP .5i
.br
Specifies the position of the upper left corner of the image.
.IP "\fIwidth, height\fP" .5i
.br
Specify the size of the image on the \fIoutput\fP.
.IP "\fIshpixel_array, pixel_array\fP" .5i
.br
Specify the data used as the source of the image.
.IP \fIquality\fP .5i
Specifies the drawing quality. Possible values are \fIGMIN_QUALITY, GBAD_QUALITY, GMEDIUM_QUALITY,
GGOOD_QUALITY, GMAX_QUALITY\fP (see also \fIGoInterf\fP subclasses).
.RE
.sp 2
.IP
.nf
void \fBexposePostcond\fP (void \fIproc\fP(void*, GoInterf*, const GExposeEvent*),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP= GADD) const;
void \fBeventPostcond\fP (void \fIproc\fP(void*, GoInterf*, const GEvent*),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBdestroyPostcond\fP (void \fIproc\fP(void*, GoInterf*), const void* \fIclosure\fP,
	GAddOrRemove \fIadd\fP = GADD) const;
void \fBresizePostcond\fP (void \fIproc\fP(void*, GoInterf*), const void* \fIclosure\fP,
	GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription:\fP .5i
These methods allow to add or remove post-condition callbacks. These callbacks are called
when an event (exposePostcond or eventPostcond) occurs, just before the \fIGoInterf\fP instance
is destroyed (destroyPostcond), or when the interface is resized (resizePostcond).
.IP \fIproc\fP .5i
.br
Specifies the callback pointer. This procedure takes 2 (destroyPostcond) or 3 (exposePostcond
and eventPostcond) arguments which are the closure pointer, the \fBGoInterf\fP instance pointer
and a pointer to the appropriate event.
.IP \fIclosure\fP .5i
.br
Specifies the user data which will be the first argument of the \fIproc\fP callback.
.IP \fIadd\fP .5i
.br
Specifies if the \fIproc\fP callback has to be added (GADD - default) or removed
(GREMOVE).
.RE
.sp 2
.IP
void \fBaddInputMask\fP (GEventMask \fImask\fP);
.br
void \fBremoveInputMask\fP (GEventMask \fImask\fP);
.RS .8i
.IP \fIDescription:\fP .5i
These methods allow to modify the input event mask of the input device
(see \fIGEvent(3Go)\fP).
.IP \fImask\fP .5i
Specifies the mask modification(see \fIGEvent(3Go)\fP).
.RE
.sp 1
.IP
GBool \fBcaptureEvent\fP (GEventMask \fIinput_mask\fP, GBool \fIconfined\fP, GTimeStamp \fIreference\fP = GCURRENT_TIME);
.RS .8i
.IP \fIDescription:\fP .5i
The method allows to \fIcapture\fP events defined by \fIinput_mask\fP. The \fIcapture\fP concept\fP is sometimes called in litterature \fIgrab\fP. If \fIinput_mask\fP included GPOINTERMOTION_MASK and \fPconfined\fP is true, the pointer is confined inside the current drawable.
.IP \fIinput_mask\fP .5i
Specifies the event mask to want to capture.
.IP \fIconfined\fP .5i
Specifies if you want to confined the pointer inside the drawable.
.IP \fIreference\fP .5i
Specifies the time when the request took place. The default is GCURRENT_TIME.
.RE
.sp 1
.IP
void \fBunCaptureEvent\fP(GTimeStamp \fIreference\fP)
.RS .8i
.IP \fIDescription:\fP .5i
The method removes the previous \fIcaptureEvent\fP request.
.IP \fIreference\fP .5i
Specifies when the request took place. If \fIreference\fP is earlier than the previous \fIcapture\fP request or later than the current time \fIunCaptureEvent\fP has no effect.
.RE
.sp 1
.IP
GEventMask \fBinputMask\fP () const;
.RS .8i
.IP \fIDescription:\fP .5i
This method allows to get the current input mask (see \fIGEvent(3Go)\fP).
.RE
.sp 1
.IP
GPoint \fBgetPointer\fP (const GCoordSys* \fIcs\fP =  NULL) const;
.br
void \fBsetPointer\fP (const GPoint& \fIposition\fP, const GCoordSys* \fIcs\fP = NULL);
.RS .8i
.IP \fIDescription:\fP .5i
These methods allow to get or to set the pointer position.
.IP \fIcs\fP .5i
.br
Specifies the coordinate system in which the pointer position is
returned/given. If \fIcs\fP is NULL, the absolute coordinate system is chosen.
.IP \fIposition\fP .5i
Specifies the new position of the pointer.
.RE
.sp 1
.IP
.nf
void* \fBgrab\fP (GGrabProc \fIprocedure\fP, void* \fIclosure\fP, GEventMask \fIinput_mask\fP =
	GBUTTON_PRESS_MASK | GBUTTON_RELEASE_MASK | GCHAR_MASK |
	GFUNCTION_KEY_MASK | GCOMPRESS_MOTION_MASK);
GBool \fBstopGrab\fP (void* \fIgrab_value\fP);
.fi
.RS .8i
.IP \fIDescription:\fP .5i
These methods allow execute the procedure \fIprocedure\fP every time an expected event
occurs (i.e. a motion event). To stop this process (to return from \fIgrab\fP the method \fIstopGrab\fP has to be called.
.br
The method verifies if the \fIgoInputDispatcher\fP is non NULL. If ok it calls \fIcaptureEvent\fP method with the current time. It calls the \fIrunEventLoop\fP of  \fIgoInputDispatcher\fP. When the loop returns it call \fIunCaptureEvent\fP.
.RE
.sp 1
.IP
void \fBhandle\fP (GEvent* \fIgoevent\fP);
.RS .8i
This method asks the \fIGoInterf\fP to pass this event to the appropriate
\fIeventPostcond\fP procedure.
.RE
.sp 1
.IP
ulong \fBinputFd\fP();
.RS .8i
.IP \fIDescription\fP .5i
This method returns the input ident associated to the user input
queue.
.RE
.sp 2
.IP
GNumber \fBwidth\fP () const;
.br
GNumber \fBheight\fP () const;
.br
GNumber \fBpixelWidth\fP () const;
.br
GNumber \fBpixelHeight\fP () const;
.br
int \fBdepth\fP () const;
.br
const GColor* \fBbackground\fP () const;
.RS .8i
.IP \fIDescription:\fP .5i
These methods allow to get the width and the height of the output and the
pixel, the depth and the background color of the output.
.RE
.sp 1
.IP
.nf
GShColor* \fBcolorFromName\fP (const char* \fIcolor_name\fP) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method allows to get an unmamed GRGB color matching the \fIcolor_name\fP.
See \fIGoInterf\fP subclasses manual to know which names are defined.
.RE
.sp 1
.IP
.nf
int \fBtoPixelWidth\fP (GNumber \fImm\fP) const;
int \fBtoPixelHeight\fP (GNumber \fImm\fP) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to convert a length expressed in millimeter into a
pixel size.
.IP \fImm\fP .5i
.br
Specifies the length expressed in millimeter.
.RE
.sp 1
.IP
void \fBresize\fP (GNumber \fIwidth\fP, GNumber \fIheight\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allow to resize the output device (i.e. the window).
.IP "\fIwidth, height\fP" .5i
Specify the new values of the output device.
.RE
.sp 1
.IP
.nf
void \fBbackground\fP (const GShColor* \fIshcolor\fP);
void \fBbackground\fP (const GColor* \fIcolor\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
This methods allow to set the background color of the output device.
.IP "\fIshcolor, color\fP" .5i
Specify the new background color.
.RE
.sp2
.IP
.nf
void \fBpolylineClips\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	int \fInpoint\fP, const GPoint* \fIpoints\fP, GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
	GQuality \fIquality\fP = GmaxGQuality);
void \fBpolylineClips\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	int \fInpoint\fP, const GPoint* \fIpoints\fP, GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
	GQuality \fIquality\fP = GmaxGQuality);

void \fBpolygonClips\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	int \fInpoint\fP, const GPoint* \fIpoints\fP, GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
	GQuality \fIquality\fP = GMAX_QUALITY);
void \fBpolygonClips\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	int \fInpoint\fP, const GPoint* \fIpoints\fP, GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
	GQuality \fIquality\fP = GMAX_QUALITY);

void \fBrectangleClips\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIposition\fP, GNumber \fIwidth\fP, GNumber \fIheight\fP,
	GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP, GQuality \fIquality\fP = GMAX_QUALITY);
void \fBrectangleClips\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIposition\fP, GNumber \fIwidth\fP, GNumber \fIheight\fP,
	GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP, GQuality \fIquality\fP = GMAX_QUALITY);

void \fBellipseClips\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
	GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
	GNumber \fIangle1\fP = 0, GNumber \fIangle2\fP = 2*PI, GQuality \fIquality\fP = GMAX_QUALITY);
void \fBellipseClips\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
	GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
	GNumber \fIangle1\fP = 0, GNumber \fIangle2\fP = 2*PI, GQuality \fIquality\fP = GMAX_QUALITY);
	
void \fBellipseChordClips\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
	GNumber \fIangle1\fP, GNumber \fIangle2\fP,
	GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP, GQuality \fIquality\fP = GMAX_QUALITY);
void \fBellipseChordClips\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
	GNumber \fIangle1\fP, GNumber \fIangle2\fP,
	GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP, GQuality \fIquality\fP = GMAX_QUALITY);

void \fBellipsePieClips\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
	GNumber \fIangle1\fP, GNumber \fIangle2\fP,
	GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP, GQuality \fIquality\fP = GMAX_QUALITY);
void \fBellipsePieClips\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
	GNumber \fIangle1\fP, GNumber \fIangle2\fP,
	GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP, GQuality \fIquality\fP = GMAX_QUALITY);

void \fBcircleClips\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& center, GNumber \fIradius\fP,
	GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
 	GNumber \fIangle1\fP = 0, GNumber \fIangle2\fP = 2*PI,
 	GQuality \fIquality\fP = GMAX_QUALITY);

void \fBcircleClips\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& center, GNumber \fIradius\fP,
	GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
	GNumber \fIangle1\fP = 0, GNumber \fIangle2\fP = 2*PI,
	GQuality \fIquality\fP = GMAX_QUALITY);
	
void \fBcircleChordClips\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& center, GNumber \fIradius\fP, GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
	GNumber \fIangle1\fP, GNumber \fIangle2\fP, GQuality \fIquality\fP = GMAX_QUALITY);
void \fBcircleChordClips\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& center, GNumber \fIradius\fP, GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
	GNumber \fIangle1\fP, GNumber \fIangle2\fP, GQuality \fIquality\fP = GMAX_QUALITY);

void \fBcirclePieClips\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& center, GNumber \fIradius\fP, GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
	GNumber \fIangle1\fP, GNumber \fIangle2\fP, GQuality \fIquality\fP = GMAX_QUALITY);
void \fBcirclePieClips\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& center, GNumber \fIradius\fP, GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
	GNumber \fIangle1\fP, GNumber \fIangle2\fP, GQuality \fIquality\fP = GMAX_QUALITY);

void \fBbezierClips\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	int \fInpoint\fP, const GPoint* \fIpoints\fP, GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
	GQuality \fIquality\fP = GMAX_QUALITY);
void \fBbezierClips\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	int \fInpoint\fP, const GPoint* \fIpoints\fP, GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
	GQuality \fIquality\fP = GMAX_QUALITY);

void \fBcubicCurveClips\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	int \fInpoint\fP, const GPoint* \fIpoints\fP, GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
	GNumber \fIbasisMatrix\fP[4][4], int \fIeval_shift\fP = 1, GQuality \fIquality\fP = GMAX_QUALITY);
void \fBcubicCurveClips\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	int \fInpoint\fP, const GPoint* \fIpoints\fP, GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP,
	GNumber \fIbasisMatrix\fP[4][4], int \fIeval_shift\fP = 1, GQuality \fIquality\fP = GMAX_QUALITY);


void \fBstringClips\fP (const GShTextBrush* \fIshtbrush\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIposition\fP, GNumber \fIheight\fP, int \fInchar\fP, const char* \fIstring\fP,
	GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP, GQuality \fIquality\fP = GMAX_QUALITY);
void \fBstringClips\fP (const GTextBrush* \fItbrush\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIposition\fP, GNumber \fIheight\fP, int \fInchar\fP, const char* \fIstring\fP,
	GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP, GQuality \fIquality\fP = GMAX_QUALITY);

void \fBimageClips\fP (const GShImageBrush* \fIshibrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIposition\fP, GNumber \fIwidth\fP, GNumber \fIheight\fP,
	GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP, GQuality \fIquality\fP = GMAX_QUALITY);
void \fBimageClips\fP (const GImageBrush* \fIibrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIposition\fP, GNumber \fIwidth\fP, GNumber \fIheight\fP,
	GRegion* \fIclip\fP, GRegion* \fIopaque_clip\fP, GQuality \fIquality\fP = GMAX_QUALITY);
.fi
.sp 1
.RS .8i
.IP \fIDescription:\fP .5i
The \fIclips\fP methods compute and add the clip and opaque_clip regions of the drawings
to the \fIclip\fP and \fIopaque_clip\fP parameters. The \fIclips\fP methods are \fIGoInterf\fP
subclass dependent (like the drawings themselves), nevertheless the \fIGoInterf\fP superclasses
compute the clip and the opaque regions (if possible) in the mathematical size.
Note that a filled area with a \fIGFillStippled\fP fill style is seen in the \fIGoInterf\fP
superclass clips methods as not opaque.
.IP "\fIdraw parameters...\fP" .5i
.br
See the corresponding output method.
.IP \fIclip\fP .5i
.br
If not NULL, the methods will \fBadd\fP (see \fIRegion(3Go)\fP) to \fIclip\fP the list of the bounding boxes (see \fIBox(3Go)\fP) of the object which will be draw with the same parameters.
.IP \fIopaque_clip\fP .5i
.br
If not NULL, the methods will \fBadd\fP (see \fIRegion(3Go)\fP) to \fIopaque_clip\fP the list of boxes (see \fIBox(3Go)\fP) which will effectively cover by a draw with the same parameters.
.RE
.sp2
.IP
.nf 
GBool \fBpolylineContains\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	int \fInpoint\fP, const GPoint* \fIpoints\fP,
	const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP, GQuality \fIquality\fP = GMAX_QUALITY);
GBool \fBpolylineContains\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	int \fInpoint\fP, const GPoint* \fIpoints\fP,
	const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP, GQuality \fIquality\fP = GMAX_QUALITY);

GBool \fBpolygonContains\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	int \fInpoint\fP, const GPoint* \fIpoints\fP,
	const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP, GQuality \fIquality\fP = GMAX_QUALITY);
GBool \fBpolygonContains\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	int \fInpoint\fP, const GPoint* \fIpoints\fP,
	const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP, GQuality \fIquality\fP = GMAX_QUALITY);

GBool \fBrectangleContains\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIposition\fP, GNumber \fIwidth\fP, GNumber \fIheight\fP,
	const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP, GQuality \fIquality\fP = GMAX_QUALITY);
GBool \fBrectangleContains\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIposition\fP, GNumber \fIwidth\fP, GNumber \fIheight\fP,
	const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP, GQuality \fIquality\fP = GMAX_QUALITY);

GBool \fBellipseContains\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
	const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
	GNumber \fIangle1\fP = 0, GNumber \fIangle2\fP = 2*PI, GQuality \fIquality\fP = GMAX_QUALITY);
GBool \fBellipseContains\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
	const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
	GNumber \fIangle1\fP = 0, GNumber \fIangle2\fP = 2*PI, GQuality \fIquality\fP = GMAX_QUALITY);
	
GBool \fBellipseChordContains\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
	GNumber \fIangle1\fP, GNumber \fIangle2\fP,
	const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP, GQuality \fIquality\fP = GMAX_QUALITY);
GBool \fBellipseChordContains\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
	GNumber \fIangle1\fP, GNumber \fIangle2\fP,
	const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP, GQuality \fIquality\fP = GMAX_QUALITY);

GBool \fBellipsePieContains\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
	GNumber \fIangle1\fP, GNumber \fIangle2\fP,
	const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP, GQuality \fIquality\fP = GMAX_QUALITY);
GBool \fBellipsePieContains\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIcenter\fP, GNumber \fIradiusX\fP, GNumber \fIradiusY\fP,
	GNumber \fIangle1\fP, GNumber \fIangle2\fP,
	const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP, GQuality \fIquality\fP = GMAX_QUALITY);

GBool circleCo\fBntains\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& center, GNumber \fIradius\fP, GNumber \fIangle1\fP = 0, GNumber \fIangle2\fP = 2*PI,
	const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP, GQuality \fIquality\fP = GMAX_QUALITY);
GBool \fBcircleContains\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& center, GNumber \fIradius\fP, GNumber \fIangle1\fP = 0, GNumber \fIangle2\fP = 2*PI,
	const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP, GQuality \fIquality\fP = GMAX_QUALITY);
	
GBool \fBcircleChordContains\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& center, GNumber \fIradius\fP, const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
	GNumber \fIangle1\fP, GNumber \fIangle2\fP, GQuality \fIquality\fP = GMAX_QUALITY);
GBool \fBcircleChordContains\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& center, GNumber \fIradius\fP, const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
	GNumber \fIangle1\fP, GNumber \fIangle2\fP, GQuality \fIquality\fP = GMAX_QUALITY);

GBool \fBcirclePieContains\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& center, GNumber \fIradius\fP, const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
	GNumber \fIangle1\fP, GNumber \fIangle2\fP, GQuality \fIquality\fP = GMAX_QUALITY);
GBool \fBcirclePieContains\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& center, GNumber \fIradius\fP, const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
	GNumber \fIangle1\fP, GNumber \fIangle2\fP, GQuality \fIquality\fP = GMAX_QUALITY);

GBool \fBbezierContains\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	int \fInpoint\fP, const GPoint* \fIpoints\fP,
	const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP, GQuality \fIquality\fP = GMAX_QUALITY);
GBool \fBbezierContains\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	int \fInpoint\fP, const GPoint* \fIpoints\fP,
	const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP, GQuality \fIquality\fP = GMAX_QUALITY);

GBool \fBcubicCurveContains\fP (const GShPen* \fIshpen\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	int \fInpoint\fP, const GPoint* \fIpoints\fP, const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
	GNumber \fIbasisMatrix\fP[4][4], int \fIeval_shift\fP = 1, GQuality \fIquality\fP = GMAX_QUALITY);
GBool \fBcubicCurveContains\fP (const GPen* \fIpen\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	int \fInpoint\fP, const GPoint* \fIpoints\fP, const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP,
	GNumber \fIbasisMatrix\fP[4][4], int \fIeval_shift\fP = 1, GQuality \fIquality\fP = GMAX_QUALITY);


GBool \fBstringContains\fP (const GShTextBrush* \fIshtbrush\fP, const GShBrush* \fIshbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIposition\fP, GNumber \fIheight\fP, int \fInchar\fP, const char* \fIstring\fP,
	const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP, GQuality \fIquality\fP = GMAX_QUALITY);
GBool \fBstringContains\fP (const GTextBrush* \fItbrush\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIposition\fP, GNumber \fIheight\fP, int \fInchar\fP, const char* \fIstring\fP,
	const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP, GQuality \fIquality\fP = GMAX_QUALITY);

GBool \fBimageContains\fP (const GShImageBrush* \fIibrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIposition\fP, GNumber \fIwidth\fP, GNumber \fIheight\fP,
	const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP, GQuality \fIquality\fP = GMAX_QUALITY);
GBool \fBimageContains\fP (const GImageBrush* \fIibrush\fP, const GCoordSys& \fIcs\fP,
	const GPoint& \fIposition\fP, GNumber \fIwidth\fP, GNumber \fIheight\fP,
	const GPoint& \fIabsolute_pos\fP, GNumber \fImax_distance\fP, GQuality \fIquality\fP = GMAX_QUALITY);
.fi
.sp 1
.RS .8i
.IP \fIDescription:\fP .5i
The \fIContains\fP methods return GTRUE if the \fIabsolute_point\fP would be inside the object drawn
with the same parameters. The \fImax_distance\fP parameter gives the \fItolerance\fP. If the
\fIabsolute_point\fP is not inside the object it returns GFALSE. Note that filled area
with a \fIGFillStippled\fP fill style is seen in the \fIGoInterf\fP superclass contains methods as
not opaque.
.IP "\fIdraw parameters...\fP" .5i
.br
See the corresponding output method.
.IP \fIabsolute_point\fP .5i
.br
Specifies the GPoint you want to known if it is inside the drawn area.
.IP \fImax_distance\fP .5i
.br
Specified the absolute tolerance around the \fIabsolute_point\fP.
.RE
.sp2
.IP
.nf
GNumber \fBstringLeftBearing\fP (const char* \fIstring\fP, int \fInchar\fP, GNumber \fIheight\fP, const GShFont* \fIshfont\fP);	
GNumber \fBstringLeftBearing\fP (const char* \fIstring\fP, int \fInchar\fP, GNumber \fIheight\fP, const GFont* \fIfont\fP);

GNumber \fBstringRightBearing\fP (const char* \fIstring\fP, int \fInchar\fP, GNumber \fIheight\fP, const GShFont* \fIshfont\fP);
GNumber  \fBstringRightBearing\fP (const char* \fIstring\fP, int \fInchar\fP, GNumber \fIheight\fP, const GFont* \fIfont\fP);

GNumber \fBstringAscent\fP (const char* \fIstring\fP, int \fInchar\fP, GNumber \fIheight\fP, const GShFont* \fIshfont\fP);
GNumber \fBstringAscent\fP (const char* \fIstring\fP, int \fInchar\fP, GNumber \fIheight\fP, const GFont* \fIfont\fP);

GNumber \fBstringDescent\fP (const char* \fIstring\fP, int \fInchar\fP, GNumber \fIheight\fP, const GShFont* \fIshfont\fP);
GNumber \fBstringDescent\fP (const char* \fIstring\fP, int \fInchar\fP, GNumber \fIheight\fP, const GFont* \fIfont\fP);

GNumber \fBstringWidth\fP (const char* \fIstring\fP, int \fInchar\fP, GNumber \fIheight\fP, const GShFont* \fIshfont\fP);
GNumber \fBstringWidth\fP (const char* \fIstring\fP, int \fInchar\fP, GNumber \fIheight\fP, const GFont* \fIfont\fP);
.fi
.RS .8i
.IP \fIDescription:\fP .5i
These methods allow to get size information about a string.
.IP \fIstring\fP .5i
.br
Specifies the character string itself.
.IP \fInchar\fP .5i
.br
Specifies the character number of the string.
.IP \fIheight\fP .5i
.br
Specifies the height of the font.
.IP "\fIshfont, font\fP" .5i
.br
Specifies a pointer to the \fIGShFont\fP or the \fIFont\fP object (see \fIFont(3Go)\fP).
.RE
.sp 1
.IP
.nf
const char* \fBfontName\fP (const GCoordSys& \fIcs\fP, GNumber \fIheight\fP, const GShFont* \fIshfont\fP);
const char* \fBfontName\fP (const GCoordSys& \fIcs\fP, GNumber \fIheight\fP, const GFont* \fIfont\fP);
.fi
.RS .8i
.IP \fIDescription:\fP .5i
This method returns the font name corresponding to the \fIfont\fP object
when using the current interface. This returned name is const so it does not have to be modified or
freed.
.IP "\fIshfont, font\fP" .5i
.br
Specifies the \fIGShFont\fP or the \fIFont\fP object (see \fIFont(3Go), ShFont(3Go)\fP).
.RE
.sp 1
.IP
.nf
GNumber \fBfontAscent\fP (GNumber \fIheight\fP, GShFont* \fIshfont\fP);
GNumber \fBfontAscent\fP (GNumber \fIheight\fP, const GFont* \fIfont\fP);

GNumber \fBfontDescent\fP (GNumber \fIheight\fP, const GShFont* \fIshfont\fP);
GNumber \fBfontDescent\fP (GNumber \fIheight\fP, const GFont* \fIfont\fP);

GNumber \fBfontUnderlineThickness\fP (GNumber \fIheight\fP, const GShFont* \fIshfont\fP);
GNumber \fBfontUnderlineThickness\fP (GNumber \fIheight\fP, const GFont* \fIfont\fP);

GNumber \fBfontUnderlinePosition\fP (GNumber \fIheight\fP, const GShFont* \fIshfont\fP);
GNumber \fBfontUnderlinePosition\fP (GNumber \fIheight\fP, const GFont* \fIfont\fP);

GNumber \fBfontItalicAngle\fP (GNumber \fIheight\fP, const GShFont* \fIshfont\fP);
GNumber \fBfontItalicAngle\fP (GNumber \fIheight\fP, const GFont* \fIfont\fP);

GNumber \fBfontStrikeoutAscent\fP (GNumber \fIheight\fP, GShFont* \fIshfont\fP);
GNumber \fBfontStrikeoutAscent\fP (GNumber \fIheight\fP, const GFont* \fIfont\fP);

GNumber \fBfontStrikeoutDescent\fP (GNumber \fIheight\fP, const GShFont* \fIshfont\fP);
GNumber \fBfontStrikeoutDescent\fP (GNumber \fIheight\fP, const GFont* \fIfont\fP);

GNumber \fBfontMinSpace\fP (GNumber \fIheight\fP, const GShFont* \fIshfont\fP);
GNumber \fBfontMinSpace\fP (GNumber \fIheight\fP, const GFont* \fIfont\fP);

GNumber \fBfontMaxSpace\fP (GNumber \fIheight\fP, const GShFont* \fIshfont\fP);
GNumber \fBfontMaxSpace\fP (GNumber \fIheight\fP, const GFont* \fIfont\fP);

GNumber \fBfontNormSpace\fP (GNumber \fIheight\fP, const GShFont* \fIshfont\fP);
GNumber \fBfontNormSpace\fP (GNumber \fIheight\fP, const GFont* \fIfont\fP);

GNumber \fBfontEndSpace\fP (GNumber \fIheight\fP, const GShFont* \fIshfont\fP);
GNumber \fBfontEndSpace\fP (GNumber \fIheight\fP, const GFont* \fIfont\fP);
.fi
.RS .8i
.IP \fIDescription:\fP .5i
These methods allow to get the font metrics. The methods returns a value \fIrelative\fP to \fIheight\fP. Informatonm like \fIdescent, ascent\fI are generaly positive for the current font.
.IP \fIheight\fP .5i
.br
Specifies the height of the font.
.IP \fIfont\fP .5i
Specifies the concerned font.
.RE
.sp2
.IP
.nf
void \fBgetImage\fP (GImageBrushValues& \fIimagebrush_result\fP, GPixelArrayValues& \fIpixelarray_result\fP,
	const GCoordSys& \fIcs\fP, const GPoint& \fIorigin\fP, GNumber \fIwidth\fP, GNumber \fIheight\fP,
	ushort \fIdepth\fP = 0, GBool \fIcompress_colormap\fP = GTRUE,
	ushort \fIx_resolution\fP = 0, ushort \fIy_resolution\fP = 0, GQuality \fIquality\fP = GMAX_QUALITY);
.RS .8i
.IP \fIDescription:\fP .5i
This method allows to get an image which is
a copy of the current output.
.IP \fIimagebrush_result\fP .5i
Specifies the reference of an \fIGImageBrushValues\fP structure to be used to
store the image brush.
.IP \fIpixelarray_result\fP .5i
Specifies the reference of a \fIGPixelArrayValues\fP structure to be used
to store the image itself.
.IP \fIcs\fP .5i
.br
Specifies the coordinate system in which the position and dimensions are
expressed. If the \fIcs\fP is not rectangular, the method will return
a rectangular area which will contains the bounding box of the wanted image.
It initializes the \fIimagebrush_result\fP with a mask corresponding to the \fIcs\fP.
.IP "\fIorigin, width, height\fP" .5i
.br
Specify the outer rectangle of the source image.
.IP "\fIdepth, x_resolution, y_resolution\fP" .5i
Specify the pixel array characteristics. \fIX_resolution\fP and \fIy_resolution\fP are
expressed in "dot-per-inch". If they
are 0, the output device resolutions are assumed.
.IP \fIcompress_colormap\fP .5i
If GTRUE, the minimum colormap is returned in the \fIGImageBrushValues\fP.
.IP \fIquality\fP .5i
Specifies the quality of the resulting image. Possible values are \fIGMIN_QUALITY, GBAD_QUALITY, GMEDIUM_QUALITY,
GGOOD_QUALITY, GMAX_QUALITY\fP (see also \fIGoInterf\fP subclasses).
.RE
.sp 1
.IP
void \fBpushCursor\fP (long \fIcursor_ident\fP);
.RS .8i
This method asks the \fIGoInterf\fP to use the the cursor defined to by \fIcursor_ident\fP.
.RE
.sp 1
.IP
void \fBpushCursor\fP (const GCursor* \fIcursor\fP);
.RS .8i
This method asks the \fIGoInterf\fP to use the cursor defined to the \fIcursor\fI object. The \fIcursor\fP class is to be defined..
.RE
.sp 1
.IP
void \fBpushCursor\fP (const GShCursor* \fIshcursor\fP);
.RS .8i
This method asks the \fIGoInterf\fP to use the cursor defined to the \fIshcursor\fI object. The \fIshcursor\fP class is to be defined.
.RE
.sp 1
.IP
void \fBpopCursor\fP ();
.RS .8i
This method asks the \fIGoInterf\fP to use the previous cursor.
.RE
.sp 1
.IP
void \fBbell\fP ();
.RS .8i
This method asks the \fIGoInterf\fP to ring a bell. \fIpercent\fP specifies the volume
for the bell. The volume of the bell is relative to a base which is window system dependent. \fIpercent\fP is in the range -100 (off) to +100 (loudest).
.RE
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
\fBGoInterf\fP objects are not created, but instead, \fBGoInterf\fP subclass
instances such as \fBXGoInterf\fP
.sp 1
.SH
\fBC BINDING\fP
.SS
\fBHeader\fP
.IP
#include <Go/cGoInterf.h>
.SS
\fBC Functions\fP
.IP
.nf
	void \fBGoInterfMap\fP (GObjectId \fIgointerf\fP)
	void \fBGoInterfUnmap\fP (GObjectId \fIgointerf\fP);
	void \fBGoInterfFlush\fP   (GObjectId \fIgointerf\fP);
	void \fBGoInterfSynchronize\fP (GObjectId \fIgointerf\fP, GBool \fIdiscard\fP);

	void \fBGoInterfHandle\fP (GObjectId \fIgointerf\fP, GObjectId \fIgevent\fP);
	ulong \fBGoInterfInputFd\fP (GObjectId \fIgointerf\fP);

	void \fBGoInterfExposePostcond\fP (GObjectId \fIgointerf\fP, GAddOrRemove \fIadd\fP,
					void \fIfunc\fP(void*, GObjectId \fIgointerf\fP),
					const GObjectId \fIgexposeEvent\fP), const void* \fIclosure\fP);
	void \fBGoInterfEventPostcond\fP (GObjectId \fIgointerf\fP,
					GAddOrRemove \fIadd\fP,
					void \fIfunc\fP(void*, GObjectId \fIgointerf\fP),
					const GObjectId \fIgevent\fP),
					const void* \fIclosure\fP); 
	void \fBGoInterfDestroyPostcond\fP (GObjectId \fIgointerf\fP, GAddOrRemove \fIadd\fP,
					void \fIfunc\fP(void*, GObjectId \fIgointerf\fP),
					const void* \fIclosure\fP);

	void \fBGoInterfResize\fP (GObjectId \fIgointerf\fP, GNumber \fIwidth\fP, GNumber \fIheight\fP);
	void \fBGoInterfSetBackground\fP (GObjectId \fIgointerf\fP, const GObjectId \fIshcolor\fP);

	GNumber    \fBGoInterfWidth\fP (GObjectId \fIgointerf\fP) ;
	GNumber    \fBGoInterfHeight\fP           (GObjectId \fIgointerf\fP);
	ushort     \fBGoInterfDepth\fP            (GObjectId \fIgointerf\fP) ;
	GObjectId  \fBGoInterfGetBackground\fP    (GObjectId \fIgointerf\fP);
	GNumber    \fBGoInterfPixelWidth\fP       (GObjectId \fIgointerf\fP) ;
	GNumber    \fBGoInterfPixelHeight\fP      (GObjectId \fIgointerf\fP) ;
	GObjectId  \fBGoInterfColorFromName\fP    (GObjectId \fIgointerf\fP, const char* \fIcolor_name\fP) ;

	void \fBGoInterfGetImage\fP (GObjectId \fIgointerf\fP, GImageBrushValues* \fIimagebrush_result\fP,
				GPixelArrayValues* \fIpixelarray_result\fP,
				const GCoordSys* \fIcs\fP, const GPoint* \fIorigin\fP,
				GNumber \fIwidth\fP, GNumber \fIheight\fP,
				short \fIdepth\fP, GBool \fIcompress_colormap\fP,
				ushort \fIx_resolution\fP, ushort \fIy_resolution\fP,
				GQuality \fIquality\fP);
.fi
.sp 1
.IP \fIDescription\fP .5i
\fIsee\fP the GoInterf::\fIname\fP method. All C++ references must be seen as an address in C.
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBPen\fP, \fBShPen\fP, \fBBrush\fP, \fBShBrush\fP, \fBTextBrush\fP,
.br
\fBShTextBrush\fP, \fBImageBrush\fP, \fBShImageBrush\fP, \fBGEvent\fP, \fBFont\fP,
.br
\fBShFont\fP,
\fBPixelArray\fP, \fBShPixelArray\fP, \fBRegion\fP, \fBCoordSys\fP, \fBPoint\fP, \fBColor\fP,
.br
\fBShColor\fP, \fBShColormap\fP and \fBColormap\fP classes.
.nrPN \n%
