.\" $Id: GoRoot.n,v 1.4 1992/12/28 15:51:53 jojic Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoRoot 3Go "December 1992" "Version 1.2" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoRoot\fP \(em the Go root object class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/GoRoot.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGoRoot\fP inherits behavior from the \fBGo\fP class.
.sp 1
.SH
\fBDESCRIPTION\fP
.IP
A \fBGoRoot\fP object is used as the root of a \fIGo\fP tree (see \fIGo(3Go)\fP). It
mainly maintains a link between the \fIGo\fP tree and a \fIGoInterf\fP instance (see \fIGoInterf(3Go)\fP.
It is responsible to keep damaged areas when a \fIGExposeEvent\fP (see \fIGExposeEvent(3Go)\fP)
occurs or when a \fIGo\fP is added, modified or removed.
The \fIflush()\fP method is responsible to refresh those damaged
areas.
.sp 1
.br
.nf
.ta .15i .25i 1.0i
class GoRoot : public Go {
	public:
		GoRoot();
		~GoRoot();
		static GoRoot* create();
		static GoRootMetaclass* metaclass();

		GoInterf* interf() const;
		void interf(GoInterf* \fInew_gointerf\fP);

		void flush();
		void flushPrecond (void (*precond)(void*, GoRoot*, const GRegion*),
				void* closure, GAddOrRemove = GADD);
		void flushPostcond (void (*postcond)(void*, GoRoot*, const GRegion*),
				void* closure, GAddOrRemove = GADD);

		void redrawForeOnly(Go* \fIgo\fP, const Region& \fIregion\fP = *(Region*)NULL);
		void redrawBackAndFore(const Region& \fIregion\fP);

		int  maxLowerOpaqueSearchCount() const;
		void maxLowerOpaqueSearchCount(int \fImax_count\fP);

		int  maxBoxesCount() const;
		void maxBoxesCount(int \fImax_count\fP);

		GNumber minOpaqueArea () const;
		void    minOpaqueArea (GNumber \fImin_area\fP);

		void callClipPostconditions();

		void disableDamage ();
		void enableDamage ();
		GBool damageEnabled () const;
};
.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
GoRootMetaclass* \fBGoRoot::metaclass\fP();
.RS .8i
This static method returns the metaclass of GoRoot.
.RE
.sp 1
.IP
GoRoot* \fBGoRoot::create\fP();
.br
\fBGoRoot\fP();
.RS .8i
.IP \fIDescription\fP .5i
The \fIGoRoot\fP method is called when a new instance of \fIGoRoot\fP is created by invoking
\fInew\fP or \fIGoRoot::create()\fP. The second form should
be preferred because it allows the call of pre/postconditions.
.RE
.sp 1
.IP
\fB~GoRoot\fP();
.RS .8i
.IP \fIDescription\fP .5i
This method is called when a \fIGoRoot\fP instance is deleted by invoking
\fIdelete\fP or \fIdestroy()\fP (see \fIGo(3Go)\fP). The second form should be preferred because it allows the call of pre/postconditions.
.RE
.sp 1
.IP
GoInterf* \fBinterf\fP() const;
.br
void \fBinterf\fP(GoInterf* \fInew_gointerf\fP);
.RS .8i
.IP \fIDescription\fP .5i
These two methods get or set the \fIGoInterf\fP of the \fIGo\fP tree.
When setting a new \fIGoInterf\fP, the pre/postconditions described below are
called.
.IP \fInew_gointerf\fP .5i
Specifies the new \fIGoInterf\fP instance which will be used to draw objects.
.RE
.sp
.IP
void \fBflush\fP();
.RS .8i
.IP \fIDescription\fP .5i
This method \fBdoes\fP the effective drawing of objects.
Instead of drawing each time it is needed
-- shape modification, coordinate system change, ... --
the clipping region affected by these modifications are stored and
grouped until the method \fIflush()\fP is called.
\fIflush()\fP will ask every \fIGo\fP which
intersects that region to draw itself.
.br
Currently a more sophisticated algorithm is used. For instance, objects under
a bigger opaque object are not drawn. For more details see the sources.
.RE
.sp
.IP
void \fBflushPrecond\fP (void (*\fIprecond\fP)(void*, GoRoot*, const GRegion*),
.br
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.br
void \fBflushPostcond\fP (void (*\fIpostcond\fP)(void*, GoRoot*, const GRegion*),
.br
				void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.RS .8i
.IP \fIDescription\fP .5i
These methods add or remove pre/post conditions to the \fIflush\fP method.
The function \fIprecond\fP, which signature is:
.br
	void precond (void* closure, GoRoot*, const GRegion* region),
.br
is called just before any other drawing.
.br
The function \fIpostcond\fP, which signature is:
.br
	void postcond (void* closure, GoRoot*, const GRegion* region),
.br
is called just after all drawings.
.br
In both cases \fIregion\fP is the full region which has to be refreshed.
.br
If a call to \fIflush()\fP is performed when nothing has to be drawn,
then \fIprecond\fP and \fIpostcond\fP are not called at all.
.RE
.sp
.IP
void disableDamage ()
.br
void enableDamage ()
.br
GBool damageEnabled () const
.RS .8i
.IP \fIDescription\fP .5i
\fBGoRoot\fP manages the region which will be redrawn at next call to \fIflush\fP.
Methods \fIredrawForeOnly\fP and \fIredrawBackAndFore\fP update that region.
Sometimes it may be faster to call these methods once (with a big region),
than to call them many times with small regions.
.br
If someone want to implement that, he must:
.br
	call \fIdisableDamage()\fP,
.br
	perform its modifications,
.br
	call \fIenableDamage()\fP,
.br
	perform a call to \fIredrawForeOnly\fP or \fIredrawBackAndFore\fP with
a big region.
.br
While the damage is disabled, \fIredrawForeOnly\fP and
\fIredrawBackAndFore\fP do nothing.
.br
For instance, this is used by the GoText. When a full page of formatted text is
updated because a character is inserted somewhere in the beginning, it would
be a waste of time to compute intersections of regions for every GoSegment of
the GoText.
.sp
Calls to \fIdisableDamage()\fP increment a counter, and calls
to \fIdisableDamage()\fP decrement that counter. It is only when that counter
comes to zero again that damage is enabled again.
.sp
The boolean method \fIdamageEnabled()\P returns \fIGTRUE\fP if the damage is
enabled (the counter above is equal to zero) and \fIGFALSE\fP otherwise.
.RE
.sp
.IP
void \fBredrawForeOnly\fP(Go* \fIgo\fP, const Region& \fIregion\fP = *(Region*)NULL);
.br
void \fBredrawBackAndFore\fP(const Region& \fIregion\fP);
.RS .8i
.IP \fIDescription\fP .5i
These methods tells to GoRoot that the region \fIregion\fP is damaged, and
therefore must be redrawn at next call to \fIflush()\fP.
.br
\fIredrawForeOnly\fP tells that drawings are damaged only upper the given
\fIgo\fP. If \fIregion\fP is missing, it is replaced by the clip of
this \fIgo\fP.
.br
These methods are normally only used by graphic
objects themselves. You may need them if you have your own drawings (without
using Go) on the same output.
.IP \fIgo\fP .5i
Specifies the \fIGo\fP from which the output is damaged.
.IP \fIregion\fP .5i
Specifies the region which has to be redrawn at next call to \fIflush()\fP.
.RE
.sp
.IP
int \fBmaxLowerOpaqueSearchCount\fP () const;
.br
void \fBmaxLowerOpaqueSearchCount\fP (int \fImax_count\fP);
.RS .8i
.IP \fIDescription\fP .5i
GoRoot stores damaged ares, and only at flush time it
refreshes the output. The idea of this implementation is to not
waste time during drawings because many damages may occur before a
refresh is requested.
.br
Without the management of opaque graphic objects, GoRoot will sometimes call
the draw method on a Go even if it is not useful. But the management of a
lower Go which has an opaque clip is not possible any more at flush time.
It is possible only inside the method \fIredrawBackAndFore()\fP.
This is nice when you have not too many graphic objects.
But if you create thousands of them, then the management of these
lower opaque clip became expensive in time. Therefore we offer a way to
say \fBstop\fP. Between two calls to the \fIflush()\fP method, GoRoot will
try to manage this lower opaque clip only \fImaxLowerOpaqueSearchCount()\fP
times. If you do not want this management you simply set this max count to
zero (or negative):
.br
	\fImaxLowerOpaqueSearchCount(0)\fP
.br
If you always want this management, you simply set this max count to
MAXINT:
.br
	\fImaxLowerOpaqueSearchCount(MAXINT)\fP
.br
The default value is 256.
.RE
.sp
.IP
int \fBmaxBoxesCount\fP () const;
.br
void \fBmaxBoxesCount\fP (int \fImax_count\fP) const;
.RS .8i
.IP \fIDescription\fP .5i
Regions (i.e. lists of boxes, see Region(3Go)) are used by GoRoot to store
damaged areas. Therefore GoRoot make additions, subtractions and intersections
between regions. In some bad cases (many very small graphic objects) the
number of boxes inside a region may became astronomical (partially because
we use floats and not pixels). In such cases it takes more time to compute
region operations that to draw more graphic objects than needed.
.br
We offer a way to say \fBstop\fP. If the number of boxes inside a region
reaches \fImaxBoxesCount()\fP, GoRoot will stop its area optimizations.
.RE
.sp
.IP
GNumber \fBminOpaqueArea\fP () const;
.br
void \fBminOpaqueArea\fP (GNumber \fImin_area\fP);
.RS .8i
.IP \fIDescription\fP .5i
To refresh the output GoRoot manages opaque regions of graphic objects.
It is easy to understand that a big opaque area will often cancel the call
of the draw method on a lower Go. But if this opaque area is too small, it
has very few chances to hide anything. For this reason it is a waste of time
to manage those small opaque areas.
.br
The \fIminOpaqueArea(min_area)\fP method tells to GoRoot to manage opaque clips
only if their surface is bigger than \fImin_area\fP.
.br
The default value is about 15x15 mm. This means an opaque box which width and
height are 15 mm or bigger will be managed.
.RE
.sp
.IP
void \fBcallClipPostconditions\fP();
.RS .8i
.IP \fIDescription\fP .5i
All postconditions (see Go(3Go)) are called just after the corresponding
action. The clip postcondition does not follow this
rule. Clip postconditions are called only just before a refresh (i.e. at
the beginning of the \fIflush()\fP method). This is more useful because
if someone sets a clip postcondition, he is rather interested by the final
output.
.br
But if you want to force the call of clip postconditions before flush time,
simply call:
.br
	\fIcallClipPostconditions();\fP
.RE
.sp 1
.SH
\fBUSER INTERACTION\fP
.IP
\fISee GoRootMetaclass(3Go)\fP
.sp 1
.SH
\fBC BINDING\fP
.IP
\fITo be defined\fP.
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
\fIGoRoot\fP has a public constructor (\fIGoRoot()\fP) and destructor (\fI~GoRoot()\fP) but
if they are directly invoked instead of \fIGoRoot::create()\fP or
\fIdestroy()\fPno pre/postcondition can be taken in account.
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBGo\fP, \fBGoMetaclass\fP, \fBEvent\fP, \fBGoInterf\fP and \fBGoRootMetaclass\fP classes.
.nrPN \n%
