.\" $Id: GoStream.n,v 1.1.1.1 1992/03/18 09:43:44 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoStream 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoStream\fP \(em the gostream object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/GoStream.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGoStream\fP does not inherit anything from another class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
This class has no specific data but defines a general programming interface
for its subclasses. It provides methods to save and restore "anonymous objects"
on a \fBMedium\fP (see corresponding man pages). The device used depends on
the \fBMedium\fP subclass. The following methods may associate a \fBMedium\fP
with a \fBGoStream\fP instance :
.RS 10
.IP \(bu 3
\fBGoStream\fP (GMedium*)
.IP \(bu 3
\fBopenRead\fP (GMedium*)
.IP \(bu 3
\fBopenWrite\fP (GMedium*)
.RE
.IP
In order for the \fBGoStream\fP to
save/restore unknown classes of objects, each class that wish to take
advantage of it services must implement two routines \(em \fIsaveFunc\fP and
\fIrestoreFunc\fP \(em and \fIbind\fP them to a string identifying its class
(ex : metaclass()->classname() for Go's).
On the other hand, \fBGoStream\fP methods to save and
restore objects are \fBsaveObj\fP and \fBrestoreObj\fP.
.br
Here is an explanation on how these routines should behave :
.RS 10
.IP \(bu 3
int (*\fIsaveFunc\fP) (const void* \fIobj\fP , GoStream*);
.br
should use the \fBwriteXxx\fP (...) methods to save \fBobj\fP data. One may even
use \fBsaveObj\fP to save other objects. It returns 0 if an error is detected.
.IP \(bu 3
int (*\fIrestoreFunc\fP) (void** \fIobj\fP, GoStream*);
.br
should use the \fBreadXxx\fP (...) methods, and even \fIrestoreObj\fP method,
to read what \fIsaveFunc\fP has written, then create a new object instance and
return a pointer to it. It returns 0 if an error is detected.
.RE
.IP
It is very important that \fIrestoreFunc\fP reads items of the same type and 
in the same order as \fIsaveFunc\fP writes them.
.sp 1
.IP
.nf
.ta .15i .25i 1.0i
class GoStream {

	public:

		static void bind(const char*,
			int (*) (const void*, GoStream*),
			int (*) (void**, GoStream*));

		GoStream(GMedium* = NULL);
		~GoStream();

		GMedium* medium();
		int openRead(GMedium* = NULL);
		int openWrite(GMedium* = NULL);
		void close();

		int writeInt(int, const char* = NULL);
		int writeBool(GBool, const char* = NULL);
		int writeShort(short, const char* = NULL);
		int writeLong(long, const char* = NULL);
		int writeChar(char, const char* = NULL);
		int writeNumber(GNumber, const char* = NULL);
		int writeDouble(double, const char* = NULL);
		int writeVector(const GVector&, const char* = NULL);
		int writePoint(const GPoint&, const char* = NULL);
		int writeBox(const GBox&, const char* = NULL);
		int writeRgb(const GRgb&, const char* = NULL);
		int writeCoordSys(const GCoordSys&, const char* = NULL);
		int writeString(const char*, const char* = NULL);
		int writeBuffer(unsigned long, const char*, const char* = NULL);

		int writeComment(const char*);

		int saveObj(const void* obj, const char*, const char* = NULL);
		int restoreObj(void** obj, const char (**));

		int readInt(int*);
		int readBool(GBool*);
		int readShort(short*);
		int readLong(long*);
		int readChar(char*);
		int readNumber(GNumber*);
		int readDouble(double*);
		int readVector(GVector*);
		int readPoint(GPoint*);
		int readBox(GBox*);
		int readRgb(GRgb*);
		int readCoordSys(GCoordSys*);
		int readString(char**);
		int readBuffer(unsigned long*, char**);
};
.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.sp 1
.IP
\fBGoStream\fP (GMedium* \fImedium\fP = NULL)
.RS .8i
.IP \fIDescription\fP .3i
Class constructor.
.IP \fImedium\fP .3i
.br
Specifies a \fIMedium\fP for the new \fIGoStream\fP instance.
.RE
.sp 1
.IP
\fB~GoStream\fP()
.RS .8i
.IP \fIDescription\fP .3i
Class destructor. Does not affect the \fIMedium\fP attached to the
\fIGoStream\fP instance (if any).
.RE
.sp 1
.IP
.nf
static void \fBbind\fP (const char* \fIclassname\fP,
			int (*saveFunc) (const void* \fIobj\fP, GoStream* \fIgostream\fP),
			int (*restoreFunc) (void** \fIobj\fP, GoStream* \fIgostream\fP));
.fi
.RS .8i
.IP \fIDescription\fP .3i
This method is meant to tell all \fBGoStream\fP instances which functions to
call (\fIsaveFunc/restoreFunc\fP) when a \fBsaveObj/restoreObj\fP request is
made with an object whose class is identified by the string \fIclassname\fP.
.IP \fIclassname\fP .3i
Specifies a string to associate with the pair \fIsaveFunc/restoreFunc\fP.
A later call to \fIgostream\fP->\fBsaveObj\fP(\fIx\fP, \fIstr\fP) with \fIstr\fP
matching exactly \fIclassname\fP will trigger
\fIsaveFunc\fP(\fIx\fP, \fIgostream\fP).
Similarly, \fIrestoreFunc\fP(\fI&y\fP, \fIgostream\fP) will be call by
\fIgostream\fP when recognizing \fIclassname\fP in the \fBGoStream\fP private
data after a call \fIgostream\fP->\fBrestoreObj\fP(\fI&y\fP), \fI&str\fP).
.IP \fIsaveFunc\fP .3i
.IP \fIrestoreFunc\fP .3i
User functions. The semantic of these functions is user dependent.
.IP \fIobj\fP .3i
Usually, pointer to (a pointer to) an object instance of anonymous type for
\fIsaveFunc\fP (resp. \fIrestoreFunc\fP)
.IP \fIgostream\fP .3i
\fBGoStream\fP parameter for \fIobj\fP to save on (resp. restore from).
.RE
.sp 1
.IP
GMedium* \fBmedium\fP ()
.RS .8i
.IP \fIDescription\fP .3i
Returns the medium associated to the \fBGoStream\fP if any, else NULL.
.RE
.sp 1
.IP
int \fBopenRead\fP (GMedium* \fImedium\fP = NULL)
.RS .8i
.IP \fIDescription\fP .3i
Opens a read session with the specified \fBMedium\fP and tries to read it at
position 0. It returns 1 on completion or 0 on error.
.br
This function must be called by the application before any call to
\fBrestoreObj\fP (...) or \fBreadXxx\fP (...).
.IP \fImedium\fP .3i
Specifies the medium to read data from :
.br
if non NULL, it becomes the \fBMedium\fP to be used by \fIthis\fP until further similar instruction ;
.br
else, \fIthis\fP will use its current \fBMedium\fP, or return 0 if none;
.RE
.sp 1
.IP
int \fBopenWrite\fP (GMedium* \fImedium\fP = NULL)
.RS .8i
.IP \fIDescription\fP .3i
Opens a write session with the specified \fBMedium\fP. It returns 0 when
\fIthis\fP has no current \fIMedium\fP to use and the argument is NULL.
.br
This function must be called by the application before any call to
\fBsaveObj\fP (...) or \fBwriteXxx\fP (...).
.IP \fImedium\fP .3i
.br
Specifies the medium to save data on :
.br
if non NULL, it becomes the \fBMedium\fP to be used by \fIthis\fP until further similar instruction ;
.br
else, \fIthis\fP will use its current \fBMedium\fP, or return 0 if none;
.
.RE
.sp 1
.IP
void \fBclose\fP ()
.RS .8i
.IP \fIDescription\fP .3i
This function is used to close the \fBGoStream\fP.
.RE
.sp 1
.IP
int \fBwriteComment\fP (const char* \fIcomment\fP)
.RS .8i
.IP \fIDescription\fP .3i
Inserts a comment. Return 0 if an error occurred.
.IP \fIcomment\fP .3i
Specifies the comment string.
.RE
.sp 1
.IP
.nf
int \fBwriteInt\fP (int \fIval\fP, const char* \fIcomment\fP)
int \fBwriteBool\fP (GBool \fIval\fP, const char* \fIcomment\fP)
int \fBwriteShort\fP (short \fIval\fP, const char* \fIcomment\fP)
int \fBwriteLong\fP (long \fIval\fP, const char* \fIcomment\fP)
int \fBwriteChar\fP (char \fIval\fP, const char* \fIcomment\fP)
int \fBwriteNumber\fP (GNumber \fIval\fP, const char* \fIcomment\fP)
int \fBwriteDouble\fP (double \fIval\fP, const char* \fIcomment\fP)
int \fBwriteVector\fP (const GVector& \fIval\fP, const char* \fIcomment\fP)
int \fBwritePoint\fP (const GPoint& \fIval\fP, const char* \fIcomment\fP)
int \fBwriteBox\fP (const GBox& \fIval\fP, const char* \fIcomment\fP)
int \fBwriteRgb\fP (const GRgb& \fIval\fP, const char* \fIcomment\fP)
int \fBwriteCoordSys\fP (const GCoordSys& \fIval\fP, const char* \fIcomment\fP)
int \fBwriteString\fP (const char* \fIval\fP, const char* \fIcomment\fP)
int \fBwriteBuffer\fP (unsigned long \fIsize\fP, const char* \fIval\fP, const char* \fIcomment\fP)
.fi
.RS .8i
.IP \fIDescription\fP .3i
Writes the specified value and a comment string in the \fBMedium\fP.
.br
Returns 0 if an error is detected.
.IP \fIval\fP
Specifies the value to save. (NULL terminated string for \fBwriteString\fP).
.IP \fIsize\fP
Specifies the number of bytes in \fIval\fP (\fBwriteBuffer\fP only).
.IP \fIcomment\fP .3i
Specifies a comment string (optional);
.RE
.sp 1
.IP
.nf
int \fBreadInt\fP (int* \fIpval\fP)
int \fBreadBool\fP (GBool* \fIpval\fP)
int \fBreadShort\fP (short* \fIpval\fP)
int \fBreadLong\fP (long* \fIpval\fP)
int \fBreadChar\fP (char* \fIpval\fP)
int \fBreadNumber\fP (GNumber* \fIpval\fP)
int \fBreadDouble\fP (double* \fIpval\fP)
int \fBreadVector\fP (GVector* \fIpval\fP)
int \fBreadPoint\fP (GPoint* \fIpval\fP)
int \fBreadBox\fP (GBox* \fIpval\fP)
int \fBreadRgb\fP (GRgb* \fIpval\fP)
int \fBreadCoordSys\fP (GCoordSys* \fIpval\fP)
.fi
.RS .8i
.IP \fIDescription\fP .3i
Reads a value from the \fBMedium\fP and return it in \fIpval\fP. No allocation
is performed by these functions.
.br
Returns 0 if an error is detected.
.IP \fIpval\fP .3i
Specifies the address of the value to update. It is assumed that \fIpval\fP
points to enough memory to store the value to read.
.RE
.sp 1
.IP
int \fBreadString\fP (char** \fIpval\fP)
.RS .8i
.IP \fIDescription\fP .3i
Reads a string from the \fBMedium\fP. If *\fIpval\fP is NULL, the function will
allocate enough memory to store the NULL terminated string, else no allocation
is performed and the string is copied in *\fIpval\fP.
.br
Returns 0 if an error is detected.
.IP \fIpval\fP .3i
Specifies a pointer allocated memory or a pointer to NULL.
.RE
.sp 1
.IP
int \fBreadBuffer\fP (unsigned long* \fIsize\fP, char** \fIpval\fP);
.RS .8i
.IP \fIDescription\fP .3i
Reads a buffer from the \fBMedium\fP. If *\fIpval\fP is NULL, the function will
allocate enough memory, else no allocation is performed. In the later case,
*\fIsize\fP must contain the actual amount (in bytes) of memory available in
*\fIpval\fP. In both cases, the function returns the buffer in *\fIpval\fP (first char is **\fIpval\fP) and its size in *\fIsize\fP.
.br
Returns 0 if an error is detected.
.IP \fIsize\fP .3i
.br
Specifies the size of the buffer.
.IP \fIpval\fP .3i
.br
Specifies a pointer to allocated memory or a pointer to NULL.
.RE
.sp 1
.IP
int \fBsaveObj\fP (const void* \fIobj\fP, const char* \fIclass_name\fP, const char* \fIcomment\fP)
.RS .8i
.IP \fIDescription\fP .3i
This function saves the "object" \fIobj\fP. It calls the user function
\fIsaveFunc\fP (obj, \fIthis\fP) which has been registered previously 
(else, error) with \fBbind\fP (\fIclass_name\fP, \fIsaveFunc\fP, \fIrestoreFunc\fP);
.br
Returns 0 if an error is detected.
.br
Note that saving NULL is a valid move and is specially useful when saving lists
of objects.
.IP \fIobj\fP .3i
.br
Specifies a pointer to the object to save. May be NULL.
.IP \fIclass_name\fP .3i
.br
Specifies its class name.
.IP \fIcomment\fP .3i
.br
Specifies a comment to insert (optional).
.RE
.sp 1
.IP
int \fBrestoreObj\fP (void** \fIobj\fP, const char** \fIclass_name\fP, const char* \fIcomment\fP)
.RS .8i
.IP \fIDescription\fP .3i
This function restores an "object" and returns a pointer to it in \fIobj\fP.
It calls the user function \fIrestoreFunc\fP (obj, \fIthis\fP) which has been registered previously 
(else, error) with \fBbind\fP (\fIclass_name\fP, \fIsaveFunc\fP, \fIrestoreFunc\fP);
.br
Returns 0 if an error is detected.
.br
Note that *\fIobj\fP may return NULL with no error (see \fBsaveObj\fP (NULL, ..) ).
.IP \fIobj\fP .3i
.br
Points to the returned value and possibly to NULL.
.IP \fIclass_name\fP .3i
.br
Specifies the address of a constant string : \fIobj\fP class name.
.RE
.sp 1
.SH
\fBC BINDING\fP
.SS
\fBHeader\fP
.IP
\fI#include <Go/cGoStream.h>\fP
.SS
\fBFunctions\fP
.IP
.nf
void \fBDeleteGoStream\fP (GObjectId \fIgostream\fP);
void \fBGoStreamBind\fP (const char*, int (*saveProc) (const void*, GObjectId), int (*restoreProc) (void**, GObjectId));
GObjectId \fBGoStreamMedium\fP ();
int \fBGoStreamOpenRead\fP (GObjectId \fIgostream\fP, GObjectId \fImedium\fP);
int \fBGoStreamOpenWrite\fP (GObjectId \fIgostream\fP, GObjectId \fImedium\fP);
int \fBGoStreamSaveObj\fP (GObjectId \fIgostream\fP, const void*, const char*, const char*);
int \fBGoStreamRestoreObj\fP (GObjectId \fIgostream\fP, void**, const char* (*));
.fi
.sp 1
.RS .8i
.IP \fIDescription\fP .3i
See \fBGoStream\fP following members :
.sp 1
.nf
void ~GoStream().
void bind(const char*, int (*) (const void*, GObjectId), int (*) (void**, GObjectId));
GMedium* medium();
int openRead();
int openWrite();
int saveObj();
int restoreObj();
.RE
.SH
\fBUSAGE INFORMATION\fP
.IP
\fBGoStream\fP is an abstract class, thus it has no public constructor :
creation may only occur through subclasses constructors.
.RE
.SH
\fBSEE ALSO\fP
.IP
\fBGo\fP and \fBMedium\fP classes.
.nrPN \n%
