.\" $Id: GoUI.n,v 1.5 1992/12/31 12:44:27 jojic Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoUI 3Go "December 1992" "Version 1.2" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoUI\fP \(em the graphic object user interface class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/GoUI.h>\fP
.SH 
\fBCLASS\fP
.IP
\fBGoUI\fP does not inherit behavior from any class.
.SH
\fBDESCRIPTION\fP
.IP
To avoid mixing graphics and input management while implementing new
graphic objects, \fIGo\fPs are not sensitive to events. To make them sensitive
we have to add them a GoSensor (see GoSensor(3Go)).
.sp
\fBThe GoUI object dispatches GEvents to GoSensors\fP.
.sp
More precisely, there is one \fBGoUI\fP per \fIGoRoot\fP.
This \fIGoRoot\fP represents a \fBGo\fP tree which contains some \fIGoSensors\fP.
\fBGoUI\fP get \fIGEvent\fPs from the GoRoot's associated \fIGoInterf\fP and
dispatches them toward those \fIGoSensor\fPs.
.br
The creation of a \fBGoUI\fP implies the existence of user interactions
onto the associated \fIGoRoot\fP; therefore this \fIGoRoot\fP must be
refreshed at time to time. \fBGoUI\fP automatically calls \fIgoroot->flush\fP
when there are no more available events (through \fIGInputDispatcher\fP).
.sp
Everyone may send \fIGEvent\fPs to \fBGoUI\fP. \fBGoUI\fP makes no difference
between this event and an event comming from the associated \fIGoInterf\fP.
.sp
The application may filter \fBGoUI\fP's incoming events. This allows,
for example, on systems where the mouse has only one or two buttons, to
emulate a three buttons mouse.
.sp
\fBGoUI\fP is also responsible to generate \fBGo\fP specific events
(enter/leave sensor events and focus in/out events).
.sp
\fBGoUI\fP manages a focusing sensor and a grabbing sensor stack (a grabbing
sensor catches almost all events and a focusing sensor catches all keyboard
events). A grabbing sensor has a higher priority than a focusing sensor.
.sp
Finally, GoUI provides some methods to make the associated GoInterf
more user friendly:
methods allowing to get or set the maximum distance to pick small graphic
objects.
.sp
The goal of \fBGoUI\fP subclasses will be implementation of
more specific user interfaces. They will provide, for example,
different managements and representations of selected objects and some
graphic object editor functionalities.
.bp
.sp
.nf
.ta .15i .25i 1.0i
class GoUI
{
	public:
		GoUI (GoRoot*);
		~GoUI ();

	/* event dispatching */

		void addInputMask (GEventMask);
		void removeInputMask (GEventMask);

		virtual void dispatch (const GEvent*);

		void filter (
			GEvent* filter_proc(void*, GoUI*, const GEvent*),
			void* closure,
			GAddOrRemove = GADD);

		GNumber maxDistance () const;
		void maxDistance (GNumber max_distance);

	/* grab and focus */

		void grab (GoSensor*);
		void ungrab (GoSensor* = NULL);
		GoSensor* grabbingSensor () const;
		void cancelGrabbers ();

		void focus (GoSensor* = NULL);
		GoSensor* focusingSensor () const;

	/* misc. */

		GoRoot* root () const;
		virtual void root (GoRoot*);

		friend GoUI* GoUIFrom (const GoRoot*);

		const GPoint& pointerPos () const;
};
.fi
.SH
\fBPUBLIC METHODS\fP
.IP
\fBGoUI::GoUI\fP (GoRoot* \fIroot\fP)
.br
\fBGoUI::~GoUI\fP ()
.RS .8i
.IP \fIDescription\fP .3i
The GoUI constructor calls \fI``this->root(root)''\fP.
.br
The GoUI destructor calls \fI``this->root(NULL)''\fP
(see \fIroot(GoRoot*)\fP).
.RE
.sp
.IP
virtual void \fBdispatch\fP (const GEvent* \fIevent\fP)
.RS .8i
.IP \fIDescription\fP .3i
This method dispatches \fIevent\fP through \fIGoSensor\fPs.
.br
There are two types of events: events without a position (expose event)
and events having a position.
.br
Usually GoRoot is responsible to keep a nice display. But sometimes a
grabbing sensor may need to overdraw directly things onto the output.
In such a case, this sensor *must* receive an expose event.
\fBdispatch\fP sends expose events to every grabbing sensor.
.sp
For events having a position, \fBdispatch\fP looks for sensors inside the
\fBGo\fP tree associated to this \fBGoUI\fP. It goes through them from top
to bottom (remember that a child is on top of its parent and the next brother
is on top of its previous brother).
To each sensor, it asks if it contains the position of the event.
If the sensor does, \fBGoUI\fP asks it if it is interested by this event.
If it is, \fBGoUI\fP send it to the sensor and stop the recursion.
Otherwise it recommences with the following sensor.
.br
In parallel to this \fIevent\fP dispatching, \fBGoUI\fP also generates
enter and leave sensor events and focus in/out events.
.br
The first sensor which contains event position and which is interested by
an enter sensor event receives a \fIGEnterSensorEvent\fP. Later, when
that sensor no more contains the mouse, or when another sensor must receive
an enter sensor event, that sensor will receive a \fIGLeaveSensorEvent\fP.
.br
The focusing sensor is set with the call \fIgoui->focus(sensor)\fP.
\fBGoUI\fP generates a \fIGFocusOutEvent\fP to the previous focusing sensor
and a \fIGFocusInEvent\fP to the new focusing sensor.
.sp
The \fBdispatch\fP method is virtual, allowing you to implement another
event dispatching while keeping all other \fBGoUI\fP (and subclasses)
functionalities.
.sp
The event dispatching behavior is modified when there are grabbing or
focusing sensors (see \fIgrab()\fP and \fIfocus()\fP).
.RE
.sp
.IP
.nf
void \fBaddInputMask\fP (GEventMask \fImask\fP)
void \fBremoveInputMask\fP (GEventMask \fImask\fP)
.fi
.RS .8i
.IP \fIDescription\fP .3i
These methods are used to inform goui about which event types will be useful.
These methods are typically used by sensors. When a sensor is activated, it
calls \fIgoui->addInputMask(this_sensor_mask)\fP, and when it is disactivated,
it calls \fIgoui->removeInputMask(this_sensor_mask)\fP. GoUI gather these
event masks and sets their union onto its associated gointerf.
.br
Enter/leave sensor events are generated by GoUI itself,
therefore if a mask contains such types, GoUI sets the compress motion mask
onto its gointerf.
.RE
.sp
.IP
void \fBfilter\fP (
.br
	GEvent* \fIfilter_proc\fP(void*, GoUI*, const GEvent*),
.br
	void* \fIclosure\fP,
.br
	GAddOrRemove \fPadd_or_remove\fP = GADD);
.RS .8i
.IP \fIDescription\fP .3i
This method allows you to add or to remove filters on events incoming
to this \fBGoUI\fP. The first action done by the dispatch method is to call
all filters. A filter is called with following parameters: the \fIclosure\fP,
this \fBGoUI\fP, the \fIevent\fP. The event, output of a filter, is passed
as input for the next filter.
.br
The filter chain may return \fINULL\fP, the original \fIevent\fP or a new
event. If it returns \fINULL\fP, \fIdispatch\fP stops, otherwise it
dispatches the event through sensors. New events are deleted by dispatch
itself at the end of the dispatching process.
.sp
.IP \fIfilter_proc\fP .3i
This is the filter function you add (or remove) to this \fBGoUI\fP. This
function has this signature:
.br
	GEvent* \fIfilter_proc\fP (void* closure, GoUI*, const GEvent*);
.br
If this function returns \fINULL\fP, the original event is discarded.
If this function returns a new event, it is automatically deleted (after
the dispatching process) by the \fIdispatch()\fP method.
.sp
.IP \fIclosure\fP .3i
This \fIclosure\fP is passed as first parameter to the corresponding filter.
.sp
.IP \fIadd_or_remove\fP .3i
If \fIadd_or_remove\fP is equal to \fIGADD\fP, the filter is added, otherwise
if it is equal to \fIGREMOVE\fP, the filter \fIfilter_proc\fP associated to
\fIclosure\fP is removed (if any).
.RE
.sp
.IP
GNumber \fBmaxDistance\fP () const;
.br
void \fBmaxDistance\fP (GNumber \fImax_distance\fP);
.RS .8i
.IP \fIDescription\fP .3i
This method allows the user to ``pick'' easy small objects.
When the user clicks on a \fBGo\fP, if the position of the mouse is nearer
than \fImax_distance\fP, \fBGoUI\fP consider that it is inside the object.
.br
Without parameter, this method returns the current \fImax_distance\fP
associated to this \fBGoUI\fP (i.e. the \fImax_distance\fP on the ``window''
of the \fIGoInterf\fP associated to this \fBGoUI\fP).
.RE
.sp
.IP
void \fBgrab\fP (GoSensor* \fIsensor\fP)
.br
void \fBungrab\fP (GoSensor* \fIsensor\fP = NULL)
.RS .8i
.IP \fIDescription\fP .3i
\fBGoUI\fP manages a stack of grabbing sensors. When an event containing a
position (i.e. different than expose) arrives, if the stack is not empty, the
\fIdispatch()\fP method sends the event to the sensor which is the top of
the grabbing sensor stack.
.br
\fIgrab(sensor)\fP pushes \fIsensor\fP on 
the grabbing sensor stack of this \fBGoUI\fP. \fIungrab(sensor)\fP removes
\fIsensor\fP from the grabbing sensor stack, or the top of the grabbing
sensor stack if \fIsensor\fP is \fINULL\fP.
.br
Grabbing sensors may get expose events.
.br
While the grabbing sensor stack is not empty, the \fIdispatch()\fP method
will not generates enter/leave sensor events.
.br
Grabbing is prior on focusing.
.RE
.sp
.IP
GoSensor* \fBgrabbingSensor\fP () const;
.RS .8i
.IP \fIDescription\fP .3i
This method returns the sensor which is the top of the grabbing sensor stack.
If this stack is empty, this method returns \fINULL\fP.
.RE
.sp
.IP
void \fBcancelGrabbers\fP ();
.RS .8i
.IP \fIDescription\fP .3i
This method destroys every grabbing sensor.
.RE
.sp
.IP
void \fBfocus\fP (GoSensor* \fIsensor\fP = NULL);
.RS .8i
.IP \fIDescription\fP .3i
\fBGoUI\fP stores a focusing sensor. If it is not \fINULL\fP, the
\fIdispatch()\fP method sends all keyboard events to it.
The method focus allows you to set (or reset if \fIsensor\fP is \fINULL\fP)
the focusing sensor.
.br
Grabbing is prior on focusing.
.RE
.sp
.IP
GoSensor* \fBfocusingSensor\fP () const;
.RS .8i
.IP \fIDescription\fP .3i
This method returns the current focusing sensor of this \fBGoUI\fP. If
there is no focusing sensor, this method returns \fINULL\fP.
.RE
.sp
.IP
GoRoot* \fBroot\fP () const;
.br
void \fBroot\fP (GoRoot* \fIroot\fP);
.RS .8i
.IP \fIDescription\fP .3i
You may get/set the \fBGoRoot\fP associated to this \fBGoUI\fP.
\fBGoUI\fP will get events from the \fIroot\fP's associated \fIinterf\fP
and send them to sensors which belong to the \fIroot\fP subtree.
.sp
.IP \fIroot\fP .3i
The new \fIGoRoot\fP associated to this \fBGoUI\fP. If it is \fINULL\fP,
this \fBGoUI\fP will no more dispatch events, nevertheless you are able
to set filters and \fImaxDistance\fP.
.RE
.sp
.IP
friend GoUI* \fBGoUIFrom\fP (const GoRoot* \fIroot\fP);
.RS .8i
.IP \fIDescription\fP .3i
This function allows you to get the \fBGoUI\fP associated to a \fIGoRoot\fP.
If there are no such \fBGoUI\fP, the functions will
return \fINULL\fP.
.RE
.sp
.IP
const GPoint& pointerPos () const
.RS .8i
.IP \fIDescription\fP .3i
This method returns the current mouse position. It is useful to call this
method rather than the usual query because GoUI stores the pointer position
and therefore we do not spend time to call the graphic system.
.RE
.SH
\fBC BINDING\fP
.IP
To be completed.
.SH
\fBSEE ALSO\fP
.IP
GoRoot, GoInterf, GoSensor, Event, Cursor, InDisp.
.nrPN \n%
