.\" $Id: Grabber.n,v 1.2 1993/01/04 09:37:44 jojic Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991, 1992 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH Grabber 3Go "December 1992" "Version 1.2" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGrabber\fP \(em grabber object classes.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Grabber.h>\fP
.sp 1
.SH
\fBCLASS\fP
.IP
\fBGGrabber(Pgm)\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGInteractor(Pgm)\fP class
.RE
.sp 1
.SH
\fBDESCRIPTION\fP
.IP
\fBGGrabberPgm is used for the programming of user interactions ala
``elastic rectangle''.\fP
.br
Such interactions follow the same scheme, i.e. a loop of:
.br
	- drawings,
.br
	- wait for a motion event,
.br
	- clear the previous drawings,
.br
	- re-computation of data values (using the new mouse position),
.br
This loop stops on some specific user events, which may generate a success or a
cancellation of the interaction.
.sp
Every action from the list above, correspond to a virtual method of
the \fBGGrabber\fP class. The virtual method \fIhandle(event)\fP
executes actions above.
.sp
Therefore, the programming of, for instance, an elastic rectangle is done
by subclassing \fBGGrabberPgm\fP, and by redefining virtual methods draw,
compute, ... . The \fBGGrabberPgm\fP class is virtual.
.sp
.nf
.ta .15i .25i 1.0i

/* The GGrabberPgm class has no public methods */


class GGrabber : public GInteractor
{
	public:
		virtual ~GGrabber ();

		virtual void compute (const GEvent*); //superclass first

		virtual void draw (); //superclass first
		virtual void drawAll ();
		virtual void clear ();
		virtual void clearAll ();

		virtual GBool isDoitEvent (const GEvent*) const;
		virtual GBool isCancelEvent (const GEvent*) const;

		GoSensor* sensor () const;

		const GPoint& position () const;

	/* superclasses virtual methods */
		virtual GBool careAbout (const GEvent*) const;
		virtual GBool handle (const GEvent*);
		virtual void doit ();
		virtual void cancel ();
};
.fi
.sp 2
.SH
\fBPUBLIC METHODS\fP
.IP
virtual GBool \fBcareAbout\fP (const GEvent* \fIevent\fP) const;
.RS .8i
.IP \fIDescription\fP .5i
\fBGGrabber\fP returns GTRUE if \fIevent\fP is an expose event, a motion event
or an arrow key event (left, up, right or down). An arrow key is equivalent
to a motion event (see the \fIhandle\fP method).
.RE
.sp
.IP
virtual GBool \fBhandle\fP (const GEvent* \fIevent\fP)
.RS .8i
.IP \fIDescription\fP .5i
This Grabber's method implement the automata.
.sp
If \fIevent\fP is an expose event, things are simply redrawn by calling
the \fIdrawAll\fP method.
.br
Now what does \fIhandle\fP do if \fIevent\fP is not an expose event ?
.br
It calls the \fIClear\fP method.
Then if \fIevent\fP is a motion event, it calls \fIcompute\fP and
\fIdraw\fP. Otherwise, if \fIisDoitEvent(event)\fP returns GTRUE,
it calls the \fIdoit()\fP method.
Otherwise, if \fIisCancelEvent(event)\fP returns GTRUE, it calls
the \fIcancel\fP method.
.sp
Motion events may be simulated with arrow keys. A pressed arrow key without
modifier is equivalent to a one mm displacement in the same direction.
If CONTROL is pressed at same time, the displacement is of 1/10 of mm.
If ALTERNATE (META) is pressed at same time, the displacement if of 10 mm.
.sp
In all these cases, the event was useful, and \fIhandle\fP returns GTRUE.
.sp
For other events, \fIhandle\fP will return GFALSE (in that case, even the
above \fIclear\fP is not called).
.RE
.sp
.IP
virtual void \fBdraw\fP () const
.RS .8i
.IP \fIDescription\fP .5i
This virtual method does nothing for the \fBGGrabber\fP class. You \fBmust\fP
defined it if you implement a \fBGGrabber\fP subclass.
.br
See the \fIhandle\fP method to know when this method is called.
.RE
.sp
.IP
virtual void \fBdrawAll\fP () const
.RS .8i
.IP \fIDescription\fP .5i
The grabber's \fIdrawAll\fP method simply calls \fIdraw()\fP.
.br
This method is called at \fBGGrabber\fP initialization and while
handling an expose event.
.RE
.sp
.IP
virtual GBool \fBisDoitEvent\fP (const GEvent* \fIevent\fP) const
.RS .8i
.IP \fIDescription\fP .5i
This virtual method returns GTRUE if it considers that \fIevent\fP indicates
that the interaction is done. \fBGGrabber\fP returns GTRUE if \fIevent\fP is a 
button press, a button release or a carriage return event.
.br
See the \fIhandle\fP method to know when this method is called.
.RE
.sp
.IP
virtual GBool \fBisCancelEvent\fP (const GEvent* \fIevent\fP) const;
.RS .8i
.IP \fIDescription\fP .5i
This virtual method returns GTRUE if it considers that \fIevent\fP indicates
that the interaction is cancelled. \fBGGrabber\fP returns GTRUE if
\fIevent\fP is an ESCAPE keyboard event or a button 3 press event.
.br
See the \fIhandle\fP method to know when this method is called.
.RE
.sp
.IP
virtual void \fBcompute\fP (const GEvent* \fIevent\fP) const;
.RS .8i
.IP \fIDescription\fP .5i
This method recomputes \fIprev_pos\fP and \fI_pos\fP in the grabber
protected data. If your grabber subclass has some
more data to recompute you must redefined this virtual method.
In such a case you first have to call the superclass's \fIcompute\fP method.
.br
See the \fIhandle\fP method to know when this method is called.
.RE
.sp
.IP
virtual void \fBclear\fP ()
.RS .8i
.IP \fIDescription\fP .5i
This method must clear the previous draw. \fBGGrabber\fP simply calls again the
\fIdraw\fP method. This will work if all drawings are done with ``invert''
pens and/or brushes.
.br
See the \fIhandle\fP method to know when this method is called.
.RE
.sp
.IP
virtual void \fBclearAll\fP ()
.RS .8i
.IP \fIDescription\fP .5i
Grabbers \fIclearAll\fP method simply calls \fIclear()\fP.
.br
This method is called by grabbers \fIdoit()\fP and \fIcancel()\fP methods.
.RE
.sp
.IP
virtual void \fBdoit\fP ()
.RS .8i
.IP \fIDescription\fP .5i
\fBGGrabber\fP calls the superclass's \fIdoit\fP method
and then calls \fIclearAll()\fP.
.br
See the \fIhandle\fP method to know when this method is called.
.RE
.sp
.IP
virtual void \fBcancel\fP ()
.RS .8i
.IP \fIDescription\fP .5i
\fBGGrabber\fP calls the superclass's \fIcancel\fP method
and then calls \fIclearAll()\fP.
.br
See the \fIhandle\fP method to know when this method is called.
.RE
.sp
.IP
GoSensor* sensor () const
.RS .8i
.IP \fIDescription\fP .5i
This method returns the sensor which is executing this grabber.
.RE
.sp
.IP
const GPoint& position () const
.RS .8i
.IP \fIDescription\fP .5i
This method returns the last mouse position handled by this grabber.
.RE
.sp 2
.SH
\fBC BINDING\fP
.IP
\fITo be defined.\fP
.sp
.SH
\fBUSAGE INFORMATION\fP
.IP
\fITo be defined.\fP
.sp
.SH
\fBSEE ALSO\fP
.IP
Interactor, Event.
.nrPN \n%
