.\" $Id: Interactor.n,v 1.2 1992/12/31 16:03:08 jojic Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH Interactor 3Go "December 1992" "Version 1.2" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBInteractor\fP \(em the interactor object class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Interactor.h>\fP
.sp 1
.SH
\fBCLASS\fP
.IP
\fBGInteractor\fP does not inherit behavior from any class.
.sp 1
.SH
\fBDESCRIPTION\fP
.IP
\fBThe GInteractorPgm class is used for the programming of user interactions.
The GInteractor class is used for their execution.\fP
.sp
Examples of user interactions:
.br
	creation of an ellipse arc,
.br
	edition of a text,
.br
	dialing a phone number by using voice recognition.
.sp
We want to allow the programming of complex interactions (i.e. creation of an
ellipse arc) without making it difficult to program obvious ones (ala
event translation table). This is why the basic GInteractor(Pgm) class is virtual.
In fact the \fBGInteractor\fP contains all virtual methods needed to the
execution of an interaction.
.sp
The fact that there is a common superclass to all objects serving the
programming of user interactions allows also their grouping
(their execution in parallel or one after the other).
.sp
How does it work?
.br
You program your interaction with a subclass of GInteractorPgm. It may be a C++
programming (i.e. \fIGGrabber\fPs subclasses) or a programming of a simple
interpreted language (i.e. the ``translation table'' given by \fIGTranslator\fP).
.br
After that programming, you are able to execute this user interaction many times,
by calling the \fIstart\fP method of the interactor program above. The \fIstart\fP
method returns a GInteractor, which is the execution part of user interactions.
.sp
The \fIhandle(event)\fP method of an interactor interprets \fIevent\fP using rules
defined in its associated interactor program.
.sp
In general, the programming of interactions is done a long time before
their use. It is then useful to have a way to retrieve them.  This is why
you may set a name to an interactor program. This name is unique. The function
\fIGInteractorPgmFromName(name)\fP returns the interactor program whos name
is \fIname\fP, and the friendly method \fIGCreateInteractor (name, ...)\fP
does everything needed to start the execution of a new \fBGInteractor\fP: it find
the \fBGInteractorPgm\fP from \fIname\fP, and it calls its \fIstart\fP method
and return the resulting GInteractor.
.br
For instance, you build an interactor asking the user to choose a Go on its
screen. You call this interactor "ChooseAGo". Later, anybody will be able
to use this interactor knowing only its name.
.sp
It is possible to have a more structured use of interactor names
(see Sensor(3Go)).
.sp
An interactor may have a return value. When it is finished, you can get it
by calling the virtual \fIreturnValue()\fP method.
.sp
In conclusion, you will learn different methods of programming user interactions
by reading the documentation of different subclasses of \fBGInteractorPgm\fP,
and you are welcome to add new ones.
.sp
.nf
.ta .15i .25i 1.0i
class GInteractorPgm
{
	public:
    
		friend GInteractorPgm*
			GInteractorPgmFromName (const char* interaction_program_name);

		const char* name () const;

		int cursorIdent () const;
		void cursorIdent (int cid);

		virtual GInteractor* start (const GEvent*, Go*) = 0;
};


class GInteractor
{
	public:

		friend GInteractor* GCreateInteractor
			(const char* name, const GEvent* startEvent, Go* go);

		GEventMask inputMask () const;
		GItorState state () const;
		GInteractorPgm* pgm () const;
		void* returnValue () const;
		Go* go () const;
    
		virtual GBool careAbout (const GEvent*) const;
		virtual GBool handle (const GEvent*) = 0;
		virtual void doit ();
		virtual void cancel ();
};
.fi
.sp 2
.SH
\fBGInteractorPgm PUBLIC METHODS\fP
.IP
friend GInteractorPgm* \fBGInteractorPgmFromName\fP (const char* \fIname\fP)
.RS .8i
.IP \fIDescription\fP .5i
This function returns the \fBGInteractorPgm\fP which name is \fIname\fP.
If there are no such interactor, \fINULL\fP is returned.
.RE
.sp
.IP
const char* name () const
.RS .8i
.IP \fIDescription\fP .5i
This method returns the name of the \fBGInteractorPgm\fP.
It may be \fINULL\fP (in that case it is not accessible through the
\fIGInteractorPgmFromName\fP method).
.RE
.sp
.IP
int cursorIdent () const
.br
void cursorIdent (int cid)
.RS .8i
.IP \fIDescription\fP .5i
This method set or get the cursor used while this interactor is running.
If no cursor were set on this interactor program, the execution of the interactor
will not change the cursor.
.br
Look in \fIGoInterf(3Go)\fP for the usage of \fIcid\fP.
.sp
.RE
.IP
virtual void \fBstart\fP (const GEvent* \fIstartEvent\fP, Go* go)
.RS .8i
.IP \fIDescription\fP .5i
This method starts the execution of the \fBGInteractor\fP
associated to the interactor program. The created interactor is in
\fIGITOR_RUNNING\fP state.
.sp
Most often, \fIgo\fP is the go on which this interactor acts (rescale, motion, ...).
But even if the interaction has nothing to do with that \fIgo\fP, this parameter
is mandatory. It will give to the interactor all contextual informations needed
to execute the user interaction (through that \fIgo\fP it can find the right
GoInterf and the right GoUI).
.sp
The \fIstartEvent\fP parameter may be \fINULL\fP. It is useful for interactor
sequences. The last event handled by the interactor \fIn\fP becomes the first
event handled by the interactor \fIn+1\fP.  
.RE
.sp 2
.SH
\fBGInteractor PUBLIC METHODS\fP
.IP
friend GInteractor* GCreateInteractor (const char* name, const GEvent* startEvent, Go* go)
.RS .8i
.IP \fIDescription\fP .5i
This friendly method is a abbreviation for \fIGInteractorPgmFromName\fP followed
by \fIstart\fP.
.RE
.sp
.IP
GEventMask \fBinputMask\fP () const
.RS .8i
.IP \fIDescription\fP .5i
This method returns the input mask of this interactor. That means the
mask of all event types which will activate some reaction during the
execution of the interactor.
.RE
.sp
.IP
GItorState \fBstate\fP () const
.RS .8i
.IP \fIDescription\fP .5i
This method returns the state of the interactor. It may be one of:
\fIGITOR_RUNNING\fP, if the interactor is not yet finished, \fIGITOR_DONE\fP if the
interactor is well finished (through a call to \fIdoit\fP), or \fIGITOR_CANCELLED\fP
if the interactor is cancelled (through a call to \fIcancel\fP).
.RE
.sp
.IP
GInteractorPgm* \fBpgm\fP () const
.RS .8i
.IP \fIDescription\fP .5i
This method returns the \fBGInteractorPgm\fP which has created this interactor.
.RE
.sp
.IP
void* \fBreturnValue\fP () const
.RS .8i
.IP \fIDescription\fP .5i
This method returns the ``return value'' (if any) of that interactor. If the
interactor has no return value, the method will return \fINULL\fP.
.br
It is a good practice, before asking the return value of an interactor, to verify
that its state is \fIGITOR_DONE\fP.
.RE
.IP
Go* \fBgo\fP () const
.RS .8i
.IP \fIDescription\fP .5i
This method returns the \fIgo\fP parameter associated to the \fIstart\fP or the
\fIGCreateInteractor\fP methods.
.RE
.sp
.IP
virtual GBool \fBcareAbout\fP (const GEvent* \fIevent\fP) const
.RS .8i
.IP \fIDescription\fP .5i
This method returns \fIGFALSE\fP if the call of \fIhandle(event)\fP will
do nothing.
.br
This method is more precise than \fIinputMask\fP (you may need \fIGCHAR_EVENT\fP
only because you are interested by a \fICARRIAGE RETURN\fP).
.RE
.sp
.IP
virtual GBool \fBhandle\fP (const GEvent* \fIevent\fP) const
.RS .8i
.IP \fIDescription\fP .5i
The execution of an interactor is done step by step by calling this method.
.br
If \fIcareAbout(event)\fP would returned \fITRUE\fP then this will effectively
activate some action from the interactor.
.br
Dependently of the interactor program, some events may stop the interactor
(i.e. it enters the \fIGITOR_DONE\fP state) or cancel the interactor (i.e. it
enters the \fIGITOR_CANCELLED_STATE\fP state).
.sp
If the interactor is not in the \fIGITOR_RUNNING\fP state, this method will do
nothing.
.RE
.sp
.IP
virtual void \fBdoit\fP ()
.RS .8i
.IP \fIDescription\fP .5i
At any time, if you want to terminate an interactor, you may call this method.
The interactor will then enter the state \fIGITOR_DONE\fP.
.br
Dependently of the interactor program, some events (through a call to the \fIhandle\fP
method) may activate a call to \fIdoit\fP.
.RE
.sp
.IP
virtual void \fBcancel\fP ()
.RS .8i
.IP \fIDescription\fP .5i
At any time, if you want to cancel an interactor, you may call this method.
The interactor will then enter the state \fIGITOR_CANCELLED\fP.
.br
Dependently of the interactor program, some events (through a call to the \fIhandle\fP
method) may activate a call to \fIcancel\fP.
.RE
.sp 2
.SH
\fBC BINDING\fP
.IP
\fITo be defined.\fP
.sp
.SH
\fBUSAGE INFORMATION\fP
.IP
For the programming of new user interactions see \fI``USAGE INFORMATION''\fP of 
\fBGInteractor\fP subclasses.
.sp
To execute the user interaction programmed in an interactor named "doSomething",
you must get the interactor program through the method \fIGInteractorPgmFromName\fP,
call the \fIstart\fP method to get an interactor instance,
call the \fIhandle\fP method each time you have a user event. All this while
the interaction is not finished:
.nf
.ta .15i .25i 1.0i

	GInteractorPgm* itorPgm = GInteractorFromName("doSomething");
	GInteractor* itor = itorPgm->start (NULL, goroot);

	while (itor->state() == GITOR_RUNNING)
	{
		GEvent* event = -- get next event --;
		if (itor->careAbout(event)) //optional
			itor->handle(event);
	}

	if (itor->state() == GITOR_CANCELLED)
		...;
	else if (itor->state() == GITOR_DONE)
		...;

	delete itor;
.fi
.sp
.SH
\fBSEE ALSO\fP
.IP
\fBGInteractor(Pgm)\fP subclasses.
.nrPN \n%
