.\" $Id: PSGoInterf.n,v 1.1.1.1 1992/03/18 09:44:04 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH PSGoInterf 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBPSGoInterf\fP \(em the PostScript language Go interface object class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/PSGoInterf.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBPSGoInterf\fP inherits behavior from the \fBGoInterf\fP class.
.sp 1
.SH
\fBDESCRIPTION\fP
.IP
The \fIPSGoInterf\fP object class implements the interface between a \fBPostScript language\fP
and \fBGo\fP. It implements all necessary methods described in \fIGoInterf(3Go)\fP, some fast methods in specific case and some additional PostScript specific methods. \fBOnly PostScript specific methods or behavior are describe here\fP.
.IP
Of course, \fIPSGoInterf\fP class does not have \fIinput\fP methods implementation. It implements only some \fIquery\fP methods of fonts.
.IP
The interface uses some resources files: 
.RS .8i
- ps/prologue.ps.
.br
- ps/image.ps.
.br
- ps/font/ALIASES.
.IP
These files are placed in the Go environment directory (cf GetFilePath() (3Go)).
.IP
The \fImetrics\fP of the fonts are read into AdobeFontMetrics(AFM) files. The ALIASES file gives names of metric file which correspond to ADOBE fonts. The metric file name are relatives to "ps/font" directory. If a wanted font does not correspond to a PostScript one the default font used will be "Courier". Note that the delivery gives you a subset of all the PostScript fonts. If you want to have a larger set of font you can ask ADOBE to get it.
.IP
Each constructor reads the \fBprologue file\fP . This \fIprologue\fP contains some particular \fIpostscript\fP functions and definitions. 
.IP
Note that all \fIpostscript\fP functions are available before,after or during the generation of the \fIpostscript\fP output using the \fImedium\fP of the interface.
.IP
Note also that the PSGoInterf uses only the write methods of the \fIMedium\fP class to write the PostScript program; so all \fIMedium\fP which implements these methods are available (.i.g a FileMedium opened with an output pipe).
.IP
The \fBPSGoInterf\fP class generates Level 1 and Level 2 postscript language. The program will test his level a run time.
.sp 1
.br
.nf
.ta .15i .25i 1.0i

enum GLayoutMode {
    GPORTRAIT,
    GLANDSCAPE,
};

class PSGoInterf : public GoInterf {
	public:
		/** specific PostScript methods **/

		PSGoInterf (GLayoutMode = GPORTRAIT);
		PSGoInterf (const char* filename, const char* openwrite_type, GLayoutMode = GPORTRAIT);
		PSGoInterf (GMedium* medium, GLayoutMode = GPORTRAIT);

		~PSGoInterf();
		
		GBool setOuptut(const char* filename, const char* openwrite_type);
		void setOutput(GMedium*);

		GMedium* medium();

		 /** specific behavior **/
		GNumber pixelWidth();
		GNumber pixelHeight();
	}
.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
\fBPSGoInterf\fP(GLayoutMode \fIlayout\fP = GPORTRAIT);
.RS .8i
.IP \fIDescription:\fP .5i
The constructor creates a \fIpostscript\fP interface. Internally it creates the \fBGFileMedium\fP with the standard output file \fIstdout\fP.
.IP
It reads the \fIprologue\fP file and writes it onto \fIstdout\fP.
.IP \fIlayout\fP .5i
.br
Specifies the \fIlayout\fP mode of the drawings.
.RE
.sp 1
.IP
\fBPSGoInterf\fP(const char* \fIfilename\fP, const char* \fIopen_type\fP, GLayoutMode \fIlayout\fP = GPORTRAIT);
.RS .8i
.IP \fIDescription:\fP .5i
The constructor creates a \fIpostscript\fP interface. Internally it creates the \fBGFileMedium\fP with the given \fIfilename\fP and \fIopen_type\fP.
.IP
It reads the \fIprologue\fP file and writes it onto the opened file.
.IP
The destructor will close and delete the created \fIGFileMedium\fP. So after the destruction the returned \fImedium\fP of the \fImedium()\fP method is not available. 
.IP \fIfilename\fP .5i
.br
Specifies the file to open.
.sp 1
.IP \fIopenwrite_type\fP .5i
.br
Specifies the type of the opening, cf \fIfopen\fP(3C) for \fItype\fP explanations.
.sp 1
.IP \fIlayout\fP .5i
.br
Specifies the \fIlayout\fP mode of the drawings.
.RE
.sp 1
.IP
\fBPSGoInterf\fP(GMedium* \fImedium\fP, GLayoutMode \fIlayout\fP = GPORTRAIT);
.RS .8i
.IP \fIDescription:\fP .5i
The constructor creates a \fIpostscript\fP interface. It takes the \fPmedium\fP. The methods \fImedium()\fP will returns the same medium. So the \fImedium\fP must be available during the life of the interface.
.IP
It reads the \fIprologue\fP file and writes it onto the \fImedium\fP.
.IP \fImedium\fP .5i
.br
Specifies the \fImedium\fP where the postscript program will be written.
.RE
.IP \fIlayout\fP .5i
.br
Specifies the \fIlayout\fP mode of the drawings.
.RE
.sp 1
.IP
\fB~PSGoInterf\fP()
.RS .8i
The destructor deletes the PSGoInterf and the resources used. It appends to the program the "showpage" postscript function and the "%%EOF" comment. If the \fImedium\fP has been created at construction, the destructor will close the file.
.RE
.sp 1
.IP
GMedium* \fBmedium()\fP
.RS .8i
.IP \fIDescription\fP .5i
The function returns the \fImedium\fP used by the interface. It is always non NULL because all constructors which do not have \fPmedium\fP in parameter will create it.
.RE
.sp 1
.IP
GNumber \fBpixelWidth()\fP
.IP
GNumber \fBpixelHeight()\fP
.RS .8i
.IP \fIDescription\fP .5i
The methods return the pixel size in mm of a 300 dots_per_inch printer.
\fI
.SH
\fBC BINDING\fP
.sp 1
.nf
	GObjectId   \fBPSGoInterfCreate\fP(GLayoutMode \fImode\fP);

	GObjectId   \fBPSGoInterfCreateWith_Filename\fP(const char* \fIfilename\fP,
                                          const char* \fIopenwrite_type\fP,
                                          GLayoutMode \fImode\fP);

	GObjectId   \fBPSGoInterfCreateWith_Medium\fP(GObjectId \fImedium\fP, 
						 GLayoutMode \fI\fP);

	GObjectId   \fBPSGoInterfMedium\fP(GObjectId \fIpsi\fP);
.fi
.sp 1
.IP \fIDescription\fP .5i
\fIsee\fP PSGoInterf::\fIname\fP method. All C++ references must be seen as an address in C.
.br
The C interface for the \fIPSGoInterf\fP object provides only the interface for the specific PSGoInterf methods.
.br
For the others available C functions of an \fIinterface\fP see \fBGoInterf\fP(3Go).
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
Specific PSGoInterf methods are strongly discouraged because of portability of your application over another GoInterf. To show the portability problem over another interface, it is usual to use PSGoInterf as an GoInterf and to cast in PSGoInterf to use specific PSGoInterf methods.
.sp 1
.SH
\fBBUGS\fP
.sp 1
.IP
The current release does not handle any \fIclip\fP during a \fIdraw\fP request. The \fIsetClip\fP GoInterf method is ignored. During a \fIrefresh\fP of all a \fIgoroot\fP hierarchy it does not matter because the \fIclip\fP is the whole page; except for specific \fIgo\fP (e.g the GoScrolledText) where the drawing is always clipped.
.br
The current release does not handle any \fIstipple\fP and \fIpattern\fP.
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBGoInterf\fP, \fBGMedium\fP, \fBGFileMedium\fP, \fBfopen(3C)\fP.
.nrPN \n%
