.\" $Id: Sensor.n,v 1.2 1992/12/31 16:42:46 jojic Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GoSensor 3Go "December 1992" "Version 1.2" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoSensor\fP \(em the sensor object class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Sensor.h>\fP
.sp 1
.SH
\fBCLASS\fP
.IP
\fBGoSensor\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGo\fP class
.RE
.sp 1
.SH
\fBDESCRIPTION\fP
.IP
To avoid mixing graphics and input management while implementing new
graphic objects, \fIGo\fPs are \fBnot sensitive\fP to events.
.sp
\fBGoSensor and its subclasses are the only sensitive objects inside
the Go World.\fP
.sp
A \fBGoSensor\fP is a \fBGo\fP. The basic \fBGoSensor\fP class is sensitive
onto the full output of its \fBGo\fP parent. Two GoSensor subclasses
implement a different sensitivity: one is sensitive onto the full screen, and
the other onto a rectangular area.
You are welcome to implement GoSensor subclasses with some specific
sensitivity matching your needs (by redefining the virtual \fIm_contains\fP
method inside a subclass of sensor. To create a new Go class use the
shell script ``create-go-class'' (see create-go-class(3Go))).

A GoSensor does not permit the programming of a behavior with regard to
user events. This is offered by the \fIGInteractor(Pgm)\fP objects.
Each sensor has an associated interactor. GoUI looks for the destination
of an event, i.e. a sensor, and this sensor sends this event to its associated
interactor.

Most often, the interaction (programmed in an interactor) will act onto
the go parent of the sensor.


A sensor has a program name defining what it has to do. This name is used to retrieve
the good interactor. In fact, to be used with sensors an interactor's name
must be compound of two parts:
the name of a Go class and the logical name of a user interaction, separated
with a ``.''. To be associated to a sensor, the first name of an interactor
must be the name of the class of the go parent of the sensor and the second
name must be the name of the sensor. If there is no such interaction,
the system tries again, using the name of the superclass
(of the Go parent of the sensor). And so on.
.sp
A little example will clarify this:
.br
GoCircle is a subclass of GoEllipse. The interaction to rescale a GoCircle
is the same than the one used to rescale an ellipse. Therefore, there is
an interactor named "GoEllipse.rescale" and there are no interactors named
"GoCircle.rescale".
.br
If you create a sensor named "rescale" as a child of a GoCircle, the sensor
will not find any interaction named "GoCircle.rescale". It will then try with
the name of the superclass. actually, it finds an interaction named
"GoEllipse.rescale". Afterwards, each time the sensor would have to
handle an event, it will use rules defined in this interaction.
.sp
Of course, each time the sensor's name is changed or the sensor is reparented,
the sensor looks for a new corresponding interaction.
.sp
Many sensors may have the same name. That means, if they are reparented under
the same class of Go, they will play an identical behavior.
But there cannot be more than one interaction program with the same name.
.sp
The basic GoSensor class implements a light weight Go. GoSensor is a direct
subclass of Go. It cannot have children, it has always the coordinate system
of its parent, it cannot make drawings.
.sp
\fIGoSensor\fPs crossing type is \fIGCROSS_AS_NOTHING\fP. To access them you must
use tree crossing methods which start with an upper case (\fIChild()\fP,
\fINext()\fP, ... and not \fIchild()\fP, \fInext()\fP, (see \fIGo(3Go)\fP).
.sp
If you create sensors, it is to start well defined interactions. This is why
the sensor destroys itself when the interaction is finished.
.br
This do not forbid having infinite interactions, which are never finished
(ala toplevel event dispatcher).
.sp
.nf
.ta .15i .25i 1.0i
class GoSensor : public Go
{
	public:

		static GoSensor* create
			(const char* program, Go* parent, const GEvent* startEvent = NULL,
			void (*)(void* closure, GoSensor*) = NULL, void* closure = NULL);

		const char* program () const;
		GBool program (const char* newProgram);

		void postcond (void(*p)(void*, GoSensor*), void* closure);

		GBool careAbout (const GEvent*) const;
		GBool handle (const GEvent*);

		GInteractor* interactor ();

		void activate ();
		void disactivate ();
		GBool active () const;
};
.fi
.sp 2
.SH
\fBPUBLIC METHODS\fP
.IP
static GoSensor* \fBcreate\fP
.br
	(const char* \fIprogram\fP, Go* \fIparent\fP, const GEvent* \fIstartEvent\fP = NULL,
.br
	void (*\fIpostcond\fP)(void* closure, GoSensor*) = NULL, void* \fIclosure\fP = NULL);
.RS .8i
.IP \fIDescription\fP .5i
This method creates a new instance of a \fIGoSensor\fP. \fIparent\fP is the
parent of the sensor. Often this parent will be updated by the sensor while its
associated interactor is running.
.br
\fIprogram\fP will be the program name of that sensor.
.sp
The new created sensor, if it has enough informations (if it is in a go tree
which root is a \fIGoRoot\fP, and if it has a program name matching an interactor
program) will automatically create and start a new \fIGInteractor\fP.
It will pass \fIstartEvent\fP and \fIgo\fP as parameters to the \fIGInteractorPgm\fP
\fIstart\fP method.
.br
At the end of the execution of the interactor (i.e. when the interactor enters the
\fIGITOR_DONE\fP or the \fIGITOR_CANCELLED\fP state), and if \fIpostcond\fP is not
\fINULL\fP, the sensor will call:
.br
	(*postcond) (closure, sensor);
.br
The application may then ask the associated interactor for any useful information
through \fIsensor->interactor()\fP. Particularly, the application may start a
new interaction with the same sensor, by renaming that sensor. In that case, the
sensor does not destroy itself (remember that when an interaction is finished,
the sensor automatically destroys itself).
.RE
.sp
.IP
void \fBpostcond\fP (void (*\fIfunction\fP) (void*, GoSensor*), void* \fIclosure\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method set (or reset) the \fIpostcond\fP and the \fIclosure\fP which will
be called when the interaction will be finished.
.br
See the \fIcreate\fP method for more information.
.RE
.sp
.IP
GInteractor* \fBinteractor\fP ()
.RS .8i
.IP \fIDescription\fP .5i
This method returns the interactor associated to the sensor.
It may be \fINULL\fP.
.RE
.sp
.IP
const char* \fBprogram\fP () const;
.br
void \fBprogram\fP (const char* \fIprogram\fP);
.RS .8i
.IP \fIDescription\fP .5i
These methods permit to get or to set the program name of the sensor. This name
represents what the sensor has to do and is used to retrieve the good
interactor program.
.RE
.sp
.IP
void \fBhandle\fP (const GEvent* \fIevent\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method executes the next step in the unfolding of the interaction with
user events, defined in the GInteractorPgm associated to the sensor.
.br
Actually, it calls \fIsensor->interactor()->handle(event)\fP, and if the interactor
leaves the \fIGITOR_RUNNING\fP state, it will eventually call the application
\fIprecond\fP and destroy itself (see the \fIcreate\fP method for more informations).
.RE
.sp
.IP
void activate ()
.br
void disactivate ()
.br
GBool active () const
.RS .8i
.IP \fIDescription\fP .5i
These methods set or get the \fIactive\fP status of a sensor.
If a sensor is not active, its \fIhandle\fP method will do nothing.
Actually it will even not have an associated interactor.
.br
At creation, a sensor is active.
.RE
.sp
.IP
GBool \fBcareAbout\fP (const GEvent* \fIevent\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method returns \fIGTRUE\fP if the interaction being executed by the
sensor is interested with \fIevent\fP (Actually, it returns
\fIsensor->interactor()->careAbout(event)).
.br
A sensor which is not yet initialized (the first call to the \fIhandle\fP
method is not yet done) will always return \fIGFALSE\fP.
.RE
.sp 2
.SH
\fBC BINDING\fP
.IP
\fITo be defined\fP.
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP "Text edition:"
One or more of the interactors "GoTextual.editor", "GoScrolledText.editor",
"GoLabel.editor", ... must exist. You add to the go (which is a subclass of
GoTextual) a sensor named "editor". You call \fIsensor->play(NULL)\fP to
initialize the interaction.
If you do not want this interaction any more, you may destroy the sensor
or rename it to NULL to use it later (in the same way), or unmap it and
remap it later.

.IP "Rotation of a go:"
You add to the go a sensor which is sensitive onto the full output, and which
name is "rotate". Following the class of the go, the system will choose itself
the best adapted interaction. As this interaction is not infinite, the
sensor will destroy itself at the end of the interaction.
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBGo(3Go)\fP,
\fBGoUI\fP,
\fBGoSensorMetaclass(3Go)\fP
and \fBGInteractor\fP classes.
.nrPN \n%
