.\" $Id: Translator.n,v 1.1 1993/01/04 10:39:35 jojic Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH Translator 3Go "December 1992" "Version 1.2" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBTranslator\fP \(em translator object classes.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Translator.h>\fP
.sp 1
.SH
\fBCLASS\fP
.IP
\fBGTranslator(Pgm)\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBGInteractor(Pgm)\fP class
.RE
.sp 1
.SH
\fBDESCRIPTION\fP
.IP
\fBA translator is used for the programming of simplest user interactions: 
event/action translation tables.\fP
.br
The main functionality of a \fBGTranslatorPgm\fP, the \fIadd\fP method, allows
the definition of a list of functions to call, on some user event.
.br
The first parameter of the \fIadd\fP method is a string. This string is
a mask representing a set of possible events. The syntax, which will be
precisely defined below, is something like:
.br
	"key<a-z>" or "press<2>s".
.br
The second parameter of the \fIadd\fP method is also a string. This string
defines the function to call and its parameters.
.br
For example:
.br
	"Go::destroy(go)"
.br
See below the description of the syntax and the definition of the set of
allowed function parameters.

If more than one function are associated to the \fBsame\fP event mask
(through many calls to \fIadd\fP), they will all be called (at the time
of the execution of the interaction), if an event corresponding to
the mask arrives.
.sp
In fact, translators will rarely be programmed in C++. It is better to define
translators in ascii files. Therefore the user will be able, without
recompiling sources, to choose which event will start which action.
.br
These ascii files contain lines such as:
.br
	Go.goDispatcher   key<^D>   Go::destroy(go)
.br
Such a line defines an entry in the event/actions table of the \fBGTranslatorPgm\fP
named \fI"Go.goDispatcher"\fP (see \fISensor(3Go)\fP for informations about the name).
See below the exact description of these files.
.br
The \fIGLoadTranslatorPgms(const char* file_name)\fP function will interpret
such files and create (or update) corresponding translators.
.sp
During the execution, translators must retrieve function pointers which
are associated to function names. To perform this, translators use the
table of names/pointers managed by the \fIGBind\fP function (see \fIBind(3Go)\fP).
.br
Each Go subclass provides a set of methods automatically loaded in GBind
tables (see the documentation of each Go subclass). Typically, sensors bin the
\fIcreate\fP method. This function allows you to start a new interaction.

You can put the call of your own functions inside these ascii files. But you
must make the association between the name of the function (inside the file)
and the function pointer to be executed. For example:
.br
	GBind("QuickQuit", exit);
.br
and inside the file:
.br
	GoRoot.mainDispatcher   key<^C>   QuikQuit(0)
.sp
.nf
.ta .15i .25i 1.0i
/*
 *-------------------------------------------------------
 * Programming of a Translator
 *-------------------------------------------------------
 */

class GTranslatorPgm : public GInteractorPgm
{
	public:

		static GTranslatorPgm* create (const char* name);

		friend GBool GLoadTranslatorPgms (const char* filename);

		GBool add (const char *eventMask, const char *functionToCall);
		GBool remove (const char *eventMask, const char *funToCall = NULL);

		static const char* checkSyntax (const char* mask, const char* fun);
		static const char* checkFileSyntax (const char* filename, int& wrongLine);
		static const char* checkFileLineSyntax (const char* line);
};


/*
  *-------------------------------------------------------
  * Execution of a Translator
  *-------------------------------------------------------
  */

class GTranslator : public GInteractor
{
	public:

	/* superclasses virtual methods */
		virtual GBool handle (const GEvent*);
};
.fi
.sp 2
.SH
\fBGTranslatorPgm PUBLIC METHODS\fP
.IP
void \fBcreate\fP (const char* \fIname\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method creates and return a \fBGTranslatorPgm\fP which name is \fIname\fP.
If \fIname\fP was already used by another interactor program, the GTranslatorPgm
will not be created and the method returns \fINULL\fP.
.RE
.sp
.IP
void \fBadd\fP (const char* \fIeventMask\fP, const char* \fIfunctionToCall);
.RS .8i
.IP \fIDescription\fP .5i
This method allows you to add an entry inside the event/action translation
table of this translator. During the execution, \fIfunctionToCall\fP will be
called if an event matching \fIeventMask\fP arrives.
.sp
.IP \fIeventMask\fP .5i
An event mask is a string of the form:
.br
	"type<detail>modifiers"
.sp
\fItype\fP must be one of:
.nf
	\fImotion\fP for a pointer motion event,
	\fIpress\fP, \fIrelease\fP for a mouse button press or release,
	\fIdouble\fP, \fItriple\fP for a mouse double or triple click,
	\fIkey\fP for a keyboard ascii character,
	\fIfkey\fP for a keyboard function key,
	\fIenter\fP, \fIleave\fP for a enter sensor or leave sensor event,
	\fIexpose\fP for an expose event,
	\fImessage\fP for an application message event.
.fi
.sp
\fIdetail\fP is \fItype\fP dependent:
.nf
	\fImotion\fP, \fIexpose\fP:
		\fIdetail\fP must be empty: <>.
	\fIpress\fP, \fIrelease\fP, \fIdouble\fP, \fItriple\fP:
		\fIdetail\fP must be a combination of mouse button numbers:
		\fI<1>\fP	means that button 1 is pressed (or released, or double clicked)
		\fI<13>\fP	means that mouse button 1 or mouse button 3 is pressed.
	\fIkey\fP:
		\fIdetail\fP is a combination of ascii characters.
		Printable characters represent themselves, with following exceptions:
			\fI\\\fP, \fI>\fP and \fI-\fP.
		You must preced those exceptions with a backslash.
			\fI<acx>\fP	means one of \fIa\fP, \fIc\fP or \fIx\fP characters.
			\fI<\\>>\fP	means character \fI>\fP.
		Non printable characters may be written as two digit hexa number preceded
		with a backslash:
			\fI<\\1F>\fP	means ascii code 31.
		You may specify a range using the \fI-\fP character.
			\fI<a-z>\fP	means all lower case letters.
		Final example:
			\fI<0-9a-fA-F>\fP means any hexa digit.
	\fIfkey\fP:
		\fIdetail\fP must be one of:
			\fILEFT, RIGHT, UP, DOWN, INSERT, DELETE, BACKSPACE, HOME, END,
			PAGEUP, PAGEDOWN, TAB, BACKTAB, HELP, HOME, F1, ..., F18, ESC\fP.
	\fImessage\fP:
		\fIdetail\fP must be a regular expression:
			\fIhello
			start*
			move??Dots\fP
.fi
.sp
\fImodifiers\fP is a combination of none or 3 letters \fIs\fP for shift,
\fIc\fP for control and \fIa\fP for alternate. You may separate such
combinations with a \fI|\fP character.
.br
Not empty \fImodifiers\fP are accepted only for those event types: \fIpress,
release, double, triple, key\fP and \fIfkey\fP.
.nf
		(nothing) means without modifiers,
	\fIc\fP	means with \fIcontrol\fP,
	\fIcs\fP	means with \fIcontrol\fP and \fIshift\fP,
	\fIcs|a\fP	means with (\fIc\fP and \fIs\fP) or \fIa\fP,
	\fIc|\fP	means \fIc\fP or nothing,
	\fI|c|s|a|cs|ca|sa|csa\fP	means any combination (eventually empty) of modifiers.
.fi
.sp
.IP \fIfunctionToCall\fP .5i
\fIfunctionToCall\fP is a string describing the function to call with its
parameters. The syntax is:
.br
	\fIFunctionName\fP(\fIParameters\fP)
.br
where \fIParameters\fP is a list of accepted parameters separated with commas ``,''.
.br
\fIFunctionName\fP is a not empty string composed with following characters:
.br
	\fIa-z, A-Z, 0-9, _\fP and \fI::\fP.
.br
``\fI::\fP'' allows the identification, inside the name of the function, of
the Go subclass. For example \fIGoRectangle::setWidth\fP. This naming will
permit the translator, if it does not know that function, to ask the
GoRectangle class to bind its methods. But be careful, it is not C++ code,
there is no default \fIthis\fP parameter. You must pass every parameters
as described in the GoRectangle documentation.
.sp
.nf
Allowed parameters are:
	integers (type \fIint\fP):
		0, -1, 5236
	chars (type \fIchar\fP):
		'a', '\''
	floats (type \fIGNumber\fP):
		0., -1., 3.14159265359, 1.e10
	strings (type \fIchar*\fP):
		"hello", "", "Anatoly Karpov"
	some keywords:
		NULL (type \fIvoid*\fP),
		GTRUE, GFALSE (type \fIGBool\fP)
	the parent of the sensor (type \fIGo*\fP):
		go
	the go at the position of the event (type \fIGo*\fP):
		goAtPos
	the goui who is managing this sensor (type \fIGoUI*\fP):
		goui
	the sensor (type \fIGoSensor*\fP):
		sensor
	the event (type \fIGEvent*\fP):
		event
	the position of the event (type \fIGPoint*\fP):
		pos
	a color (type GShColor*):
		COLORblue, COLORred
.fi
.RE
.sp
.IP
void \fBremove\fP (const char* \fIeventMask\fP, const char* \fIfunctionToCall\fP = NULL);
.RS .8i
.IP \fIDescription\fP .5i
This method removes an entry of the event/actions translation table
of the translator. If \fIfunctionToCall\fP is \fINULL\fP (the default value) all
entries having an event mask equal to \fIeventMask\fP are removed.
.RE
.sp
.IP
friend void \fBGLoadTranslatorPgms\fP (const char* \fIfileName\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method loads an ascii file containing translator definitions.
Once these translator programs are created, it is sufficient to create sensors
with corresponding names, as children of Gos with corresponding classes,
to activate such translators.
.br
Here is the syntax of this file:
.br
This file is compound of lines. Each line defines an event/action translation
for a given translator. A line has this form:
.br
	\fIGoClassName.InteractionName   EventMask   Function(Parameters)\fP
.br
When the translator named \fI"GoClassName.InteractionName"\fP is executed,
an event matching \fIEventMask\fP will cause the execution of the function
\fIFunction\fP with parameters \fIParameters\fP.
.sp
If this line starts with a star ``*'', then this translation is removed from
the translator named \fI"GoClassName.InteractionName"\fP. If the line starts
with a star and does not contain a function call, then every translations
having this event mask are removed.
.sp
A comment line starts with a ``#'', except if it starts with:
.br
	\fI#include\fP FileName
.br
which forces the load of FileName also.
.sp
All this permits the inclusion of other files defining translators, but also
to update them.
.RE
.\".sp
.\".IP
.\".nf
.\"void \fBCreateSensor\fP (
.\"	const char* \fIsensor_class_name\fP, Go* \fIgo_parent\fP,
.\"	const char* \fIsensor_name\fP, const GEvent* \fIstarting_event\fP);
.\".fi
.\".RS .8i
.\".IP \fIDescription\fP .5i
.\"This function allows you to start new interactions.
.\".br
.\"This function is automatically binded in the name/pointer table of \fIGBind\fP.
.\"You can use it in your ascii files discribing translations. This function
.\"will create a sensor wich class is \fIsensor_class_name\fP, as a child of
.\"\fIgo_parent\fP, with the name \fIsensor_name\fP. It will then activate
.\"the associated interactor (named "go_parentClassName.sensor_name"), by
.\"sending it \fIstarting_event\fP to its \fIhandle\fP method. If it is not an
.\"infinite interaction, the sensor will be automatically destroyed at the end
.\"of the interaction.
.\".br
.\"If such an interactor does not exist, the sensor is not created.
.\".sp
.\".IP \fIsensor_class_name\fP .5i
.\"It must be the name of a sensor subclass: "GoSensor", "GoFullSensor", ... .
.\".IP \fIgo_parent\fP .5i
.\"It must be ``go'' or ``goAtPos''. If it appends that the go parameter is
.\"\fINULL\fP, the sensor is not created.
.\".IP \fIsensor_name\fP .5i
.\"It must be the logical name of an interaction.
.\".IP \fIstarting_event\fP
.\"It must be ``\fIevent\fP'' or ``\fINULL\fP''.
.\".RE
.sp
.IP
static const char* \fBcheckSyntax\fP (const char* \fImask\fP, const char* \fIfun\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method is similar to the \fIadd\fP method, but it only checks
the syntax. If the syntax of \fImask\fP and \fIfun\fP are right, the method
returns \fINULL\fP, otherwise it returns a string explaining the error.
.RE
.sp
.IP
static const char* checkFileSyntax (const char* filename, int& wrongLine)
.RS .8i
.IP \fIDescription\fP .5i
This method is similar to the \fIGLoadTranslatorPgms\fP method, but it only
checks the syntax. If the syntax is right, the method returns \fINULL\fP,
otherwise, it sets \fIwrongLine\fP to the line number on which the error
occurred and returns a string explaining the error.
.RE
.sp
.IP
static const char* checkFileLineSyntax (const char* line)
.RS .8i
.IP \fIDescription\fP .5i
This method checks the syntax of one line of a GTranslatorPgm file.
If the syntax is right, the method returns \fINULL\fP, otherwise it returns
a string explaining the error.
.RE
.sp 2
.SH
\fBGTranslator PUBLIC METHODS\fP
.IP
virtual GBool \fBhandle\fP (const GEvent* \fIevent\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method executes those functions associated to \fIevent\fP in the
event/actions table of the associated GTranslatorPgm.
.sp
More precisely:
.br
First, it looks for an event mask matching \fIevent\fP in the GTranslatorPgm
which has created this translator. If one or more actions are found, they are
executed and the method returns \fIGTRUE\fP. Otherwise the method looks for
a ``translator superclass program''. That means if this translator program name
is \fIGoRectangle.rescale\fP and if \fIGoRectangle\fP is a \fBGo\fP subclass of
\fIGoGeometric\fP, then the method will look for a translator program which name
is \fIGoGeometric.rescale\fP.
Once the method finds such other translator program, it will try again to 
handle \fIevent\fP using the event/actions table of the new translator program.
.br
The described behavior is repeated until an action is found (as seen above)
or until there are no more ``translator superclass program'', in which case the
method returns \fIGFALSE\fP.
.RE
.sp 2
.SH
\fBC BINDING\fP
.IP
\fITo be defined.\fP
.sp
.SH
\fBUSAGE INFORMATION\fP
.IP
To be defined.
.sp
.SH
\fBSEE ALSO\fP
.IP
GInteraction, GSensor, GBind
.nrPN \n%
