.\" $Id: XGoInterf.n,v 1.2 1992/07/20 07:21:59 smadja Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH XGoInterf 3Go "February 1992" "Version 1.2" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBXGoInterf\fP \(em the X Window System Go interface object class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/XGoInterf.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBXGoInterf\fP inherits behavior from the \fBGoInterf\fP class.
.sp 1
.SH
\fBDESCRIPTION\fP
.IP
The \fIXGoInterf\fP object class implements the interface between a \fBX Window System\fP
drawable and \fBGo\fP. It implements all necessary methods described in \fIGoInterf(3Go)\fP, some fast methods in specific case and some additional X specific methods. \fBOnly X specific methods or behavior are described here\fP.
.IP
Like other GoInterf, XGoInterf does not read event by itself outside the \fIgrab\fP method, so it is the responsibility of the application to read the events and to keep the coherence between the XGoInterf data (i.e. the \fIwidth\fP) and the effective data for any modification of the drawable (i.e. call \fIresize()\fP on the ConfigureNotify event if the width or the height of the window change).
.IP
For convenience, the \fBXGoInterf\fP library implements the \fIoperating system\fP function \fBWaitEventProc\fP. see \fIInDisp(3Go)\fP for detail.
.sp 1
.br
.nf
.ta .15i .25i 1.0i
class XGoInterf : public GoInterf {
	public:
		/** specific X methods **/

		XGoInterf (const char* \fIdisplayName\fP = NULL);
		XGoInterf (Display* \fIdisplay\fP, Window \fIwindow\fP);
		XGoInterf (Display* \fIdisplay\fP, int \fIscreen\fP, Drawable \fIdrawable\fP, GBool \fIisWindow\fP,
			int \fIwidth_in_pixels\fP, int \fIheight_in_pixels\fP, int \fIdepth\fP,
			ulong \fIbackgroundPixel\fP, Colormap \fIcolormap\fP, Visual* \fIvisual\fP,
			Number \fIpixelWidth_in_mm\fP = 0, Number \fIpixelHeight_in_mm\fP = 0);

		~XGoInterf();

		void  useColorPatternMatching(GBool);
		void  allocContinuousColormap(Pixel*& \fIpixels\fP, int& \fInpixels\fP);

		Display* display() const;
		Drawable drawable() const;
		Colormap colormap() const;
		uchar screen() const;
		Visual* visual() const;
		uchar bitsPerPixel() const;
		uchar bitOrder() const;
		uchar byteOrder() const;
    
		uchar bitmapUnit() const;
		uchar bitmapPad() const;
		uchar bitmapCoding() const;

		void resize (int \fIwidth_in_pixel\fP, int \fIheight_in_pixel\fP);
		void background (ulong \fIpixel\fP);
		GShFont* xFontNameToShFont(const char* \fIname\fP);
		GFont* xFontNameToFont(const char* \fIname\fP);
		int  fontHeightInPixels(const char* \fIname\fP;
		void  handleXEvent(const XEvent \fIxevent\fP);

		 /** specific behavior **/

		GShColor* colorFromName(const char* \fIcolor_name\fP) const;
		void background (const GShColor* \fIcolor\fP);

		void string (const GShTextBrush* \fItext_brush\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP, 
			const GPoint& \fIpos\fP, Number \fIheight\fP, int \fInchar\fP, const char* \fIstring\fP, Quality \fIquality\fP);
		
		/* specific font metrics computation */

		stringLeftBearing(const char* \fIstring\fP, int \fIsize\fP, GNumber \fIheight\fP, const GShFont* \fIshfont\fP);
		stringRightBearing(const char* \fIstring\fP, int \fIsize\fP, GNumber \fIheight\fP, const GShFont* \fIshfont\fP);
		stringAscent(const char* \fIstring\fP, int \fIsize\fP, GNumber \fIheight\fP, const GShFont* \fIshfont\fP);
		stringDescent(const char* \fIstring\fP, int \fIsize\fP, GNumber \fIheight\fP, const GShFont* \fIshfont\fP);
		stringWidth(const char* \fIstring\fP, int \fIsize\fP, GNumber \fIheight\fP, const GShFont* \fIshfont\fP);

		GNumber fontUnderlineThickness (GNumber \fIheight\fP, const GShFont* \fIshfont\fP);

		GNumber fontUnderlinePosition (GNumber \fIheight\fP, const GShFont* \fIshfont\fP);

		GNumber fontItalicAngle (const GShFont* \fIshfont\fP);

		GNumber fontStrikeoutAscent (GNumber \fIheight\fP, GShFont* \fIshfont\fP);

		GNumber fontStrikeoutDescent (GNumber \fIheight\fP, const GShFont* \fIshfont\fP) ;

		GNumber fontMinSpace (GNumber \fIheight\fP, const GShFont* \fIshfont\fP) ;

		GNumber fontMaxSpace (GNumber \fIheight\fP, const GShFont* \fIshfont\fP) ;

		GNumber fontNormSpace (GNumber \fIheight\fP, const GShFont* \fIshfont\fP) ;

		GNumber fontEndSpace (GNumber \fIheight\fP, const GShFont* \fIshfont\fP) ;

		const char* fontName (const GCoordSys& \fIcs\fP, GNumber \fIheight\fP,
			const GShFont* \fIfont\fP) ;

}
.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
\fBXGoInterf\fP(const char* \fIdisplay_name\fP);
.RS .8i
.IP \fIDescription:\fP .5i
This method makes an XGoInterf with a \fIwhite input/output simple window\fP parent of the \fIDefaultRootWindow\fP. The XDisplay will be opened or got if another XGoInterf uses the same \fIdisplay_name\fP. Parameters are the XDefault... one. Because this constructor may open the \fIdisplay\fP  the input and output queues are handle only by the XGoInterf.
.br
By default the color pattern matching flag is set to GTRUE if the number of entries in the colormap is less or equal to 16. Use the \fIuseColorPatternMatching()\fP method to change it if necessary.
.IP \fIdisplay_name\fP .5i
.br
Specifies the \fIdisplay_name\fP. The \fIdisplay_name\fP may be NULL; in this case the DISPLAY environment variable  will be used to get the effective display name.
.RE
.sp 1
.IP
\fBXGoInterf\fP(Display* \fIdisplay\fP, Window \fIwindow\fP);
.RS .8i
.IP \fIDescription:\fP .5i
The method creates an XGoInterf with  \fIdisplay\fP and \fIwindow\fP. The characteristics of the \fIwindow\fP are got by XGetWindowAttributes(). Note that if you known the window attributes use the next XGoInterf constructor.
.br
By default the color pattern matching flag is set to GTRUE if the number of entries in the colormap is less or equal to 16. Use the \fIuseColorPatternMatching()\fP method to change it if necessary.
.IP \fIdisplay\fP .5i
.br
Specifies the wanted \fIdisplay\fP.
.IP \fIwindow\fP .5i
.br
Specifies the \fIwindow\fP. Note that the \fIwindow\fP must be input/output.
.RE
.sp 1
.IP
\fBXGoInterf\fP (Display* \fIdisplay\fP, int \fIscreen\fP, Drawable \fIdrawable\fP, GBool \fIisWindow\fP,
	int \fIwidth_in_pixels\fP, int \fIheight_in_pixels\fP, int \fIdepth\fP,
	ulong \fIbackgroundPixel\fP, Colormap \fIcolormap\fP, Visual* \fIvisual\fP,
	Number \fIpixelWidth_in_mm\fP = 0, Number \fIpixelHeight_in_mm\fP = 0);
.RS .8i
.IP \fIDescription:\fP .5i
This constructor makes a XGoInterf with all the needed parameters.
.br
By default the color pattern matching flag is set to GTRUE if the number of entries in the colormap is less or equal to 16. Use the \fIuseColorPatternMatching()\fP method to change it if necessary.
.sp 1
.IP \fIdisplay\fP .5i
.br
Specifies the wanted \fIdisplay\fP.
.IP  \fIscreen\fP .5i
.br
Specifies the screen number.
.IP \fIdrawable\fP .5i
.br
Specifies the \fIdrawable\fP. The \fIdrawable\fP is a  input/output window or a pixmap.
.IP \fIisWindow\fP .5i
.br
If GTRUE the \fIdrawable\fP is a window. If not it is a pixmap.
.IP \fIwidth_in_pixel\fP
.IP \fIheight_in_pixel\fP
.IP \fIdepth\fP
.IP \fIbackgroundPixel\fP
.IP \fIcolormap\fP
.IP \fIvisual\fP .5i
.br
Specify the \fBcurrent\fP characteristics of the \fIdrawable\fP.
.IP \fIpixelWidth_in_mm\fP
.IP \fIpixelHeight_in_mm\fP .5i
.br
Specify the pixel sizes in mm. If a pixel size is 0 (default parameter) the constructor will compute the pixel size with the \fIscreen\fP characteristics. Note That very often the pixel sizes computed with the \fIscreen\fP characteristics are not corrects because of error of the effective size of the screen in mm.
.RE
.sp 1
.IP 
\fB~XGoInterf\fP()
.RS .8i
.IP \fIDescription\fP .5i
The destructor deletes the XGoInterf and the X resources used.
.RE
.sp 1
.IP
.nf
\fBdisplay()\fP
\fBdrawable()\fP
\fBcolormap()\fP
\fBscreen()\fP
\fBvisual()\fP
\fBbitsPerPixel()\fP
\fBbitOrder()\fP
\fBbytesOrder()\fP
\fBbitmapUnit()\fP
\fBbitmapPad()\fP
\fBbitmapCoding()\fP 
.fi
.br 
.RS .8i
.IP \fIDescription\fP .5i
Access methods to get current characteristics.
.RE
.sp 1
.IP
void \fBuseColorPatternMatching(GBool \fIuse_or_not\fP)
.RS .8i
.IP \fIDescription\fP .5i
If GTRUE the XGoInterf will make \fIpattern\fP to simulate color that cannot be allocated in the colormap. Note the pattern matching functionality is not use to map color image. In this case we use for each color the \fInearest\fP color in the colormap.
.RE
.sp 1
.IP
void \fBallocContinuousColormap(Pixel*& \fIpixels\fP, int& \fInpixels)
.RS .8i
.IP \fIDescription\fP .5i
The function allocs a continuous set a colors inside the colormap. It is available for colormap  greater or equal to 256. If the number of entries inside the colormap is less than 256 \fInpixels\fP and \fIpixels\fP will be NULL. \fIpixels\fP is allocated by the method. It is the responsability of the caller to free  \fIpixels\fP. Note that if you want to free the pixels inside the \fIcolormap\fP you have to call yourself XFreeColors();
.br
The methods begins to alloc 6 gray, the rgb cube corners. It continuous by variation of Hue,Saturation,Value in the HSV color model. The result is not so bad.
.br
The method may be used for applications which map lot of images. In this case all images have a smaller quality but they can be mapped together without to much color distorsion.
.RE
.sp 1
.IP
void \fBresize\fP(int \fIwidth_in_pixel\fP, int \fIheight_in_pixel\fP)
.RS .8i
.IP \fIDescription\fP .5i
If the \fIdrawable\fP is a window, the method resizes it. It is a specific function of XGoInterf because the GoInterf::resize function has \fIwidth\fP and \fIheight\fP in mm.
.sp 1
.IP \fIwidth_in_pixel\fP
.IP \fIheight_in_pixel\fP
.br
Specifies the wanted sizes.
.RE
.sp 1
.IP
void \fBbackground\fP(ulong \fIpixel\fP)
.RS .8i
.IP \fIDescription\fP .5i
The function calls the virtual GoInterf function \fIbackground()\fP with the color created with \fIpixel\fP.
.sp 1
.IP \fIpixel\fP.
.br
Specifies the  allocated yet \fIpixel\fP.
.RE
.sp 1
.IP
GShFont* \fBxFontNameToShFont\fP(const char* \fIxfont_name\fP);
.IP
GFont* \fBxFontNameToFont\fP(const char* \fIxfont_name\fP);
.RS .8i
.IP \fIDescription\fP .5i
Theses functions make a  GShFont* or a GFont* object with the \fIxfont_name\fP. See X manual for
font naming conventions. On error it returns a NULL  object.
.sp 1
.IP \fIxfont_name\fP .5i
.br
Specifies the source font name.
.RE
.sp 1
.IP
int \fBfontHeightInPixels\fP(const char* \fIxfont_name\fP);
.RS .8i
.IP \fIDescription\fP .5i
The method computes the height in pixels of the font describe to by \fIxfont_name\fP for the current interface \fIresolution\fP. Note that it does not load the font.
.sp 1
.IP \fIxfont_name\fP .5i
.br
Specifies the source font name.
.RE
.sp 1
.IP
void \fBhandleXEvent\fP(const XEvent* \fIxevent\fP, const XRectangle* \fIrects\fP, int \fInrect\fP);
.RS .8i
.IP \fIDescription\fP .5i
The convenient function handles \fIxevent\fP which has sense for Go. It makes an GoEvent with the XEvent and if the event is not NULL (it has a sense) it calls the virtual  GoInterf function \fIhandle\fP(GoEvent* goevent). It is the responsibility of the application to handle the other events for itself or to keep coherence between the XGoInterf internal values and the effective current one.
.br
The XEvent which have sense for Go are the following:
.sp 1
.nf
.ta .15i .25i 1.0i
	KeyPress	-->	GStringEvent or GoFunctionKeyEvent
	ButtonPress	-->	GButtonPressEvent
	ButtonRelease	-->	GButtonReleaseEvent
	Expose		-->	GExposeEvent
	MotionNotify	-->	GMotionEvent or GCompressMotionEvent
.fi
.sp 1
.IP \fIxevent\fP .5i
.br
Specifies the \fIxevent\fP to handle.
.IP \fIrects, nrects\fP .5i
.br
Specifies the XRectangle list. The XRectangle list is used only for GExposeeEvent. the list may be NULL, in this case the rectangle of the ExposeEvent will be used.
.RE
.sp 1
.IP
void \fBbackground\fP(const GShColor* \fIcolor\fP)
.RS .8i
.IP \fIDescription\fP .5i
If the \fIdrawable\fP is a window, the method set the window background with the  pixel associated to \fIcolor\fP. It fills the window with the new color and sends an \fBexpose event\fP.
.sp 1
.IP \fIcolor\fP .5i
.br
Specifies the wanted \fIcolor\fP.
.RE
.sp 1
.IP
GShColor* \fBcolorFromName\fP(const char* \fIcolor_name\fP);
.RS .8i
.IP \fIDescription\fP .5i
The function makes an unnamed  GShColor* object with the \fIcolor_name\fP. See X manual for available \fIcolor_name\fP. If \fIcolor_name\fP is not available the function returns an unnamed black color.
.sp 1
.IP \fIcolor_name\fP .5i
.br
Specifies the name of the wanted color.
.RE
.sp 1
.IP
.nf
void \fBstring\fP (const GTextBrush* \fItext_brush\fP, const GBrush* \fIbrush\fP, const GCoordSys& \fIcs\fP, 
	const GPoint& \fIpos\fP, Number \fIheight\fP, int \fInchar\fP, const char* \fIstring\fP, Quality \fIquality\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
For general understanding of the methods see \fBGoInterf\fP.
.br
The first specific behavior of the method is that an \fIcs\fP with I.angle different 0 degree or J.angle != 90 degrees if displayed with GMIN_QUALITY. 
.br
The second specific behavior is that the  wanted \fIheight\fP may not be available on the Xserver for the \fIfont\fP. The height of font used to display the string will be smaller of equal to the \fIheight\fP if possible.  For a good presentation, the used vector is the smallest between \fIcs.I\fP and \fIcs.J\fP. Note the space between each character corresponds to the metric of the font and is computed with the wanted \fIcs\fP. So in general the \fIstring\fP is displayed character by character. Note that the method cumulates the XDrawString() calls if it is possible.
.br
The GMIN_QUALITY is displayed by drawing the \fIbaseline\fP of the string.
.RE
.sp 2
.IP
.nf
GNumber \fBstringLeftBearing\fP (const char* \fIstring\fP, int \fInchar\fP, GNumber \fIheight\fP, const GShFont* \fIfont\fP);
GNumber \fBstringRightBearing\fP (const char* \fIstring\fP, int \fInchar\fP, GNumber \fIheight\fP, const GShFont* \fIfont\fP);
GNumber \fBstringAscent\fP (const char* \fIstring\fP, int \fInchar\fP, GNumber \fIheight\fP, const GShFont* \fIfont\fP);
GNumber \fBstringDescent\fP (const char* \fIstring\fP, int \fInchar\fP, GNumber \fIheight\fP, const GShFont* \fIfont\fP);
GNumber \fBstringWidth\fP (const char* \fIstring\fP, int \fInchar\fP, GNumber \fIheight\fP, const GShFont* \fIfont\fP);
GNumber \fBfontUnderlineThickness\fP (GNumber \fIheight\fP, const GShFont* \fIfont\fP);
GNumber \fBfontUnderlinePosition\fP (GNumber \fIheight\fP, const GShFont* \fIfont\fP);
GNumber \fBfontItalicAngle\fP (const GShFont* \fIfont\fP);
GNumber \fBfontStrikeoutAscent\fP (GNumber \fIheight\fP, const GShFont* \fIfont\fP);
GNumber \fBfontStrikeoutDescent\fP (GNumber \fIheight\fP, const GShFont* \fIfont\fP);
GNumber \fBfontMinSpace\fP (GNumber \fIheight\fP, const GShFont* \fIfont\fP);
GNumber \fBfontMaxSpace\fP (GNumber \fIheight\fP, const GShFont* \fIfont\fP);
GNumber \fBfontNormSpace\fP (GNumber \fIheight\fP, const GShFont* \fIfont\fP);
GNumber \fBfontEndSpace\fP (GNumber \fIheight\fP, const GShFont* \fIfont\fP);
.fi
.RS .8i
.IP \fIDescription:\fP .5i
These methods allow to get size information about a \fIstring\fP or a \fIfont\fP  \fBrelatively\fP to any coordinate system used to draw a \fIstring\fP. Note that in X release <= 4 the metrics are computed with the biggest font available matching the font characteristics. In X release >= 5: we will use the font server (not implemented yet).

.IP \fIstring\fP .5i
.br
Specifies the character string itself.
.IP \fInchar\fP .5i
.br
Specifies the character number of the string.
.IP \fIheight\fP .5i
.br
Specifies the height of the font.
.IP \fIfont\fP .5i
.br
Specifies a pointer to the  \fBGShFont\fP object (see \fIShFont(3Go)\fP).
.RE
.sp 1
.IP
.nf
const char* \fBfontName\fP (const GCoordSys& \fIcs\fP, GNumber \fIheight\fP, const GShFont* \fIfont\fP);
.fi
.RS .8i
.IP \fIDescription:\fP .5i
This method returns the font name corresponding to the \fIfont\fP object
when using the current interface. This returned name is const so it does not have to be modified or freed.
.IP \fIfont\fP .5i
.br
Specifies the  \fBGShFont\fP object (see GShFont(3Go)\fP).
.RE
.sp 1
.SH
\fBC BINDING\fP
.sp 1
.nf
	GObjectId   \fBXGoInterfCreateWith_Displayname\fP(const char* \fIdisplayName\fP);


	GObjectId   \fBXGoInterfCreateWith_Window\fP(Display* \fIdisplay\fP, Window \fIwindow\fP);

	GObjectId   \fBXGoInterfCreate\fP(Display* \fIdisplay\fP, int \fIscreen\fP,
			   Drawable \fIdrawable\fP, GBool \fIisWindow\fP,
			   int \fIwidth_in_pixels\fP, int \fIheight_in_pixels\fP, int \fIdepth\fP,
			   ulong \fIbackgroundPixel\fP, Colormap \fIcolormap\fP, Visual* \fIvisual\fP,
			   GNumber \fIpixelWidth_in_mm\fP, GNumber \fIpixelHeight_in_mm\fP);


	Display*    \fBXGoInterfDisplay\fP         (GObjectId \fIxi\fP);
	Drawable    \fBXGoInterfDrawable\fP        (GObjectId \fIxi\fP);
	Colormap    \fBXGoInterfColormap\fP        (GObjectId \fIxi\fP);
	uchar       \fBXGoInterfScreen\fP          (GObjectId \fIxi\fP);
	Visual*     \fBXGoInterfVisual\fP          (GObjectId \fIxi\fP);
	uchar       \fBXGoInterfBitsPerPixel\fP    (GObjectId \fIxi\fP);
	uchar       \fBXGoInterfBitOrder\fP        (GObjectId \fIxi\fP);
	uchar       \fBXGoInterfByteOrder\fP       (GObjectId \fIxi\fP);
	uchar       \fBXGoInterfBitmapUnit\fP      (GObjectId \fIxi\fP);
	uchar       \fBXGoInterfBitmapPad\fP       (GObjectId \fIxi\fP);
	uchar       \fBXGoInterfBitmapCoding\fP    (GObjectId \fIxi\fP);
	GObjectId   \fBXGoInterfXFontNameToShFont\fP   (GObjectId \fIxi\fP, const char* \fIname\fP);
	int         \fBXGoInterfFontHeightInPixels\fP (GObjectId \fIxi\fP, const char* \fIname\fP);
	void        \fBXGoInterfHandleXEvent\fP       (GObjectId \fIxi\fP, const XEvent* \fIxevent\fP,
				    const XRectangle* \fIrects\fP, int \fInrects\fP);

	void        \fBXGoInterfResize\fP               (GObjectId \fIxi\fP,
					 int \fIwidth_in_pixel\fP, int \fIheight_in_pixel\fP);
	void        \fBXGoInterfBackground\fP           (GObjectId \fIxi\fP,ulong \fIpixel\fP);

.fi
.sp 1
.IP \fIDescription\fP .5i
\fIsee\fP the XGoInterf::\fIname\fP method. All C++ references must be seen as an address in C.
.br
The C interface for the \fIXGoInterf\fP object provides only the interface for the specific XGoInterf methods
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
Specific X methods are strongly discouraged because of portability of your application over another GoInterf. To show the portability problem over another interface, it is usual to use XGoInterf as an GoInterf and to cast in XGoInterf to use specific XGoInterf methods.
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBGoInterf\fP, \fBGInputDispatcher\fP,
\fBGShPen\fP, \fBGShBrush\fP,
\fBGShTextBrush\fP, \fBGShImageBrush\fP, \fBGEvent\fP,
\fBGShFont\fP,
\fBGShPixelArray\fP, \fBGRegion\fP, \fBGCoordSys\fP, \fBGPoint\fP, \fBGColor\fP,
\fBGShColor\fP, \fBGShColormap\fP classes.
.nrPN \n%
