.\" $Id: XmGoInterf.n,v 1.2 1992/07/20 07:30:20 smadja Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH XmGoInterf 3Go "July 1992" "Version 1.2" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBXmGoInterf\fP \(em the X Window System Go interface object class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/XmGoInterf.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBXmGoInterf\fP inherits behavior from the \fBXtGoInterf\fP class.
.sp 1
.SH
\fBDESCRIPTION\fP
.RS .8i
.sp 1
The \fBXmGoInterf\fP object class implements the interface between \fBOSF/Motif\fP and \fBGo\fP. It is used specially by the \fIXbGraphic\fP widget. An XmGoInterf is needed  for the following reason:
.IP
-: \fBOSF/Motif\fP: some specific widgets which handle the TRAVERSAL resource read the  XK_Return key symbol (GKEY_PRESS_EVENT) and do not put it again in the X input queue; so in this case we only receive the GKEY_RELEASE_EVENT.
.sp 1
.br 
.RE
.sp 2
.nf
.ta .15i .25i 1.0i
class XmGoInterf : public XtGoInterf {

	public:
		/** specific Xm methods **/

		XmGoInterf (Widget \fIwidget\fP);
		~XmGoInterf();

		/* to handle KEY_PRESS,  KEY_RELEASE */
		/* MOTIF HANDLER */
		
		void      addInputMask(GEventMask \fIinputmask\fP);
		void      removeInputMask(GEventMask \fIinputmask\fP);
		void      handleXEvent(const XEvent* \fIxevent\fP);
    
	}
.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
\fBXmGoInterf\fP(Widget \fIwidget\fP);
.RS .8i
.IP \fIDescription:\fP .5i
.IP \fIwidget\fP .5i
.br
Specifies the \fIwidget\fP used to retreive associated window. Note that the \fIwidget\fP must be realized.
.RE
.sp 1
.IP 
\fB~XmGoInterf\fP()
.RS .8i
.IP \fIDescription\fP .5i
The destructor deletes the XmGoInterf and the X resources used. The \fIwidget\fP itself is not destroyed.
.RE
.sp 1
.IP
void \fBaddInputMask\fP(GEventMask \fImask\fP).
.RS .8i
.IP \fIDescription:\fP .5i
The method adds the \fImask\fP to the current input mask (cf \fIGoInterf::addInputMask\fP()). It translates the result of \fIinputMask()\fP into the corresponding X values: \fIx_mask\fP. If GKEY_PRESS_MASK is wanted it adds KeyReleaseMask to \fIx_mask\fP.
.SH
.sp 1
.IP
void \fBremoveInputMask\fP(GEventMask \fImask\fP).
.RS .8i
.IP \fIDescription:\fP .5i
The method removes the \fImask\fP to the current input mask (cf \fIGoInterf::removeInputMask\fP()). It translates the result of \fIinputMask()\fP into the corresponding X values: \fIx_mask\fP. If GKEY_PRESS_MASK is wanted it adds KeyReleaseMask to \fIx_mask\fP.
.RE
.sp 1
.IP
void \fBhandleXEvent\fP(XEvent* \fIxevent\fP);
.RS .8i
.IP \fIDescription:\fP .5i
The method bypasses the KeyPress event of the XK_Return symbol. It does not calls \fIXGoInterf::handleXEvent()\fP.
.br
If it receives the KeyRelease with the  XK_Return symbol it translates it into KeyPress event.
.br
For each event it calls \fIXGoInterf::handleXEvent()\fP one time for a given key symbol (on KeyPress only).
.IP
The method is specially called directly by widget (cf \fBXbGraphic\fP).
.RE
.SH
\fBC BINDING\fP
.sp 1
.nf
   \fI#include <Go/cXmGoInterf.h>\fP

	GObjectId   \fBXmGoInterfCreate\fP(Widget \fIwidget\fP);
.sp 1
.IP \fIDescription\fP .5i
\fIsee\fP the XmGoInterf::\fIname\fP method.
.br
The C interface for the \fIXmGoInterf\fP object provides only the interface for the specific XmGoInterf methods.
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
Specific X methods are strongly discouraged because of portability of your application over another GoInterf. To show the portability problem over another interface, it is usual to use XmGoInterf as an GoInterf and to cast in XmGoInterf to use specific XmGoInterf methods.
.IP
.sp 1
An \fBXmGoInterf\fP is usualy created by a widget. The \fBXbGraphic\fP widget provides an interface between \fBOSF/Motif\fP and \fBGo\fP.
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBXGoInterf(3Go)\fP, \fBGoInterf(3Go)\fP, \fBXtInputDispatcher(3Go)\fP,
.IP
\fBXToolkit\fP, and \fBXbGraphic\fP.
.nrPN \n%

