.\" $Id: mGo.n,v 1.1.1.1 1992/03/18 09:44:33 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF '''2.\n(PN+1'
.TH GoMetaclass 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGoMetaclass\fP \(em the GoMetaclass object class.
.SH
\fBSYNOPSIS\fP
.IP
\fI#include <Go/mGo.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGoMetaclass\fP does not inherit behavior from any class.
.sp 1
.SH
\fBDESCRIPTION\fP
.IP
The \fBGoMetaclass\fP class is the common superclass for all \fIGoMetaclass\fP objects.
There is only one static instance of the class. You can get it with
\fIGo::metaclass()\fP.
.IP
The \fIGoMetaclass\fP object is defined to provide methods on \fIGo\fP at
class level. Such metaclass objects exist for every \fIGo\fP class. If the
object class \fIGoBar\fP is a subclass of the object class \fIGoFoo\fP, then
the metaclass object class \fIGoBarMetaclass\fP will be a subclass
of the metaclass object class \fIGoFooMetaclass\fP.
For example, if pre and post conditions are needed when modifying the coordinate
system of all \fIGoFoo\fP instances, then pre/postcondtions will be defined at the
\fIGoFooMetaclass\fP level by calling the appropriate method (i.e. \fIrelcsPrecond()\fP)
of the single \fIGoFoo::metaclass()\fP object. In that case, any instance of \fIGoFoo\fP
will be affected by pre/postconditions attached to the \fIGoFoo metaclass\fP.
.IP
One of the main capabilities is to provide \fIprecondition\fP on \fIGo\fP creation or
restoring from a \fIGoStream\fP (see \fIGoStream(3Go)\fP) and
\fIpostconditions\fP on \fIGo\fP destruction.
.IP
.sp 1
.br
.nf
.ta .15i .25i 1.0i
class GoMetaclass {
	public:

		/*
	 	 * \fBGo creation and destruction:\fP
	 	 */

		// preconditions:

		void createPrecond(GBool \fIproc\fP(void* \fIclosure\fP, const GoMetaclass* \fIgo_class\fP),
			void* \fIclosure\fP, AddOrRemove \fIadd\fP = GADD);
		void destroyPrecond(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);

		// postconditions:

		void createPostcond(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void destroyPostcond(void \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
    

		/*
	 	 * \fBtree structure:\fP
	 	 */

		// preconditions:

		void shiftPrecond(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP, const Go* (*\fInext_brother\fP)),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void removeChildPrecond(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP, const Go* \fIchild_to_remove\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void addChildPrecond(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP,
			const Go* \fIchild_to_add\fP, const Go* (*\fInext_brother\fP)),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void reparentPrecond(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP,
			const Go* \fInew_parent\fP, const Go* (*\fInext_brother\fP)),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void rootPrecond(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP, const GoRoot* \fIgoroot\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void crossTypePrecond(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP, GCrossType* \fIcross_type\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);

		// postconditions:

		void shiftPostcond(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, Go* old_\fInext_brother\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void removeChildPostcond(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, Go* \fIrem_child\fP, Go* \fIold_next_brother\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void addChildPostcond(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, Go* \fIadded_child\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void reparentPostcond(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, Go* \fIold_parent\fP, Go* \fIold_next_brother\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void rootPostcond(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, GoRoot* \fIold_root\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void crossTypePostcond(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, GCrossType \fIold_cross_type\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);


		/*
	 	 * \fBcoordinate systems:\fP
	 	 */

		// preconditions:

		void relcsPrecond(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP, GCoordSys* \fInew_relcs\fP,
			const GCoordSys* \fIoldparabs\fP, const GCoordSys* \fInewparabs\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void abscsPrecond(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP, GCoordSys* \fInew_abscs\fP,
			const GCoordSys* \fIoldparabs\fP, const GCoordSys* \fInewparabs\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);

		// postconditions:

		void relcsPostcond(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, const GCoordSys* \fIparabs\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void abscsPostcond(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, const GCoordSys* \fIparabs\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);

		/*
	 	 * \fBabout drawings:\fP
	 	 */

		// preconditions:

		void mapPrecond(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP), void* \fIclosure\fP,
			GAddOrRemove \fIadd\fP = GADD);
		void selectPrecond(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP), void* \fIclosure\fP,
			GAddOrRemove \fIadd\fP = GADD);
		void interfPreconf (GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP, const GoInterf* \fIgointerf\fP,
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);

		// postconditions:

		void mapPostcond(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP), void* \fIclosure\fP,
			GAddOrRemove \fIadd\fP = GADD);
		void selectPostcond(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP), void* \fIclosure\fP,
			GAddOrRemove \fIadd\fP = GADD);
		void interfPostcond (void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, GoInterf* \fIold_gointerf\fP,
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void myClipPostcond(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP), void* \fIclosure\fP,
			GAddOrRemove \fIadd\fP = GADD);
		void clipPostcond(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP), void* \fIclosure\fP,
			GAddOrRemove \fIadd\fP = GADD);


		/*
		 * \fBsaving and copying:\fP
		 */

		// preconditions:

		void dupPrecond(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void restorePrecond(GBool \fIproc\fP(void* \fIclosure\fP, const GoMetaclass* \fIgo_class\fP, GoStream* \fIstream\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void savePrecond(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP, const GoStream* \fIstream\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);

		// postconditions:
    
		void dupPostcond(void \fIproc\fP(void* \fIclosure\fP, Go* \fIsource\fP, Go* \fIcopy\fP),
			void* \fIclosure\fP, GAddOrRemove = GADD);
		void restorePostcond(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, GoStream* \fIstream\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
		void savePostcond(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, GoStream* \fIstream\fP),
			void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);


		/*
	 	 * \fBmiscellianeous:\fP
	 	 */

		const char* classname() const;
		GoMetaclass* superclass() const;
		const GoMSet& subclasses() const;
		GBool isSubclass(const GoMetaclass* \fIgo_class\fP) const;
		GAssoc& assoc() const;
		const GoSet& instances () const;
		const GActionRec* actions() const;
};
.fi
.sp 1
.SH
\fBPUBLIC CREATION AND DESTRUCTION METHODS\fP
.IP
.nf
void \fBcreatePrecond\fP(GBool \fIproc\fP(void* \fIclosure\fP, const GoMetaclass* \fIgo_class\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBcreatePostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add/remove pre/postcondition on creating \fIGo's\fP.
If \fIthis\fP is \fIgoFooClass\fP,
when the \fIgoFooClass.create()\fP method is invoked,
precondition callbacks (\fIcreatePrecond\fP) of \fIgoFooClass\fP are called.
If all of these callbacks return GTRUE, then an \fIGoFoo\fP instance is created and the
postcondition are called.
.IP \fIproc\fP .5i
.br
Specifies the pre/postcontion callback which is called on creating \fIGo's\fP.
It takes two parameters: the closure (private application data), the \fIgo_class\fP
(precondition) or the created \fIgo\fP (postcondition).
.IP \fIclosure\fP .5i
.br
Specifies the private application data which is passed to the pre/post condition callback \fIproc\fP
as the first parameter.
.IP \fIadd\fP .5i
.br
Specifies if the pre/post condition callback \fIproc\fP has to added (default) or removed (GREMOVE).
.RE
.sp 1
.IP
.nf
void \fBdestroyPrecond\fP(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBdestroyPostcond\fP(void \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add/remove pre/postcondition on destroying \fIGo\fP instances. If \fIthis\fP is
\fIgoFooClass\fP, when the \fIdestroy()\fP
method (see \fIGo(3Go)\fP of a \fIGoFoo\fP instance is called (instead of \fIdelete\fP), precondition callbacks
of \fIgoFooClass\fP are called.
If all precondition callbacks return GTRUE, the \fIGoFoo\fP will be destroyed. Just before the destruction,
the \fIGoFoo\fP is removed from the \fIGo\fP tree (reparented to NULL) and the postcondition callbacks of
\fIgoFooClass\fP, if any, are called. Then the \fIGoFoo\fP instance is deleted.
.IP \fIproc\fP .5i
.br
Specifies the callback procedure which is called as either precondtion (GBoolean function) or
postcondition (void function). It takes two parameters which are the closure (application private
data) and the \fIGo\fP to be destroyed. It cannot be modified (const).
.IP \fIclosure\fP .5i
.br
Specifies the private application data which is passed to the pre/post condition callback \fIproc\fP
as the first parameter.
.IP \fIadd\fP .5i
.br
Specifies if the pre/post condition callback \fIproc\fP has to added (default) or removed (GREMOVE).
.RE
.sp 2
.SH
\fBPUBLIC CONDITION METHODS ON TREE MANAGEMENT\fP
.IP
.nf
void \fBshiftPrecond\fP(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP, const Go* (*\fInext_brother\fP)),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBshiftPostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, Go* \fIold_next_brother\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBremoveChildPrecond\fP(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP,
	const Go* \fIchild_to_remove\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBremoveChildPostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP,
	Go* \fIrem_child\fP, Go* \fIold_next_brother\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBaddChildPrecond\fP(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP,
	const Go* \fIchild_to_add\fP, const Go* (*\fInext_brother\fP)),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBaddChildPostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, Go* \fIadded_child\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBreparentPrecond\fP(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP,
	const Go* \fInew_parent\fP, const Go* (*\fInext_brother\fP)),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBreparentPostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP,
	Go* \fIold_parent\fP, Go* \fIold_next_brother\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.nf
.RS .8i
.IP \fIDescription\fP .5i
This set of methods allows to add/remove pre/postconditions when modifying the \fIGo\fP
tree structure around a \fIGo\fP (i.e. change brothers, parent, remove child of a \fIGoFoo\fP
instance may imply the call of the \fIgoFooClass\fP (\fIthis\fP) pre/postconditions). Preconditions allow
to refuse the modification (return GFALSE), but they cannot modify the request. Postconditions are
called after the modification of the \fIGo\fP structure.
.IP \fIproc\fP .5i
.br
Specifies the pre/postcondition callback which is called when a \fIGo\fP environment in the
\fIGo\fP tree is changed. It takes up to four paramaters (depending on the modification type).
The two first are the closure (private application data) and the concerned \fIGo\fP itself.
The other parameters are concerned \fIGo\fP brothers (\fInext_brother, old_next_brother\fP
or concerned children or parents (\fIchild_to_remove, child_to_add, rem(oved)_child, added_child,
new_parent, old_parent\fP). 
.IP \fIclosure\fP .5i
.br
Specifies the private application data which is passed to the pre/post condition callback \fIproc\fP
as the first parameter.
.IP \fIadd\fP .5i
.br
Specifies if the pre/post condition callback \fIproc\fP has to added (default) or removed (GREMOVE).
.RE
.sp 1
.IP
.nf
void \fBrootPrecond\fP(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP, const GoRoot* \fIgoroot\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBrootPostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, GoRoot* \fIold_root\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add/remove pre/postcondition callbacks on \fIGoRoot\fP changing. Preconditions
may refuse the modification. Postconditions are called after the \fIGoRoot\fP changing.
.IP \fIproc\fP .5i
.br
Specifies the pre/postcondition callback procedure which is called when the \fIGoRoot\fP is
changed. It takes three parameters: the closure (private application data), the \fIGo\fP instance
itself and the new/old \fIGoRoot\fP.
.IP \fIclosure\fP .5i
.br
Specifies the private application data which is passed to the pre/post condition callback \fIproc\fP
as the first parameter.
.IP \fIadd\fP .5i
.br
Specifies if the pre/post condition callback \fIproc\fP has to added (default) or removed (GREMOVE).
.RE
.sp 1
.IP
.nf
void \fBcrossTypePrecond\fP(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP, GCrossType* \fIcross_type\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBcrossTypePostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, GCrossType \fIold_cross_type\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add/remove pre/postconditions on \fIcross type\fP modification of a \fIGo\fP (see \fIGo(3Go)\fP).
For example: If \fIthis\fP is \fIgoFooClass\fP, when the \fIcross_type\fP of a \fIGoFoo\fP instance is changed,
the pre/postconditions of \fIgoFooClass\fP are called.
The precondition may accept the new cross type, modify it or refuse the modification. In the last case, it
has to return GFALSE, else it returns GTRUE.
.IP \fIproc\fP .5i
.br
Specifies the pre/postcondition which is called when the \fIGo\fP cross type is modified. It takes three parameters:
the closure (private application data), the \fIGo\fP that the cross type is going to be (or has been) modified
and a pointer to the new cross type (or the old cross type).
.IP \fIclosure\fP .5i
.br
Specifies the private application data which is passed to the pre/post condition callback \fIproc\fP
as the first parameter.
.IP \fIadd\fP .5i
.br
Specifies if the pre/post condition callback \fIproc\fP has to added (default) or removed (GREMOVE).
.RE
.sp 2
.SH
\fBPUBLIC CONDITION METHODS ON COORDINATE SYSTEMS\fP
.IP
.nf
void \fBrelcsPrecond\fP(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP, GCoordSys* \fInew_relcs\fP,
	const GCoordSys* \fIoldparabs\fP, const GCoordSys* \fInewparabs\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBrelcsPostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, const GCoordSys* \fIparabs\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBabscsPrecond\fP(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP, GCoordSys* \fInew_abscs\fP,
	const GCoordSys* \fIoldparabs\fP, const GCoordSys* \fInewparabs\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBabscsPostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, const GCoordSys* \fIparabs\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add/remove pre/postconditions on relative coordinate system (\fIrelcs\fP)
or absolute coordinate system (\fIabscs\fP) changing. Preconditions allow to refuse the coordinate
system change but they are able to force other modifications.
.sp 1
\fIWarning:\fP Preconditions on coordinate system modifications are called recursively in the
\fIGo\fP subtree before any modification, but a precondition callback in a child receives
the old (\fIcurrent\fP) and the new (\fIfuture\fP)
coordinate systems of its parent in order to allow to decide if the
modification is either acceptable or has to be forced or has to be refused.
.IP \fIproc\fP .5i
.br
Specifies the pre/postcondition callback routine which is called when the relative/absolute
coordinate system is changed. Preconditions take five parameters: the closure (private
application data), the \fIGo\fP itself, the new relative/absolute coordinate system, the old
parent asolute coordinate system (before the coordinate system modification) and the new parent
absolute coordinate system (after the modification).
Postconditions take three parameters: the closure, the \fIGo\fP with the new coordinate system
and and the new parent coordinate system.
.IP \fIclosure\fP .5i
.br
Specifies the private application data which is passed to the pre/post condition callback \fIproc\fP
as the first parameter.
.IP \fIadd\fP .5i
.br
Specifies if the pre/post condition callback \fIproc\fP has to added (default) or removed (GREMOVE).
.RE
.sp 2
.SH
\fBPUBLIC CONDITION METHODS ON DISPLAYING\fP
.IP
.nf
void \fBmapPrecond\fP(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBmapPostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add/remove pre/postcondition callbacks when a \fIGo\fP (which
\fIGo class\fP object is \fIthis\fP) is
mapped (visible) or unmapped (unvisible). Preconditions allow to refuse or accept the (un)mapping.
.IP \fIproc\fP .5i
.br
Specifies the pre/postcondition callback routine which is called when a mapping modification
occurs for a \fIGo\fP. It takes two parameters: the closure (private application data) and
the \fIGo\fP itself.
.IP \fIclosure\fP .5i
.br
Specifies the private application data which is passed to the pre/post condition callback \fIproc\fP
as the first parameter.
.IP \fIadd\fP .5i
.br
Specifies if the pre/post condition callback \fIproc\fP has to added (default) or removed (GREMOVE).
.RE
.sp 1
.IP
.nf
void \fBselectPrecond\fP(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBselectPostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add/remove pre/postcondition callbacks which are invoked when a \fIGo\fP
(which its \fIGo class\fP object is \fIthis\fP) is selected or deselected. Preconditions
may refuse or accept the (de)selection of the \fIGo\fP.
.IP \fIproc\fP .5i
.br
Specifies the pre/postcondtion callback routine which is called when a (de)selection
occurs. It takes two parameters: the closure (private application data) and the \fIGo\fP itself.
.IP \fIclosure\fP .5i
.br
Specifies the private application data which is passed to the pre/post condition callback \fIproc\fP
as the first parameter.
.IP \fIadd\fP .5i
.br
Specifies if the pre/post condition callback \fIproc\fP has to added (default) or removed (GREMOVE).
.RE
.sp 1
.IP
.nf
void \fBinterfPreconf\fP (GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP, const GoInterf* \fIgointerf\fP,
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBinterfPostcond\fP (void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, GoInterf* \fIold_gointerf\fP,
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.fi
.RS .8i
.IP \fIdescription\fP .5i
These two methods allow to add/remove pre/postcondtions on \fIGoInterf\fP change.
Preconditions may refuse the modification. Postconditions are called after the
\fIGoInterf\fP changing.
.IP \fIproc\fP .5i
.br
Specifies the pre/postcondition callback procedure which will be called when the
\fIGoInterf\fP is changed. It takes three parameters: the closure (private application
data), the \fIGo\fP instance itself and the new/old \fIGoInterf\fP.
.IP \fIclosure\fP .5i
.br
Specifies the private application data which is passed to the pre/postcondtion callback
\fIproc\fP as the first parameter.
.IP \fIadd\fP .5i
.br
Specifies if the pre/postcondition callback \fIproc\fP has to be added (default) or
removed (GREMOVE).
.RE
.sp 1
.IP
.nf
void \fBmyClipPostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBclipPostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add/remove postcondition functions in order to be notified when
the absolute clipping region (overall dimensions) of a \fIGo\fP (which \fIGo class\fP object is
\fIthis\fP) is changed.
\fIMyClipPostcond\fP allows to be notified when the clipping region of the \fIGo\fP is
changed, \fIclipPostcond\fP allows to be notified when the clipping region of the \fIGo\fP
and all its children is changed.
.IP \fIproc\fI .5i
.br
Specifies the postcondition callback function which is called when the \fIGo\fP clipping region
is changed. It takes two parameters: the closure (private application data) and the \fIGo\fP itself.
.IP \fIclosure\fP .5i
.br
Specifies the private application data which is passed to the pre/post condition callback \fIproc\fP
as the first parameter.
.IP \fIadd\fP .5i
.br
Specifies if the pre/post condition callback \fIproc\fP has to added (default) or removed (GREMOVE).
.RE
.sp 2
\fBPUBLIC CONDITION METHODS ON SAVING AND DUPLICATING\fP
.IP
.nf
void \fBdupPrecond\fP(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBdupPostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIsource\fP, Go* \fIcopy\fP),
	void* \fIclosure\fP, GAddOrRemove = GADD);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add/remove pre/postcondition callback routines in order to be notified
when a duplication of a \fIGo\fP (which \fIGo class\fP object is \fIthis\fP)
is requested/done. Preconditions allow to refuse the copy of the \fIGo\fP.
.IP \fIproc\fP .5i
.br
Specifies the pre/postcondition callback function which is called when a \fIGo\fP is duplicated.
Preconditions take two paramaterd: the closure (private application data) anf the \fIGo\fP itself.
Postconditions take three parameters: the closure, the \fIGo\fP (\fIsource\fP) and the new copy.
.IP \fIclosure\fP .5i
.br
Specifies the private application data which is passed to the pre/post condition callback \fIproc\fP
as the first parameter.
.IP \fIadd\fP .5i
.br
Specifies if the pre/post condition callback \fIproc\fP has to added (default) or removed (GREMOVE).
.RE
.sp 1
.IP
.nf
void \fBsavePrecond\fP(GBool \fIproc\fP(void* \fIclosure\fP, const Go* \fIgo\fP, const GoStream* \fIstream\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBsavePostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, GoStream* \fIstream\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBrestorePrecond\fP(GBool \fIproc\fP(void* \fIclosure\fP, const GoMetaclass* \fIgo_class\fP, GoStream* \fIstream\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
void \fBrestorePostcond\fP(void \fIproc\fP(void* \fIclosure\fP, Go* \fIgo\fP, GoStream* \fIstream\fP),
	void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add/remove pre/postconditions on \fIGo\fP saving/restoring.
Preconditions may refuse the saving/restoring (return GFALSE).
.IP \fIproc\fP .5i
.br
Specifies the pre/postcondition callback which is called when a \fIGo\fP is saved/restored. It takes
three parameters: the closure (private application data), the \fIGo\fP to be saved/restored
(or the metaclass, before restore) and the stream that can be used by the application to
save/restore its own data.
.IP \fIclosure\fP .5i
.br
Specifies the private application data which is passed to the pre/post condition callback \fIproc\fP
as the first parameter.
.IP \fIadd\fP .5i
.br
Specifies if the pre/post condition callback \fIproc\fP has to added (default) or removed (GREMOVE).
.RE
.sp 2
.SH
\fBOTHER PUBLIC METHODS\fP
.IP
const char* \fBclassname\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns a pointer to a character string containing the classname. For \fIgoMetaclass\fP, it
returns "Go".
.RE
.sp 1
.IP
GoMetaclass* \fBsuperclass\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns a pointer to the supclass object. The \fIGo::metaclass()\fP
itself returns NULL.
.RE
.sp 1
.IP
GBool \fBisSubclass\fP(const GoMetaclass* \fIgo_class\fP) const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns GTRUE if \fIgo_class\fP is subclass of \fIthis\fP or if \fIgo_class\fP is \fIthis\fP.
.IP \fIgo_class\fP .5i
Points to a class object.
.RE
.sp 1
.IP
GAssoc& \fBassoc\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the \fIGAssoc\fP (see \fIGAssoc(3Go)\fP) of \fIthis\fP. This \fIGAssoc\fP instance
allows to manage associations at the \fIGo\fP class level.
.RE
.sp 1
.IP
const GActionRec* \fBactions\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the \fIUser Action\fP table, see \fIGoUI(3Go)\fP.
.RE
.sp 1
.IP
const GoSet& \fBinstances\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns a pointer to a \fIGoSet\fP object containing the \fIGo\fP instances.
.RE
.sp 2
.SH
\fBUSER INTERACTION\fP
.IP
User interactions are defined by the following functions which may be
included in the customization files to be interpreted by the \fIGo User Interaction\fP
object \fBGoUI\fP, (see \fIGoUI(3Go)\fP). 
.sp 1
.IP
Functions availables for user interaction are:
.IP
\fBGo::destroy()\fP
.br
\fBGo::raise()\fP
.br
\fBGo::lower()\fP
.br
\fBGo::leaf()\fP
.br
\fBGo::unleaf()\fP
.br
\fBGo::map()\fP
.br
\fBGo::unmap()\fP
.br
\fBGo::select()\fP
.br
\fBGo::unselect()\fP
.br
\fBGo::dup()\fP
.RS .8i
.IP \fIDescription\fP .5i
See the corresponding public methods.
.RE
.sp 2
.SH
\fBC BINDING\fP
.SS
\fBHeader\fP
.IP
#include <Go/cGo.h>
.SS
\fBC Functions\fP
.IP
.nf
.ta .15i 1.0i
	\fIC function\fP
		corresponding C++ method

	const char* \fBGoMetaclassName\fP (GObjectId \fImetaclass\fP)
		const char* GoMetaclass::classname () const;
	GObjectId \fBGoSuperMetaclass\fP (GObjectId \fImetaclass\fP)
		GoMetaclass* GoMetaclass::superclass () const;
	int \fBGoIsSubclass\fP (GObjectId \fImetaclass\fP, GObjectId \fIsuperMetaclass\fP)
		GBool GoMetaclass::isSubclass (GoMetaclass* \fIsuperMetaclass\fP) const;
.fi
.IP
.nf
.ta .15i 1.0i
	void \fBGoClassCreatePrecond\fP (
		GObjectId \fIgometaclass\fP, GGAddOrRemove \fIadd\fP,
		int (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIgometaclass\fP),
		void* \fIclosure\fP);
	void \fBGoClassCreatePostcond\fP (
		GObjectId \fIgometaclass\fP, GGAddOrRemove \fIadd\fP,
		void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fBnew_created_go\fP),
		void* \fIclosure\fP);

	void \fBGoClassDestroyPrecond\fP (
		GObjectId gometaclass, GGAddOrRemove \fIadd\fP,
		int (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP),
		void* \fIclosure\fP);
	void \fBGoClassDestroyPostcond\fP (
		GObjectId gometaclass, GGAddOrRemove \fIadd\fP,
		void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP),
		void* \fIclosure\fP);

	void \fBGoClassDupPrecond\fP (
		GObjectId gometaclass, GGAddOrRemove \fIadd\fP,
		int (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP),
		void* \fIclosure\fP);
	void \fBGoClassDupPostcond\fP (
		GObjectId gometaclass, GGAddOrRemove \fIadd\fP,
		void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP),
		void* \fIclosure\fP);

	void \fBGoClassShiftPrecond\fP (
		GObjectId gometaclass, GGAddOrRemove \fIadd\fP,
		int (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP, GObjectId* p_next_brother),
		void* \fIclosure\fP);
	void \fBGoClassShiftPostcond\fP (
		GObjectId gometaclass, GGAddOrRemove \fIadd\fP,
		void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP, GObjectId old_next_brother),
		void* \fIclosure\fP);

	void \fBGoClassRemoveChildPrecond\fP (
		GObjectId gometaclass, GGAddOrRemove \fIadd\fP,
		int (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP, GObjectId child_to_remove),
		void* \fIclosure\fP);
	void \fBGoClassRemoveChildPostcond\fP (
		GObjectId gometaclass, GGAddOrRemove \fIadd\fP,
		void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP, GObjectId removed_child),
		void* \fIclosure\fP);

	void \fBGoClassAddChildPrecond\fP (
		GObjectId gometaclass, GGAddOrRemove \fIadd\fP,
		int (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP,
		                 GObjectId child_to_add, GObjectId *p_next_brother),
		void* \fIclosure\fP);
	void \fBGoClassAddChildPostcond\fP (
		GObjectId gometaclass, GGAddOrRemove \fIadd\fP,
		void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP, GObjectId added_child),
		void* \fIclosure\fP);

	void \fBGoClassReparentPrecond\fP (
		GObjectId gometaclass, GGAddOrRemove \fIadd\fP,
		int (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP,
		                 GObjectId new_parent, GObjectId *p_next_brother),
		void* \fIclosure\fP);
	void \fBGoClassReparentPostcond\fP (
		GObjectId gometaclass, GGAddOrRemove \fIadd\fP,
		void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP,
		                 GObjectId old_parent, GObjectId old_next_brother),
		void* \fIclosure\fP);

	void \fBGoClassRootPrecond\fP (
		GObjectId gometaclass, GGAddOrRemove \fIadd\fP,
		int (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP, GObjectId new_goroot),
		void* \fIclosure\fP);
	void \fBGoClassRootPostcond\fP (
		GObjectId gometaclass, GGAddOrRemove \fIadd\fP,
		void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP, GObjectId old_goroot),
		void* \fIclosure\fP);

	void \fBGoClassCrossTypePrecond\fP (
		GObjectId gometaclass, GGAddOrRemove \fIadd\fP,
		int (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP, GCrossType* p_new_cross_type),
		void* \fIclosure\fP);
	void \fBGoClassCrossTypePostcond\fP (
		GObjectId gometaclass, GGAddOrRemove \fIadd\fP,
		void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP, GCrossType old_cross_type),
		void* \fIclosure\fP);

	void \fBGoClassRelcsPrecond\fP (
		GObjectId gometaclass, GGAddOrRemove \fIadd\fP,
		int (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP, GCoordSys* p_new_relcs),
		void* \fIclosure\fP);
	void \fBGoClassRelcsPostcond\fP (
		GObjectId gometaclass, GGAddOrRemove \fIadd\fP,
		void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP),
		void* \fIclosure\fP);

	void \fBGoClassAbscsPrecond\fP (
		GObjectId gometaclass, GGAddOrRemove \fIadd\fP,
		int (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP, GCoordSys* p_new_abscs),
		void* \fIclosure\fP);
	void \fBGoClassAbscsPostcond\fP (
		GObjectId gometaclass, GGAddOrRemove \fIadd\fP,
		void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP),
		void* \fIclosure\fP);

	void \fBGoClassMapPrecond\fP (
		GObjectId gometaclass, GGAddOrRemove \fIadd\fP,
		int (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP),
		void* \fIclosure\fP);
	void \fBGoClassMapPostcond\fP (
		GObjectId gometaclass, GGAddOrRemove \fIadd\fP,
		void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP),
		void* \fIclosure\fP);

	void \fBGoClassSelectPrecond\fP (
		GObjectId gometaclass, GGAddOrRemove \fIadd\fP,
		int (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP),
		void* \fIclosure\fP);
	void \fBGoClassSelectPostcond\fP (
		GObjectId gometaclass, GGAddOrRemove \fIadd\fP,
		void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP),
		void* \fIclosure\fP);

	void \fBGoClassInterfPrecond\fP (
		GObjectId gometaclass, GGAddOrRemove \fIadd\fP,
		int (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP, GObjectId new_gointerf),
		void* \fIclosure\fP);
	void \fBGoClassInterfPostcond\fP (
		GObjectId gometaclass, GGAddOrRemove \fIadd\fP,
		int (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIgo\fP, GObjectId old_gointerf),
		void* \fIclosure\fP);
.fi
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
New \fIGoMetaclass\fP instances cannot be created, this explains why there
are not public constructor. There are accesses to a single instance of \fBGoMetaclass\fP which are \fBGoSub::metaclass()\fP or \fBgo->getMetaclass()\fP.
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBGAssoc\fP, \fBGCoordSys\fP, \fBGo\fP, \fBGoInterf\fP, \fBGoRoot\fP, \fBGoStream\fP and \fBGoUI\fP classes.
.nrPN \n%
