.\" $Id: Array.n,v 1.2 1992/07/22 11:02:37 smadja Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH Array 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBArray\fP \(em the array object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/Array.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBArray\fP does not inherit anything from another class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
\fBArray\fP is an object containing elements of fixed size. The element size is
given as a parameter to the class constructor.
.IP
Methods allow to add or remove elements from the \fIArray\fP. The array size
is updated with respect of the \fIincrement\fP value.
.sp 1
\fBGArray\fP is the C++ type for the \fIArray\fP object class.
.sp 1
.nf
.ta .15i .25i 1.5i
class GArray {
	public:
		GArray (int \fIelemsize\fP = sizeof(void*), int \fIincr\fP = 1);
		GArray (const void* \fIvalue\fP, int \fInelems\fP = 1, int \fIelemsize\fP = sizeof(void*),
			int \fIincr\fP = 1);
		~GArray ();

		void add (const void* \fIvalue\fP, uint \fInelems\fP = 1, int \fIindex\fP = -1);

		void rem (int \fIindex\fP = -1, uint \fInelems_to_free\fP = 1); 
		void rem (const void* \fIvalue\fP, GBool \fIonly_first\fP = \fIGTRUE\fP);
		void reset ();

		int   incr () const;
		void* data () const;
		int   elemsize () const;
		int   nelems ()  const
}
.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
\fBGArray\fP (int \fIelemsize\fP = sizeof(void*), int \fIincr\fP = 1);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to create an array of elements. The element size is
defined by \fIelemsize\fP. The array size is modulo \fIincr\fP elements.
.IP \fIelemsize\fP .5i
.br
Specifies the size in bytes of each array element.
.IP \fIincr\fP .5i
.br
Specifies the granule in element size for the array size update.
.RE
.sp 1
.IP
\fBGArray\fP (const void* \fIvalues\fP, int \fInelems\fP, int \fIelemsize\fP = sizeof(void*), int \fIincr\fP = 1);
.RS .8i
.IP \fIDescription\fP .5i
This method creates an array of \fInelems\fP elements and, if \fIvalues\fP is not \fINULL\fP,
it copies the elements pointed by \fIvalues\fP inside the array.
.IP \fIvalues\fP .5i
.br
Specifies the data to be copied inside the array. If \fIvalues\fP is \fINULL\fP,
the function does not copy anything.
.IP \fInelems\fP .5i
.br
Specifies the initial size of the array. If \fIvalues\fP is not \fINULL\fP,
\fInelems\fP elements will be copied into the array.
.IP \fIelemsize\fP .5i
.br
Specifies the size of each array element.
.IP \fIincr\fP .5i
.br
Specifies the granule in element size for the array size update.
.RE
.sp 1
.IP
\fB~GArray\fP ();
.RS .8i
.IP \fIDescription\fP
This method is called when an instance of \fIGArray\fP is deleted.
.RE
.sp 1
.IP
void \fBadd\fP (const void* \fIvalues\fP, int \fInelems\fP, int \fIindex\fP = -1);
.RS .8i
.IP \fIDescription\fP .5i
This methods inserts the data pointed by \fIvalues\fP inside the array at
\fIindex\fP position.
.IP \fIvalues\fP .5i
.br
Specifies the source of data to be copied as an array element.
.IP \fInelems\fP .5i
.br
Specifies the number of elements pointed by \fIvalues\fP.
.IP \fIindex\fP .5i
.br
Specifies the \fIindex\fP position for the new element insertion.
If \fIindex\fP is -1 (default), the new elements are added at the end of the
array. \fIindex\fP is in the range of 0 to the number of elements of the array.
.RE
.sp1
.IP
void \fBrem\fP (int \fIindex\fP = -1, int \fInelems_to_remove\fP = 1);
.RS .8i
.IP \fIDescription\fP .5i
This method removes elements from the array. Elements are defined by their
index position in the array.
.IP \fIindex\fP .5i
.br
Specifies the index of the first element to be removed.
.IP \fInelems_to_remove\fP .5i
.br
Specifies the number of elements to be removed. \fIIndex\fP plus \fInelems_to_remove\fP must be less or equal to the actual number of elements.
.RE
.sp 1
.IP
void \fBrem\fP (const void* \fIvalue\fP, GBool \fIonly_first\fP = \fIGTRUE\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method removes elements matching \fIvalue\fP from the array.
The function uses \fImemcmp\fP to find element to remove. If no element
matches \fIvalue\fP the function simply returns.
.IP \fIvalue\fP .5i
.br
Specifies the data used to find out elements to be removed.
.IP \fIonly_first\fP .5i
.br
Specifies if only the first found element (\fIGTRUE\fP, default) or all elements
(\fIGFALSE\fP) have to be removed.
.RE
.sp 1
.IP
void \fBreset ()\fP;
.RS .8i
.IP \fIDescription\fP .5i
This method frees all the elements of the array. The \fIincr\fP and
the size of an element do not change.
.RE
.sp 1
.IP
int \fBincr\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the modulo (in elements) used for updating the array
size.
.RE
.sp 1
.IP
void* \fBdata ()\fP const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the address of the first element of the array.
.RE
.sp 1
.IP
void* \fBelemsize\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the element size.
.RE
.sp 1
.IP
void* \fBnelems\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the number of elements inside the array.
.RE
.sp 1
.SH
\fBC BINDING\fP
.IP
None.
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBAlloc(3Go), PointerArray(3Go)\fP.
.nrPN \n%
