.\" $Id: Assoc.n,v 1.1.1.1 1992/03/18 09:45:07 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH Assoc 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBAssoc\fP \(em the association object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/Assoc.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBAssoc\fP does not inherit anything from another class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBAssoc\fP class implements the association object. An association
object is a set of couples. A couple associates an association key with
a set of values. The first element of the couple is the \fIAssociation Key\fP
and the second element is the set of values associated with the key.
Keys and values are both ``const void*''.
.IP
Using an \fIAssoc\fP instance, the application will be able to set, add,
get or remove an association couple.
.IP
The \fBStringAssoc\fP class allows to use \fIstring\fP for the key of the
association (see \fIStringAssoc(3Go)\fP).
.sp 1
\fBGAssoc\fP is the C++ type for the \fIAssoc\fP object class.
.sp 1
.nf
.ta .15i .25i 1.5i
class GAssoc {
	public:
		GAssoc();
		~GAssoc();

		void set (const void* \fIkey\fP, const void* \fIvalue\fP);
		void set (const void* \fIkey\fP, int \fPsize\fP, const void* \fIaddr\fP);

		int add (const void* \fIkey\fP, const void* \fIvalue\fP);
		int add (const void* \fIkey\fP, int \fIsize\fP, const void* \fIaddr\fP);

		void* get (const void* \fIkey\fP) const;
		const void* get (const void* \fIkey\fP, int& \fInumElem\fP) const;

		void rem (const void* \fIkey\fP);
		int rem (const void* \fIkey\fP, const void* \fIvalue\fP);
		int rem (const void* \fIkey\fP, int \fIsize\fP, const void* \fIaddr\fP);
		void reset ();

		void** getKeys (int& \fIcount\fP) const;

		void setArraySize(int \fIn\fP);	//\fImust be a power of 2 <= 256\fP
};
.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
\fBGAssoc\fP ();
.RS .8i
.IP \fIDescription\fP .5i
This function allows to create an instance of the \fIAssoc\fP class.
.RE
.sp 1
.IP
\fB~GAssoc\fP ();
.RS .8i
.IP \fIDescription\fP .5i
This method is called when an instance of this class is deleted.
.RE
.sp 1
.IP
.nf
void \fBset\fP (const void* \fIkey\fP, const void* \fIvalue\fP);
void \fBset\fP (const void* \fIkey\fP, int \fPsize\fP, const void* \fIaddr\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to associate a value to a key. If such an association
already exists, it is removed.
.IP \fIkey\fP .5i
.br
Specifies the key used as the identifier of the association.
.IP \fIvalue\fP .5i
.br
Specifies the value of the association (which is a void*).
.IP "\fIsize, addr\fP" .5i
.br
Specify the value which is a \fIsize\fP byte buffer located
at the address \fIaddr\fP. The buffer is copied inside the \fIAssoc\fP
instance and then may be freed by the application.
.RE
.sp 1
.IP
.nf
int \fBadd\fP (const void* \fIkey\fP, const void* \fIvalue\fP);
int \fBadd\fP (const void* \fIkey\fP, int \fIsize\fP, const void* \fIaddr\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These functions allow to add a value to an existing association. If the
association does not exist, it is created. It returns the index of this
value in the association identified by \fIkey\fP.
.IP \fIkey\fP .5i
.br
Specifies the key used as the identifier of the association.
.IP \fIvalue\fP .5i
.br
Specifies the value (which is a void*) to be added in the association.
.IP "\fIsize, addr\fP" .5i
.br
Specify the value to be added, which is a \fIsize\fP byte buffer located
at the address \fIaddr\fP. The buffer is copied inside the \fIAssoc\fP
instance and then may be freed by the application.
.RE
.sp 1
.IP
.nf
void* \fBget\fP (const void* \fIkey\fP);
const void* \fBget\fP (const void* \fIkey\fP, int& \fInumElem\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to get an association value. The first method returns
the first value associated to the given key. The second allows to get
all the values associated to a key. It returns the value array.
.IP \fIkey\fP .5i
.br
Specifies the key used as the identifier of the association.
.IP \fInumElem\fP .5i
.br
Specifies the value array size returned by the method.
.RE
.sp 1
.IP
.nf
void \fBrem\fP (const void* \fIkey\fP);
int \fBrem\fP (const void* \fIkey\fP, const void* \fIvalue\fP);
int \fBrem\fP (const void* \fIkey\fP, int \fIsize\fP, const void* \fIaddr\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to remove associations. The association may totally
broken if no specific value is given, else only the association of the 
given value is broken; in that last case, the method returns the number
of reminding values for the key.
.IP \fIkey\fP
.br
Specifies the key used as the identifier of the association.
.IP \fIvalue\fP .5i
.br
Specifies the value of the association (which is a void*).
.IP "\fIsize, addr\fP" .5i
.br
Specify the value to be removed, which is a \fIsize\fP byte buffer located
at the address \fIaddr\fP.
.RE
.sp 1
.IP
void \fBreset\fP();
.RS .8i
.IP \fIDescription\fP .5i
This method allows to reset the \fIAssoc\fP instance: all values associated
to all keys are removed form the association.
.RE
.IP
void** \fBgetKeys\fP (int& \fIcount\fP) const
.RS .8i
.IP \fIDescription\fP .5i
This method returns the key array of the association. It has to
be freed by the application.
.IP \fIcount\fP .5i
Gives the size of the key array.
.RE
.sp 1
.IP
void \fBsetArraySize\fP (int \fIn\fP);
.RS .8i
.IP \fIdescription\fP .5i
This method allows to set the hash code array (by default this array is 1,
if the number of associations increases (>= 10), it is automatically set to 256). This
functions allows to set this upper limit.
.IP \fIn\fP .5i
.br
Specifies the hash code array size. It must be less than 256 and a power of 2.
.RE
.sp 1
.SH
\fBC BINDING\fP
.SS 
\fBHeader file\fP
.IP
#include <Go/Tools/cAssoc.h>
.SS 
\fBC Functions\fP
.IP
GObjectId \fBCreateAssoc\fP ();
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GAssoc().
.RE
.sp 1
.IP
void \fBDestroyAssoc\fP (GObjectId \fIassoc\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: ~GAssoc().
.RE
.sp 1
.IP
void \fBSetAssocValue\fP (GObjectId \fIassoc\fP, const void* \fIkey\fP, const void* \fIvalue\fP);
.br
void \fBSetAssocData\fP (GObjectId \fIassoc\fP, const void* \fIkey\fP, int \fIsize\fP, const void* \fIaddr\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP:
.br
  void set (const void* \fIkey\fP, const void* \fIvalues\fP) and
.br
  void set (const void* \fIkey\fP, int \fIsize\fP, const void* \fIaddr\fP)
.RE
.sp 1
.IP
int \fBAddAssocValue\fP (GObjectId \fIassoc\fP, const void* \fIkey\fP, const void* \fIvalue\fP);
.br
int \fBAddAssocData\fP (GObjectId \fIassoc\fP, const void* \fIkey\fP, int \fIsize\fP, const void* \fIaddr\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP:
.br
  int add (const void* \fIkey\fP, const void* \fIvalue\fP) and
.br
  int add (const void* \fIkey\fP, int \fIsize\fP, const void* \fIaddr\fP);
.RE
.sp 1
.IP
void* \fBGetAssocValue\fP (const GObjectId \fIassoc\fP, const void* \fIkey\fP);
.br
const void* \fBGetAssocValues\fP (const GObjectId \fIassoc\fP, const void* \fIkey\fP, int* \fIcount\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP:
.br
  void* get (const void* \fIkey\fP) const; and
.br
  const void* get (const void* \fIkey\fP, int& \fIcount\fP) const;
.br
.RE
.sp 1
.IP
void** \fBGetAssocKeys\fP (GObjectId \fIassoc\fP, int* \fIcount\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void** getKeys (int& \fIcount\fP) const; The returned array has to
be freed by the caller.
.RE
.sp 1
.IP
void \fBRemAssocKey\fP (GObjectId \fIassoc\fP, const void* \fIkey\fP);
.br
int  \fBRemAssocValue\fP (GObjectId \fIassoc\fP, const void* \fIkey\fP, const void* \fIvalue\fP);
.br
int \fBRemAssocData\fP (GObjectId \fIassoc\fP, const void* \fIkey\fP, int \fIsize\fP, const void* \fIaddr\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP:
.br
  void rem (const void* \fIkey\fP);
.br
  int rem (const void* \fIkey\fP, const void* \fIvalue\fP);
.br
  int rem (const void* \fIkey\fP, int \fIsize\fP, const void* \fIaddr\fP);
.RE
.sp 1
.IP
void \fBRemAssocKeys\fP (GObjectId \fIassoc\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void reset().
.RE
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBStringAssoc(3Go)\fP.
.nrPN \n%
