.\" $Id: Box.n,v 1.1.1.1 1992/03/18 09:45:20 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH Box 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBBox\fP \(em the box object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/Box.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBBox\fP does not inherit anything from another class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBBox\fP class is a rectangle defined by four numbers: \fIxmin, ymin,
xmax, ymax\fP.
.sp 1
\fBGBox\fP is the C++ type for the \fIBox\fP object.
.sp 1
.br
.nf
.ta .15i .25i 1.5i
struct GBox {
		// Instance variables
		GNumber xmin, ymin;
		GNumber xmax, ymax;

		// Public methods
		GBox ();
		GBox (GNumber \fIxMin\fP, GNumber \fIyMin\fP, GNumber \fIxMax\fP, GNumber \fIyMax\fP);
		GBox (const GBox& \fIbox\fP);
		GBox (const GPoint& \fIp1\fP, const GPoint& \fIp2\fP);
		GBox (const GPoint& \fIp1\fP, const GPoint& \fIp2\fP,
			const GPoint& \fIp3\fP, const GPoint& \fIp4\fP);

		GBox& reset (GNumber \fIx1Min\fP, GNumber \fIy1Min\fP,
			GNumber \fIx2Max\fP, GNumber \fIy2Max\fP);
		GBox& operator = (const GBox& \fIbox\fP);

		GBool   contains (const GPoint& \fIpoint\fP) const;
		GBool   contains (const GPoint& \fIpoint\fP, GNumber \fImax_dist\fP) const;
		GNumber width () const;
		GNumber height () const;
		GBool   empty () const;

		// Move the Box
		GBox& operator += (const GVector& \fIv\fP);
		GBox& operator -= (const GVector& \fIv\fP);

		// functions WITHOUT checking if boxes are empty
		friend GBool GEqual (const GBox& \fIbox1\fP, const GBox& \fIbox2\fP);
		friend GBool GNotEqual (const GBox& \fIbox1\fP, const GBox& \fIbox2\fP);
		friend GBool GIntersect (const GBox& \fIbox1\fP, const GBox& \fIbox2\fP);
		friend int   GUnion(const GBox& \fIbox1\fP, const GBox& \fIbox2\fP, GBox* \fIboxes\fP);
		friend int   GSubtraction(const GBox& \fIbox1\fP, const GBox& \fIbox2\fP, GBox* \fIboxes\fP);
		friend GBox  GIntersection(const GBox& \fIbox1\fP, const GBox& \fIbox2\fP);

		// functions WITH checking if boxes are empty
		friend GBool operator == (const GBox& \fIbox1\fP, const GBox& \fIbox2\fP);
		friend GBool operator != (const GBox& \fIbox1\fP, const GBox& \fIbox2\fP);
		friend GBool operator && (const GBox& \fIbox1\fP, const GBox& \fIbox2\fP);
		friend GBox  operator +  (const GBox& \fIbox1\fP, const GBox& \fIbox2\fP);
		friend GBox  operator -  (const GBox& \fIbox1\fP, const GBox& \fIbox2\fP);
		friend GBox  operator &  (const GBox& \fIbox1\fP, const GBox& \fIbox2\fP);

		GBox& operator += (const GBox& \fIbox\fP);
		GBox& operator -= (const GBox& \fIbox\fP);
		GBox& operator &= (const GBox& \fIbox\fP);
};

extern const GBox gEmptyBox;
.fi
.sp 1
.SH
\fBPUBLIC VARIABLES\fP
.IP
GNumber \fBxmin\fP;
.br
GNumber \fBymin\fP;
.br
GNumber \fBxmax\fP;
.br
GNumber \fBymax\fP;
.RS .8i
.IP \fIDescription\fP .5i
These variables specify the rectangle of the box: xmin and ymin specify
the left upper point, xmax and ymax specify the right lower point.
.RE
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
.nf
\fBGBox\fP ();
\fBGBox\fP (GNumber \fIxMin\fP, GNumber \fIyMin\fP, GNumber \fIxMax\fP, GNumber \fIyMax\fP);
\fBGBox\fP (const GBox& \fIbox\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to create a new instance of the \fIGBox\fP structure. When the
\fIBox\fP is created without any parameter, it is empty.
.IP "\fIxMin, yMin\fP" .5i
.br
Specify the left upper point of the box.
.IP "\fIxMax, yMax\fP" .5i
.br
Specify the right lower point of the box.
.IP \fIbox\fP .5i
.br
Specifies the box to be duplicated.
.RE
.IP
.nf
\fBGBox\fP (const GPoint& \fIp1\fP, const GPoint& \fIp2\fP);
\fBGBox\fP (const GPoint& \fIp1\fP, const GPoint& \fIp2\fP, const GPoint& \fIp3\fP, const GPoint& \fIp4\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These functions allow to create the smallest instance of the \fIGBox\fP structure
containing two or four points.
.IP "\fIp1\fP, \fIp2\fP, \fIp3\fP, \fIp4\fP" .5i
.br
Specify the points which have to be include in the box.
.RE
.sp 1
.IP
GBox& \fBreset\fP (GNumber \fIxMin\fP, GNumber \fIyMin\fP, GNumber \fIxMax\fP, GNumber \fIyMax\fP);
.br
GBox& \fBoperator =\fP (const GBox& \fIbox\fP);
.RS .8i
.IP \fIDescription\fP .5i
These methods are used to modify the box value. The first
method allows to set the box values with the four numbers. The second allows
to set the box values from the \fIbox\fP values.
.IP "\fIxMin, yMin\fP" .5i
.br
Specify the left upper point of the box.
.IP "\fIxMax, yMax\fP" .5i
.br
Specify the right lower point of the box.
.IP \fIbox\fP .5i
Specifies the box which is used to get the new values \fIthis\fP.
.RE
.sp 1
.IP
GBool \fBcontains\fP (GPoint& \fIpoint\fP)
.br
GBool \fBcontains\fP (GPoint& \fIpoint\fP, GNumber \fImax_dist\fP)
.RS .8i
.IP \fIDescription\fP .5i
These methods returns \fIGTRUE\fP if the point \fIpoint\fP is contained in the box,
else it returns \fIGFALSE\fP. The box (0,0,0,0) contains the point (0,0).
.IP \fIpoint\fP .5i
.br
Specifies the point which has to be considered for the test.
.IP \fImax_dist\fP .5i
.br
Gives the accepted tolerance.
.RE
.sp 1
.IP
GNumber \fBwidth\fP ();
.br
GNumber \fBheight\fP ();
.RS .8i
.IP \fIDescription\fP .5i
These methods return the width and the height of the \fIBox\fP instance.
A box which the width or the height is 0 is not empty, it is reduced to a line.
.RE
.sp 1
.IP
GBool \fBempty\fP ();
.RS .8i
.IP \fIDescription\fP .5i
This method returns \fIGTRUE\fP if one of the following conditions are \fIGTRUE\fP:
(xmin > xmax) or (ymin > ymax). A box where xmin = ymin = xmax = ymax = 0 is
not empty.
.RE
.sp 1
.IP
GBox& \fBoperator +=\fP (GVector& \fIv\fP);
.br
GBox& \fBoperator -=\fP (GVector& \fIv\fP);
.RS .8i
.IP \fIDescription\fI .5i
These functions modify the box by adding/subtracting a vector. Adding/subtracting
a vector to/from a box may be considered as a "move" of the box.
.IP "\fIv\fP" .5i
.br
Specifies the vector to be added/subtracted to/from the box
coordinates.
.RE
.sp 1
.nf
.IP
friend GBool \fBoperator ==\fP (const GBox& \fIbox1\fP, const GBox& \fIbox2\fP);
friend GBool \fBoperator !=\fP (const GBox& \fIbox1\fP, const GBox& \fIbox2\fP);
friend GBool \fBoperator &&\fP (const GBox& \fIbox1\fP, const GBox& \fIbox2\fP);
.sp 1
friend GBool \fBGEqual\fP (const GBox& \fIbox1\fP, const GBox& \fIbox2\fP);
friend GBool \fBGNotEqual\fP (const GBox& \fIbox1\fP, const GBox& \fIbox2\fP);
friend GBool \fBGIntersect\fP (const GBox& \fIbox1\fP, const GBox& \fIbox2\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to compare boxes. The three last functions do not check
if boxes are empty (for performance reasons).
.IP "\fIbox1, box2\fP" .5i
Specify the two boxes to be compared.
.RE
.sp 1
.IP
friend GBox \fBoperator +\fP (const GBox& \fIbox1\fP, const GBox& \fIbox2\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method returns the smallest box containing two boxes (\fIbox1, box2\fP).
.RE
.sp 1
.IP
friend GBox \fBoperator -\fP (const GBox& \fIbox1\fP, const GBox& \fIbox2\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method returns a box which is the result of the operation \fIbox1\fP - \fIbox2\fP.
.RE
.sp 1
.IP
friend GBox \fBoperator &\fP (const GBox& \fIbox1\fP, const GBox& \fIbox2\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method returns a box which the intersection of \fIbox1\fP and \fIbox2\fP.
.RE
.sp 1
.IP
friend int \fBGUnion\fP (const GBox& \fIbox1\fP, const GBox& \fIbox2\fP, GBox* \fIboxes\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method returns the number of boxes inscribed in ``\fIbox1\fP union
\fIbox2\fP''.
The box array is returned in \fIboxes\fP.
.RE
.sp 1
.IP
friend int \fBGSubtraction\fP (const GBox& \fIbox1\fP, const GBox& \fIbox2\fP, GBox* \fIboxes\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method returns a list of boxes (maximum 4) which are the result of the
\fIbox1\fP minus \fIbox2\fP operation.
.RE
.sp 1
.IP
friend GBox \fBGIntersection\fP (const GBox& \fIbox1\fP, const GBox& \fIbox2\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method returns the intersion box between \fIbox1\fP and \fIbox2\fP.
.RE
.sp 1
.IP
.nf
GBox& \fBoperator +=\fP (const GBox& \fIbox\fP);
GBox& \fBoperator -=\fP (const GBox& \fIbox\fP);
GBox& \fBoperator &=\fP (const GBox& \fIbox\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods returns the smallest box contained in ``\fIthis\fP union
\fIbox\fP'', or ``\fIthis\fP minus \fIbox\fP'' or ``\fIthis\fP intersection
\fIbox\fP''
.RE
.sp 1
.SH
\fBC BINDING\fP
.SS
\fBHeader File\fP
.IP
#include <Go/Tools/cBox.h>
.SS
\fBType Definitions\fP
.IP
.nf
.ta .15i .25i 1.0i
typedef struct _GBox
{
	GNumber xmin, ymin;
	GNumber xmax, ymax;
} GBox;

.fi
.sp 1
\fISee\fP public variables xmin, ymin, xmax, ymax of the C++ object.
.SS
\fBC Functions\fP
.IP
GBool \fBGIsEmptyBox\fP (GBox* \fIbox\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GBool empty() const.
.RE
.sp 1
.IP
GBool \fBGIsPointInBox\fP (const GBox* \fIbox\fP, const GPoint \fIpoint\fP, GNumber \fImaxDistance\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GBool contains( const GPoint& \fIpoint\fP, GNumber \fImaxDistance\fP);
.RE
.sp 1
.IP
GBool \fBGIsBoxInterBox\fP (const GBox* \fIbox1\fP, const GBox* \fIbox2\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GBool GIntersect(const GBox& \fIbox1\fP, const GBox& \fIbox2\fP);
.RE
.sp 1
.IP
GBox \fBGBoxUnion\fP (const GBox* \fIbox1\fP, const GBox* \fIbox2\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GBox operator + (const GBox& \fIbox1\fP, const GBox& \fIbox2\fP);
.RE
.sp 1
.IP
GBox \fBGBoxIntersection\fP (const GBox* \fIbox1\fP, const GBox* \fIbox2\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GBox operator & (const GBox& \fIbox1\fP, const GBox& \fIbox2\fP);
.RE
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBBool(3Go)\fP, \fBPoint(3Go)\fP, \fBVector(3Go)\fP and \fBNumber(3Go)\fP.
.nrPN \n%
