.\" $Id: Brush.n,v 1.1.1.1 1992/03/18 09:45:26 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH Brush 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBBrush\fP \(em the brush object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/Brush.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBBrush\fP does not inherit behavior from any class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBBrush\fP object gives a non-shared object interface to the \fBShBrush\fP
object. As a \fIShBrush\fP, a \fIBrush\fP is defined by a set of
values (see \fIGBrushValues\fP). As \fIShBrush's\fP, \fIBrush's\fP are used
for drawing surfaces through a \fIGoInterf\fP subclass instance (see
\fIGoInterf(3Go)\fP.
.sp 1
The \fIBrush\fP class allows to set additional pre/postconditions.
.sp 1
\fBGBrush\fP is the C++ type of the \fIBrush\fP object.
.sp 1
.nf
.ta .15i .25i 1.5i
class GBrush {
	public:
		GBrush ();
		GBrush (const GBrush* \fIbrush\fP);
		GBrush (const GShBrush* \fIsh_brush\fP);
		GBrush (ulong mask, const GBrushValues* \fIvalues\fP, const char* \fIname\fP = NULL);
		GBrush (const char* \fIname\fP);
		~GBrush ();

		// Getting values
		const GShBrush* GShBrush () const;
		const GBrushValues* values () const;
		ulong mask () const;

		const char* name () const;
		GBool isNamed () const;

		ulong function () const;
		ulong planeMask() const;
		const GShColor* color () const;
		const GShColor* altColor () const;

		ushort fillStyle () const;
		ushort fillRule () const;
		const GShPattern* tile () const;
		const GShPattern* stipple () const;
		GNumber xtsOrigin() const;
		GNumber ytsOrigin() const;

		// Modifying methods
		void modify (ulong \fImask\fP, const GBrushValues* \fIvalues\fP);
		void modify (const char* \fIname\fP);
		void modify (const GShBrush* \fIsh_brush\fP);

		void function (ulong \fIfunction\fP);
		void planeMask(ulong \fIplane_mask\fP);
		void color (const GColor* \fIcolor\fP);
		void color (const GShColor* \fIsh_color\fP);
		void color (const char* \fIcolor_name\fP);
		void altColor (const GColor* \fIalt_color\fP);
		void altColor (const GShColor* \fIsh_alt_color\fP);
		void altColor (const char* \fIalt_color_name\fP);

		void fillStyle(ushort \fIfill_style\fP);
		void fillRule (ushort \fIfill_rule\fP);
		void tile (const GPattern* \fItile\fP);
		void tile (const ShPattern* \fIsh_tile\fP);
		void tile (const char* \fItile_name\fP);
		void stipple (const GPattern* \fIstipple\fP);
		void stipple (const ShPattern* \fIsh_stipple\fP);
		void stipple (const char* \fIstipple_name\fP);
		void tsOrigin (GNumber \fIx_origin\fP, GNumber \fIy_origin\fP);

		// Pre and Post Conditions
		void modifyPrecond (GBool (*\fIproc\fP)(void* \fIclosure\fP, const GBrush* \fIbrush\fP,
			ulong& \fImask\fP, GBrushValues* \fInewValues\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void modifyPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, const GBrush* \fIbrush\fP,
			ulong \fImask\fP), const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void destroyPostcond(void (*\fIproc\fP)(void* \fIclosure\fP, const GBrush* \fIbrush\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
};
.fi
.sp 1
.SH
\fBGBrushValues STRUCTURE\fP
.IP
\fISee GShBrush(3Go)\fP
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
.nf
\fBGBrush\fP();
\fBGBrush\fP(const GBrush* \fIbrush\fP);
\fBGBrush\fP(const GShBrush* \fIsh_brush\fP);
\fBGBrush\fP(ulong mask, const GBrushValues* \fIvalues\fP, const char* \fIname\fP = NULL);
\fBGBrush\fP(const char* \fIname\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to create a new instance of the \fIBrush\fP class. When no
parameters are passed to the constructor, the brush is created with the
default \fIShBrush\fP (see \fIShBrush(3Go)\fP).
.IP \fIbrush\fP .5i
.br
Specifies the \fIBrush\fP instance used to intialize the new brush values. Pre and
postconditions are not copied.
.IP \fIsh_brush\fP .5i
.br
Specifies the \fIShBrush\fP instance which is going to be referred in the
brush (the reference count of the shared brush is incremented).
.IP "\fImask, values\fP" .5i
.br
Specify the values of the brush. Unspecified fields in the \fIGBrushValues\fP
structure take default values (see \fIShBrush(3Go)\fP).
.IP \fIname\fP .5i
.br
Specifies the name of the named \fIShBrush\fP object to be refered. If no such
\fIShBrush\fP exists, it is created.
.RE
.sp 1
.IP
\fB~GBrush\fP ();
.RS .8i
.IP \fIDescription\fP .5i
This method is called when a \fIBrush\fP instance is deleted. The referred \fShBrush\fP
reference count is decremented. The \fIdestroyPostcond\fP is invoked.
.RE
.sp 1
.IP
.nf
const GShBrush* \fBshBrush\fP() const;
const GBrushValues* \fBvalues\fP() const;
ulong \fBmask\fP() const;
const char* \fBname\fP() const;
GBool \fBisNamed\fP() const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods returns either the \fIShBrush\fP referred by the brush, or
the values, the mask, the name of this \fIShBrush\fP. \fIisNamed()\fP returns
\fIGTRUE\fP, if the referred \fIShBrush\fP is named else it returns \fIGFALSE\fP and \fIname()\fP
returns NULL.
.RE
.sp 1
.IP
.nf
ulong \fBfunction\fP() const;
ulong \fBplaneMask\fP() const;
.sp 1
const GShColor* \fBcolor\fP() const;
const GShColor* \fBaltColor\fP() const;
.sp 1
ushort \fBfillStyle\fP() const;
ushort \fBfillRule\fP() const;
const ShPattern* \fBtile\fP() const;
const ShPattern* \fBstipple\fP() const;
GNumber \fBxtsOrigin\fP() const;
GNumber \fBytsOrigin\fP() const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to get field by field the \fIGBrushValues\fP structure
of the \fIShBrush\fP referred in the brush. These fields are only valid
if the corresponding bits in the mask (\fImask()\fP) are set.
.RE
.sp 1
.IP
.nf
void \fBmodify\fP(ulong \fImask\fP, const GBrushValues* \fIvalues\fP);
void \fBmodify\fP(const char* \fIname\fP);
void \fBmodify\fP(const GShBrush* \fIsh_brush\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to modify the brush value either by giving a ``mask, values''
couple, or by giving a \fIShBrush\fP identified by its name or by its pointer.
.IP "\fImask, values\fP" .5i
Specify the values to be modified. Only fields specified in the mask will be
affected by the modification. Pre and postconditions are invoked when \fImodify()\fP
is called with these parameters.
.IP \fIname\fP .5i
.br
Specifies the name of a named \fIShBrush\fP instance. If such an instance
does not exist, a new named \fIShBrush\fP is created with the current brush
values. Preconditions and postconditions are invoked when \fImodify()\fP 
is called with this parameter; the value mask is the complete named
\fIShBrush\fP mask. In preconditions functions, modifying the proposed
values will imply the named \fIShBrush\fP modification.
.IP \fIsh_brush\fP .5i
.br
Specifies a pointer to a \fIShBrush\fP instance, which will become the
\fIShBrush\fP referred in the brush. Pre and postconditions are invoked
when \fImodify()\fP is invoked with this parameter.
.RE
.sp 1
.IP
.nf
void \fBfunction\fP(ulong \fIfunction\fP);
void \fBplaneMask\fP(ulong \fIplane_mask\fP);
void \fBcolor\fP(const GColor* \fIcolor\fP);
void \fBcolor\fP(const GShColor* \fIsh_color\fP);
void \fBcolor\fP(const char* \fIcolor_name\fP);
void \fBaltColor\fP(const GColor* \fIalt_color\fP);
void \fBaltColor\fP(const GShColor* \fIsh_alt_color\fP);
void \fBaltColor\fP(const char* \fIalt_color_name\fP);
.sp 
void \fBfillStyle\fP(ushort \fIfill_style\fP);
void \fBfillRule\fP(ushort \fIfill_rule\fP);
void \fBtile\fP(const GPattern* \fItile\fP);
void \fBtile\fP(const ShPattern* \fIsh_tile\fP);
void \fBtile\fP(const char* \fItile_name\fP);
void \fBstipple\fP(const GPattern* \fIstipple\fP);
void \fBstipple\fP(const ShPattern* \fIsh_stipple\fP);
void \fBstipple\fP(const char* \fIstipple_name\fP);
void \fBtsOrigin\fP(GNumber \fIx_origin\fP, GNumber \fIy_origin\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to modify field by field the \fIGBrushValues\fP structure
of the referred \fIShBrush\fP. Pre and postconditions are invoked.
It is recommended for perfomance reasons, to use \fImodify(mask, values)\fP when several
fields have to be modified, rather than calling the specific method for each field.
.RE
.sp 1
.IP
.nf
void \fBmodifyPrecond\fP(GBool (*\fIproc\fP)(void* \fIclosure\fP, const GBrush* \fIbrush\fP,
	ulong& \fImask\fP, GBrushValues* \fInewValues\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBmodifyPostcond\fP(void (*\fIproc\fP)(void* \fIclosure\fP, const GBrush* \fIbrush\fP, ulong \fImask\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or to remove pre or postcondition procedures when the
\fIBrush\fP is modified. That means the referred \fIShBrush\fP has been updated.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the \fIBrush\fP will be modified. The precondition procedure is
called before the modification. It can either accept, refuse or force an other modification.
The postcondition procedure is invoked after the modification is done.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the pre/postcondition procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the modify
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp1
.IP
.nf
void \fBdestroyPostcond\fP(void (*\fIproc\fP)(void* \fIclosure\fP, const GBrush* \fIbrush\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP
This method allows to add or remove a callback procedure which will be called
when the \fIBrush\fP will be destroyed.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the object will be destroyed.
The callback procedure is called \fIjust before\fP the destruction of the object. Its parameters are
the \fIclosure\fP and the object \fIBrush\fP itself.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the
destruction callback list. If \fIadd\fP is GREMOVE, the callback procedure
\fIproc\fP will be removed from  the callback list.
.RE
.sp 1
.SH
\fBC BINDING\fP
.IP
.SS
\fBHeader File\fP
.IP
#include <Go/Tools/cBrush.h>
.SS
\fBType Definitions\fP
.IP
The \fIShBrush\fP C interface defines the \fIGBrushValues\fP structure. This
structure is used by the \fIBrush\fP C interface (see \fIShBrush(3Go)\fP).
.SS
\fBC Functions\fP
.IP
GObjectId \fBGCreateBrush\fP (ulong \fImask\fP, const GBrushValues* \fIvalues\fP, const char* \fIname\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GBrush (ulong \fImask\fP, const GBrushValues* \fIvalues\fP, const char* \fIname\fP).
.RE
.sp 1
.IP
void \fBGDestroyBrush\fP (GObjectId \fIbrush\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP ~GBrush ().
.RE
.sp 1
.IP
.nf
void \fBGModifyBrush\fP (GObjectId \fIbrush\fP, ulong \fImask\fP, const GBrushValues* \fIvalues\fP);
void \fBGModifyBrushFromName\fP (GObjectId \fIbrush\fP, const char* \fIname\fP);
void \fBGModifyBrushFromShBrush\fP (GObjectId \fIbrush\fP, const GObjectId \fIsh_brush\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP:
.nf
  void modify (ulong \fImask\fP, const GBrushValues* \fIvalues\fP);
  void modify (const char* \fIname\fP);
  void modify (const GShBrush* \fIsh_brush\fP);
.fi
.RE
.sp 1
.IP
.nf
const GBrushValues* \fBGGetBrushValues\fP (const GObjectId \fIbrush\fP);
const GObjectId \fBGGetBrushShBrush\fP (const GObjectId \fIbrush\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP:
.nf
   const GBrushValues* values ();
   const GShBrush* shBrush ().
.fi
.RE
.sp 1
.IP
.nf
void \fBGModifyBrushPrecond\fP (GObjectId \fIbrush\fP, GAddOrRemove \fIadd\fP,
	GBool (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIbrush\fP,
		ulong* \fImask\fP, GBrushValues* \fIvalues\fP),
	const void* \fIclosure\fP);
void \fBGModifyBrushPostcond\fP (GObjectId \fIbrush\fP, GAddOrRemove \fIadd\fP,
	void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIbrush\fP, ulong \fImask\fP),
	const void* \fIclosure\fP);
void \fBGDestroyBrushPostcond\fP (GObjectId \fIbrush\fP, GAddOrRemove \fIadd\fP,
	void (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIbrush\fP),
	const void* \fIclosure\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP
.nf
   void modifyPrecond (GBool (*\fIfunction\fP)(void* \fIclosure\fP, const GBrush* \fIbrush\fP,
	ulong& \fImask\fP, GBrushValues* \fInewValues\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;
   void modifyPostcond (void (*\fIfunction\fP)(void* \fIclosure\fP, const GBrush* \fIbrush\fP, ulong \fImask\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;   
   void destroyPostcond (void (*\fIfunction\fP)(void* \fIclosure\fP, const GBrush* \fIbrush\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;
.fi
.RE
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
The \fIBrush\fP object is a non-shared object interface for the \fIShBrush\fP object,
see the \fIShBrush(3Go)\fP and \fISharedObject(3Go)\fP to know the shared object
usage.
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBBool(3Go)\fP,
\fBCallback(3Go)\fP, \fBColor(3Go)\fP, \fBPattern(3Go)\fP
\fBSharedObject(3Go)\fP, \fBShBrush(3Go)\fP, \fBShColor(3Go)\fP, \fBShPattern(3Go)\fP.
.nrPN \n%
