.\" $Id: Buffer.n,v 1.1.1.1 1992/03/18 09:45:31 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH Buffer 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBBuffer\fP \(em the buffer object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/Buffer.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBBuffer\fP does not inherit anything from another class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBBuffer\fP class (which defines a linked list of buffers) was created in order to offer the possibility of reading and writing into memory buffers without managing them. Buffers are added transparently when necessary.
.IP
Reading and writing use two different pointers. This allows programmer to perform both read and write access at the same time. For instance, writing in a linked list of buffers and reading in the same list before the writing operation ended.
.IP
There is no need to delete a linked list of buffers and recreating it after, in order to rewrite that list. The programmer can do it transparently using a specific method.
.IP
Direct access for writing and reading in the linked list is also provided: two methods are available.
.IP
\fBGBuffer\fP is the C++ type for the \fIBuffer\fP object class.
.sp 1
.br
.nf
.ta .15i .25i 1.0i
class GBuffer {
	public:
		GBuffer (unsigned int \fIsize\fP = \fIBUFSIZ\fP);
		~GBuffer ();

		ulong write (const char* \fIaddr\fP, ulong \fIsize\fP)
		ulong read(const char* \fIaddr\fP, ulong \fIsize\fP);

		friend ulong GCopy(GBuffer* \fIdst\fP, GBuffer* \fIsrc\fP);

		char* readString();

		ulong writeInFile (FILE* \fIdst_file\fP);
		ulong readFile (FILE* \fIsrc_file\fP);

		int resetWrite(ulong \fIposition\fP = 1);
		int seekWrite (ulong \fIposition\fP);
		void appendWrite();
    
		int seekRead(ulong \fIposition\fP);
		void appendRead();
    
		ulong getNumberBytes();

		ulong getCurrentReadOffset() const;
		int stepBackRead();
};
.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
\fBGBuffer\fP (unsigned int \fIsize\fP = \fIBUFSIZ\fP);
.RS .8i
.IP \fIDescription\fP .5i
These functions allow to create an instance of the \fBBuffer\fP class.
.IP \fIsize\fP .5i
.br
Specify the size of the GBuffer in bytes. The default value is defined
in \fI<stdio.h>\fP.
.RE
.sp1
.IP
ulong \fBwrite\fP (const char* \fIaddr\fP, ulong \fIsize\fP)
.RS .8i
.IP \fIDescription\fP .5i
These function allows to write in the buffer object.
.br
The method returns the position in the linked list where the data has been written. 
If an error occurred (out of memory), the method returns 0.
.IP \fIaddr\fP .5i
.IP \fIsize\fP .5i
.br
Specify a pointer to the data to be written (cast as a char pointer) and the size in 
bytes of the data.
.RE
.sp1
.IP
ulong \fBread\fP (const char* \fIaddr\fP, ulong \fIsize\fP)
.RS .8i
.IP \fIDescription\fP .5i
These function allow to read from the buffer object.
The method returns the position in the linked list where the data have been read. 
If an error occurred, the method returns 0.
.IP \fIaddr\fP .5i
.IP \fIsize\fP .5i
.br
Specify a pointer to the data to be read (cast as a char pointer) and the number of 
bytes to be read. 
.RE
.sp1
.IP
char* \fBreadString\fP ()
.RS .8i
.IP \fIDescription\fP .5i
These function reads bytes in the linked list until it finds a NULL character.
The method returns the string.
.RE
.sp1
.IP
friend ulong \fBGCopy\fP (GBuffer* \fIdest\fP, GBuffer* \fIsrc\fP)
.RS .8i
.IP \fIDescription\fP .5i
These function copies a buffer in another buffer. In fact, it copies all the bytes 
from the current position of the read pointer to the end of source buffer. 
.br
The function returns the position in the destination buffer when it began to write. If 
an error occurred (out of memory), the function returns 0.
.IP \fIdest\fP .5i
.IP \fIsrc\fP .5i
.br
Specifies the two buffer objects.
.RE
.sp1
.IP
ulong \fBwriteInFile\fP (FILE* \fIdest\fP)
.RS .8i
.IP \fIDescription\fP .5i
These function writes all the bytes which are between the bytes of last reading and
the end of buffer. 
.br
The function returns the number of bytes which have been written in
the file. If an error occurred, the method returns 0.
.IP \fIdest\fP .5i
.br
Specifies the stream.
.RE
.sp1
.IP
ulong \fBreadFile\fP (FILE* \fIsrc\fP)
.RS .8i
.IP \fIDescription\fP .5i
These function reads a file and copies datas in the buffer.
.br
The function returns the number of bytes which have been written in
the buffer. If an error occurred, the method returns 0.
.IP \fIsrc\fP .5i
.br
Specifies the stream.
.RE
.sp1
.IP
int \fBresetWrite\fP (ulong \fIposition\fP =  1)
.RS .8i
.IP \fIDescription\fP .5i
These function allows the user to reuse several times the buffer. The write pointer
 is moved to the position given as parameter. This method deletes no buffer but the 
datas written from the given position are lost, because the next writing in the buffer 
will overwrite them.
.br
The read pointer is moved at the end of the truncated linked list if necessary
 (i.e if it was after the position given as parameter).
.br
If a error occurred, the function returns 0, otherwise it returns 1.
.IP \fIposition\fP .5i
.br
Specifies the new position of the write pointer.
.br
Default value is 1.
.RE
.sp1
.IP
int \fBseekWrite\fP (ulong \fIposition\fP)
.RS .8i
.IP \fIDescription\fP .5i
These method allows direct accesses to write datas. It moves the write pointer from 
its current position to the byte in the buffer corresponding to the seeking position.
.br 
These method returns 0 if the position is invalid, otherwise it returns 1.
.IP \fIposition\fP .5i
.br
Specifies the new position of the write pointer. The initial index is 1.
.RE
.sp1
.IP
void \fBappendWrite\fP ()
.RS .8i
.IP \fIDescription\fP .5i
These method moves the write pointer at the end of the buffer.
.RE
.sp1
.IP
int \fBseekRead\fP (ulong \fIposition\fP)
.RS .8i
.IP \fIDescription\fP .5i
These method allows direct accesses to read datas. It moves the read pointer from its 
current position to the byte in the buffer corresponding to the seeking position.
.br 
These method returns 0 if the position is invalid, otherwise it returns 1.
.IP \fIposition\fP .5i
.br
Specifies the new position of the read pointer. The initial index is 1.
.RE
.sp1
.IP
void \fBappendRead\fP ()
.RS .8i
.IP \fIDescription\fP .5i
These method moves the read pointer at the end of the buffer.
.RE
.sp1
.IP
ulong \fBgetNumberBytes\fP ()
.RS .8i
.IP \fIDescription\fP .5i
This function returns the number of written bytes in the linked list.
.RE
.sp1
.IP
ulong \fBgetCurrentReadOffset\fP () const
.RS .8i
.IP \fIDescription\fP .5i
This function returns the current position of the read pointer.
.RE
.sp1
.IP
int \fBstepBackRead\fP ()
.RS .8i
.IP \fIDescription\fP .5i
This function moves the read pointer from its current position to its current
position - 1.
.br
If an error occured, it returns 0.
.RE
.sp 1
.SH
\fBC BINDING\fP
.IP
None.
.SH
\fBSEE ALSO\fP
.nrPN \n%
