.\" $Id: Callback.n,v 1.1.1.1 1992/03/18 09:45:35 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH CallbackRec 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBCallbackRec\fP \(em the callback record class
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/Callback.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBCallbackRec\fP does not inherit from any other class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
A \fBCallbackRec\fP object represents a callback record including the procedure
and the closure. Such records are used to store pre and post conditions in
callback lists.
.sp 1
\fBGCallbackRec\fP is the C++ type for \fICallbackRec\fP. The following types
are also defined:
.sp 1
.nf
.ta .15i .25i 1.50i
enum GAddOrRemove { GREMOVE, GADD };
typedef void (*GCBProc)(void*, ...);  // ...from 1 to 5 parameters

struct GCallbackRec {
		GCBProc proc;
		void* closure;

		GCallbackRec(GCBProc \fIproc\fP, const void* \fIclosure\fP);
};

extern void GCallCallbacks(GCallbackRec* cbr, int ncbr, void* p1);
extern void GCallCallbacks(GCallbackRec* cbr, int ncbr, void* p1, ulong p2);
extern void GCallCallbacks(GCallbackRec* cbr, int ncbr, void* p1, ulong p2, ulong p3);
extern void GCallCallbacks(GCallbackRec* cbr, int ncbr, void* p1, ulong p2, ulong p3);
extern GBool GCallCallbacks(GCallbackRec* cbr, int ncbr, void* p1, ulong p2, ulong p3,
		ulong p4, ulong p5);

extern void GCallCallbacks(GCallbackRec* cbr, int ncbr, void* p1, void* p2);
extern void GCallCallbacks(GCallbackRec* cbr, int ncbr, void* p1, void* p2, void* p3);
extern void GCallCallbacks(GCallbackRec* cbr, int ncbr, void* p1, void* p2, void* p3);
extern void GCallCallbacks(GCallbackRec* cbr, int ncbr, void* p1, void* p2, void* p3,
		void* p4, void* p5);

.fi
.sp 1
.SH
\fBPUBLIC VARIABLES\fP
.IP
They are two public variables: \fIproc\fP and \fIclosure\fP.
.RS .8i
.IP \fIproc\fP .5i
.br
Specifies the callback procedure.
.IP \fIclosure\fP .5i
Specifies the closure pointer.
.RE
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
\fBGCallbackRec\fP (GCBProc \fIproc\fP, const void* \fIclosure\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to create a new instance of the \fICallbackRec\fP.
.IP \fIproc\fP .5i
.br
Specifies the callback procedure.
.IP \fIclosure\fP .5i
.br
Specifies the pointer to the application data.
.RE
.sp 1
.IP
.nf
void \fBGCallCallbacks\fP(GCallbackRec* \fIcbrec\fP, int \fIcount\fP, void* \fBp1\fP);
void \fBGCallCallbacks\fP(GCallbackRec* \fIcbrec\fP, int \fIcount\fP, void* \fBp1\fP, ulong \fIp2\fP);
void \fBGCallCallbacks\fP(GCallbackRec* \fIcbrec\fP, int \fIcount\fP, void* \fBp1\fP, ulong \fIp2\fP,
	ulong \fIp3\fP);
void \fBGCallCallbacks\fP(GCallbackRec* \fIcbrec\fP, int \fIcount\fP, void* \fBp1\fP, ulong \fIp2\fP,
	ulong \fIp3\fP, ulong \fIp4\fP);
void \fBGCallCallbacks\fP(GCallbackRec* \fIcbrec\fP, int \fIcount\fP, void* \fBp1\fP, ulong \fIp2\fP,
	ulong \fIp3\fP, ulong \fIp4\fP, ulong \fIp5\fP);
.fi
.IP
.nf
void \fBGCallCallbacks\fP(GCallbackRec* \fIcbrec\fP, int \fIcount\fP, void* \fBp1\fP, void* \fIp2\fP);
void \fBGCallCallbacks\fP(GCallbackRec* \fIcbrec\fP, int \fIcount\fP, void* \fBp1\fP, void* \fIp2\fP,
	void* \fIp3\fP);
void \fBGCallCallbacks\fP(GCallbackRec* \fIcbrec\fP, int \fIcount\fP, void* \fBp1\fP, void* \fIp2\fP,
	void* \fIp3\fP, void* \fIp4\fP);
void \fBGCallCallbacks\fP(GCallbackRec* \fIcbrec\fP, int \fIcount\fP, void* \fBp1\fP, void* \fIp2\fP,
	void* \fIp3\fP, void* \fIp4\fP, void* \fIp5\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These functions call the callbacks of the callback list \fIcbrec\fP. The callbacks are
called with \fIclosure\fP as the first parameter, \fIp1\fP as the second, etc... If \fIcount\fP
is not 1, the functions copy the callback list in a local buffer. This allows a callback to remove
one or more callbacks of the callback list but all callbacks are called at this time.
.br
At the end of execution of a callback function, \fIGCallCallbacks\fP verifies
if the function \fIStopPostcondLoopOn\fP has been called with parameter \fBp1\fP.
If yes it stops the execution of the loop. If \fIStopPostcondLoopOn(void* p1)\fP
has been called during the loop \fIGCallCallbacks\fP returns GTRUE else GFALSE.
.IP \fIcbrec\fP .5i
.br
Specifies the CallbackRec list.
.IP \fIcount\fP .5i
.br
Specifies the number of \fICallbackRec\fP in the list.
.IP \fIp1\fP .5i
.br
Specifies the second parameter of the callback procedure \fIproc\fP of the current
\fICallbackRec\fP used. The first parameter is the \fPclosure\fP field of the current
\fICallBackRec\fP used. \fIp1\fP is also the callback loop ident, cf \fIStopPostcondLoopOn\fI().
.IP \fIp2,p3,p4,p5\fP .5i
.br
Specify the parameters of the callback procedure \fIproc\fP of the current CallbackRec used.
.SH
\fBC BINDING\fP
.IP
None.
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
.SH
\fBSEE ALSO\fP
.nrPN \n%
