.\" $Id: Color.n,v 1.1.1.1 1992/03/18 09:45:40 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH Color 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBColor\fP \(em the color object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/Color.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBColor\fP does not inherit behavior from any class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBColor\fP object gives a non-shared object interface to the \fBShColor\fP
object. As a \fIShColor\fP, a \fIColor\fP is defined by a set of three
optional values,
each of them representing the color value on a color, gray scale or black and white
output device. A \fIColor\fP (or a \fIShColor\fP) is normally used
to draw something through a \fBGoInterf\fP (see \fIGoInterf(3Go)\fP) instance.
For example, when \fIGo\fP are drawn,
the \fIGoInterf\fP will use the appropriate value of the color according to the output
device capabilities. If the appropriate value is not defined, the
\fIGoInterf\fP will take the better decision.
.sp 1
The three color values are: \fBRgb\fP value, \fBGray\fP value, \fBHalftone\fP
value. The Rgb value contains the red, green and blue intensities, the Gray
value specifies one of the 256 gray levels (\fI0\fP is black, \fI0xff\fP is white),
the Halftone is a \fIShPattern\fP (see \fIShPattern(3Go)\fP) used to simulate a color
on a black and white screen.
.sp 1
A \fIColor\fP maintains a pointer to a \fIShColor\fP and offers the possibility to
set pre/post conditions on modifying and deleting.
.sp 1
\fBGColor\fP is the C++ type for the \fIColor\fP object class. See also types
defined in \fIShColor(3Go)\fP.
.sp 1
.nf
.ta .15i .25i 1.50i
class GColor {
	public:
		GColor ();
		GColor (const GColor* \fIcolor\fP);
		GColor (const GShColor* \fIsh_color\fP);
		GColor (ulong \fImask\fP, const GColorValues* \fIvalues\fP, const char* \fIname\fP = NULL);
		GColor (const GRgb* \fIrgb\fP, const char* \fIname\fP = NULL);
		GColor (uchar \fIgray\fP, const char* \fIname\fP = NULL);
		GColor (const GShPattern* \fIsh_halftone\fP, const char* \fIname\fP = NULL);
		GColor (const char* \fIname\fP);
		~GColor ();

		// Getting values
		const GShColor* shColor() const;
		const GColorValues* values() const;
		ulong mask() const;

		const char* name() const;
		GBool isNamed() const;

		const GRgb* rgb() const;
		int gray () const;
		const GShPattern* halftone () const;

		// Modifying methods
		void modify (ulong \fImask\fP, const GColorValues* \fIvalues\fP);
		void modify (const GShColor* \fIsh_color\fP);
		void modify (const char* \fIname\fP);

		void rgb (const GRgb* \fIrgb\fP);
		void gray (uchar \fIgray\fP);
		void halftone (const GPattern* \fIhalftone\fP);
		void halftone (const GShPattern* \fIsh_halftone\fP);
		void halftone (const char* \fIhalftone_name\fP);

		// Pre and Post Conditions
		void modifyPrecond (GBool (*\fIproc\fP)(void* \fIclosure\fP, GColor* \fIcolor\fP,
			ulong& \fImask\fP, GColorValues* \fInew_values\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void modifyPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GColor* \fIcolor\fP, ulong \fImask\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void destroyPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GColor* \fIcolor\fP),
				const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
};
.fi
.sp 1
.SH
\fBGRgb STRUCTURE\fP
.IP
\fISee ShColor(3Go)\fP
.sp 1
.SH
\fBGColorValues STRUCTURE\fP
.IP
\fISee ShColor(3Go)\fP
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
.nf
\fBGColor\fP ();
\fBGColor\fP (const GColor* \fIcolor\fP);
\fBGColor\fP (const GShColor* \fIsh_color\fP);
\fBGColor\fP (ulong \fImask\fP, const GColorValues* \fIvalues\fP, const char* \fIname\fP = NULL);
\fBGColor\fP (const GRgb* \fIrgb\fP, const char* \fIname\fP = NULL);
\fBGColor\fP (const uchar \fIgray\fP, const char* \fIname\fP = NULL);
\fBGColor\fP (const GShPattern* \fIhalftone\fP, const char* \fIname\fP = NULL);
\fBGColor\fP (const char* \fIname\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to create a new \fIColor\fP instance. The new \fIColor\fP
points to a \fIShColor\fP which may be shared between several other \fIColor\fP
instances. When the \fIname\fP field is specified, a named \fIShColor\fP
is explicitly referred. Specifying values (color, gray of halftone) and the
name implies the corresponding named \fIShColor\fP modification.
.IP \fIcolor\fP .5i
.br
Specifies the \fIColor\fP used to initialize the new instance.
.IP \fIsh_color\fP .5i
Specifies the \fIShColor\fP which will be pointed by the \fIColor\fP. The
\fIShColor\fP reference count is incremented.
.IP \fImask\fP .5i
.br
Specifies the value bitmask (see \fIShColor(3Go)\fP).
.IP \fIvalues\fP .5i
.br
Specifies a \fIGColorValues\fP structure pointer. Valid fields are defined by
the \fImask\fP.
.IP "\fIrgb, gray, halftone\fP" .5i
.br
Specify the \fIColor\fP value (either a \fIRgb\fP structure, either a gray level or
a \fIShPattern\fP pointer).
.IP \fIname\fP .5i
.br
Identifies the named \fIShColor\fP which is called \fIname\fP. If such
\fIShColor\fP does not exit it is created. If values (rgb, gray, halftone) are
defined, the named \fIShColor\fP will be modified.
.RE
.sp 1
.IP
\fB~GColor\fP ();
.RS .8i
.IP \fIDescription\fP .5i
This method is called when a \fIColor\fP instance is deleted. The corresponding
\fIShColor\fP reference count is decremented. The \fIdestroyPostcond\fP callback,
if exits, is called \fIjust before\fP the deletion.
.RE
.sp 2
.IP
const GShColor* \fBshColor\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the \fIShColor\fP associated to the \fIColor\fP object.
.RE
.sp 1
.IP
const GColorValues* \fBvalues\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the pointer to the \fIColor\fP values.
.RE
.sp 1
.IP
ulong \fBmask\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the current value bit mask of the corresponding \fIShColor\fP.
.RE
.sp 1
.IP
const char* \fBname\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the name of the associated \fIShColor\fP or NULL.
.RE
.sp 1
.IP
GBool \fBisNamed\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This method return GTRUE, if the associated \fIShColor\fP is
named, else it returns GFALSE.
.RE
.sp 1
.IP
const GRgb* \fBrgb\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns a pointer to the \fIRgb\fP value. This pointer may
be NULL if this value is undefined in the associated \fIShColor\fP.
.RE
.sp 1
.IP
int \fBgray\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the gray level value (<255). It may be -1, if this
value is undefined in the associated \fIShColor\fP.
.RE
.sp 1
.IP
const GShPattern* \fBhalftone\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns a pointer to the halftone pattern (\fIShPattern\fP). It may
be NULL, if this value is undefined in the associated \fIShColor\fP.
.RE
.sp 2
.IP
void \fBmodify\fP (ulong \fImask\fP, const GColorValues* \fIvalues\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to modify the \fIColor\fP values. It calls the
\fImodify()\fP function of the associated \fIShColor\fP. After this
call, the \fIShColor\fP pointer may be different. The pre/post
conditions will be called if they exist.
.IP \fImask\fP .5i
.br
Specifies the value bitmask of the valid fields in the \fIGColorValues\fP
structure.
.IP \fIvalues\fP .5i
.br
Specifies the new values which will be assigned to the \fIColor\fP.
.RE
.sp 1
.IP
void \fBmodify\fP (const GShColor* \fIsh_color\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to modify the \fIColor\fP object by changing
the \fIShColor\fP pointed by the \fIColor\fP. The pre/post conditions
are called if they exist.
.IP \fIsh_color\fP .5i
.br
Specifies the \fIShColor\fP which has to replace the previous
\fIShColor\fP contained in the \fIColor\fP.
.RE
.sp 1
.IP
void \fBmodify\fP (const char* \fIname\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to (re)name the associated \fIShColor\fP. If \fIname\fP
is NULL, a unnamed \fIShColor\fP will be created. The pre/post conditions
are invoked; the value mask is the complete named \fIShColor\fP mask.
In preconditions functions, modifying the proposed values will imply the
named \fIShColor\fP modification.
.IP \fIname\fP .5i
.br
Specifies the new name of the associated \fIShColor\fP.
.RE
.sp 1
.IP
void \fBrgb\fP (const GRgb* \fIrgb\fP);
.br
void \fBgray\fP (uchar \fIgray\fP);
.br
void \fBhalftone\fP (const GPattern* \fIhalftone\fP);
.br
void \fBhalftone\fP (const GShPattern* \fIsh_halftone\fP);
.br
void \fBhalftone\fP (const char* \fIhalftone_name\fP);
.RS .8i
.IP \fIDescription\fP .5i
These method allow to modify some value fields (rgb, gray, halftone) of the
\fIColor\fP. The associated \fIShColor\fP \fImodify()\fP method is called.
The pre/post conditions are called if they exist.
.IP \fIrgb\fP .5i
.br
Specifies the new rgb value of the \fIColor\fP.
.IP \fIgray\fP .5i
.br
Specifies the new gray level value of the \fIColor\fP.
.IP "\fIhalftone, sh_halftone, halftone_name\fI" .5i
Specify the new halftone pattern of the \fIColor\fP.
.RE
.sp2
.IP
.nf
void \fBmodifyPrecond\fP (GBool (*\fIproc\fP)(void* \fIclosure\fP, GColor* \fIcolor\fP,
	ulong& \fImask\fP, GColorValues* \fInew_values\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBmodifyPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GColor* \fIcolor\fP, ulong \fImask\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These method allow to add or remove pre or post conditions on \fIColor\fP modifying.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called before (pre-condition) or after (post-condition)
the modification. Its parameters are the \fIclosure\fP, the object \fIColor\fP
itself and the modification \fImask\fP. For the pre-condition, if \fIproc\fP returns
GFALSE, the modification is nor proceeded. In addition, the precondition procedure
may modify the action (\fInew_values\fP).
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the condition
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp1
.IP
.nf
void \fBdestroyPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GColor* \fIcolor\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP
This method allows to add or remove a callback procedure which will be called
when the object \fIColor\fP will be destroyed.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the object will be destroyed.
The callback procedure is called \fIjust before\fP the destruction of the object. Its parameters are
the \fIclosure\fP and the object \fIColor\fP itself.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the
destruction callback list. If \fIadd\fP is GREMOVE, the callback procedure
\fIproc\fP will be removed from  the callback list.
.RE
.sp1
.SH
\fBC BINDING\fP
.SS
\fBHeader File\fP
.IP
#include <Go/Tools/cColor.h>
.SS
\fBType Definitions\fP
.IP
The \fIShColor\fP C interface defines the \fIGColorValues\fP structure. This
structure is used by the \fIColor\fP C interface (see \fIShColor(3Go)\fP).
.SS
\fBC Functions\fP
.IP
GObjectId \fBGCreateColor\fP (ulong \fImask\fP, const GColorValues* \fIvalues\fP, const char* \fIname\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GColor (ulong \fImask\fP, const GColorValues* \fIvalues\fP, const char* \fIname\fP).
.RE
.sp 1
.IP
void \fBGDestroyColor\fP (GObjectId \fIcolor\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP ~GColor ().
.RE
.sp 1
.IP
.nf
void \fBGModifyColor\fP (GObjectId \fIcolor\fP, ulong \fImask\fP, const GColorValues* \fIvalues\fP);
void \fBGModifyColorFromName\fP (GObjectId \fIcolor\fP, const char* \fIname\fP);
void \fBGModifyColorFromShColor\fP (GObjectId \fIcolor\fP, const GObjectId \fIsh_color\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP:
.nf
  void modify (ulong \fImask\fP, const GColorValues* \fIvalues\fP);
  void modify (const char* \fIname\fP);
  void modify (const GShColor* \fIsh_color\fP);
.fi
.RE
.sp 1
.IP
.nf
const GColorValues* \fBGGetColorValues\fP (const GObjectId \fIcolor\fP);
const GObjectId \fBGGetColorShColor\fP (const GObjectId \fIcolor\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP:
.nf
   const GColorValues* values ();
   const GShColor* shColor ().
.fi
.RE
.sp 1
.IP
.nf
void \fBGModifyColorPrecond\fP (GObjectId \fIcolor\fP, GAddOrRemove \fIadd\fP,
	GBool (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIcolor\fP,
		ulong* \fImask\fP, GColorValues* \fIvalues\fP),
	const void* \fIclosure\fP);
void \fBGModifyColorPostcond\fP (GObjectId \fIcolor\fP, GAddOrRemove \fIadd\fP,
	void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIcolor\fP, ulong \fImask\fP),
	const void* \fIclosure\fP);
void \fBGDestroyColorPostcond\fP (GObjectId \fIcolor\fP, GAddOrRemove \fIadd\fP,
	void (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIcolor\fP),
	const void* \fIclosure\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP
.nf
   void modifyPrecond (GBool (*\fIfunction\fP)(void* \fIclosure\fP, const GColor* \fIcolor\fP,
	ulong& \fImask\fP, GColorValues* \fInewValues\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;
   void modifyPostcond (void (*\fIfunction\fP)(void* \fIclosure\fP, const GColor* \fIcolor\fP, ulong \fImask\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;   
   void destroyPostcond (void (*\fIfunction\fP)(void* \fIclosure\fP, const GColor* \fIcolor\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;
.fi
.RE
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
The \fIColor\fP object is a non-shared object interface for the \fIShColor\fP object,
see the \fIShColor(3Go)\fP and \fISharedObject(3Go)\fP to know the shared object
usage.
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBBool(3Go)\fP, \fBGoInterf(3Go)\fP, \fBPattern(3Go)\fP, \fBSharedObject(3Go)\fP,
\fBShColor(3Go)\fP, \fBShPattern(3Go)\fP.
.nrPN \n%
