.\" $Id: Colormap.n,v 1.1.1.1 1992/03/18 09:45:46 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH Colormap 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBColormap\fP \(em the colormap object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/Colormap.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBColormap\fP does not inherit behavior from any class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBColormap\fP object gives a non-shared object interface to the
\fBShColormap\fP object. As a \fIShColormap\fP, a
\fIColormap\fP object is a \fBShColor\fP (see \fIShColor(3Go)\fP table.
It is used when drawing image or when using pattern (see \fIShPattern(3Go)\fP)
by \fBGoInterf\fP instances (see \fIGoInterf(3Go)\fP).
.sp 1
\fBShColor\fP objects may be added to or removed from the colormap. A
color in a table has an \fBindex\fP used in the \fBShPixelArray\fP (see
\fIShPixelArray(3Go)\fP) description.
.sp 1
The \fBColormap\fP object maintains to a \fIShColormap\fP and offers the possibility
to add/remove pre/post conditions on modifying and deleting.
.sp 1
\fBGColormap\fP is the C++ type for the \fIColormap\fP object. See
also types defined in \fIShColormap(3Go)\fP.
.sp 1
.nf
.ta .15i .25i 1.50i
class GColormap {
	public:
		GColormap ();
		GColormap (const GColormap* \fIcolormap\fP);
		GColormap (const GShColormap* \fIsh_colormap\fP);
		GColormap (ulong \fImask\fP, const GColormapValues* \fIvalues\fP, const char* \fIname\fP = NULL);
		GColormap (const char* \fIname\fP);
		~GColormap ();

		// Getting values
		const GShColormap* shColormap() const;
		const GColormapValues* values() const;

		const char* name() const;
		GBool isNamed() const;

		ulong nColor() const;
		const GShColor** colors () const;

		// Getting color object, returns NULL if not found
		const GShColor* getColor (const char* \fIname\fP) const;
		const GShColor* getColor (const GRgb* \fIrgb\fP) const;
		const GShColor* getColor (uchar \fIgray\fP) const;
		const GShColor* getColor (const GShPattern* \fIhalftone\fP) const;
		const GShColor* getColor (ulong \fIindex\fP) const;

		// Getting index, returns -1 if not found
		long getIndex (const char* \fIname\fP) const;
		long getIndex (const GRgb* \fIrgb\fP) const;
		long getIndex (uchar \fIgray\fP) const;
		long getIndex (const GShPattern* \fIhalftone\fP) const;
		long getIndex (const GShColor* \fIsh_color\fP) const;

		// Modifying methods
		void modify (ulong \fImask\fP, const GColormapValues* \fIvalues\fP);
		void modify (const GShColormap \fIsh_colormap\fP);
		void modify (const char* \fIname\fP);

		ulong addColor (const GShColor* \fIsh_color\fP); // returns index
		void remColor (const GShColor* \fIsh_color\fP);
		void remColor (ulong \fIindex\fP);
		ulong replaceColor (const GShColor* \fIold_color\fP, const GShColor* \fInew_color\fP);
		ulong replaceColor (ulong \fIindex\fP, const GShColor* \fInew_color\fP);

		// Pre and Post Conditions
		void modifyPrecond (GBool (*\fIproc\fP)(void* \fIclosure\fP, GColormap* \fIcmap\fP,
			ulong& \fImask\fP, GColormapValues* \fInew_values\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void modifyPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GColormap* \fIcmap\fP , ulong \fImask\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void destroyPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GColormap* \fIcmap\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void addColorPrecond (GBool (*\fIproc\fP)(void* \fIclosure\fP, GColormap* \fIcmap\fP, const GShColor* \fIsh_color\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void addColorPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GColormap* \fIcmap\fP, ulong \fIindex\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void remColorPrecond (GBool (*\fIproc\fP)(void* \fIclosure\fP, GColormap* \fIcmap\fP, ulong \fIindex\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void remColorPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GColormap* \fIcmap\fP, ulong \fIindex\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void replaceColorPrecond (GBool (*\fIproc\fP)(void* \fIclosure\fP, GColormap* \fIcmap\fP, const GShColor* \fIsh_color\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void replaceColorPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GColormap* \fIcmap\fP, ulong \fIindex\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
};
.fi
.sp 1
.SH
\fBGColormapValues STRUCTURE\fP
.IP
\fISee ShColormap(3Go)\fP
.sp 1
.SH
\fBPUBLIC FUNCTIONS\fP
.IP
\fBGColormap\fP ();
.br
\fBGColormap\fP (const GShColormap* \fIsh_colormap\fP);
.br
\fBGColormap\fP (ulong \fImask\fP, const GColormapValues* \fIvalues\fP, const char* \fIname\fP = NULL);
.br
\fBGColormap\fP (const char* \fIname\fP);
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to create a new \fIColormap\fP instance. The new \fIColormap\fP
points to a \fIShColormap\fP which may be shared between several other \fIColormap\fP
instances. When the \fIname\fP field is present, a named \fIShColormap\fP is explicitly
referred. Specifying values (color table) and the name implies the corresponding named
\fIShColormap\fP to be modifyed.
.IP \fIsh_colormap\fP .5i
Specifies the \fIShColormap\fP which will be pointed be the \fIColormap\fP. The
\fIShColormap\fP reference count is incremented.
.IP \fImask\fP .5i
.br
Specifies the value bitmask (see \fIShColormap(3Go)\fP).
.IP \fIvalues\fP .5i
.br
Specifies a \fIGColormapValues\fP structure pointer. Valid fields are defined by the
\fImask\fP.
.IP \fIname\fP .5i
.br
Identifies the named \fIShColormap\fP which is called \fIname\fP. If such
\fIShColormap\fP does not exit, it is created. If values (color table) are
defined, the named \fIShColormap\fP will be updated.
.RE
.sp 1
.IP
\fB~GColormap\fP ();
.RS .8i
.IP \fIDescription\fP .5i
This method us called when a \fIColormap\fP instance is deleted. The corresponding
\fIShColormap\fP reference count is decremented. The \fIdestroyPostcond\fP callback,
if exits, is called \fIjust before\fP the deletion.
.RE
.sp 2
.IP
const GShColormap* \fBshColormap\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the \fIShColormap\fP associated to the \fIColormap\fP object.
.RE
.sp 1
.IP
const GColormapValues* \fBvalues\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the pointer to the \fIColormap\fP values.
.RE
.sp 1
.IP
const char* \fBname\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the name of the associated \fIShColormap\fP or NULL.
.RE
.sp 1
.IP
GBool \fBisNamed\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns GTRUE, if the associated \fIShColormap\fP is named,
else it returns GFALSE.
.RE
.sp 1
.IP
ulong \fBnColor\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the valid entry number of the colormap.
.RE
.sp 1
.IP
const GShColor** \fBcolors\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the pointer to the color array of the colormap.
.RE
.sp 2
.IP
const GShColor* \fBgetColor\fP (const char* \fIname\fP) const;
.br
const GShColor* \fBgetColor\fP (const GRgb* \fIrgb\fP) const;
.br
const GShColor* \fBgetColor\fP (uchar \fIgray\fP) const;
.br
const GShColor* \fBgetColor\fP (const GShPattern* \fIhalftone\fP) const;
.br
const GShColor* \fBgetColor\fP (ulong \fIindex\fP) const;
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to retrieve a colormap entry (\fIShColor\fP) from
a given parameter. They returns a pointer to this entry or NULL if the
entry is not found.
.IP \fIname\fP .5i
.br
Specifies a \fIShColor\fP name. If a colormap entry is this \fIShColor\fP,
it is returned, else NULL is returned.
.IP "\fIrgb, gray, halftone\fP" .5i
.br
Specify \fIShColor\fP attributes. If a colormap entry owns the requested
attribute, it is returned, else NULL is returned.
.IP \fIindex\fP .5i
.br
Specifies the entry index in the colormap. If this entry is valid, the
\fIShColor\fP is returned, else NULL is returned.
.RE
.sp 2
.IP
long \fBgetIndex\fP (const char* \fIname\fP) const;
.br
long \fBgetIndex\fP (const GRgb* \fIrgb\fP) const;
.br
long \fBgetIndex\fP (uchar \fIgray\fP) const;
.br
long \fBgetIndex\fP (const GShPattern* \fIhalftone\fP) const;
.br
long \fBgetIndex\fP (const GShColor* \fIsh_color\fP) const;
.RS .8i
.IP \fIDescription\fP .5i
These methods return the entry index of a \fIShColor\fP in the colormap.
The \fIShColor\fP may be specified by its \fIname\fP, by one of its attributes
(\fIrgb, gray, halftone\fP) or by its pointer. These methods return -1
if the specified \fIShColor\fP does not exist in the table.
.IP \fIname\fP
.br
Specifies the \fIShColor\fP name. The index of the first entry of the colormap called by
\fIname\fP is returned. If such entry does not exit, the method returns -1.
.IP "\fIrgb, gray, halftone\fP .5i
.br
Specify \fIShColor\fP attributes. The index of the first entry of the colormap
owning the requested attribute is returned, If such entry does not exist, the method returns -1.
.IP \fIsh_color\fP .5i
.br
Specifies the \fIShColor\fP. The index of the first entry of the colormap
which is \fIsh_color\fP is returned. If such entry does not exist, the method returns -1.
.RE
.sp 2
.IP
void \fBmodify\fP (ulong \fImask\fP, const GColormapValues* \fIvalues\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to modify the \fIColormap\fP values. It calls the
\fImodify()\fP function of the associated \fIShColormap\fP. After this
call, the \fIShColormap\fP pointer may be different. The pre/post
conditions will be called if they exist.
.IP \fImask\fP
.br
Specifies the value bitmask of the valid fields of the \fIGColormapValues\fP
structure.
.IP \fIvalues\fP .5i
.br
Specifies the new values which will e assigned to the \fIColormap\fP.
.RE
.sp 1
.IP
void \fBmodify\fP (const GShColormap \fIsh_colormap\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to modify the \fIColormap\fP by changing the
\fIShColormap\fP pointed by the \fIColormap\fP. The pre/post conditions
are called if they exist.
.IP \fIsh_colormap\fP .5i
.br
Specifies the \fIShColormap\fP whish has to replace the previous
\fIShColormap\fP contained in the \fIColormap\fP.
.RE
.sp 1
.IP
void \fBmodify\fP (const char* \fIname\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to (re)name the associated \fIShColormap\fP. If \fIname\fP
is NULL, a unnamed \fIShColormap\fP will created. The pre/post conditions
are invoked; the value mask is the complete named \fIShColormap\fP mask.
In preconditions functions, modifying the proposed values will imply the
named \fIShColormap\fP modification.
.IP \fIname\fP .5i
.br
Specifies the new name of the associated \fIShColormap\fP.
.RE
.sp 2
.IP
ulong \fBaddColor\fP (const GShColor* \fIsh_color\fP); // returns index
.RS .8i
.IP \fIDescription\fP .5i
This method allows to add a new color in the colormap. It returns the index of the
color in the colormap. If the color already exists, it simply returns the index and
the \fIaddColorPostcond\fP is not called. The color may freed after the method call.
.IP \fIsh_color\fP .5i
.br
Specifies the \fIShColor\fP instance to be added.
.RE
.sp 1
.IP
void \fBremColor\fP (const GShColor* \fIsh_color\fP);
.br
void \fBremColor\fP (ulong \fIindex\fP);
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to remove an entry from the colormap. If such entry does not
exist, it simply returns and the \fIremColorPostcond\fP is not called.
.IP \fIsh_color\fP .5i
.br
Specifies the \fIShColor\fP entry to be removed.
.IP \fIindex\fP .5i
.br
Specifies the index of the colormap entry to be removed.
.RE
.sp 1
.IP
ulong \fBreplaceColor\fP (const GShColor* \fIold_color\fP, const GShColor* \fInew_color\fP);
.br
ulong \fBreplaceColor\fP (ulong \fIindex\fP, const GShColor* \fInew_color\fP);
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to replace an existing color by an other in the
colormap and returns the index position of the color. If the old color does not exist,
the new one is inserted either at the first free location in the table or at the given
index position. In that last case, the \fIaddColorPostcond\fP procedure is called
instead of the \fIreplaceColorPostcond\fP procedure.
.IP \fIold_color\fP .5i
.br
Specifies the \fIShColor\fP to be replaced.
.IP \fInew_color\fP .5i
.br
Specifies the \fIShColor\fP to be inserted.
.IP \fIindex\fP .5i
.br
Specifies the index position for the \fInew_color\fP.
.RE
.sp 2
.IP
.nf
void \fBmodifyPrecond\fP (GBool (*\fIproc\fP)(void* \fIclosure\fP, GColormap* \fIcmap\fP,
	ulong& \fImask\fP, GColormapValues* \fInew_values\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBmodifyPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GColormap* \fIcmap\fP , ulong \fImask\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or remove pre or post conditions on the \fIColormap\fP modification.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called before (pre-condition) or after (post-condition)
the modification. Its parameters are the \fIclosure\fP, the object \fIColormap\fP
itself and the modification \fImask\fP. For the pre-condition, if \fIproc\fP returns
GFALSE, the modification is not done, it may also change \fInew_values\fP.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the condition
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp1
.IP
.nf
void \fBdestroyPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GColormap* \fIcmap\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method allows to add or remove a callback procedure which will be called
when the object \fIColormap\fP will be destroyed.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the object will be destroyed.
The callback procedure is called \fIjust before\fP the destruction of the object. Its parameters are
the \fIclosure\fP and the object \fIColormap\fP itself.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the
destruction callback list. If \fIadd\fP is GREMOVE, the callback procedure
\fIproc\fP will be removed from  the callback list.
.RE
.sp1
.IP
.nf
void \fBaddColorPrecond\fP (GBool (*\fIproc\fP)(void* \fIclosure\fP, GColormap* \fIcmap\fP, const GShColor* \fIsh_color\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBaddColorPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GColormap* \fIcmap\fP, ulong \fIindex\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or remove pre or post condition callbacks which will be called
when a \fIShColor\fP will be added in the colormap.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when a \fIShColor\fP will be added.
Its parameters are the \fIclosure\fP, the object \fIColormap\fP itself and either
the \fIShColor\fP to be added (pre-condition) or the index of the added \fIShColor\fP.
For the pre-condition, if \fIproc\fP returns GFALSE, the color will not be added.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the
destruction callback list. If \fIadd\fP is GREMOVE, the callback procedure
\fIproc\fP will be removed from  the callback list.
.RE
.sp1
.IP
.nf
void \fBremColorPrecond\fP (GBool (*\fIproc\fP)(void* \fIclosure\fP, GColormap* \fIcmap\fP, ulong \fIindex\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBremColorPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GColormap* \fIcmap\fP, ulong \fIindex\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or remove pre or post condition callbacks which will be called
when a \fIShColor\fP will be removed from the colormap.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when a \fIShColor\fP will be removed.
Its parameters are the \fIclosure\fP, the object \fIColormap\fP itself and
the index of the \fIShColor\fP to be removed. For the pre-condition, if \fIproc\fP
returns GFALSE, the color is not removed.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the
destruction callback list. If \fIadd\fP is GREMOVE, the callback procedure
\fIproc\fP will be removed from  the callback list.
.RE
.sp1
.IP
.nf
void \fBreplaceColorPrecond\fP (GBool (*\fIproc\fP)(void* \fIclosure\fP, GColormap* \fIcmap\fP,
	ulong \fIindex\fP, const GShColor* \fInew_sh_color\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBreplaceColorPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GColormap* \fIcmap\fP, ulong \fIindex\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or remove pre or post condition callbacks which will be called
when an colormap entry will be replaced by an other \fIShColor\fP.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when a \fIShColor\fP will be replaced.
Its parameters are the \fIclosure\fP, the object \fIColormap\fP itself and
either for the pre-condition, the index of the color to be replaced and the new color, or
for the post-condition, the colormap index (post-condition) of the replaced color.
For the pre-condition, if \fIproc\fP returns GFALSE, the color is not replaced.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the
destruction callback list. If \fIadd\fP is GREMOVE, the callback procedure
\fIproc\fP will be removed from  the callback list.
.RE
.sp1
.SH
\fBC BINDING\fP
.SS
\fBHeader File\fP
.IP
#include <Go/Tools/cColormap.h>
.SS
\fBType Definitions\fP
.IP
The \fIShColormap\fP C interface defines the \fIGColormapValues\fP structure. This
structure is used by the \fIColormap\fP C interface (see \fIShColormap(3Go)\fP).
.SS
\fBC Functions\fP
.IP
GObjectId \fBGCreateColormap\fP (ulong \fImask\fP, const GColormapValues* \fIvalues\fP, const char* \fIname\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GColormap (ulong \fImask\fP, const GColormapValues* \fIvalues\fP, const char* \fIname\fP).
.RE
.sp 1
.IP
void \fBDestroyColormap\fP (GObjectId \fIcolormap\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP ~GColormap ().
.RE
.sp 1
.IP
.nf
void \fBGModifyColormap\fP (GObjectId \fIcolormap\fP, ulong \fImask\fP, const GColormapValues* \fIvalues\fP);
void \fBGModifyColormapFromName\fP (GObjectId \fIcolormap\fP, const char* \fIname\fP);
void \fBGModifyColormapFromShColormap\fP (GObjectId \fIcolormap\fP, const GObjectId \fIsh_colormap\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP:
.nf
  void modify (ulong \fImask\fP, const GColormapValues* \fIvalues\fP);
  void modify (const char* \fIname\fP);
  void modify (const GShColormap* \fIsh_colormap\fP);
.fi
.RE
.sp 1
.IP
.nf
const GColormapValues* \fBGGetColormapValues\fP (const GObjectId \fIcolormap\fP);
ulong \fBGGetColormapColorNumber\fP (const GObjectId \fIcolormap\fP);
const GObjectId \fBGGetColormapShColormap\fP (const GObjectId \fIcolormap\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP:
.nf
   const GColormapValues* values () const;
   ulong nColor () const;
   const GShColormap* shColormap () const.
.fi
.RE
.sp 1
.IP
.nf
long \fBGAddColormapColor\fP (GObjectId \fIcolormap\fP, const GObjectId \fIsh_color\fP);
void \fBGRemColormapColor\fP (GObjectId \fIcolormap\fP, const GObjectId \fIsh_color\fP);
void \fBGRemColormapIndexedColor\fP (GObjectId \fIcolormap\fP, ulong \fIindex\fP);
long \fBGRepColormapColor\fP (GObjectId \fIcolormap\fP, const GObjectId \fIo_sh_color\fP, const GObjectId \fIn_sh_color\fP);
long \fBGRepColormapIndexedColor\fP (GObjectId \fIcolormap\fP, ulong \fIindex\fP, const GObjectId \fIsh_color\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP
.nf
   ulong addColor (const GShColor* \fIsh_color\fP); // returns index
   void remColor (const GShColor* \fIsh_color\fP);
   void remColor (ulong \fIindex\fP);
   ulong replaceColor (const GShColor* \fIo_sh_color\fP, const GShColor* \fIn_sh_color\fP);
   ulong replaceColor (ulong \fIindex\fP, const GShColor* \fIsh_color\fP);
.fi
.RE
.sp 1
.IP
.nf
void \fBGModifyColormapPrecond\fP (GObjectId \fIcolormap\fP, GAddOrRemove \fIadd\fP,
	GBool (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIcolormap\fP, ulong* \fImask\fP, GColormapValues* \fIvalues\fP),
	const void* \fIclosure\fP);
void \fBGModifyColormapPostcond\fP (GObjectId \fIcolormap\fP, GAddOrRemove \fIadd\fP,
	void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIcolormap\fP, ulong \fImask\fP),
	const void* \fIclosure\fP);
void \fBGAddColormapColorPrecond\fP (GObjectId \fIcolormap\fP, GAddOrRemove \fIadd\fP,
	GBool (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIcolormap\fP, const GObjectId \fIsh_color\fP),
	const void* \fIclosure\fP);
void \fBGAddColormapColorPostcond\fP (GObjectId \fIcolormap\fP, GAddOrRemove \fIadd\fP,
	void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIcolormap\fP, ulong \fIindex\fP),
	const void* \fIclosure\fP);
void \fBGRemColormapColorPrecond\fP (GObjectId \fIcolormap\fP, GAddOrRemove \fIadd\fP,
	GBool (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIcolormap\fP, ulong \fIindex\fP),
	const void* \fIclosure\fP);
void \fBGRemColormapColorPostcond\fP (GObjectId \fIcolormap\fP, GAddOrRemove \fIadd\fP,
	void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIcolormap\fP, ulong \fIindex\fP),
	const void* \fIclosure\fP);
void \fBGRepColormapColorPrecond\fP (GObjectId \fIcolormap\fP, GAddOrRemove \fIadd\fP,
	GBool (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIcolormap\fP, ulong \fIindex\fP, const GObjectId \fIsh_color\fP),
	const void* \fIclosure\fP);
void \fBGRepColormapColorPostcond\fP (GObjectId \fIcolormap\fP, GAddOrRemove \fIadd\fP,
	void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIcolormap\fP, ulong \fIindex\fP),
	const void* \fIclosure\fP);
void \fBGDestroyColormapPostcond\fP (GObjectId \fIcolormap\fP, GAddOrRemove \fIadd\fP,
	void (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIcolormap\fP),
	const void* \fIclosure\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP
.nf
   void modifyPrecond (GBool (*\fIfunction\fP)(void* \fIclosure\fP, const GColormap* \fIcolormap\fP,
        ulong& \fImask\fP, GColormapValues* \fInewValues\fP),
        const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;
   void modifyPostcond (void (*\fIfunction\fP)(void* \fIclosure\fP, const GColormap* \fIcolormap\fP,
        ulong \fImask\fP), const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;   
   void addColorPrecond (GBool (*\fIfunction\fP)(void* \fIclosure\fP, GColormap* \fIcolormap\fP,
        const GShColor* \fIsh_color\fP), const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;
   void addColorPostcond (void (*\fIfunction\fP)(void* \fIclosure\fP, GColormap* \fIcolormap\fP,
        ulong \fIindex\fP), const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;
   void remColorPrecond (GBool (*\fIfunction\fP)(void* \fIclosure\fP, GColormap* \fIcolormap\fP,
        ulong \fIindex\fP), const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;
   void remColorPostcond (void (*\fIfunction\fP)(void* \fIclosure\fP, GColormap* \fIcolormap\fP,
        ulong \fIindex\fP), const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;
   void replaceColorPrecond (GBool (*\fIfunction\fP)(void* \fIclosure\fP, GColormap* \fIcolormap\fP,
        const GShColor* \fIsh_color\fP), const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;
   void replaceColorPostcond (void (*\fIfunction\fP)(void* \fIclosure\fP, GColormap* \fIcolormap\fP,
        ulong \fIindex\fP), const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;
   void destroyPostcond (void (*\fIfunction\fP)(void* \fIclosure\fP, const GColormap* \fIcolormap\fP),
        const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;
.fi
.RE
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
The \fIColormap\fP object is a non-shared object interface for the \fIShColormap\fP object,
see the \fIShColormap(3Go)\fP and \fISharedObject(3Go)\fP to know the shared object
usage.
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBBool(3Go)\fP,  \fBGoInterf(3Go)\fP,
\fBSharedObject(3Go)\fP, \fBShColormap(3Go)\fP, \fBShColor(3Go)\fP,
\fBShPattern(3Go)\fP.
.nrPN \n%
