.\" $Id: CoordSys.n,v 1.1.1.1 1992/03/18 09:45:52 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH CoordSys 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBCoordSys\fP \(em the coordinate system object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/CoordSys.h.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBCoordSys\fP does not inherit anything from another class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBCoordSys\fP class implements a coordinate system which is defined
by an origin point \fBO\fP, an X axis vector \fBI\fP and Y axis vector \fBJ\fP.
\fBI\fP and \fBJ\fP may have any size or orientation. A \fBCoordSys\fP
instance may also be seen as a position (\fIO\fP) and a matrix
.EQ
size 6
left (
matrix {
ccol {I sub x above I sub y}
ccol {J sub x above J sub y}
}
right )
" ."
.EN
.sp 1
\fBGCoordSys\fP is the C++ type for the \fICoordSys\fP object class.
.sp 1
.nf
.ta .15i .25i 1.50i
struct GCoordSys {
		GPoint O;
		GVector I, J;

		GCoordSys();
		GCoordSys(const GPoint& \fIo\fP, const GVector& \fIi\fP, const GVector& \fIj\fP);
		GCoordSys(const GCoordSys& \fIcs\fP);
		GCoordSys(const GPoint& \fIp1\fP, const GPoint& \fIp2\fP);

		GVector from(const GVector& \fIvector\fP) const;
		GVector to(const GVector& \fIvector\fP) const;
		GBox from(const GBox& \fIbox\fP) const;
		GBox to(const GBox& \fIbox\fP) const;
		GPoint from(const GPoint& \fIpoint\fP) const;
		GPoint to(const GPoint& \fIpoint\fP) const;
		GRegion from(const GRegion& \fIregion\fP) const;
		GRegion to(const GRegion& \fIregion\fP) const;
		GCoordSys from(const GCoordSys& \fIcs\fP) const;
		GCoordSys to(const GCoordSys& \fIcs\fP) const;

		GBool isOrthogonal() const;
		GNumber deter() const;
		void rotate(const GPoint& \fIcenter\fP, GNumber \fIangle\fP);

		friend GBool operator == (const GCoordSys& \fIcs1\fP, const GCoordSys& \fIcs2\fP);
		friend GBool operator != (const GCoordSys& \fIcs1\fP, const GCoordSys& \fIcs2\fP);
		friend GCoordSys operator * (const GCoordSys& \fIcs1\fP, const GCoordSys& \fIcs2\fP);
		GCoordSys invert() const;
		GCoordSys operator ~ ();
};
extern GCoordSys gUnitCoordSys;
.fi
.sp 1
.SH
\fBPUBLIC VARIABLES\fP
.IP
GPoint \fBO\fP;
.RS .8i
.IP \fIDescription\fP .5i
Specifies the origin of the coordinate system.
.RE
.sp 1
.IP
GVector \fBI\fP;
.RS .9i
.IP \fIDescription\fP .5i
Specifies the X axis vector.
.RE
.sp 1
.IP
GVector \fBJ\fP;
.RS .8i
.IP \fIDescription\fP .5i
Specifies the Y axis vector.
.RE
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
\fBGCoordSys\fP ();
.br
\fBGCoordSys\fP (const GPoint& \fIo\fP, const GVector& \fIi\fP, const GVector& \fIj\fP);
.br
\fBGCoordSys\fP (const GCoordSys& \fIcs\fP);
.br
\fBGCoordSys\fP (const GPoint& \fIp1\fP, const GPoint& \fIp2\fP);
.RS .8i
.IP \fIDescription\fP .5i
These functions create an instance of the \fICoordSys\fP class.
.IP "\fIo, i, j\fP" .5i
The origin and two vectors of the new coordinate system.
.IP \fIcs\fP .5i
The new coordinate system is equal to \fIcs\fP.
.IP "\fIp1, p2\fP" .5i
Specify two points to buil the new coordinate system as follow: the origin
is the upper left point, the I(resp. J) vector is horizontal (resp. vertical)
and "I + J" is equal to "p2 - p1".
.RE
.sp 1
.IP
GVector \fBfrom\fP (const GVector& \fIvector\fP) const;
.br
GVector \fBto\fP (const GVector& \fIvector\fP) const;
.br
GBox \fBfrom\fP (const GBox& \fIbox\fP) const;
.br
GBox \fBto\fP (const GBox& \fIbox\fP) const;
.br
GPoint \fBfrom\fP (const GPoint& \fIpoint\fP) const;
.br
GPoint \fBto\fP (const GPoint& \fIpoint\fP) const;
.br
GRegion \fBfrom\fP (const GRegion& \fIregion\fP) const;
.br
GRegion \fBto\fP (const GRegion& \fIregion\fP) const;
.br
GCoordSys \fBfrom\fP (const GCoordSys& \fIcs\fP) const;
.br
GCoordSys \fBto\fP (const GCoordSys& \fIcs\fP) const;
.RS .8i
.IP \fIDescription\fP .5i
Often you have an object \fIrelobj\fP (Vector, Point, ...) which coordinates
are expressed relative to some coordinate system \fIcs\fP. If you need the
absolute coordinates of \fIrelobj\fP, you get them with the method:
	\fIabsobj = cs.to(relobj)\fP
.br
\fIto\fP means \fI\fBto\fP absolute coordinates\fP.

At the opposite, if you have and object \fIabsobj\fP which coordinates are
absolute, and you need its coordinates relative to some coordinate
system \fIcs\fP, you get them with the method:
	\fIrelobj = cs.from(absobj)\fP
\fIfrom\fP means \fI\fBfrom\fP absolute\fP.

If you prefer mathematical notation:
.br
\fIcs.to(obj)\fP is the application of the \fIcs\fP operator to \fIobj\fP:
.br
	\fIcs.to(obj)\fP    <==>    \fIcs * obj\fP

\fIcs.from(obj)\fP is the invert operation:
.br
	\fIcs.from(obj)\fP    <==>    \fI~cs * obj\fP

(because: absobj = cs * relobj    ==>    ~cs * absobj = relobj).

Obviously everybody knows (?!) what means the application of a matrix operator
to a vector, matrix, ... . But a coordinate system is a matrix plus an origin.
What is the differance ? We will see now what means \fIcs.to(obj)\fP
(i.e. the multiplication by a \fIcs\fP operator) for each specific \fIobj\fP:

.IP \fIvector\fP .5i
A vector has no origin, therefore the origin of the coordinate system is not
used and the effect of the cs operator is the same than a matrix operator.
.br
	absVector = cs.matrix() * vector

.IP \fIpoint\fP .5i
A point is a position. Therefore it does care about the origin of the
coordinate system.
.br
The origin of the coordinate system is used as a displacement:
.br
	absPoint = cs.O + cs.matrix() * point

.IP \fIbox\fP .5i
A box is compound of four points (the four corners). We apply the point
transormation for these four points, and the result is the 
smallest box containing the resulting points.

.IP \fIregion\fP .5i
A region is compound of a list of boxes. We apply the box transformation for
all boxes, and the result is a region builded from all these resulting boxes.

.IP \fIcoordinate system\fP .5i
A coordinate system can be seen as an origin and two vectors. We apply the
point transformation to the origin, and the vector transformation to the two
vectors. The result is a coordinate system builded with the resulting origin
and the resulting vectors:
.br
	absCS.O = cs.O + cs.matrix() * relCS.O
.br
	absCS.I = cs.matrix() * relCS.I
.br
	abscs.J = cs.matrix() * relCS.J
.RE
.sp 1
.IP 
friend GBool \fBoperator ==\fP (const GCoordSys& \fIcs1\fP, const GCoordSys& \fIcs2\fP);
.br
friend GBool \fBoperator !=\fP (const GCoordSys& \fIcs1\fP, const GCoordSys& \fIcs2\fP);
.br
.RS .8i
.IP \fIDescription\fP .5i
Two coordinate systems are equal if their origin, I vector and J vector are
equals.
.RE
.sp 1
.IP
friend GCoordSys \fBoperator *\fP (const GCoordSys& \fIcs1\fP, const GCoordSys& \fIcs2\fP);
.RS .8i 
.IP \fIDescription\fP .5i
This method is equivalent to \fIcs1.to(cs2)\fP.
.RE
.sp 1
.IP
GBool \fBisOrthogonal\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns GTRUE if one of the two vectors I and J is horizontal and
the other vertical.
.RE
.sp 1
.IP
GNumber \fBdeter\fP() const;
.RS .8i
.IP \fI Description\fP .5i
This function returns the determinant of the matrix of the coordinate system.
.RE
.sp 1
.IP
void \fBrotate\fP (const GPoint& \fIcenter\fP, GNumber \fIangle\fP);
.RS .8i
.IP \fIDescription\fP .5i
This function rotates the coordinate system around \fIcenter\fP.
.IP \fIcenter\fP .5i
.br
Specify the rotation center. This center has its coordinates relative to this
coordinate system. If you need to rotate around an absolute point
\fIabsPoint\fP, you can do:
.br
	cs.rotate(cs.from(absPoint), angle);
.IP \fIangle\fP .5i
.br
Specify the rotation angle expressed in radians.
.RE
.sp 1
.IP
GCoordSys \fBinvert\fP () const;
.br
GCoordSys \fBoperator ~\fP ();
.RS .8i
.IP \fIDescription\fP .5i
These two methods return the invert coordinate system of this coordinate
system. The signification of an inverted coordinate system is defined by
this rule:
.br
	absCS = opCS * relCS    <==>  ~opCS * absCS = relCS
.RE
.sp 1
.SH
\fBC BINDING\fP
.SS
\fBHeader File\fP
.IP
#include <Go/Tools/cCoordSys.h>
.SS
\fBType Definitions\fP
.IP
.nf
.ta .15i .25i 1.0i
typedef struct _GCoordSys
{
	GPoint O;
	GVector I;
	GVector J;
} GCoordSys;
.fi
.sp 1
\fISee\fP public variables O, I and J of the C++ object.
.SS
\fBC Functions\fP
.IP
GBool \fBGIsOrthogonalCoordSys\fP (const GCoordSys* \fIcs\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP GBool isOrthogonal() const.
.RE
.sp 1
.IP
void \fBGUnitCoordSys\fP (GCoordSys* \fIcs\fP);
.RS .8i
.IP \fIDescription\fP .5i
This function intializes \fIcs\fP with the global variable \fIunitCoordSys\fP.
.RE
.sp 1
.IP
void \fBGInvertCoordSys\fP (GCoordSys* \fIcs\fP);
.br
void \fBGRotateCoordSys\fP (GCoordSys* \fIcs\fP, GPoint \fIcenter\fP, GNumber \fIangle\fP);
.br
GNumber \fBGCoordSysDeter\fP (GCoordSys* \fIcs\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP
.br
   GCoordSys invert() const;
.br
   void rotate (const GPoint& \fIcenter\fP, GNumber \fIangle\fP);
.br
   GNumber deter () const;
.RE
.sp 1
.IP
GCoordSys \fBGCoordSysProduct\fP (GCoordSys* \fIcs1\fP, GCoordSys* \fIcs2\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP
   friend GCoordSys operator * (const GCoordSys& \fIcs1\fP, const GCoordSys& \fIcs2\fP);
.RE
.sp 1
.IP
.nf
GVector \fBGVectorFromCS\fP (GCoordSys* \fIcs\fP, GVector \fIvector\fP);
GVector \fBGVectorToCS\fP (GCoordSys* \fIcs\fP, GVector \fIvector\fP);
GBox \fBGBoxFromCS\fP (GCoordSys* \fIcs\fP, GBox* \fIbox\fP);
GBox \fBGBoxToCS\fP (GCoordSys* \fIcs\fP, GBox* \fIbox\fP);
GPoint \fBGPointFromCS\fP (GCoordSys* \fIcs\fP, GPoint \fIpoint\fP);
GPoint \fBGPointToCS\fP (GCoordSys* \fIcs\fP, GPoint \fIpoint\fP);
GObjectId \fBGRegionFromCS\fP (GCoordSys* \fIcs\fP, GObjectId \fIregion\fP);
GObjectId \fBGRegionToCS\fP (GCoordSys* \fIcs\fP, GObjectId \fIregion\fP);
GCoordSys \fBGCoordSysFromCS\fP (GCoordSys* \fIcs\fP, GCoordSys* \fIcoordsys\fP);
GCoordSys \fBGCoordSysToAbsCS\fP (GCoordSys* \fIcs\fP, GCoordSys* \fIcoordsys\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP
.nf
   GVector from(const GVector& \fIvector\fP) const;
   GVector to(const GVector& \fIvector\fP) const;
   GBox \fBfrom\fP (const GBox& \fIbox\fP) const;
   GBox \fBto\fP (const GBox& \fIbox\fP) const;
   GPoint from(const GPoint& \fIpoint\fP) const;
   GPoint to(const GPoint& \fIpoint\fP) const;
   GRegion from(const GRegion& \fIregion\fP) const;
   GRegion to(const GRegion& \fIregion\fP) const;
   GCoordSys from(const GCoordSys& \fIcoordsys\fP) const;
   GCoordSys to(const GCoordSys& \fIcoordsys\fP) const;
.fi
.RE
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBBox(3Go)\fP, \fBPoint(3Go)\fP, \fBVector(3Go)\fP, \fBNumber(3Go)\fP and \fBRegion(3Go)\fP.
.nrPN \n%
