.\" $Id: Dash.n,v 1.1.1.1 1992/03/18 09:45:57 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH Dash 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBDash\fP \(em the dash object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/Dash.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBDash\fP does not inherit behavior from any class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBDash\fP object gives a non-shared object interface to the \fBShDash\fP
object. As a \fIShDash\fP, a \fIDash\fP is defined by a set of three
values (see \fIGDashValues\fP).
.sp 1
The \fIdash_list\fP value is a list of dash element (dash or gap),
each element is a number representing the size in millimeters of the dash/gap.
The initial (0) and the alternating elements (2, 4, ...) are the even dashes/gaps,
the others are the odd dashes/gaps. The \fIdash_number\fP value is the number of elements
in the dash list.
The \fIdash_offset\fP value specifies the first element used in the drawing.
.sp 1
A \fBDash\fP object is normally used when drawing lines and the line style is
\fILineOnOffDash\fP or \fILineDoubleDash\fP. When the line style is \fILineOnOffDash\fP,
the odd dashes are used as gaps. When the line style is \fILineDoubleDash\fP, both
are used.
.sp 1
\fBGDash\fP is the C++ type for the \fIDash\fP object class.
.sp 1
.nf
.ta .15i .25i 1.50i
class GDash {
	public:
		GDash ();
		GDash (const GDash* \fIdash\fP);
		GDash (const GShDash* \fIsh_dash\fP);
		GDash (ulong \fImask\fP, const GDashValues* \fIvalues\fP, const char* \fIname\fP = NULL);
		GDash (const char* \fIname\fP);
		~GDash ();

		// Getting values
		const GShDash* shDash() const;
		const GDashValues* values() const;

		const char* name() const;
		bool isNamed() const;

		ushort dash_offset() const;
		ushort dash_number() const;
		const Number* dash_list () const;

		// Modifying methods
		void modify (ulong \fImask\fP, const GDashValues* \fIvalues\fP);
		void modify (const GShDash* \fIsh_dash\fP);
		void modify (const char* \fIname\fP);

		// Pre and Post Conditions
		void modifyPrecond (GBool (*\fIproc\fP)(void* \fIclosure\fP, GDash* \fIdash\fP,
			ulong& \fImask\fP, GDashValues* \fInew_values\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void modifyPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GDash*\fIdash\fP, ulong \fImask\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void destroyPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GDash* \fIdash\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
};
.fi
.sp 1
.SH
\fBGDashValues STRUCTURE\fP
.IP
\fISee ShDash(3Go)\fP
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
.nf
\fBGDash\fP ();
\fBGDash\fP (const GDash* \fIdash\fP);
\fBGDash\fP (const GShDash* \fIsh_dash\fP);
\fBGDash\fP (ulong \fImask\fP, const GDashValues* \fIvalues\fP, const char* \fIname\fP = NULL);
\fBGDash\fP (const char* \fIname\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to create a new \fIDash\fP instance. The new \fIDash\fP
points to a \fIShDash\fP which may be shared between several other \fIDash\fP
instances. When the \fIname\fP field is specified, a named \fIShDash\fP
is explicitly referred. Specifying the values and the
name implies the corresponding named \fIShDash\fP modification.
.IP \fIdash\fP .5i
.br
Specifies the \fIDash\fP used to initialize the new instance.
.IP \fIsh_dash\fP .5i
Specifies the \fIShDash\fP which will be pointed by the \fIDash\fP. The
\fIShDash\fP reference count is incremented.
.IP \fImask\fP .5i
.br
Specifies the value bitmask (see \fIShDash(3Go)\fP).
.IP \fIvalues\fP .5i
.br
Specifies a \fIDashValues\fP structure pointer. Valid fields are defined by
the \fImask\fP.
.IP \fIname\fP .5i
.br
Identifies the named \fIShDash\fP which is called \fIname\fP. If such
\fIShDash\fP does not exit it is created. If values (rgb, gray, halftone) are
defined, the named \fIShDash\fP will be modified.
.RE
.sp 1
.IP
\fB~GDash\fP ();
.RS .8i
.IP \fIDescription\fP .5i
This method is called when a \fIDash\fP instance is deleted. The corresponding
\fIShDash\fP reference count is decremented. The \fIdestroyPostcond\fP callback,
if exits, is called \fIjust before\fP the deletion.
.RE
.sp 2
.IP
const GShDash* \fBshDash\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the \fIShDash\fP associated to the \fIDash\fP object.
.RE
.sp 1
.IP
const GDashValues* \fBvalues\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the pointer to the \fIDash\fP values.
.RE
.sp 1
.IP
const char* \fBname\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the name of the associated \fIShDash\fP or NULL.
.RE
.sp 1
.IP
GBool \fBisNamed\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This method return GTRUE, if the associated \fIShDash\fP is
named, else it returns GFALSE.
.RE
.sp 1
.IP
.nf
ushort \fBdash_offset\fP() const;
ushort \fBdash_number\fP() const;
const Number* \fBdash_list\fP () const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods return the /fIdash_offset\fP, \fIdash_number\fP, \fIdash_list\fP
fields of the \fIDash\fP values.
.RE
.sp 1
.IP
void \fBmodify\fP (ulong \fImask\fP, const GDashValues* \fIvalues\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to modify the \fIDash\fP values. It calls the
\fImodify()\fP function of the associated \fIShDash\fP. After this
call, the \fIShDash\fP pointer may be different. The pre/post
conditions will be called if they exist.
.IP \fImask\fP .5i
.br
Specifies the value bitmask of the valid fields in the \fIGDashValues\fP
structure.
.IP \fIvalues\fP .5i
.br
Specifies the new values which will be assigned to the \fIDash\fP.
.RE
.sp 1
.IP
void \fBmodify\fP (const GShDash* \fIsh_dash\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to modify the \fIDash\fP object by changing
the \fIShDash\fP pointed by the \fIDash\fP. The pre/post conditions
are called if they exist.
.IP \fIsh_dash\fP .5i
.br
Specifies the \fIShDash\fP which has to replace the previous
\fIShDash\fP contained in the \fIDash\fP.
.RE
.sp 1
.IP
void \fBmodify\fP (const char* \fIname\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to (re)name the associated \fIShDash\fP. If \fIname\fP
is NULL, a unnamed \fIShDash\fP will be created.  The pre/post conditions
are invoked; the value mask is the complete named \fIShDash\fP mask.
In preconditions functions, modifying the proposed values will imply the
named \fIShDash\fP modification.
.IP \fIname\fP .5i
.br
Specifies the new name of the associated \fIShDash\fP.
.RE
.sp 1
.IP
.nf
void \fBmodifyPrecond\fP (GBool (*\fIproc\fP)(void* \fIclosure\fP, GDash* \fIdash\fP,
	ulong& \fImask\fP, GDashValues* \fInew_values\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBmodifyPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GDash* \fIdash\fP, ulong \fImask\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These method allow to add or remove pre or post conditions on \fIDash\fP modifying.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called before (pre-condition) or after (post-condition)
the modification. Its parameters are the \fIclosure\fP, the object \fIDash\fP
itself and the modification \fImask\fP. For the pre-condition, if \fIproc\fP returns
GFALSE, the modification is nor proceeded. In addition, the precondition procedure
may modify the action (\fInew_values\fP).
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the condition
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp1
.IP
.nf
void \fBdestroyPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GDash* \fIdash\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP
This method allows to add or remove a callback procedure which will be called
when the object \fIDash\fP will be destroyed.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the object will be destroyed.
The callback procedure is called \fIjust before\fP the destruction of the object. Its parameters are
the \fIclosure\fP and the object \fIDash\fP itself.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the
destruction callback list. If \fIadd\fP is GREMOVE, the callback procedure
\fIproc\fP will be removed from  the callback list.
.RE
.sp 1
.SH
\fBC BINDING\fP
.SS
\fBHeader File\fP
.IP
#include <Go/Tools/cDash.h>
.SS
\fBType Definitions\fP
.IP
The \fIShDash\fP C interface defines the \fIDashValues\fP structure. This
structure is used by the \fIDash\fP C interface (see \fIShDash(3Go)\fP).
.SS
\fBC Functions\fP
.IP
GObjectId \fBGCreateDash\fP (ulong \fImask\fP, const GDashValues* \fIvalues\fP, const char* \fIname\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GDash (ulong \fImask\fP, const GDashValues* \fIvalues\fP, const char* \fIname\fP).
.RE
.sp 1
.IP
void \fBGDestroyDash\fP (GObjectId \fIdash\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP ~GDash ().
.RE
.sp 1
.IP
.nf
void \fBGModifyDash\fP (GObjectId \fIdash\fP, ulong \fImask\fP, const GDashValues* \fIvalues\fP);
void \fBGModifyDashFromName\fP (GObjectId \fIdash\fP, const char* \fIname\fP);
void \fBGModifyDashFromShDash\fP (GObjectId \fIdash\fP, const GObjectId \fIsh_dash\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP:
.nf
  void modify (ulong \fImask\fP, const GDashValues* \fIvalues\fP);
  void modify (const char* \fIname\fP);
  void modify (const GShDash* \fIsh_dash\fP);
.fi
.RE
.sp 1
.IP
.nf
const GDashValues* \fBGGetDashValues\fP (const GObjectId \fIdash\fP);
const GObjectId \fBGGetDashShDash\fP (const GObjectId \fIdash\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP:
.nf
   const GDashValues* values ();
   const GShDash* shDash ().
.fi
.RE
.sp 1
.IP
.nf
void \fBGModifyDashPrecond\fP (GObjectId \fIdash\fP, GAddOrRemove \fIadd\fP,
	GBool (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIdash\fP,
		ulong* \fImask\fP, GDashValues* \fIvalues\fP),
	const void* \fIclosure\fP);
void \fBGModifyDashPostcond\fP (GObjectId \fIdash\fP, GAddOrRemove \fIadd\fP,
	void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIdash\fP, ulong \fImask\fP),
	const void* \fIclosure\fP);
void \fBGDestroyDashPostcond\fP (GObjectId \fIdash\fP, GAddOrRemove \fIadd\fP,
	void (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIdash\fP),
	const void* \fIclosure\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP
.nf
   void modifyPrecond (GBool (*\fIfunction\fP)(void* \fIclosure\fP, const GDash* \fIdash\fP,
	ulong& \fImask\fP, GDashValues* \fInewValues\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;
   void modifyPostcond (void (*\fIfunction\fP)(void* \fIclosure\fP, const GDash* \fIdash\fP, ulong \fImask\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;   
   void destroyPostcond (void (*\fIfunction\fP)(void* \fIclosure\fP, const GDash* \fIdash\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;
.fi
.RE
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
The \fIDash\fP object is a non-shared object interface for the \fIShDash\fP object,
see the \fIShDash(3Go)\fP and \fISharedObject(3Go)\fP to know the shared object
usage.
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBBool(3Go)\fP, \fBNumber(3Go)\fP,
\fBSharedObject(3Go)\fP, \fBShDash(3Go)\fP, \fBShPen(3Go)\fP.
.nrPN \n%
