.\" $Id: FileMedium.n,v 1.3 1992/12/28 12:42:51 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH FileMedium 3Go "December 1992" "Version 1.2" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBFileMedium\fP \(em the basic FileMedium object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/FileMedium.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGFileMedium\fP inherits behavior from the  GMedium class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBGFileMedium class provides an interface to \fIread/write\fP onto a file. Only specific behaviors of the \fBGFileMedium\fP class are describe here. All the methods are implemented in this derived class: they are available if the current \fIfile\fP is opened correctly.
.IP
.sp 1
.nf
.ta .15i .25i 1.0i

	class GFileMedium : public GMedium {

	public:
		GFileMedium();
		GFileMedium(FILE* file);
		GFileMedium(const char* filename,
				const char* type = "r");
		FILE* file() ;

		~GFileMedium();

		int open(const char* filename,
				const char* type);
		void flush();
		void close();
	};
.fi
.RE
.SH
\fBPUBLIC METHODS\fP
.sp 1
.IP
\fBGFileMedium\fP();
.RS .8i
.IP \fIDescription:\fP .5i
The method initializes the FileMedium with NO file. So you have to call \fIopen\fP to use it; otherwise any read/write requests are removed.
.RE
.sp 1
.IP
\fBGFileMedium\fP(FILE* \fIfile\fP);
.RS .8i
.IP \fIDescription:\fP .5i
The method initializes the FileMedium with the \fIfile\fP. The \fIfile\fP may be a \fIpipe\fP.
.br
The \fIdelete\fP will flush \fIfile\fP.
.IP \fIfile\fP .5i
.br
Specifies the \fIfile\fP to use.
.RE
.sp 1
.IP
\fBGFileMedium\fP(const char* \fIfilename\fP, const char* \fIopen_type\fP);
.RS .8i
.IP \fIDescription:\fP .5i
The method opens \fIfilename\fP with \fIopen_type\fP (cf fopen (3S)). The \fIopen_type\fP must available for next calls of the \fIread\fP, \fIwrite\fP or \fIseek\fP methods. It sets the current \fIfile\fP to the result of fopen(3S).
.br
 The \fIdelete\fP will flush and close \fIfile\fP.
.IP \fIfilename\fP .5i
.br
Specifies the fullpath of the wanted file.
.IP \fIopen_type\fP .5i
.br
Specifies the string to be passes to the fopen(3S) function.
.RE
.sp 1
.IP
FILE* \fBfile\fP();
.RS .8i
.IP \fIDescription:\fP .5i
The method returns the \fIfile\fP used by the medium; note that it may be NULL.
.RE
.sp 1
.IP
int \fBopen\fP(const char* \fIfilename\fB, const char* \fIopen_type\fP);
.RS .8i
.IP \fIDescription:\fP .5i
If the current \fIfile\fP is available: it calls the \fIflush\fP method; if the current \fIfile\fP is opened by the class, it calls the \fIclose\fP method.
.br
The method opens \fIfilename\fP with \fIopen_type\fP (cf fopen (3S)). The \fIopen_type\fP must available for next calls of the \fIread\fP, \fIwrite\fP or \fIseek\fP methods. It sets the current \fIfile\fP to the result of fopen(3S). The returned value is non 0 on error and 0 if fopen(3S) returns a valid \fIfile\fP.
.RE
.sp 1
.IP
void \fBflush\fP();
.RS .8i
.IP \fIDescription:\fP .5i
The method calls the fflush(3S) function with the current \fIfile\fP.
.RE
.sp 1
.IP
void \fBclose\fP();
.RS .8i
.IP \fIDescription:\fP .5i
The method calls the fclose(3S) function with the current \fIfile\fP. Note that it is an error to call this method if the \fIfile\fP given to the \fIFileMedium\fP is a \fIpipe\fP (cf \fIpopen\fP(3S) and \fIpclose\fP(3S)).
.IP
\fB~GFileMedium()\fP.
.RS .8i
.IP \fIDescription:\fP .5i
The method calls the \fIflush\fP method. If the used \fIfile\fP  is opened by the class, it calls also the \fIclose\fP method.
.RE
.SH
\fBC BINDING\fP
.IP
.sp 1
.nf
.ta .15i .25i 1.0i
	GObjectID GCreateFileMediumWithOpenedFILE(FILE*);
	GObjectId GCreateFileMedium(const char* filename, const char* open_type);
	int      GFileMediumOpen(GObjectId filemedium, const char* filename,
			const char* open_type);
	void     GFileMediumClose(GObjectId filemedium);
	FILE*    GFileMediumFILE(GObjectId filemedium);

	// for delete see the GDeleteMedium() of the GMedium class.
.fi
.sp 1
.IP \fIDescription\fP .5i
See GFileMedium::\fIname\fP method.
.SH
\fBUSAGE INFORMATION\fP
.IP
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBMedium\fP (3Go), \fBfread\fP, \fBfwrite\fP, \fBfopen\fP etc.. (3S).
.nrPN \n%


