.\" $Id: GeomUtil.n,v 1.1.1.1 1992/03/18 09:46:27 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH GeomUtil 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBGeomUtil\fP \(em convenient functions (curve approximation, bounding boxes...)
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/GeomUtil.h>\fP
.SH 
\fBDESCRIPTION\fP
.IP
Some useful functions dealing with :
.RS 10
.IP \(bu 3
rectangles and polylines (bounding box)
.IP \(bu 3
ellipse and elliptical arcs (approximation with a polyline, bounding box).
.IP \(bu 3
bezier and cubic curves (approximation with a polyline).
.br
.RE
.IP
An ellipse has an implicit coordinate system :
.RS 10
.IP \(bu 3
origin = ellipse center
.IP \(bu 3
axes = ellipse symetry axes.
.RE
.IP
In their implicit coordinate system, ellipses are defined by two radii radX,
radY : P(x, y) in ellipse(radX, radY) <==>  (x/radX)^2 + (y/radY)^2 = 1
.sp 1
.br
.nf
.ta .15i .25i 1.0i
	/*
	 * \fBpolylines, polygons and rectangles\fP
	 */
	void GPolypointGetOutPoints (int, const GPoint*, GPoint&, GPoint&);
	void GPolypointGetAbsOutPoints (const GCoordSys&, int, const GPoint*,
				GPoint&, GPoint&);
	GBool GPointInPolygon (int, const GPoint*, const GPoint&, GBool);
	GBool GPointOnPolyline (const GCoordSys&, int, const GPoint*,
				const GPoint&, GNumber, GBool);
	GBox GPolypointJoinMiterBox (const GCoordSys&, int, const GPoint*,
				GNumber, GBool);
	void GRectangleClip (const GPoint&, const GPoint&, GBool, GNumber, GRegion&);

	/*
	 * \fBangles, arcs and ellipses\fP
	 */
	GNumber GModulo (GNumber, GNumber = 2*PI);
	void GOrientedAngles(GNumber, GNumber, GNumber*, GNumber*);
	GNumber GEllipseGetAngle(GNumber, GNumber, GPoint&);
	int GEllipseNbLines(const GCoordSys&, GNumber, GNumber,
				GNumber&, GNumber&, GQuality);
	int GEllipseArcLimits(const GCoordSys&, GNumber, GNumber, GNumber,
				GNumber, GPoint&, GPoint&, GPoint&, GPoint&, GQuality);
	void GEllipseComputePoints (const GCoordSys&, GNumber, GNumber, 
				GNumber, GNumber, GQuality, int&, GPoint*);
	GPoint GEllipseGetTangentPoint (GNumber, GNumber, const GVector&);
	void GEllipseGetOutPoints (GNumber, GNumber, GNumber, GNumber, 
				GPoint&, GPoint&);
	GBox GEllipseGetBox (const GCoordSys&, GNumber, GNumber, GNumber, GNumber);

	/*
	 * \fBbezier and cubic curves\fP
	 */
	void GBezierComputePoints (int, const GPoint*, GQuality, int&, GPoint*);
	void GCubicCurveComputePoints (int, const GPoint*, const GNumber[4][4], 
				int, GQuality, int&, GPoint*);

.fi
.SH
\fBPUBLIC METHODS\fP
.IP
void \fBGPolypointGetOutPoints\fP (int \fInb\fP, const GPoint* \fIpts\fP, GPoint& \fIpmin\fP, GPoint& \fIpmax\fP);
.RS .8i
.IP \fIDescription\fP .3i
It returns in \fIpmin\fP/\fIpmax\fP the minimum/maximum x and y values of points
in pts.
.br
Warning : \fIpts\fP and \fInb\fP MUST be non null.
.IP \fInb\fP .3i
specifies the number of elements (minimum 1) in \fIpts\fP
.IP \fIpts\fP .3i
array of \fInb\fP points (assumed to be non empty).
.IP \fIpmin\fP .3i
contains the returned values (min(x), min(y))
.IP \fIpmax\fP .3i
contains the returned values (max(x), max(y))
.RE
.sp1
.IP
.nf
void \fBGPolypointGetAbsOutPoints\fP (const GCoordSys& \fIcs\fP, int \fInb\fP, const GPoint* \fIpts\fP,
				GPoint& \fIpmin\fP, GPoint& \fIpmax\fP);
.fi
.RS .8i
.IP \fIDescription\fP .3i
This function has the same use as \fBGPolypointGetOutPoints\fP except the fact
that the points in the array are expressed in another coordinate system,
\fIcs\fP. It returns in \fIpmin\fP (resp \fIpmax\fP) the minimal (resp maximal)
absolute x and absolute y values of all points in pts.
.br
Warning : \fIpts\fP and \fInb\fP MUST be non null.
.IP \fIcs\fP .3i
specifies the coordinate system in which the array of points is expressed.
.IP \fInb\fP .3i
specifies the number of elements (minimum 1) in the array \fIpts\fP
.IP \fIpts\fP .3i
array of \fInb\fP points expressed in the coordinate system \fIcs\fP.
.IP \fIpmin\fP .3i
stores the minimal absolute x and absolute y values.
.IP \fIpmax\fP .3i
stores the maximal absolute x and absolute y values.
.RE
.sp1
.IP
GBool \fBGPointInPolygon\fP (int \fInb\fP, const GPoint* \fIpts\fP, const GPoint& \fIpoint\fP, GBool \fIfillWinding\fP);
.RS .8i
.IP \fIDescription\fP .3i
Returns GTRUE if \fIpoint\fP is within the area surrounded by the polygon 
\fIpts\fP[], according to the filling rule specified by \fIfillWinding\fP, else
returns GFALSE.
.br
Warning : \fIpts\fP and \fInb\fP MUST be non null.
.IP \fInb\fP .3i
specifies the number of elements (minimum 1) in the array \fIpts\fP
.IP \fIpts\fP .3i
array of \fInb\fP points
.IP \fIpoint\fP .3i
specifies the point being checked.
.IP \fIfillWinding\fP .3i
specifies the filling rule : winding rule if GTRUE, odd-even rule if GFALSE.
.RE
.sp1
.IP
.nf
GBool \fBGPointOnPolyline\fP (const GCoordSys& \fIcs\fP, int \fInb\fP, const GPoint* \fIpts\fP,
				const GPoint& \fIabsPoint\fP, GNumber \fImaxSquare\fP, GBool \fIclosed\fP);
.fi
.RS .8i
.IP \fIDescription\fP .3i
This function returns GTRUE if the square distance from \fIabsPoint\fP to one
segment \fIpts\fP[i] \fIpts\fP[i+1] is smaller than \fImaxSquare\fP, else
returns GFALSE. Distances are of course evaluated in the absolute coordinate
system.
.br
Warning : \fIpts\fP and \fInb\fP MUST be non null.
.IP \fIcs\fP .3i
specifies the coordinate system in which the array of points is expressed.
.IP \fInb\fP .3i
specifies the number of elements (minimum 1) in the array \fIpts\fP
.IP \fIpts\fP .3i
array of \fInb\fP points expressed in \fIcs\fP coordinate system.
.IP \fIabsPoint\fP .3i
specifies the point (expressed in the absolute coordinate system) being checked.
.IP \fImaxSquare\fP .3i
specifies the square distance, thus must be positive.
.IP \fIclosed\fP .3i
if GTRUE, we take in account the segment \fIpts\fP[\fInb\fP-1] to \fIpts\fP[0],
i.e. \fIpts\fP[] is seen as a polygon, else we ignore it, i.e. \fIpts\fP[] is
seen as a polyline.
.RE
.sp1
.IP
.nf
GBox \fBGPolypointJoinMiterBox\fP (const GCoordSys& \fIcs\fP, int \fInb\fP, const GPoint* \fIpts\fP,
				GNumber \fIabsWidth\fP, GBool \fIclosed\fP);
.fi
.RS .8i
.IP \fIDescription\fP .3i
This function returns the smallest box containing the
poly(line/gon), including the drawing extensions caused by the following
attributes of a GPen : line width = \fIabsWidth\fP (assumed to be > 0) and join
style = GJOIN_MITER. All points are expressed in the coordinate system \fIcs\fP
and \fIabsWidth\fP is considered to be evaluated in the absolute coordinate
system.
.br
Warning : \fIpts\fP MUST contain at least 3 points.
.IP \fIcs\fP .3i
specifies the coordinate system in which the array of points is expressed.
.IP \fInb\fP .3i
specifies the number of elements in the array \fIpts\fP (minimum 3).
.IP \fIpts\fP .3i
array of \fInb\fP points expressed in the coordinate system \fIcs\fP.
.IP \fIabsWidth\fP .3i
specifies a line width, thus must be positive.
.IP \fIclosed\fP .3i
if GTRUE, we take in account the segment \fIpts\fP[\fInb\fP-1] to \fIpts\fP[0],
i.e. \fIpts\fP is seen as a polygon, else we ignore it, i.e. \fIpts\fP is seen
as a polyline.
.RE
.sp1
.IP
.nf
void \fBGRectangleClip\fP (const GPoint& \fIp1\fP, const GPoint& \fIp2\fP, GBool \fIfilled\fP,
				GNumber \fImaxDist\fP, GRegion& \fIregion\fP);
.fi
.RS .8i
.IP \fIDescription\fP .3i
Considering the rectangle R defined by \fIp1\fP and \fIp2\fP, this function
adds to \fIregion\fP a region containing all points P(x,y) such as :
point P(x,y) is close to R, i.e. distance(P, R) <= \fImaxDist\fP.
If \fIfilled\fP is true, the function considers that R is filled, else it
considers an empty rectangle (outline only).
.IP \fIp1\fP .3i
upper left corner of the rectangle
.IP \fIp2\fP .3i
lower right corner of the rectangle
.IP \fIfilled\fP .3i
specifies if the rectangle is filled or empty.
.IP \fImaxDist\fP .3i
specifies the distance "around" the rectangle to take in account.
.IP \fIregion\fP .3i
specifies the region to store the result.
.RE
.sp1
.IP
GNumber \fBGModulo\fP (GNumber \fIx\fP, GNumber \fIy\fP = 2*PI);
.RS .8i
.IP \fIDescription\fP .3i
Returns \fIx\fP modulo \fIy\fP, error if \fIy\fP is null.
.RE
.sp1
.IP
void \fBGOrientedAngles\fP(GNumber \fIampl\fP, GNumber \fIstart\fP, GNumber* \fImin\fP, GNumber* \fImax\fP);
.RS .8i
.IP \fIDescription\fP .3i
Considering an arc with an amplitude of \fIampl\fP and starting at angle
\fIstart\fP, this function returns returns the two angles \fImin\fP and
\fImax\fP such as the same arc starts at \fImin\fP and ends at \fImax\fP with \fImin\fP < \fImax\fP and 0 <= \fImin\fP < 2*PI.
.IP \fIampl\fP .3i
.IP \fIstart\fP .3i
two angle values (possibly negative) defining an arc.
.IP \fImin\fP .3i
.IP \fImax\fP .3i
angle values returned by the function and defining the same arc.
.RE
.sp1
.IP
GNumber \fBGEllipseGetAngle\fP(GNumber \fIradX\fP, GNumber \fIradY\fP, GPoint& \fIpt\fP);
.RS .8i
.IP \fIDescription\fP .3i
Let \fIE\fP be the ellipse defined by \fIradX\fP and \fIradY\fP (both positive).
Let \fIf\fP be the bijection from [ 0, 2*PI [ to \fIE\fP defined as
.br
\fIf(alpha)\fP = (\fIradX\fP * cos(\fIalpha\fP), \fIradY\fP * sin(\fIalpha\fP)).
.br
The current function computes and returns this angle \fIalpha\fP such as
\fIpt\fP, \fIf(alpha)\fP and (0, 0) the center of \fIE\fP are aligned.
.IP \fIradX\fP .3i
.IP \fIradY\fP .3i
specify the ellipse radii.
.IP \fIpt\fP .3i
see function description.
.RE
.sp1
.IP
.nf
int \fBGEllipseNbLines\fP(const GCoordSys& \fIcs\fP, GNumber \fIradX\fP, GNumber \fIradY\fP,
				GNumber& \fImin\fP, GNumber& \fImax\fP, GQuality \fIquality\fP);
.fi
.RS .8i
.IP \fIDescription\fP .3i
This function is similar to \fBGEllipseComputePoints\fP. It returns the
number of segments necessary for polyline approximation of the elliptical arc.
The precision of the approximation depends on \fIquality\fP (from GMIN_QUALITY to
GMAX_QUALITY).
.br
Warning : the returned value is 1 less than the number of points returned by
\fBGEllipseComputePoints\fP. Side effects : \fImin\fP and \fImax\fP are
modified to equivalent (modulo 2*PI) and more convenient values.
.IP \fIcs\fP .3i
Specifies the coordinate system in which the ellipse is expressed.
.IP \fIradX\fP .3i
.IP \fIradY\fP .3i
specify the ellipse radii (expressed in \fIcs\fP)
.IP \fImin\fP .3i
.IP \fImax\fP .3i
specify the ellipse starting and ending angles. These values are modified by
this function.
.IP \fIquality\fP .3i
defines the precision of the approximation (worst = GMIN_QUALITY, best =
GMAX_QUALITY)
.RE
.sp1
.IP
.nf
int \fBGEllipseArcLimits\fP(const GCoordSys& \fIcs\fP, GNumber \fIradX\fP, GNumber \fIradY\fP,
				GNumber \fImin\fP, GNumber \fImax\fP, GPoint& \fIbeginPt\fP, GPoint& \fIendPt\fP,
				GPoint& \fInearBeginPt\fP, GPoint& \fInearEndPt\fP, GQuality \fIquality\fP);
.fi
.RS .8i
.IP \fIDescription\fP .3i
This method returns four points on the elliptical arc defined by \fIradX\fP,
 \fIradY\fP, \fImin\fP and \fImax\fP ; \fIbeginPt\fP and \fIendPt\fP are the arc
extremities. \fInearBeginPt\fP and \fInearEndPt\fP are two points on the arc
close enough to the extremities so the segments
[ \fIbeginPt\fP, \fInearBeginPt\fP ] and [ \fIendPt\fP, \fInearEndPt\fP ]
can be considered tangent to the arc ; each segment is an approximation of the
arc. This is used to get the bounding box (or clip) of the arc.
.IP \fIcs\fP .3i
specifies the coordinate system in which the ellipse and the points are
 expressed
.IP \fIradX\fP .3i
.IP \fIradY\fP .3i
specify the ellipse radii (expressed in \fIcs\fP)
.IP \fImin\fP .3i
.IP \fImax\fP .3i
specify angles delimiting the arc (expressed in \fIcs\fP)
.IP \fIbeginPt\fP .3i
.IP \fIendPt\fP .3i
returned values storing the arc extremities (expressed in \fIcs\fP)
.IP \fInearBeginPt\fP .3i
.IP \fInearEndPt\fP .3i
returned values storing points close to the arc extremities (expressed
in \fIcs\fP)
.IP \fIquality\fP .3i
defines the precision of the approximation (worst = GMIN_QUALITY, best =
GMAX_QUALITY)
.RE
.sp1
.IP
void \fBGEllipseComputePoints\fP (const GCoordSys& \fIcs\fP, GNumber \fIradX\fP, GNumber \fIradY\fP, GNumber \fIangle1\fP, GNumber \fIangle2\fP, GQuality \fIquality\fP, int& \fInb\fP, GPoint* \fIpts\fP);
.RS .8i
.IP \fIDescription\fP .3i
Let us consider the elliptical arc defined by \fIcs\fP (giving its center and
its axes), \fIradX\fP and \fIradY\fP (its radii expressed in \fIcs\fP),
\fIangle1\fP and \fIangle2\fP (the arc starts at \fIangle1\fP and ends at
\fIangle2\fP). This function returns \fInb\fP and \fIpts\fP, a polyline
approximation of the elliptical arc.  The precision of the approximation depends
on \fIquality\fP (from GMIN_QUALITY to GMAX_QUALITY). The points \fIpts\fP are
expressed in the absolute coordinate system. 
.br
Warning : the array \fIpts\fP must be allocated before
the call and must contain at least MAX_ELLIPSE_POINTS Points.
.IP \fIcs\fP .3i
Specifies the coordinate system in which the ellipse is expressed.
.IP \fIradX\fP .3i
.IP \fIradY\fP .3i
specify the ellipse radii (expressed in \fIcs\fP)
.IP \fIangle1\fP .3i
.IP \fIangle2\fP .3i
specify the ellipse starting and ending angles
.IP \fIquality\fP .3i
defines the precision of the approximation (worst = GMIN_QUALITY, best =
GMAX_QUALITY)
.IP \fInb\fP .3i
returned value: number of points in the returned array \fIpts\fP
.IP \fIpts\fP .3i
array of \fInb\fP points returned (in the absolute coordinate system).
.RE
.sp1
.IP
GPoint \fBGEllipseGetTangentPoint\fP (GNumber \fIradX\fP, GNumber \fIradY\fP, const GVector& \fIv\fP);
.RS .8i
.IP \fIDescription\fP .3i
Considering the ellipse defined by the radii \fIradX\fP and \fIradY\fP, this
function returns \fItangentPt\fP, point of the ellipse, such as the tangent in
\fItangentPt\fP is parallel to vector \fIv\fP. We consider the lower half of the
ellipse (y >= 0). There is another point with the same property :
-\fItangentPt\fP.
.IP \fIradX\fP .3i
.IP \fIradY\fP .3i
the ellipse radii
.IP \fIv\fP .3i
gives the direction of the tangent segment to the ellipse at the point returned.
.RE
.sp1
.IP
void \fBGEllipseGetOutPoints\fP (GNumber \fIradX\fP, GNumber \fIradY\fP, GNumber \fIangle1\fP, GNumber \fIangle2\fP, GPoint& \fIpmin\fP, GPoint& \fIpmax\fP);
.RS .8i
.IP \fIDescription\fP .3i
Considering the elliptical arc defined by the radii \fIradX\fP and \fIradY\fP
the angles \fIangle1\fP < \fIangle2\fP, delimiting the arc, this function
returns in \fIpmin\fP and \fIpmax\fP the arc bounding box in its own coordinate
system (i.e. gets the minimum and maximum values of x and y for points on the
arc).
.IP \fIradX\fP .3i
.IP \fIradY\fP .3i
specify the ellipse radii
.IP \fIangle1\fP .3i
.IP \fIangle2\fP .3i
angles delimiting the arc.
.IP \fIpmin\fP .3i
upper left corner of the bounding box
.IP \fIpmax\fP .3i
lower right corner of the bounding box
.RE
.sp1
.IP
GBox \fBGEllipseGetBox\fP (const GCoordSys& \fIcs\fP, GNumber \fIradX\fP, GNumber \fIradY\fP, GNumber \fIangle1\fP, GNumber \fIangle2\fP);
.RS .8i
.IP \fIDescription\fP .3i
This function is similar to \fBGEllipseGetOutPoints\fP, except the fact that
the ellipse arc is expressed in another coordinate system.
It returns the arc bounding box with respect to the absolute coordinate system.
.IP \fIcs\fP .3i
coordinate system in which the ellipse is expressed (specifies the center and
the axes).
.IP \fIradX\fP .3i
.IP \fIradY\fP .3i
ellipse radii expressed in \fIcs\fP
.IP \fIangle1\fP .3i
.IP \fIangle2\fP .3i
angles delimiting the arc (\fIangle1\fP < \fIangle2\fP)
.RE
.sp1
.IP
void \fBGBezierComputePoints\fP (int \fInctrl\fP, const GPoint* \fIctrl\fP, GQuality \fIquality\fP, int& \fInb\fP, GPoint* \fIpts\fP);
.RS .8i
.IP \fIDescription\fP .3i
This function provides a polyline approximation of a the bezier curve defined
by an array of \fInctrl\fP control points \fIctrl\fP. The precision of the
approximation depends on \fIquality\fP (from GMIN_QUALITY to GMAX_QUALITY).
.br
Warning : the array \fIpts\fP must be allocated before
the call and must contain at least GMAX_BEZIER_POINTS (\fInctrl\fP) Points.
.IP \fInctrl\fP .3i
number of control points in the array \fIctrl\fP
.IP \fIctrl\fP .3i
array of \fInctrl\fP control points defining the curve.
.IP \fIquality\fP .3i
defines the precision of the approximation (worst = GMIN_QUALITY, best =
GMAX_QUALITY)
.IP \fInb\fP .3i
returned value: number of points in the returned array \fIpts\fP
.IP \fIpts\fP .3i
array of \fInb\fP points returned (in the absolute coordinate system).
.RE
.sp1
.IP
void \fBGCubicCurveComputePoints\fP (int \fInctrl\fP, const GPoint* \fIctrl\fP, const GNumber \fIbasisMatrix\fP[4][4], int \fIevalShift\fP, GQuality \fIquality\fP, int& \fInb\fP, GPoint* \fIpts\fP);
.RS .8i
.IP \fIDescription\fP .3i
This function provides a polyline approximation of a the cubic curve defined
by an array \fIctrl\fP of \fInctrl\fP control points, a 4x4 matrix
\fIbasisMatrix\fP and an integer \fIevalShift\fP. In fact, the two later define
the type of the cubic curve (beta spline, tau spline, etc). The precision of the
approximation depends on \fIquality\fP (from GMIN_QUALITY to GMAX_QUALITY).
An evaluation window of exactly four control points is necessary to determine a
piece of curve called a "segment", then this evaluation window shifts to
the next serie of four points. The appropriate shift in control points between
segments is an important attribute of a curve type, here \fIevalShift\fP.
The points on the curve segment are calculated using the basis matrix of the
particular type of the curve and the geometric vector of the corresponding
control points. Choosing the basis matrix suitably, we can have various types
of interpolating and approximating splines. 
.IP \fInctrl\fP .3i
number of control points in the array \fIctrl\fP
.IP \fIctrl\fP .3i
array of \fInctrl\fP control points defining the curve.
.IP \fIbasisMatrix\fP .3i
4x4 matrix used to calculate points on the curve.
.IP \fIevalShift\fP .3i
shift of the "evaluation window", in number of control points, at each
"segment" computation.
.IP \fIquality\fP .3i
defines the precision of the approximation (worst = GMIN_QUALITY, best =
GMAX_QUALITY)
.IP \fInb\fP .3i
returned value : number of points in the returned array \fIpts\fP
.IP \fIpts\fP .3i
array of \fInb\fP points returned (in the absolute coordinate system).
.RE
.SH
\fBC BINDING\fP
.IP
\fITo be defined\fP.
.SH
\fBSEE ALSO\fP
.IP
\fBBox\fP, \fBCoordSys\fP and \fBRegion\fP tools.
.nrPN \n%


