.\" $Id: ImgBrush.n,v 1.1.1.1 1992/03/18 09:46:41 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH ImageBrush 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBImageBrush\fP \(em the ImageBrush object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/ImageBrush.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBImageBrush\fP does not inherit behavior from any class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBImageBrush\fP object gives a non-shared object interface to the \fBShImageBrush\fP
object. As a \fIShImageBrush\fP, a \fIImageBrush\fP is defined by a set of
values (see \fIImageBrushValues\fP).
.sp 1
\fBGImageBrush\fP is the C++ type of the \fIImageBrush\fP object class.
.sp 1
.nf
.ta .15i .25i 1.50i
class GImageBrush {
	public:
		GImageBrush ();
		GImageBrush (const GImageBrush* ibrush);
		GImageBrush (const GShImageBrush* \fIsh_ibrush\fP);
		GImageBrush (ulong \fImask\fP, const GImageBrushValues* \fIvalues\fP, const char* \fIname\fP = NULL);
		GImageBrush (const char* \fIname\fP);
		~GImageBrush ();

		// Getting values
		const GShImageBrush* shImageBrush() const;
		const GImageBrushValues* values() const;
		ulong mask() const;

		const char* name() const;
		GBool isNamed() const;

		ulong function () const;
		ulong planeMask () const;
		ulong fillStyle () const;
		const GShColormap* colormap () const;
		const GShPattern*  stipple () const;

		// Modifying methods
		void modify (ulong \fImask\fP, const GImageBrushValues* \fIvalues\fP);
		void modify (const char* \fIname\fP);
		void modify (const GShImageBrush* \fIsh_ibrush\fP);

		void function (ulong \fIfunction\fP);
		void planeMask (ulong \fIplane_mask\fP);
		void fillStyle (ulong \fIfill_style\fP);

		void colormap (const GColormap* \fIcolormap\fP);
		void colormap (const GShColormap* \fIsh_colormap\fP);
		void colormap (const char* \fIcolormap_name\fP);

		void stipple (const GPattern* \fIstipple\fP);
		void stipple (const GShPattern* \fIsh_stipple\fP);
		void stipple (const char* \fIstipple_name\fP);

		// Pre and Post Conditions
		void modifyPrecond (GBool (*\fIproc\fP)(void* \fIclosure\fP, GImageBrush* \fIibrush\fP,
			ulong& \fImask\fP, GImageBrushValues* \fInew_values\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void modifyPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GImageBrush* \fIibrush\fP, ulong \fImask\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void destroyPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GImageBrush* \fIibrush\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
};
.fi
.sp 1
.SH
\fBGImageBrushValues STRUCTURE\fP
.IP
\fISee ShImageBrush(3Go)\fP
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
.nf
\fBGImageBrush\fP ();
\fBGImageBrush\fP (const GImageBrush* \fIibrush\fP);
\fBGImageBrush\fP (const GShImageBrush* \fIsh_ibrush\fP);
\fBGImageBrush\fP (ulong \fImask\fP, const GImageBrushValues* \fIvalues\fP, const char* \fIname\fP = NULL);
\fBGImageBrush\fP (const char* \fIname\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to create a new \fIImageBrush\fP instance. The new \fIImageBrush\fP
points to a \fIShImageBrush\fP which may be shared between several other \fIImageBrush\fP
instances. When the \fIname\fP field is specified, a named \fIShImageBrush\fP
is explicitly referred. Specifying the values and the
name implies the corresponding named \fIShImageBrush\fP modification.
.IP \fIibrush\fP .5i
.br
Specifies the \fIGImageBrush\fP used to initialize the new instance.
.IP \fIsh_ibrush\fP .5i
Specifies the \fIShImageBrush\fP which will be pointed by the \fIGImageBrush\fP. The
\fIShImageBrush\fP reference count is incremented.
.IP \fImask\fP .5i
.br
Specifies the value bitmask (see \fIShImageBrush(3Go)\fP).
.IP \fIvalues\fP .5i
.br
Specifies a \fIImageBrushValues\fP structure pointer. Valid fields are defined by
the \fImask\fP.
.IP \fIname\fP .5i
.br
Identifies the named \fIShImageBrush\fP which is called \fIname\fP. If such
\fIShImageBrush\fP does not exit it is created. If values (rgb, gray, halftone) are
defined, the named \fIShImageBrush\fP will be modified.
.RE
.sp 1
.IP
\fB~GImageBrush\fP ();
.RS .8i
.IP \fIDescription\fP .5i
This method is called when a \fIImageBrush\fP instance is deleted. The corresponding
\fIShImageBrush\fP reference count is decremented. The \fIdestroyPostcond\fP callback,
if exits, is called \fIjust before\fP the deletion.
.RE
.sp 2
.IP
const GShImageBrush* \fBshImageBrush\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the \fIShImageBrush\fP associated to the \fIImageBrush\fP object.
.RE
.sp 1
.IP
const GImageBrushValues* \fBvalues\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the pointer to the \fIImageBrush\fP values.
.RE
.sp 1
.IP
ulong \fBmask\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the mask associated to the values of the corresponding
\fIShImageBrush\fP.
.RE
.sp 1
.IP
const char* \fBname\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the name of the associated \fIShImageBrush\fP or NULL.
.RE
.sp 1
.IP
GBool \fBisNamed\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This method return GTRUE, if the associated \fIShImageBrush\fP is
named, else it returns GFALSE.
.RE
.sp 1
.IP
.nf
ulong \fBfunction\fP () const;
ulong \fBplaneMask\fP () const;
ulong \fBfillStyle\fP () const;
.sp 1
const GShPattern* \fBstipple\fP () const;
const GShColormap* \fBcolormap\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to get field by field the \fIGImageBrushValues\fP structure
of the \fIShImageBrush\fP referred in the \fIImageBrush\fP. These fields are only valid
if the corresponding bits in the mask (\fImask()\fP) are set.
.RE
.sp 1
.IP
.nf
void \fBmodify\fP (ulong \fImask\fP, const GImageBrushValues* \fIvalues\fP);
void \fBmodify\fP (const char* \fIname\fP);
void \fBmodify\fP (const GShImageBrush* \fIsh_ImageBrush\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to modify the \fIImageBrush\fP value either by giving a ``mask, values''
couple, or by giving a \fIShImageBrush\fP identified by its name or by its pointer.
.IP "\fImask, values\fP" .5i
Specify the values to be modified. Only fields specified in the mask will be
affected by the modification. Pre and postconditions are invoked when \fImodify()\fP
is called with these parameters.
.IP \fIname\fP .5i
.br
Specifies the name of a named \fIShImageBrush\fP instance. If such an instance
does not exist, a new named \fIShImageBrush\fP is created with the current \fIImageBrush\fP
values. Preconditions and postconditions are invoked when \fImodify()\fP 
is called with this parameter; the value mask is the complete named
\fIShImageBrush\fP mask. In preconditions functions, modifying the proposed
values will imply the named \fIShImageBrush\fP modification.
.IP \fIsh_ImageBrush\fP .5i
.br
Specifies a pointer to a \fIShImageBrush\fP instance, which will become the
\fIShImageBrush\fP referred in the \fIImageBrush\fP. Pre and postconditions are invoked
when \fImodify()\fP is invoked with this parameter.
.RE
.sp 1
.IP
.nf
void \fBfunction\fP (ulong \fIfunction\fP);
void \fBplaneMask\fP (ulong \fIplane_mask\fP);
void \fBfillStyle\fP (ushort \fIfill_style\fP);
.sp
void \fBcolormap\fP (const GColormap* \fIcolormap\fP);
void \fBcolormap\fP (const GShColormap* \fIsh_colormap\fP);
void \fBcolormap\fP (const char* \fIcolormap_name\fP);v
.sp
void \fBstipple\fP (const GPattern* \fIstipple\fP);
void \fBstipple\fP (const GShPattern* \fIsh_stipple\fP);
void \fBstipple\fP (const char* \fIstipple_name\fP);v
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to modify field by field the \fIGImageBrushValues\fP structure
of the referred \fIShImageBrush\fP. Pre and postconditions are invoked.
It is recommended for performance reasons, to use \fImodify(mask, values)\fP when several
fields have to be modified, rather than calling the specific method for each field.
.RE
.sp 1
.IP
.nf
void \fBmodifyPrecond\fP (GBool (*\fIproc\fP)(void* \fIclosure\fP, GImageBrush* \fIibrush\fP,
	ulong& \fImask\fP, GImageBrushValues* \fInew_values\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBmodifyPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GImageBrush* \fIibrush\fP, ulong \fImask\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These method allow to add or remove pre or post conditions on \fIImageBrush\fP modifying.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called before (pre-condition) or after (post-condition)
the modification. Its parameters are the \fIclosure\fP, the object \fIImageBrush\fP
itself and the modification \fImask\fP. For the pre-condition, if \fIproc\fP returns
GFALSE, the modification is nor proceeded. In addition, the precondition procedure
may modify the action (\fInew_values\fP).
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the condition
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp1
.IP
.nf
void \fBdestroyPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GImageBrush* \fIibrush\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP
This method allows to add or remove a callback procedure which will be called
when the object \fIImageBrush\fP will be destroyed.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the object will be destroyed.
The callback procedure is called \fIjust before\fP the destruction of the object. Its parameters are
the \fIclosure\fP and the object \fIImageBrush\fP itself.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the
destruction callback list. If \fIadd\fP is GREMOVE, the callback procedure
\fIproc\fP will be removed from  the callback list.
.RE
.sp 1
.SH
\fBC BINDING\fP
.SS
\fBHeader File\fP
.IP
#include <Go/Tools/cImgBrush.h>
.SS
\fBType Definitions\fP
.IP
The \fIShImageBrush\fP C interface defines the \fIGImageBrushValues\fP structure. This
structure is used by the \fIImageBrush\fP C interface (see \fIShImageBrush(3Go)\fP).
.SS
\fBC Functions\fP
.IP
GObjectId \fBCreateImageBrush\fP (ulong \fImask\fP, const GImageBrushValues* \fIvalues\fP, const char* \fIname\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GImageBrush (ulong \fImask\fP, const GImageBrushValues* \fIvalues\fP, const char* \fIname\fP).
.RE
.sp 1
.IP
void \fBDestroyImageBrush\fP (GObjectId \fIibrush\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP ~GImageBrush ().
.RE
.sp 1
.IP
.nf
void \fBModifyImageBrush\fP (GObjectId \fIibrush\fP, ulong \fImask\fP, const GImageBrushValues* \fIvalues\fP);
void \fBModifyImageBrushFromName\fP (GObjectId \fIibrush\fP, const char* \fIname\fP);
void \fBModifyImageBrushFromShImageBrush\fP (GObjectId \fIibrush\fP, const GObjectId \fIsh_ibrush\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP:
.nf
  void modify (ulong \fImask\fP, const GImageBrushValues* \fIvalues\fP);
  void modify (const char* \fIname\fP);
  void modify (const GShImageBrush* \fIsh_ibrush\fP);
.fi
.RE
.sp 1
.IP
.nf
const GImageBrushValues* \fBGetImageBrushValues\fP (const GObjectId \fIibrush\fP);
const GObjectId \fBGetImageBrushShImageBrush\fP (const GObjectId \fIibrush\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP:
.nf
   const GImageBrushValues* values ();
   const GShImageBrush* shImageBrush ().
.fi
.RE
.sp 1
.IP
.nf
void \fBModifyImageBrushPrecond\fP (GObjectId \fIibrush\fP, GAddOrRemove \fIadd\fP,
	GBool (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIibrush\fP,
		ulong* \fImask\fP, GImageBrushValues* \fIvalues\fP),
	const void* \fIclosure\fP);
void \fBModifyImageBrushPostcond\fP (GObjectId \fIibrush\fP, GAddOrRemove \fIadd\fP,
	void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIibrush\fP, ulong \fImask\fP),
	const void* \fIclosure\fP);
void \fBDestroyImageBrushPostcond\fP (GObjectId \fIibrush\fP, GAddOrRemove \fIadd\fP,
	void (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIibrush\fP),
	const void* \fIclosure\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP
.nf
   void modifyPrecond (GBool (*\fIfunction\fP)(void* \fIclosure\fP, const GImageBrush* \fIibrush\fP,
	ulong& \fImask\fP, GImageBrushValues* \fInewValues\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;
   void modifyPostcond (void (*\fIfunction\fP)(void* \fIclosure\fP, const GImageBrush* \fIibrush\fP, ulong \fImask\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;   
   void destroyPostcond (void (*\fIfunction\fP)(void* \fIclosure\fP, const GImageBrush* \fIibrush\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;
.fi
.RE
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
The \fIImageBrush\fP object is a non-shared object interface for the \fIShImageBrush\fP object,
see the \fIShImageBrush(3Go)\fP and \fISharedObject(3Go)\fP to know the shared object
usage.
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBBool(3Go)\fP, \fBColormap(3Go)\fP,
\fBSharedObject\fP, \fBShImageBrush\fP.
.nrPN \n%
