.\" $Id: List.n,v 1.2 1992/12/31 15:04:14 mbikina Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH List 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBList\fP \(em the simple list object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/List.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBList\fP does not inherit behavior from any class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBList\fP class implements a simple list object. A \fIList\fP
only contains a pointer to the next element in the list. A list element
(\fIElem\fP) is declared as a \fIvoid*\fP.
.sp 1
Any \fIList\fP element may be a head list.
.sp 1
See also \fIUSAGE INFORMATION\fP.
.sp 1
\fBGList\fP is the C++ type of the \fIList\fP object class.
.sp 1
.nf
.ta .15i .25i 1.50i
class GList {
	public:
		GList (GList*& \fIhead\fP );

		GList*  next() const;

		void remove (GList*& \fIhead\fP);
		void raise (GList*& \fIbefore\fP) const;
		void tobegin(GList*& \fIhead\fP)  const;
		void toend (GList*& \fIhead\fP)   const;
};
.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
\fBGList\fP (GList*& \fIhead\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allow to create a new instance of the \fIList\fP class.
.IP \fIhead\fP .5i
.br
Specifies a pointer to be used to store the head of the \fIList\fP
(the first element is \fIthis\fP). If \fIhead\fP is not an empty list,
the element (\fIthis\fP is added in the current list (see \fItobegin\fP).
.RE
.sp 1
.IP
void \fBtobegin\fP (GList*& \fIhead\fP);
.br
void \fBtoend\fP (GList*& \fIhead\fP);
.RS .8i
.IP \fIDescription\fP .5i
These two methods allow to add in an existing list (\fIhead\fP) a new
element (\fIthis\fP). This element is put at the beginning (\fItobegin()\fP)
or at the end (\fItoend\fP) of the list.
.RE
.sp 1
.IP
void \fBremove\fP (GList*& \fIhead\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method removes from the list \fIhead\fP, the element \fIthis\fP. The
element is not deleted (the caller has explicitly to invoke \fIdelete\fP
for this element after removing it from the list). A very simple utilisation
of \fIremove()\fP is to call it in the destructor of the derived class.
.RE
.sp 1
.IP
GList* \fBnext\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the next element of the current position (\fIthis\fP) or \fINULL\fP.
.RE
.sp 1
.IP
void \fBraise\fP (GList*& \fIbefore\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method put the element \fIthis\fP at the beginning of the list \fIhead\fP.
.RE
.sp 1
.SH
\fBC BINDING\fP
.IP
None.
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
The \fIList\fP class should not be directly used but as a super class of
another class (i.e. \fISharedObject\fP).
.sp 1
.SH
\fBSEE ALSO\fP
.IP
.nrPN \n%
