.\" $Id: Matrix.n,v 1.1.1.1 1992/03/18 09:47:04 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH Matrix 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBMatrix\fP \(em the 2x2 matrix object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/Matrix.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBMatrix\fP does not inherit behavior from any class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBMatrix\fP class implements the 2x2 matrix object.
It is defined by two \fIVector's\fP vx and vy.
.sp 1
\fBGMatrix\fP is the C++ type for the \fIMatrix\fP object class.
.sp 1
.nf
.ta .15i .25i 1.50i
class GMatrix {
	public:
		GMatrix();
		GMatrix(const GVector& \fIvx\fP, const GVector& \fIvy\fP);
		GMatrix(GNumber \fIangle\fP);
		GMatrix(const GMatrix& \fImatrix\fP);

		const GVector& vx() const;
		const GVector& vy() const;

		GMatrix& operator *= (GNumber \fIn\fP);
		GMatrix& operator /= (GNumber \fIn\fP);
		GMatrix& rotate(GNumber \fIangle\fP);

		GMatrix operator ~ () const;
		friend GMatrix operator * (const GMatrix& \fIm1\fP, const GMatrix& \fIm2\fP);
		friend GVector operator * (const GMatrix& \fIm\fP, const GVector& \fIv\fP);
		friend GVector& operator *= (GVector& \fIv\fP, const GMatrix& \fIm\fP);
		friend GMatrix GRotationMatrixFromVectors(const GVector& \fIv1\fP, const GVector& \fIv2\fP);
		GNumber deter() const;
};
.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
.nf
\fBGMatrix\fP();
\fBGMatrix\fP(const GVector& \fIvx\fP, const GVector& \fIvy\fP);
\fBGMatrix\fP(GNumber \fIangle\fP);
\fBGMatrix\fP(const GMatrix& \fImatrix\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to create new instances of the \fIMatrix\fP class
from various parameters. When no parameters are given, the matrix
.EQ
size 6
left (
matrix {
ccol {1 above 0}
ccol {0 above 1}
}
right )
" is created."
.EN
.IP "\fIvx, vy\fP" .5i
.br
Specify the two vectors of the matrix (see \fIVector(3Go)\fP).
.IP \fIangle\fP .5i
.br
Defines the angle used to create the matrix
.EQ
size 6
left (
matrix {
ccol {cos(\fIangle\f) above sin(\fIangle\fP)}
ccol {sin(\fIangle\fP) above -cos(\fIangle\fP)}
}
right )
" ."
.EN
.IP \fImatrix\fP .5i
Specifies the \fIMatrix\fP object which will be used to intialize the
the new matrix.
.RE
.sp 1
.IP
const GVector& \fBvx\fP() const;
.br
const GVector& \fBvy\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
These two methods respectively returns the two vectors (\fIvx, vy\fP) of the
matrix.
.RE
.sp 1
.IP
.nf
GMatrix& \fBoperator *=\fP (GNumber \fIn\fP);
GMatrix& \fBoperator /=\fP (GNumber \fIn\fP);
GMatrix& \fBrotate\fP (GNumber \fIangle\fP);
.sp 1
GMatrix \fBoperator ~\fP () const;
friend GMatrix \fBoperator *\fP (const GMatrix& \fIm1\fP, const GMatrix& \fIm2\fP);
friend GVector \fBoperator *\fP (const GMatrix& \fIm\fP, const GVector& \fIv\fP);
friend GVector& \fBoperator *=\fP (GVector& \fIv\fP, const GMatrix& \fIm\fP);
friend GMatrix \fBGRotationMatrixFromVectors\fP (const GVector& \fIv1\fP, const GVector& \fIv2\fP);
.fi
.sp 1
.IP
GNumber \fBdeter\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the determinant of the matrix.
.RE
.sp 1
.SH
\fBC BINDING\fP
.SS
\fBHeader File\fP
.IP
#include <Go/Tools/cMatrix.h>
.SS
\fBType Definitions\fP
.IP
.nf
.ta .15i .25i 1.0i
typedef struct _GMatrix
{
	GVector I;
	GVector J;
} GMatrix;
.fi
.sp 1
\fII\fP anf \IJ\fP specify the two vectors of the matrix (see \fIVector(3Go)\fP, C Binding
section).
.SS
\fBC Functions\fP
.IP
.nf
void \fBGRotateMatrix\fP (GMatrix* \fImatrix\fP, GNumber \fIangle\fP);
void \fBGInvertMatrix\fP (GMatrix* \fImatrix\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP
.nf
   GMatrix& \fBrotate\fP (GNumber \fIangle\fP);
   GMatrix \fBoperator ~\fP () const;
.fi
.RE
.sp 1
.IP
GMatrix \fBGMatrixProduct\fP (GMatrix* \fIm1\fP, GMatrix* \fIm2\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP friend GMatrix \fBoperator *\fP (const GMatrix& \fIm1\fP, const GMatrix& \fIm2\fP);
.RE
.sp 1
.IP
GNumber \fBGMatrixDeter\fP (GMatrix* \fImatrix\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP GNumber \fBdeter\fP() const.
.RE
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBVector(3Go)\fP, \fBNumber(3Go)\fP.
.nrPN \n%
