.\" $Id: Medium.n,v 1.2 1992/12/28 12:42:56 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH Medium 3Go "December 1992" "Version 1.2" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBMedium\fP \(em the basic medium object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/Medium.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBGMedium\fP does not inherit behavior from any class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBGMedium class provides an interface to \fIread/write\fP from or to a support called here \fImedium\fP. The \fBMedium\fP class is abstract so it must be derived to implement the effective \fIread/write\fP.
.IP
.sp 1
.nf
.ta .15i .25i 1.0i
	#define	 GEOM (-1)   // G end_of_medium;

	enum GMSeekType {
		GMSEEK_FROM_BEGINNING = 0,
		GMSEEK_FROM_CURRENT,
		GMSEEK_FROM_END
	};

	class GMedium {

	public:

		virtual ~GMedium();
    
		// OUPUT;
    
		virtual long write(const char*, long) = 0;
		virtual int mputc(char c) = 0;
		virtual int mputs(const char* s) = 0;
		virtual int mputback(char) = 0;

		// INPUT;
    
		virtual long read(char*, long) = 0;
		virtual int  mgetc() = 0;
		virtual char*  mgets(char* s, ulong max_size) = 0;
		int  mungetc(char);
		virtual int readuntil(char stop);

		// POSITION;
	
		virtual int mseek(long offset,
			GMSeekType st = GMSEEK_FROM_BEGINNING) = 0;
		virtual long mtell() = 0;
	};
.fi
.RE
.SH
\fBPUBLIC METHODS\fP
.sp 1
.IP
\fBGMedium~()\fP.
.RS .8i
.IP \fIDescription:\fP .5i
The method deletes the current \fPmedium\fP.
.RE
.sp 1
.IP
long \fBwrite\fP(const char* \fIdata\fP, long \fInchar\fP);
.RS .8i
.IP \fIDescription:\fP .5i
The method \fIwrites\fP onto the \fImedium\fP \fInchar\fP pointed to by \fIdata\fP. It returns the number of char effectively written onto the \fImedium\fP or -1 on error.
.IP \fIdata,nchar\fP .5i
.br
Specifies the buffer to be written;
.RE
.sp 1
.IP
int \fBmputc\fP(const char \fIchar\fP);
.RS .8i
.IP \fIDescription:\fP .5i
The method \fIwrites\fP the \fIchar\fP onto the \fImedium\fP. It returns \fIc\fP if there is no error otherwise it returns GEOM.
.IP \fIchar\fP .5i
.br
Specifies the char to be written.
.RE
.sp 1
.IP
int \fBmputs\fP(const char* \fIstring\fP);
.RS .8i
.IP \fIDescription:\fP .5i
The method \fIwrites\fP the NULL terminated \fIstring\fP onto the \fImedium\fP. It does not write the '\\0' and does not happen a '\\n' onto the \fImedium\fP. On error \fImputs\fP returns GEOM otherwise it returns 0.
.RE
.sp 1
.IP
int \fBmputback\fP(char \fIc\fP);
int \fImungetc\fP (char \fIc\fP);
.RS .8i
.IP \fIDescription:\fP .5i
The two methods push back the character \fIc\fP onto the \fImedium\fP. It will be read by the next \fImgetc\fP call. If \fIc\fP is GEOM it returns GEOM and does nothing, otherwise it returns \fIc\fP.
.IP \fIc\fP .5i
Specifies the character to insert before the current \fIposition\fP.
.RE
.sp 1
.IP
long \fBread\fP(char* \fIbuffer\fP, long \fInbytes\fP);
.RS .8i
.IP \fIDescription:\fP .5i
The method \fIreads nbytes\fP from the \fImedium\fP onto \fIbuffer\fP. It returns the number of bytes copied inside \fIbuffer\fP. On error it returns GEOM.
.IP \fIbuffer\fP .5i
.br
Specifies the \fIbuffer\fP which will receive the data. It must be large enought to receive \fPnbytes\fP.
.IP \fPnbytes\fP .5i
Specifies the number of bytes to read.
.RE
.sp 1
.IP
int \fBmgetc\fP();
.RS .8i
.IP \fIDescription:\fP .5i
The method returns the next character available on the \fImedium\fP. On error or at end of \fImedium\fP it returns GEOM.
.RE
.sp 1
.IP
char* \fBmgets\fP(char* \fIstring\fP, ulong \fPmax_size\fP);
.RS .8i
.IP \fIDescription:\fP .5i
the method \fIreads\fP characters from the \fImedium\fP, until \fImax_size\fP-1 characters are read or a GEOM is encountered. The \fIstring\fP is then terminated with a null character. On error GEOM is returned otherwise \fIstring\fP is returned.
.IP \fIstring\fP .5i
Specifies the buffer which will receive the data.
.IP \fImax_size\fP .5i
Specifies the maximun number of characters to read (including the null character).
.RE
.sp 1
.IP
int \fBreaduntil\fP(char \fIstop\fP).
.RS .8i
.IP \fIDescription:\fP .5i
The method reads the \fImedium\fP from the current \fIposition\fP until it gets the \fPstop\fP character. If \fPstop\fP is read it returns \fPstop\fP otherwise  it returns GEOM.
.IP \fIstop\fP .5i
Specifies the character which stops the read.
.RE
.sp 1
.IP
int \fBmseek\fP(long \fIoffset\fP, GMSeekType \fPmode\fP);
.RS .8i
.IP \fIDescription:\fP .5i
The method sets the current read/write \fIposition\fP according \fPoffset\fP and \fImode\fP. The new \fIposition\fP is at the signed distance \fIoffset\fP bytes from:
.IP
- 1: the beginning of the medium with \fImode\fP: GMSEEK_FROM_BEGINNING;
.IP
- 2: the current position with \fImode\fP: GMSEEK_FROM_CURRENT;
.IP
- 3: the end of  the medium with \fImode\fP: GMSEEK_FROM_END;
.br
.sp 1
.IP \fIoffset\fP .5i
.br
Specifies the signed \fIoffset\fP.
.IP \fPmode\fP .5i
.br
Specifies the seek type.
.RE
.sp 1
.IP
long \fBmtell\fP();
.RS .8i
.IP \fIDescription:\fP .5i
The method returns the current read/write \fIposition\fP. It is the offset of the current byte relative to the beginning of the \fImedium\fP. On error it returns GEOM.
.SH
\fBC BINDING\fP
.IP
.sp 1
.nf
.ta .15i .25i 1.0i
	void   GDeleteMedium(GObjectId medium);

	long   GMediumWrite(GObjectId medium, const char*, long);
	int    GMediumPutc (GObjectId medium, char c);
	int    GMediumPuts(GObjectId medium, const char* s);
	int    GMediumPutback(GObjectId medium, char);

	long   GMediumRead(GObjectId medium, char*, long);
	int    GMediumGetc(GObjectId medium);
	char*  GMediumGets(GObjectId medium, char* s, ulong max_size);
	int    GMediumUngetc(GObjectId medium, char);

	int    GMediumSeek(GObjectId medium, long offset, enum GMSeekType st);
	long   GMediumTell(GObjectId medium);
.fi

.sp 1
.IP \fIDescription\fP .5i
See GMedium::\fIname\fP method.
.SH
\fBUSAGE INFORMATION\fP
.IP
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBFileMedium\fP.
.nrPN \n%
