.\" $Id: Pattern.n,v 1.1.1.1 1992/03/18 09:47:18 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH Pattern 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBPattern\fP \(em the pattern object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/Pattern.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBPattern\fP does not inherit behavior from any class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBPattern\fP object gives a non-shared object interface to the \fBShPattern\fP
object. As a \fIShPattern\fP, a \fIPattern\fP is defined by a set values (\fIShPixelArray,
ShColormap, width, height\fP) described in the \fIGPatternValues\fP structure.
.sp 1
\fBGPattern\fP is the C++ type for the \fIPattern\fP object class.
.sp 1
.nf
.ta .15i .25i 1.50i
class GPattern {
	public:
		GPattern ();
		GPattern (const GPattern* \fIpattern\fP);
		GPattern (const GShPattern* \fIsh_pattern\fP);
		GPattern (ulong \fImask\fP, const GPatternValues* \fIvalues\fP, const char* \fIname\fP = NULL);
		GPattern (const char* \fIname\fP);
		~GPattern ();

		// Getting values
		const GShPattern* shPattern() const;
		const GPatternValues* values() const;

		const char* name() const;
		GBool isNamed() const;

		const GShPixelArray* pixelArray () const;
		const GShColormap* colormap () const;
		GNumber width () const;
		GNumber height () const;

		// Modifying methods
		void modify (ulong \fImask\fP, const GPatternValues* \fIvalues\fP);
		void modify (const GShPattern* \fIsh_pattern\fP);
		void modify (const char* \fIname\fP);

		// Pre and Post Conditions
		void modifyPrecond (GBool (*\fIproc\fP)(void* \fIclosure\fP, GPattern* \fIpattern\fP,
			ulong& \fImask\fP, GPatternValues* \fInew_values\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void modifyPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GPattern*\fIpattern\fP, ulong \fImask\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void destroyPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GPattern* \fIpattern\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
};
.fi
.sp 1
.SH
\fBGPatternValues STRUCTURE\fP
.IP
\fISee ShPattern(3Go)\fP
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
.nf
\fBGPattern\fP ();
\fBGPattern\fP (const GPattern* \fIpattern\fP);
\fBGPattern\fP (const GShPattern* \fIsh_pattern\fP);
\fBGPattern\fP (ulong \fImask\fP, const GPatternValues* \fIvalues\fP, const char* \fIname\fP = NULL);
\fBGPattern\fP (const char* \fIname\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to create a new \fIPattern\fP instance. The new \fIPattern\fP
points to a \fIShPattern\fP which may be shared between several other \fIPattern\fP
instances. When the \fIname\fP field is specified, a named \fIShPattern\fP
is explicitly referred. Specifying the values and the
name implies the corresponding named \fIShPattern\fP modification.
.IP \fIpattern\fP .5i
.br
Specifies the \fIPattern\fP used to initialize the new instance.
.IP \fIsh_pattern\fP .5i
Specifies the \fIShPattern\fP which will be pointed by the \fIPattern\fP. The
\fIShPattern\fP reference count is incremented.
.IP \fImask\fP .5i
.br
Specifies the value bitmask (see \fIShPattern(3Go)\fP).
.IP \fIvalues\fP .5i
.br
Specifies a \fIGPatternValues\fP structure pointer. Valid fields are defined by
the \fImask\fP.
.IP \fIname\fP .5i
.br
Identifies the named \fIShPattern\fP which is called \fIname\fP. If such
\fIShPattern\fP does not exit it is created. If some values are
defined, the named \fIShPattern\fP will be modified.
.RE
.sp 1
.IP
\fB~GPattern\fP ();
.RS .8i
.IP \fIDescription\fP .5i
This method is called when a \fIPattern\fP instance is deleted. The corresponding
\fIShPattern\fP reference count is decremented. The \fIdestroyPostcond\fP callback,
if exits, is called \fIjust before\fP the deletion.
.RE
.sp 2
.IP
const GShPattern* \fBshPattern\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the \fIShPattern\fP associated to the \fIPattern\fP object.
.RE
.sp 1
.IP
const GPatternValues* \fBvalues\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the pointer to the \fIPattern\fP values.
.RE
.sp 1
.IP
const char* \fBname\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the name of the associated \fIShPattern\fP or NULL.
.RE
.sp 1
.IP
GBool \fBisNamed\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This method return GTRUE, if the associated \fIShPattern\fP is
named, else it returns GFALSE.
.RE
.sp 1
.IP
.nf
const GShPixelArray* \fBpixelArray\fP () const;
const GShColormap* \fBcolormap\fP () const;
GNumber \fBwidth\fP () const;
GNumber \fBheight\fP () const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods return the /fIShPixelArray\fP, \fIShColormap\fP, \fIwidth\fP and \fIheight\fP
fields of the \fIPattern\fP values.
.RE
.sp 1
.IP
void \fBmodify\fP (ulong \fImask\fP, const GPatternValues* \fIvalues\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to modify the \fIPattern\fP values. It calls the
\fImodify()\fP function of the associated \fIShPattern\fP. After this
call, the \fIShPattern\fP pointer may be different. The pre/post
conditions will be called if they exist.
.IP \fImask\fP .5i
.br
Specifies the value bitmask of the valid fields in the \fIGPatternValues\fP
structure.
.IP \fIvalues\fP .5i
.br
Specifies the new values which will be assigned to the \fIPattern\fP.
.RE
.sp 1
.IP
void \fBmodify\fP (const GShPattern* \fIsh_pattern\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to modify the \fIPattern\fP object by changing
the \fIShPattern\fP pointed by the \fIPattern\fP. The pre/post conditions
are called if they exist.
.IP \fIsh_pattern\fP .5i
.br
Specifies the \fIShPattern\fP which has to replace the previous
\fIShPattern\fP contained in the \fIPattern\fP.
.RE
.sp 1
.IP
void \fBmodify\fP (const char* \fIname\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to (re)name the associated \fIShPattern\fP. If \fIname\fP
is NULL, a unnamed \fIShPattern\fP will be created.  The pre/post conditions
are invoked; the value mask is the complete named \fIShPattern\fP mask.
In preconditions functions, modifying the proposed values will imply the
named \fIShPattern\fP modification.
.IP \fIname\fP .5i
.br
Specifies the new name of the associated \fIShPattern\fP.
.RE
.sp 1
.IP
.nf
void \fBmodifyPrecond\fP (GBool (*\fIproc\fP)(void* \fIclosure\fP, GPattern* \fIpattern\fP,
	ulong& \fImask\fP, GPatternValues* \fInew_values\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBmodifyPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GPattern* \fIpattern\fP, ulong \fImask\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These method allow to add or remove pre or post conditions on \fIPattern\fP modifying.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called before (pre-condition) or after (post-condition)
the modification. Its parameters are the \fIclosure\fP, the object \fIPattern\fP
itself and the modification \fImask\fP. For the pre-condition, if \fIproc\fP returns
GFALSE, the modification is nor proceeded. In addition, the precondition procedure
may modify the action (\fInew_values\fP).
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the condition
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp1
.IP
.nf
void \fBdestroyPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GPattern* \fIpattern\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP
This method allows to add or remove a callback procedure which will be called
when the object \fIPattern\fP will be destroyed.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the object will be destroyed.
The callback procedure is called \fIjust before\fP the destruction of the object. Its parameters are
the \fIclosure\fP and the object \fIPattern\fP itself.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the
destruction callback list. If \fIadd\fP is GREMOVE, the callback procedure
\fIproc\fP will be removed from  the callback list.
.RE
.sp 1
.SH
\fBC BINDING\fP
.SS
\fBHeader File\fP
.IP
#include <Go/Tools/cPattern.h>
.SS
\fBType Definitions\fP
.IP
The \fIShPattern\fP C interface defines the \fIGPatternValues\fP structure. This
structure is used by the \fIPattern\fP C interface (see \fIShPattern(3Go)\fP).
.SS
\fBC Functions\fP
.IP
GObjectId \fBGCreatePattern\fP (ulong \fImask\fP, const GPatternValues* \fIvalues\fP, const char* \fIname\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GPattern (ulong \fImask\fP, const GPatternValues* \fIvalues\fP, const char* \fIname\fP).
.RE
.sp 1
.IP
void \fBGDestroyPattern\fP (GObjectId \fIpattern\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP ~GPattern ().
.RE
.sp 1
.IP
.nf
void \fBGModifyPattern\fP (GObjectId \fIpattern\fP, ulong \fImask\fP, const GPatternValues* \fIvalues\fP);
void \fBGModifyPatternFromName\fP (GObjectId \fIpattern\fP, const char* \fIname\fP);
void \fBGModifyPatternFromShPattern\fP (GObjectId \fIpattern\fP, const GObjectId \fIsh_pattern\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP:
.nf
  void modify (ulong \fImask\fP, const GPatternValues* \fIvalues\fP);
  void modify (const char* \fIname\fP);
  void modify (const GShPattern* \fIsh_pattern\fP);
.fi
.RE
.sp 1
.IP
.nf
const GPatternValues* \fBGGetPatternValues\fP (const GObjectId \fIpattern\fP);
const GObjectId \fBGGetPatternShPattern\fP (const GObjectId \fIpattern\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP:
.nf
   const GPatternValues* values ();
   const GShPattern* shPattern ().
.fi
.RE
.sp 1
.IP
.nf
void \fBGModifyPatternPrecond\fP (GObjectId \fIpattern\fP, GAddOrRemove \fIadd\fP,
	GBool (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIpattern\fP,
		ulong* \fImask\fP, GPatternValues* \fIvalues\fP),
	const void* \fIclosure\fP);
void \fBGModifyPatternPostcond\fP (GObjectId \fIpattern\fP, GAddOrRemove \fIadd\fP,
	void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIpattern\fP, ulong \fImask\fP),
	const void* \fIclosure\fP);
void \fBGDestroyPatternPostcond\fP (GObjectId \fIpattern\fP, GAddOrRemove \fIadd\fP,
	void (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIpattern\fP),
	const void* \fIclosure\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP
.nf
   void modifyPrecond (GBool (*\fIfunction\fP)(void* \fIclosure\fP, const GPattern* \fIpattern\fP,
	ulong& \fImask\fP, GPatternValues* \fInewValues\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;
   void modifyPostcond (void (*\fIfunction\fP)(void* \fIclosure\fP, const GPattern* \fIpattern\fP, ulong \fImask\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;   
   void destroyPostcond (void (*\fIfunction\fP)(void* \fIclosure\fP, const GPattern* \fIpattern\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;
.fi
.RE
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
The \fIPattern\fP object is a non-shared object interface for the \fIShPattern\fP object,
see the \fIShPattern(3Go)\fP and \fISharedObject(3Go)\fP to know the shared object
usage.
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBBool(3Go)\fP, \fBNumber(3Go)\fP,
\fBSharedObject(3Go)\fP, \fBShPattern(3Go)\fP, \fBShColormap(3Go)\fP, \fBShPixelArray(3Go)\fP.
.nrPN \n%
