.\" $Id: Pen.n,v 1.1.1.1 1992/03/18 09:47:23 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH Pen 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBPen\fP \(em the pen object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/Pen.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBPen\fP does not inherit behavior from any class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBPen\fP object gives a non-shared object interface to the \fBShPen\fP
object. As a \fIShPen\fP, a \fIPen\fP is defined by a set of
values (see \fIPenValues\fP).
.sp 1
The \fIPen\fP class allows to set additional pre/postconditions.
.sp 1
\fBGPen\fP is the C++ type for the \fIPen\fP object class.
.sp 1
.nf
.ta .15i .25i 1.50i
class GPen {
	public:
		GPen ();
		GPen (const GPen* \fIpen\fP);
		GPen (const GShPen* \fIsh_pen\fP);
		GPen (ulong \fImask\fP, const GPenValues* \fIvalues\fP, const char* \fIname\fP = NULL);
		GPen (const char* \fIname\fP);
		~GPen ();

		// Getting values
		const GShPen* shPen() const;
		const GPenValues* values() const;
		ulong mask() const;

		const char* name() const;
		GBool isNamed() const;

		ulong function () const;
		ulong planeMask () const;
		const GShColor* color () const;
		const GShColor* altColor () const;

		GNumber lineWidth () const;
		ushort lineStyle () const;
		ushort capStyle () const;
		ushort joinStyle () const;
		GNumber miterLimit () const;
		const GShDash* dash () const;

		ushort fillStyle () const;
		const GShPattern* tile () const;
		const GShPattern* stipple () const;
		GNumber xtsOrigin () const;
		GNumber ytsOrigin () const;

		// Modifying methods
		void modify (ulong \fImask\fP, const GPenValues* \fIvalues\fP);
		void modify (const char* \fIname\fP);
		void modify (const GShPen* \fIsh_pen\fP);

		void function (ulong \fIfunction\fP);
		void planeMask (ulong \fIplane_mask\fP);
		void color (const GColor* \fIcolor\fP);
		void color (const GShColor* \fIsh_color\fP);
		void color (const char* \fIcolor_name\fP);
		void altColor (const GColor* \fIalt_color\fP);
		void altColor (const GShColor* \fIsh_alt_color\fP);
		void altColor (const char* \fIalt_color_name\fP);

		void lineWidth (GNumber \fIline_width\fP);
		void lineStyle (ushort \fIline_style\fP);
		void capStyle (ushort \fIcap_style\fP);
		void joinStyle (ushort \fIjoin_style\fP);
		void miterLimit (GNumber \fImiter_limit\fP);
		void dash (const GDash* \fIdash\fP);
		void dash (const GShDash* \fIsh_dash\fP);
		void dash (const char* \fIdash_name\fP);

		void fillStyle (ushort \fIfill_style\fP);
		void tile (const GPattern* \fItile\fP);
		void tile (const GShPattern* \fIsh_tile\fP);
		void tile (const char* \fItile_name\fP);
		void stipple (const GPattern* \fIstipple\fP);
		void stipple (const GShPattern* \fIsh_stipple\fP);
		void stipple (const char* \fIstipple_name\fP);
		void tsOrigin (GNumber \fIx_origin\fP, GNumber \fIy_origin\fP);

		// Pre and Post Conditions
		void modifyPrecond (GBool (*\fIproc\fP)(void* \fIclosure\fP, const GPen* \fIpen\fP,
			ulong& \fImask\fP, GPenValues* \fInewValues\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void modifyPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, const GPen* \fIpen\fP, ulong \fImask\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void destroyPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, const GPen* \fIpen\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
};
.fi
.sp 1
.SH
\fBGPenValues STRUCTURE\fP
.IP
\fISee ShPen(3Go)\fP
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
.nf
\fBGPen\fP ();
\fBGPen\fP (const GPen* \fIpen\fP);
\fBGPen\fP (const GShPen* \fIsh_pen\fP);
\fBGPen\fP (ulong \fImask\fP, const GPenValues* \fIvalues\fP, const char* \fIname\fP = NULL);
\fBGPen\fP (const char* \fIname\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to create a new instance of the \fIPen\fP class. When no
parameters are passed to the constructor, the pen is created with the
default \fIShPen\fP (see \fIShPen(3Go)\fP).
.IP \fIpen\fP .5i
.br
Specifies the \fIPen\fP instance used to intialize the new pen values. Pre and
postconditions are not copied.
.IP \fIsh_pen\fP .5i
.br
Specifies the \fIShPen\fP instance which is going to be referred in the
pen (the reference count of the shared pen is incremented).
.IP "\fImask, values\fP" .5i
.br
Specify the values of the pen. Unspecified fields in the \fIGPenValues\fP
structure take default values (see \fIShPen(3Go)\fP).
.IP \fIname\fP .5i
.br
Specifies the name of the named \fIShPen\fP object to be referred. If no such \fIShPen\fP
exists, it is created.
.RE
.sp 1
.IP
\fB~GPen\fP ();
.RS .8i
.IP \fIDescription\fP .5i
This method is called when a \fIPen\fP instance is deleted. The referred \fIShPen\fP
reference count is decremented. The \fIdestroyPostcond\fP is invoked.
.RE
.sp 1
.IP
.nf
const GShPen* \fBshPen\fP() const;
const GPenValues* \fBvalues\fP() const;
ulong \fBmask\fP() const;
const char* \fBname\fP() const;
GBool \fBisNamed\fP() const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods returns either the \fIShPen\fP referred by the pen, or
the values, the mask, the name of this \fIShPen\fP. \fIIsNamed()\fP returns
GTRUE, if the referred \fIShPen\fP is named else it returns GFALSE and \fIname()\fP
returns NULL.
.RE
.sp 1
.IP
.nf
ulong \fBfunction\fP () const;
ulong \fBplaneMask\fP () const;
const GShColor* \fBcolor\fP () const;
const GShColor* \fBaltColor\fP () const;
.sp 1
GNumber \fBlineWidth\fP () const;
ushort \fBlineStyle\fP () const;
ushort \fBcapStyle\fP () const;
ushort \fBjoinStyle\fP () const;
GNumber \fBmiterLimit\fP () const;
const GShDash* \fBdash\fP () const;
.sp 1
ushort \fBfillStyle\fP () const;
const GShPattern* \fBtile\fP () const;
const GShPattern* \fBstipple\fP () const;
GNumber \fBxtsOrigin\fP () const;
GNumber \fBytsOrigin\fP () const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to get field by field the \fIGPenValues\fP structure
of the \fIShPen\fP referred in the pen. These fields are only valid
if the corresponding bits in the mask (\fImask()\fP) are set.
.RE
.sp 1
.IP
.nf
void \fBmodify\fP (ulong \fImask\fP, const GPenValues* \fIvalues\fP);
void \fBmodify\fP (const char* \fIname\fP);
void \fBmodify\fP (const GShPen* \fIsh_pen\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to modify the pen value either by giving a ``mask, values''
couple, or by giving a \fIShPen\fP identified by its name or by its pointer.
.IP "\fImask, values\fP" .5i
Specify the values to be modified. Only fields specified in the mask will be
affected by the modification. Pre and postconditions are invoked when \fImodify()\fP
is called with these parameters.
.IP \fIname\fP .5i
.br
Specifies the name of a named \fIShPen\fP instance. If such an instance
does not exist, a new named \fIShPen\fP is created with the current pen
values. Preconditions and postconditions are invoked when \fImodify()\fP 
is called with this parameter; the value mask is the complete named
\fIShPen\fP mask. In preconditions functions, modifying the proposed
values will imply the named \fIShPen\fP modification.
.IP \fIsh_pen\fP .5i
.br
Specifies a pointer to a \fIShPen\fP instance, which will become the
\fIShPen\fP referred in the pen. Pre and postconditions are invoked
when \fImodify()\fP is invoked with this parameter only if \fIsh_pen\fP is not
named. If \fIsp_pen\fP is named, preconditions are not invoked and 
postconditions are invoked only if the requested named \fIShPen\fP exists.
.RE
.sp 1
.IP
.nf
void \fBfunction\fP (ulong \fIfunction\fP);
void \fBplaneMask\fP (ulong \fIplane_mask\fP);
void \fBcolor\fP (const GColor* \fIcolor\fP);
void \fBcolor\fP (const GShColor* \fIsh_color\fP);
void \fBcolor\fP (const char* \fIcolor_name\fP);
void \fBaltColor\fP (const GColor* \fIalt_color\fP);
void \fBaltColor\fP (const GShColor* \fIsh_alt_color\fP);
void \fBaltColor\fP (const char* \fIalt_color_name\fP);
.sp 1
void \fBlineWidth\fP (GNumber \fIline_width\fP);
void \fBlineStyle\fP (ushort \fIline_style\fP);
void \fBcapStyle\fP (ushort \fIcap_style\fP);
void \fBjoinStyle\fP (ushort \fIjoin_style\fP);
void \fBmiterLimit\fP (GNumber \fImiter_limit\fP);
void \fBdash\fP (const GDash* \fIdash\fP);
void \fBdash\fP (const GShDash* \fIsh_dash\fP);
void \fBdash\fP (const char* \fIdash_name\fP);
.sp 1
void \fBfillStyle\fP (ushort \fIfill_style\fP);
void \fBtile\fP (const GPattern* \fItile\fP);
void \fBtile\fP (const GShPattern* \fIsh_tile\fP);
void \fBtile\fP (const char* \fItile_name\fP);
void \fBstipple\fP (const GPattern* \fIstipple\fP);
void \fBstipple\fP (const GShPattern* \fIsh_stipple\fP);
void \fBstipple\fP (const char* \fIstipple_name\fP);
void \fBtsOrigin\fP (GNumber \fIx_origin\fP, GNumber \fIy_origin\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to modify field by field the \fIGPenValues\fP structure
of the referred \fIShPen\fP. Pre and postconditions are invoked.
It is recommended for performance reasons, to use \fImodify(mask, values)\fP when several
fields have to be modified, rather than calling the specific method for each field.
.RE
.sp 1
.IP
.nf
void \fBmodifyPrecond\fP (GBool (*\fIproc\fP)(void* \fIclosure\fP, const GPen* \fIpen\fP,
	ulong& \fImask\fP, GPenValues* \fInewValues\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBmodifyPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, const GPen* \fIpen\fP, ulong \fImask\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add or to remove pre or postcondition procedures when the \fIPen\fP is
modified. That means the referred \fIShPen\fP has been updated.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the \fIPen\fP will be modified. The precondition procedure is
called before the modification. It can either accept, refuse or force an other modification.
The postcondition procedure is invoked after the modification is done.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the pre/postcondition procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the modify
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp1
.IP
.nf
void \fBdestroyPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, const GPen* \fIpen\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP
This method allows to add or remove a callback procedure which will be called
when the \fIPen\fP will be destroyed.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the object will be destroyed.
The callback procedure is called \fIjust before\fP the destruction of the object. Its parameters are
the \fIclosure\fP and the object \fIPen\fP itself.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the
destruction callback list. If \fIadd\fP is GREMOVE, the callback procedure
\fIproc\fP will be removed from  the callback list.
.RE
.sp 1
.SH
\fBC BINDING\fP
.SS
\fBHeader File\fP
.IP
#include <Go/Tools/cPen.h>
.SS
\fBType Definitions\fP
.IP
The \fIShPen\fP C interface defines the \fIGPenValues\fP structure. This
structure is used by the \fIPen\fP C interface (see \fIShPen(3Go)\fP).
.SS
\fBC Functions\fP
.IP
GObjectId \fBGCreatePen\fP (ulong \fImask\fP, const GPenValues* \fIvalues\fP, const char* \fIname\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GPen (ulong \fImask\fP, const GPenValues* \fIvalues\fP, const char* \fIname\fP).
.RE
.sp 1
.IP
void \fBGDestroyPen\fP (GObjectId \fIpen\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP ~GPen ().
.RE
.sp 1
.IP
.nf
void \fBGModifyPen\fP (GObjectId \fIpen\fP, ulong \fImask\fP, const GPenValues* \fIvalues\fP);
void \fBGModifyPenFromName\fP (GObjectId \fIpen\fP, const char* \fIname\fP);
void \fBGModifyPenFromShPen\fP (GObjectId \fIpen\fP, const GObjectId \fIsh_pen\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP:
.nf
  void modify (ulong \fImask\fP, const GPenValues* \fIvalues\fP);
  void modify (const char* \fIname\fP);
  void modify (const GShPen* \fIsh_pen\fP);
.fi
.RE
.sp 1
.IP
.nf
const GPenValues* \fBGGetPenValues\fP (const GObjectId \fIpen\fP);
const GObjectId \fBGGetPenShPen\fP (const GObjectId \fIpen\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP:
.nf
   const GPenValues* values ();
   const GShPen* shPen ().
.fi
.RE
.sp 1
.IP
.nf
void \fBGModifyPenPrecond\fP (GObjectId \fIpen\fP, GAddOrRemove \fIadd\fP,
	GBool (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIpen\fP,
		ulong* \fImask\fP, GPenValues* \fIvalues\fP),
	const void* \fIclosure\fP);
void \fBGModifyPenPostcond\fP (GObjectId \fIpen\fP, GAddOrRemove \fIadd\fP,
	void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIpen\fP, ulong \fImask\fP),
	const void* \fIclosure\fP);
void \fBGDestroyPenPostcond\fP (GObjectId \fIpen\fP, GAddOrRemove \fIadd\fP,
	void (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIpen\fP),
	const void* \fIclosure\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP
.nf
   void modifyPrecond (GBool (*\fIfunction\fP)(void* \fIclosure\fP, const GPen* \fIpen\fP,
	ulong& \fImask\fP, GPenValues* \fInewValues\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;
   void modifyPostcond (void (*\fIfunction\fP)(void* \fIclosure\fP, const GPen* \fIpen\fP, ulong \fImask\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;   
   void destroyPostcond (void (*\fIfunction\fP)(void* \fIclosure\fP, const GPen* \fIpen\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;
.fi
.RE
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
The \fIPen\fP object is a non-shared object interface for the \fIShPen\fP object,
see the \fIShPen(3Go)\fP and \fISharedObject(3Go)\fP to know the shared object
usage.
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBBool(3Go), Number(3Go)\fP,
\fBSharedObject(3Go)\fP, \fBShPen(3Go)\fP.
.nrPN \n%
