.\" $Id: PxlArray.n,v 1.1.1.1 1992/03/18 09:47:38 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH PixelArray 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBPixelArray\fP \(em the pixel array object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/PixelArray.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBPixelArray\fP does not inherit behavior from any class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBPixelArray\fP object gives a non-shared object interface to the \fBShPixelArray\fP
object. As a \fIShPixelArray\fP, a \fIPixelArray\fP is defined by a set values
described in the \fIPixelArrayValues\fP structure (see \fIShPixelArray(3Go)\fP).
.sp 1
\fBGPixelArray\fP is the C++ type for the \fIPixelArray\fP object class.
.sp 1
.nf
.ta .15i .25i 1.50i
class GPixelArray {
	public:
		GPixelArray ();
		GPixelArray (const GPixelArray* \fIpxl_array\fP);
		GPixelArray (const GShPixelArray* \fIsh_pxl_array\fP);
		GPixelArray (ulong \fImask\fP, const GPixelArrayValues* \fIvalues\fP, const char* \fIname\fP = NULL, GDataSpace \fIcopy\fP = GDATA_COPY);
		GPixelArray (const char* \fIname\fP);
		~GPixelArray ();

		// Getting values
		const GShPixelArray* shPixelArray() const;
		const GPixelArrayValues* values() const;
		ulong mask () const;

		const char* name() const;
		GBool isNamed() const;

		ulong bytesPerLine () const;
		ulong dataSize () const;

		GShPixelArray* subPixelArray (ushort \fIx\fP, ushort \fIy\fP, ushort \fIwidth\fP, ushort \fIheight\fP) const;
		GShPixelArray* subPixelArray (GNumber \fIx\fP, GNumber \fIy\fP, GNumber \fIwidth\fP, GNumber \fIheight\fP) const;
		void subPixelArrayValues (ushort \fIx\fP, ushort \fIy\fP, ushort \fIwidth\fP, ushort \fIheight\fP,
			GPixelArrayValues& \fIvalues\fP) const;

		// Modifying methods
		void modify (ulong \fImask\fP, const GPixelArrayValues* \fIvalues\fP);
		void modify (const GShPixelArray* \fIsh_pattern\fP);
		void modify (const char* \fIname\fP);

		// Pre and Post Conditions
		void modifyPrecond (GBool (*\fIproc\fP)(void* \fIclosure\fP, GPixelArray* \fIpattern\fP,
			ulong& \fImask\fP, GPixelArrayValues* \fInew_values\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void modifyPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GPixelArray* \fIpixelArray\fP, ulong \fImask\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void destroyPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GPixelArray* \fIpixelArray\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
};
.fi
.sp 1
.SH
\fBGPixelArrayValues STRUCTURE\fP
.IP
\fISee ShPixelArray(3Go)\fP
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
.nf
\fBGPixelArray\fP ();
\fBGPixelArray\fP (const GPixelArray* \fIpxl_array\fP);
\fBGPixelArray\fP (const GShPixelArray* \fIsh_pxl_array\fP);
\fBGPixelArray\fP (ulong \fImask\fP, const GPixelArrayValues* \fIvalues\fP, const char* \fIname\fP = NULL, GDataSpace \fIcopy\fP);
\fBGPixelArray\fP (const char* \fIname\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to create a new \fIPixelArray\fP instance. The new \fIPixelArray\fP
points to a \fIShPixelArray\fP which may be shared between several other \fIPixelArray\fP
instances. When the \fIname\fP field is specified, a named \fIShPixelArray\fP
is explicitly referred. Specifying the values and the
name implies the corresponding named \fIShPixelArray\fP modification.
.IP \fIpxl_array\fP .5i
.br
Specifies the \fIPixelArray\fP used to initialize the new instance.
.IP \fIsh_pxl_array\fP .5i
Specifies the \fIShPixelArray\fP which will be pointed by the \fIPixelArray\fP. The
\fIShPixelArray\fP reference count is incremented.
.IP \fImask\fP .5i
.br
Specifies the value bitmask (see \fIShPixelArray(3Go)\fP).
.IP \fIvalues\fP .5i
.br
Specifies a \fIGPixelArrayValues\fP structure pointer. Valid fields are defined by
the \fImask\fP.
.IP \fIname\fP .5i
.br
Identifies the named \fIShPixelArray\fP which is called \fIname\fP. If such
\fIShPixelArray\fP does not exit it is created. If some values are
defined, the named \fIShPixelArray\fP will be modified.
.IP \fIcopy\fP .5i
Specifies if the \fIShPixelArray\fP data have to be duplicated (\fIGDATA_COPY\fP, a memory
allocation is performed), shared (\fIGDATA_SHARE\fP, the data can be used simultaneously
by the application and the \fIShPixelArray\fP) or given (\fIGDATA_GIFT\fP, the data
will be exclusively used by the \fIShPixelArray\fP). This parameter is very
useful for memory and time saving aspects. \fIGDATA_GIFT\fP value for this paramater
is the best choice.
.RE
.sp 1
.IP
\fB~GPixelArray\fP ();
.RS .8i
.IP \fIDescription\fP .5i
This method is called when a \fIPixelArray\fP instance is deleted. The corresponding
\fIShPixelArray\fP reference count is decremented. The \fIdestroyPostcond\fP callback,
if exits, is called \fIjust before\fP the deletion.
.RE
.sp 2
.IP
const GShPixelArray* \fBshPixelArray\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the \fIShPixelArray\fP associated to the \fIPixelArray\fP object.
.RE
.sp 1
.IP
const GPixelArrayValues* \fBvalues\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the pointer to the \fIPixelArray\fP values.
.RE
.sp 1
.IP
const char* \fBname\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the name of the associated \fIShPixelArray\fP or NULL.
.RE
.sp 1
.IP
GBool \fBisNamed\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This method return GTRUE, if the associated \fIShPixelArray\fP is
named, else it returns GFALSE.
.RE
.sp 1
.IP
.nf
ulong \fBbytesPerLine\fP () const;
.br
ulong \fBdataSize\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
These two methods allow to get information about the data memory storage:
the number of bytes per line and the effective data size.
.RE
.sp 1
.IP
.nf
GShPixelArray* \fBsubPixelArray\fP (ushort \fIx\fP, ushort \fIy\fP, ushort \fIwidth\fP, ushort \fIheight\fP) const;
GShPixelArray* \fBsubPixelArray\fP (GNumber \fIx\fP, GNumber \fIy\fP, GNumber \fIwidth\fP, GNumber \fIheight\fP) const;
void subPixelArrayValues (ushort \fIx\fP, ushort \fIy\fP, ushort \fIwidth\fP, ushort \fIheight\fP,
	GPixelArrayValues& \fIvalues\fP) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods return \fIShPixelArray's\fP extracted form the current \fIShPixelArray\fP
or the values of such \fIShPixelArray's\fP. The sub pixel array can be defined in
pixels (ushort) or in per cent (GNumber).
.IP "\fIx, y, whidth, height\fP" .5i
Specify the sub pixel array (either in pixels or percentages).
.IP \fIvalues\fP .5i
Specifies the GPixelArrayValues structure which will be used to store the
values of the extracted sub pixel array.
.RE
.sp 1
.IP
void \fBmodify\fP (ulong \fImask\fP, const GPixelArrayValues* \fIvalues\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to modify the \fIPixelArray\fP values. It calls the
\fImodify()\fP function of the associated \fIShPixelArray\fP. After this
call, the \fIShPixelArray\fP pointer may be different. The pre/post
conditions will be called if they exist.
.IP \fImask\fP .5i
.br
Specifies the value bitmask of the valid fields in the \fIGPixelArrayValues\fP
structure.
.IP \fIvalues\fP .5i
.br
Specifies the new values which will be assigned to the \fIPixelArray\fP.
.RE
.sp 1
.IP
void \fBmodify\fP (const GShPixelArray* \fIsh_pxl_array\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to modify the \fIPixelArray\fP object by changing
the \fIShPixelArray\fP pointed by the \fIPixelArray\fP. The pre/post conditions
are called if they exist.
.IP \fIsh_pxl_array\fP .5i
.br
Specifies the \fIShPixelArray\fP which has to replace the previous
\fIShPixelArray\fP contained in the \fIPixelArray\fP.
.RE
.sp 1
.IP
void \fBmodify\fP (const char* \fIname\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to (re)name the associated \fIShPixelArray\fP. If \fIname\fP
is NULL, a unnamed \fIShPixelArray\fP will be created.  The pre/post conditions
are invoked; the value mask is the complete named \fIShPixelArray\fP mask.
In preconditions functions, modifying the proposed values will imply the
named \fIShPixelArray\fP modification.
.IP \fIname\fP .5i
.br
Specifies the new name of the associated \fIShPixelArray\fP.
.RE
.sp 1
.IP
.nf
void \fBmodifyPrecond\fP (GBool (*\fIproc\fP)(void* \fIclosure\fP, GPixelArray* \fIpxl_array\fP,
	ulong& \fImask\fP, GPixelArrayValues* \fInew_values\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBmodifyPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GPixelArray* \fIpxl_array\fP, ulong \fImask\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These method allow to add or remove pre or post conditions on \fIPixelArray\fP modifying.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called before (pre-condition) or after (post-condition)
the modification. Its parameters are the \fIclosure\fP, the object \fIPixelArray\fP
itself and the modification \fImask\fP. For the pre-condition, if \fIproc\fP returns
GFALSE, the modification is nor proceeded. In addition, the precondition procedure
may modify the action (\fInew_values\fP).
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the condition
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp1
.IP
.nf
void \fBdestroyPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GPixelArray* \fIpxl_array\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP
This method allows to add or remove a callback procedure which will be called
when the object \fIpxl_array\fP will be destroyed.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the object will be destroyed.
The callback procedure is called \fIjust before\fP the destruction of the object. Its parameters are
the \fIclosure\fP and the object \fIPixelArray\fP itself.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the
destruction callback list. If \fIadd\fP is GREMOVE, the callback procedure
\fIproc\fP will be removed from  the callback list.
.RE
.sp 1
.SH
\fBC BINDING\fP
.SS
\fBHeader File\fP
.IP
#include <Go/Tools/cPixelArray.h>
.SS
\fBType Definitions\fP
.IP
The \fIShPixelArray\fP C interface defines the \fIGPixelArrayValues\fP structure. This
structure is used by the \fIPixelArray\fP C interface (see \fIShPixelArray(3Go)\fP).
.SS
\fBC Functions\fP
.IP
GObjectId \fBGCreatePixelArray\fP (ulong \fImask\fP, const GPixelArrayValues* \fIvalues\fP, const char* \fIname\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GPixelArray (ulong \fImask\fP, const GPixelArrayValues* \fIvalues\fP, const char* \fIname\fP).
.RE
.sp 1
.IP
void \fBGDestroyPixelArray\fP (GObjectId \fIpxl_array\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP ~GPixelArray ().
.RE
.sp 1
.IP
.nf
void \fBGModifyPixelArray\fP (GObjectId \fIpxl_array\fP, ulong \fImask\fP, const GPixelArrayValues* \fIvalues\fP);
void \fBGModifyPixelArrayFromName\fP (GObjectId \fIpxl_array\fP, const char* \fIname\fP);
void \fBGModifyPixelArrayFromShPixelArray\fP (GObjectId \fIpxl_array\fP, const GObjectId \fIsh_pxl_array\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP:
.nf
  void modify (ulong \fImask\fP, const GPixelArrayValues* \fIvalues\fP);
  void modify (const char* \fIname\fP);
  void modify (const GShPixelArray* \fIsh_pxl_array\fP);
.fi
.RE
.sp 1
.IP
.nf
const GPixelArrayValues* \fBGGetPixelArrayValues\fP (const GObjectId \fIpxl_array\fP);
const GObjectId \fBGGetPixelArrayShPixelArray\fP (const GObjectId \fIpxl_array\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP:
.nf
   const GPixelArrayValues* values ();
   const GShPixelArray* shPixelArray ().
.fi
.RE
.sp 1
.IP
.nf
void \fBGModifyPixelArrayPrecond\fP (GObjectId \fIpxl_array\fP, GAddOrRemove \fIadd\fP,
	GBool (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIpxl_array\fP,
		ulong* \fImask\fP, GPixelArrayValues* \fIvalues\fP),
	const void* \fIclosure\fP);
void \fBGModifyPixelArrayPostcond\fP (GObjectId \fIpxl_array\fP, GAddOrRemove \fIadd\fP,
	void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIpxl_array\fP, ulong \fImask\fP),
	const void* \fIclosure\fP);
void \fBGDestroyPixelArrayPostcond\fP (GObjectId \fIpxl_array\fP, GAddOrRemove \fIadd\fP,
	void (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIpxl_array\fP),
	const void* \fIclosure\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP
.nf
   void modifyPrecond (GBool (*\fIfunction\fP)(void* \fIclosure\fP, const GPixelArray* \fIpxl_array\fP,
	ulong& \fImask\fP, GPixelArrayValues* \fInewValues\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;
   void modifyPostcond (void (*\fIfunction\fP)(void* \fIclosure\fP, const GPixelArray* \fIpxl_array\fP, ulong \fImask\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;   
   void destroyPostcond (void (*\fIfunction\fP)(void* \fIclosure\fP, const GPixelArray* \fIpxl_array\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;
.fi
.RE
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
The \fIPixelArray\fP object is a non-shared object interface for the \fIShPixelArray\fP object,
see the \fIShPixelArray(3Go)\fP and \fISharedObject(3Go)\fP to know the shared object
usage.
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBBool(3Go)\fP, \fBNumber(3Go)\fP,
\fBSharedObject(3Go)\fP, \fBShPixelArray(3Go)\fP.
.nrPN \n%
