.\" $Id: Queue.n,v 1.1.1.1 1992/03/18 09:47:43 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH Queue 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBQueue\fP \(em the queue object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/Queue.h>\fP
.sp 1
.SH 
n\fBCLASS\fP
.IP
\fBQueue\fP does not inherit behavior from any class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBQueue\fP class implements a queue which can be updated (\fIput, get\fP)
either from the first element or from the last element. An element is seen as
a \fIvoid*\fP.
.sp 1
\fBGQueue\fP is the C++ type for the \fIQueue\fP object class.
.sp 1
.nf
.ta .15i .25i 1.50i
class GQueue {
	public:
		GQueue(int \fIinitial_size\fP = 32);
		~GQueue();

		GBool empty() const;
		int length() const;

		void* getfirst();
		void* getlast();
		void putfirst(void* \fIelement\fP);
		void putlast(void* \fIelement\fP);

		void putfirst(GQueue& \fIqueue\fP);
		void putlast(GQueue& \fIqueue\fP);

		void** arrayFromFirst(int& \fIcount\fP) const;
};
.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
\fBGQueue\fP (int \fIinitial_size\fP = 32);
.RS .8i
.IP \fIDescription\fP .5i
This method allow to create a new empty \fIQueue\fP instance.
.IP \fIinitial_size\fP .5i
Specifies the initial size of the queue (Default is 32).
.RE
.sp 1
.IP
\fB~GQueue\fP ();
.RS .8i
.IP \fIDescription\fP .5i
This method is called when a \fIQueue\fP instance is deleted.
.RE
.sp 1
.IP
GBool \fBempty\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns GTRUE if the queue is empty, else it
returns GFALSE.
.RE
.sp1
.IP
int \fBlength\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the actual size of the queue.
.RE
.sp 1
.IP
void* \fBgetfirst\fP();
.br
void* \fBgetlast\fP();
.RS .8i
.IP \fIDescription\fP .5i
These two methods allow to get the first (\fIgetfirst()\fP) or
the last (\fIgetlast()\fP) element of the queue. This element
is removed from the queue.
.RE
.sp 1
.IP
void \fBputfirst\fP(void* \fIelement\fP);
.br
void \fBputlast\fP(void* \fIelement\fP);
.RS .8i
.IP \fIDescription\fP .5i
These two methods allow to put at the beginning (\fIputfirst()\fP) or
at the end (\fIputlast()\fP) an element in the queue.
.IP \fIelement\fP .5i
.br
Specifies the element to be added in the queue.
.RE
.sp 1
.IP
void \fBputfirst\fP (GQueue& \fIqueue\fP);
.br
void \fBputlast\fP (GQueue& \fIqueue\fP);
.RS .8i
.IP \fIDescription\fP .5i
These two methods allow to move the \fIQueue queue\fP in the
\fIQueue this\fP either at the beginning (\fIputfirst()\fP)or at
the end (\fIputlast()\fP) of \fIthis\fP.
.IP \fIqueue\fP .5i
Specifies the queue to be moved into \fIthis\fP. It becomes empty.
.RE
.sp 1
.IP
void** \fBarrayFromFirst\fP (int& \fIcount\fP) const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns an array containing the queue (from the
first element).
.IP \fIcount\fP .5i
Receives the actual size of the returned array.
.RE
.sp 1
.SH
\fBC BINDING\fP
.IP
None.
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBBool(3Go)\fP.
.nrPN \n%
