.\" $Id: Region.n,v 1.1.1.1 1992/03/18 09:47:52 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH Region 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBRegion\fP \(em the region object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/Region.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBRegion\fP does not inherit anything from another class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBRegion\fP class is a list of boxes. It is also defined by the
outer box of this list of boxes. It defines to special \fIRegions\fP
which are \fIgEmptyRegion\fP and \fIgBiggestRegion\fP.
.sp 1
\fBGRegion\fP is the C++ type for the \fIRegion\fP object class.
.sp 1
.nf
.ta .15i .25i 1.50i
class GRegion {
	public:
		GRegion();
		GRegion(int \fIn\fP); // number of boxes allowed;
		GRegion(const GBox& \fIbox\fP);
		GRegion(const GRegion& \fIregion\fP);
		~GRegion();

		void operator = (const GRegion& \fIregion\fP);
		void operator = (const GBox& \fIbox\fP);

		friend GBool operator == (const GRegion& \fIr1\fP, const GRegion& \fIr2\fP);
		friend GBool operator != (const GRegion& \fIr1\fP, const GRegion& \fIr2\fP);
		friend GBool operator >= (const GRegion& \fIr1\fP, const GRegion& \fIr2\fP);
		friend GBool operator >  (const GRegion& \fIr1\fP, const GRegion& \fIr2\fP);
		friend GBool operator <= (const GRegion& \fIr1\fP, const GRegion& \fIr2\fP);
		friend GBool operator <  (const GRegion& \fIr1\fP, const GRegion& \fIr2\fP);
		friend GBool operator && (const GRegion& \fIr1\fP, const GRegion& \fIr2\fP);
		friend GBool operator && (const GRegion& \fIr\fP, const GBox& \fIbox\fP);

		void operator += (const GBox& \fIbox\fP);
		void operator += (const GRegion& \fIregion\fP);
		void operator -= (const GRegion& \fIregion\fP);

		friend void GAdd (const GRegion& \fIr1\fP, const GRegion& \fIr2\fP, GRegion& \fIresult\fP);
		friend void GSub (const GRegion& \fIr1\fP, const GRegion& \fIr2\fP, GRegion& \fIresult\fP);
		friend void GIntersect (const GRegion& \fIr1\fP, const GRegion& \fIr2\fP, GRegion& \fIresult\fP);

		const GBox& bigbox() const;
		GBool exist(int \fIn\fP) const;
		const GBox& box(int \fIn\fP) const;
		int numboxes() const;
		GBool empty() const;
		GBool contains(const GPoint& \fIpoint\fP, GNumber \fImaxdist\fP = 0) const;

		void setEmpty();
};
.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
.nf
\fBGRegion\fP();
\fBGRegion\fP(int \fIn\fP);
\fBGRegion\fP(const GBox& \fIbox\fP);
\fBGRegion\fP(const GRegion& \fIregion\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to create a new instance of the \fIRegion\fP class.
When no parameter is given, the empty region is created.
.IP \fIn\fP .5i
.br
Specifies the maximum number of boxes allowed in the region.
.IP \fIbox\fP .5i
.br
Specifies the \fIBox\fP which will constitute the first box of the region.
.IP \fIregion\fP .5i
Specifies the \fIRegion\fP which will be copied in order to
initialize the new created region.
.RE
.sp 1
.IP
\fB~GRegion\fP();
.RS .8i
.IP \fIDescription\fP .5i
This method is called when a \fIRegion\fP is deleted. Every box
contained in the region is also deleted.
.RE
.sp 1
.IP
void \fBoperator =\fP (const GRegion& \fIregion\fP);
.br
void \fBoperator =\fP (const GBox& \fIbox\fP);
.RS .8i
.IP \fIDescription\fP .5i
These two methods allow to assign a new value to the region.
The previous value is deleted.
.IP \fIregion\fP .5i
.br
Specifies the region to be used for initializing \fIthis\fP.
.IP \fIbox\fP .5i
.br
Specifies the box to be used to assign the region.
.RE
.sp 1
.IP
.nf
friend GBool \fBoperator ==\fP (const GRegion& \fIr1\fP, const GRegion& \fIr2\fP);
friend GBool \fBoperator !=\fP (const GRegion& \fIr1\fP, const GRegion& \fIr2\fP);
friend GBool \fBoperator >=\fP (const GRegion& \fIr1\fP, const GRegion& \fIr2\fP);
friend GBool \fBoperator >\fP  (const GRegion& \fIr1\fP, const GRegion& \fIr2\fP);
friend GBool \fBoperator <=\fP (const GRegion& \fIr1\fP, const GRegion& \fIr2\fP);
friend GBool \fBoperator <\fP  (const GRegion& \fIr1\fP, const GRegion& \fIr2\fP);
.fi
.RS 8i
.IP \fIDescription\fP .5i
These methods allow to compare two regions.
.IP "\fIr1, r2\fP" .5i
.br
Specify the two region to be compared.
.RE
.sp 1
.IP
.nf
friend GBool \fBoperator && (const GRegion& \fIr1\fP, const GRegion& \fIr2\fP);
friend GBool \fBoperator && (const GRegion& \fIr\fP, const GBox& \fIbox\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These two methods compute the intersection between two region or between
a region and a box.
.RE
.sp 1
.nf
void \fBoperator +=\fP (const GBox& \fIbox\fP);
void \fBoperator +=\fP (const GRegion& \fIregion\fP);
void \fBoperator -=\fP (const GRegion& \fIregion\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to add (or subtract) a box or a region to (from)
the region.
.IP \fIbox\fP .5i
.br
Specifies the \fIBox\fP to be added to the region.
.IP \fIregion\fP .5i
.br
Specifies the \fIRegion\fP to be added (or subtracted) to (from) the region.
.RE
.sp 1
.IP
.nf
friend void \fBGAdd\fP (const GRegion& \fIr1\fP, const GRegion& \fIr2\fP, GRegion& \fIresult\fP);
friend void \fBGSub\fP (const GRegion& \fIr1\fP, const GRegion& \fIr2\fP, GRegion& \fIresult\fP);
friend void \fBGIntersect\fP (const GRegion& \fIr1\fP, const GRegion& \fIr2\fP, GRegion& \fIresult\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to assign a new value to the region \fIresult\fP.
.IP "\fIr1, r2\fP" .5i
.br
Specify the two source region used to compute the value of \fIresult\fP.
.IP \fIresult\fP .5i
Specifies the \fIRegion\fP to be assigned with the result of the computation
between the two region \fIr1\fP and \fIr2\fP.
.RE
.sp 1
.IP
const GBox& \fBbigbox\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the outer box of the region.
.RE
.sp 1
.IP
GBool \fBexist\fP(int \fIn\fP) const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns GTRUE is a box exits at a given index in the
\fIRegion\fP box list.
.IP \fIn\fP .5i
.br
Specifies the box index.
.RE
.sp 1
.IP
const GBox& \fBbox\fP(int \fIn\fP) const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the \fIn\u\s4th\s0\d\fP box of the region.
.RE
.sp 1
.IP
int \fBnumboxes\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the box number of the region.
.RE
.sp 1
.IP
GBool \fBempty\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns GTRUE is the region is empty.
.RE
.sp 1
.IP
GBool \fBcontains\fP(const GPoint& \fIpoint\fP, GNumber \fImaxdist\fP = 0) const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns GTRUE is a point belongs to the region.
.IP \fIpoint\fP .5i
.br
Specifies the concerned point.
.IP \fImaxdist\fP .5i
.br
Specify the accepted tolerance.
.RE
.sp 1
.IP
void \fBsetEmpty\fP();
.RS .8i
.IP \fIDescription\fP .5i
This method clears out the region.
.RE
.sp 1
.IP
.sp 1
.SH
\fBC BINDING\fP
.SS
\fBHeader File\fP
.IP
#include <Go/Tools/cRegion.h>
.SS
\fBC Functions\fP
.IP
.nf
GObjectId \fBGCreateRegion\fP ();
GObjectId \fBGCreateRegionFromRegion\fP (GObjectId \fIregion\fP);
GObjectId \fBGCreateRegionFromBox\fP (GBox* \fIbox\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP
.nf
   GRegion();
   GRegion(const GRegion& \fIregion\fP);
   GRegion(const GBox& \fIbox\fP);
.fi
.RE
.sp 1
.IP
void \fBGDestroyRegion\fP (GObjectId \fIregion\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP ~GRegion();
.RE
.sp 1
.IP
GObjectId \fBGIntersectRegions\fP (const GObjectId \fIr1\fP, const GObjectId \fIr2\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP friend void intersect (const GRegion& \fIr1\fP, const GRegion& \fIr2\fP, GRegion& \fIresult\fP);
.RE
.sp 1
.IP
.nf
void \fBGSetRegionFromRegion\fP (GObjectId \fIregion\fP, GObjectId \fIsrcRegion\fP);
void \fBGSetRegionFromBox\fP (GObjectId \fIregion\fP, GBox* \fIbox\fP);
void \fBGResetRegion\fP (GObjectId \fIregion\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP
.nf
   void operator = (const GRegion& \fIsrcRegion\fP);
   void operator = (const GBox& \fIbox\fP);
   void setEmpty();
.RE
.sp 1
.IP
.nf
GBool \fBGIsRegionEqual\fP (const GObjectId \fIr1\fP, const GObjectId \fIr2\fP);
GBool \fBGIsRegionGreater\fP (const GObjectId \fIr1\fP, const GObjectId \fIr2\fP);
GBool \fBGIsRegionLess\fP (const GObjectId \fIr1\fP, const GObjectId \fIr2\fP);
GBool \fBGIsRegionInterRegion\fP (const GObjectId \fIr1\fP, const GObjectId \fIr2\fP);
GBool \fBGIsRegionInterBox\fP (const GObjectId \fIr\fP, const GBox* \fIbox\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP
.nf
   friend GBool operator == (const GRegion& \fIr1\fP, const GRegion& \fIr2\fP);
   friend GBool operator >  (const GRegion& \fIr1\fP, const GRegion& \fIr2\fP);
   friend GBool operator <  (const GRegion& \fIr1\fP, const GRegion& \fIr2\fP);
   friend GBool operator && (const GRegion& \fIr1\fP, const GRegion& \fIr2\fP);
   friend GBool operator && (const GRegion& \fIr\fP, const GBox& \fIbox\fP);
.fi
.RE
.sp 1
.IP
GBool \fBGIsPointInRegion\fP (const GObjectId \fIregion\fP, const GPoint \fIpoint\fP, GNumber \fImaxdist\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP GBool contains(const GPoint& \fIpoint\fP, GNumber \fImaxdist\fP) const;
.RE
.sp 1
.IP
.nf
void \fBGAddBoxToRegion\fP (GObjectId \fIregion\fP, GBox* \fIbox\fP);
void \fBGAddRegionToRegion\fP (GObjectId \fIregion\fP, GObjectId \fIsrcRegion\fP);
void \fBGRemRegionToRegion\fP (GObjectId \fIregion\fP, GObjectId \fIsrcRegion\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP
.nf
   void operator += (const GBox& \fIbox\fP);
   void operator += (const GRegion& \fIsrcRegion\fP);
   void operator -= (const GRegion& \fIsrcRegion\fP);
.fi
.RE
.sp 1
.IP
.nf
GBox \fBGBigBox\fP (const GObjectId \fIregion\fP);
int \fBGNumBoxes\fP (const GObjectId \fIregion\fP);
GBool \fBGIsEmptyRegion\fP (const GObjectId \fIregion\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP
.nf
   const GBox& bigbox() const;
   int numboxes() const;
   GBool empty() const;
.fi
.RE
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBBool(3Go)\fP,
\fBBox(3Go)\fP, \fBPoint(3Go)\fP, \fBVector(3Go)\fP and \fBNumber(3Go)\fP.
.nrPN \n%
