.\" $Id: ShArray.n,v 1.1.1.1 1992/03/18 09:48:01 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH ShArray 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBShArray\fP \(em the shared array object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/ShArray.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBShArray\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBSharedObject\fP class
.RE
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBShArray\fP object is defined by three values: a \fIdata\fP pointer, a number of \fIelements\fP and a \fIsize\fP of an element pointed to by \fIdata\fP. It useful to shared a same array. To match two arrays we use the \fImemcmp(3C)\fP function. Because the array is shared the \fIdata\fP points to a \fIread-only\fP memory. To modify  the \fIShArray\fP specific methods are implemented.
.IP
Note that the implemented interface is simplified. There is not specific interface to \fIdup\fP, to \fIrename\fP or create \fInamed\fP shared array. Like wise there is not specific interface to add or remove \fIpostcond\fP. If you want to do this, you have to use directly the \fIShAredObject\fP method which obliges to cast the \fIShArray\fP  to \fISharedObject\fP.
.sp 1
\fBGShArray\fP is the C++ type for the \fIShArray\fP object class.
.sp 1
.nf
.ta .15i .25i .50i
class GShArray : public GSharedObject {
public:
	friend GShArray* GCreateShArray (const GShArrayValues* values);
	friend GShArray* GCreateShArray (void* data, int nelems= 1, int elemsize = sizeof(void*));
	friend void GAddElem(GShArray*&, void* elem, int nelems_to_add = 1);
	friend void GRemElem(GShArray*&, int index, int nelems_to_free = 1);

	void* data();
	int nelems();
	int elemsize();

	static const char* classname ();
};
.fi
.sp 1
.SH
\fBGShArrayValues STRUCTURE\fP
.IP
This structure may be used when creating \fIShArray\fP. All members of the structure must be initialized.
.sp 1
\fIGShArrayValues\fP structure:
.sp 1
.nf
.ta .25i .60i 1.80i
struct GShArrayValues {
	void* data;
	int   elemsize;
	int   nelems;
} ;
.fi
.sp 1
.RS .8i
.IP \fIdata\fP .5i
.br
Specifies the \fIaddress\fP of the data you want to share.
.IP \fIelemsize\fP .5i
.br
Specifies the size of each element in byte.
.IP \fInelems\fP .5i
.br
Specifies the number of elements pointed to by \fIdata\fP.
.RE
.sp 1
\fBPUBLIC METHODS\fP
.IP
friend GShArray* \fBGCreateShArray\fP (GShArrayValues* \fIvalues\fP);
.br
friend GShArray* \fBGCreateShArray\fP (void* \fIdata\fP, int nelems= 1, int elemsize = sizeof(void*));
.RS .8i
.IP \fIDescription\fP .5i
These functions allow to create an instance of the \fIShArray\fP class. If the requested \fIShArray\fP exists, its reference count is incremented.
.IP \fIvalues\fP .5i
.br
Specifies a \fIShArrayValues\fP value structure pointer.
.IP "\fIdata, elemsize, nelems\fP" .5i
.br
Specify the \fIShArray\fP attributes instead of values.
.sp 1
.RE
.IP
friend void \fBGAddElem\fP (GShArray*& \fIsharray\fP, void* \fIelem\fP, int \fInelems_to_add\fP = 1);
.RS .8i
.IP \fIDescription\fP .5i
The function modifies the \fIsharray\fP by adding \fInelems_to_add\fP pointed to by \fIelems\fP at the \fBend\fP of the array.
.br
If the new array is found in the sharray list, his reference count is incremented by 1 and it is returned in \fIsharrray\fP. If the new array is not found and the current \fIsharray\fP reference count is 1 \fIsharray\fP is modified else a new instance is created and returned in \fIsharray\fP, the old instance is \fIdestroyed\fP.
.RE
.IP
friend void \fBGRemElem\fP (GShArray*&, int index, int nelems_to_free = 1);
.IP
.RS .8i
.IP \fIDescription\fP .5i
The function modifies the \fIsharray\fP by removing \fInelems_to_free\fP at \fIindex\fP of the array.
.br
If the new array is found in the sharray list, his reference count is incremented by 1 and it is returned in \fIsharrray\fP. If the new array is not found and the current \fIsharray\fP reference count is 1 \fIsharray\fP is modified else a new instance is created and returned in \fIsharray\fP, the old instance is \fIdestroyed\fP.
.RE
.IP
const void* \fBdata\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This function returns the data pointer. Note that \fIdata\fP is read only.
.RE
.sp 1
.IP
int \fBnelems\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This function returns the number of elements pointed to by \fIdata\fP.
.RE
.sp 1
.IP
int \fBelemsize\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This function returns the size in byte of an element pointed to by \fIdata\fP.
.RE
.sp 1
.IP
static const char* \fBclassname\fP ();
.RS .8i
.IP \fIDescription\fP .5i
This static method returns a pointer to the string \fI``GShArray''\fP.
.RE
.SH
\fBC BINDING\fP
.IP
None.
.SH
\fBUSAGE INFORMATION\fP
.IP
The \fIShArray\fP class is a subclass of \fIShAredObject\fP class. So, the \fIconstructor\fP
and \fIdestructor\fP methods are not public and the method \fIGCreateShArray()\fP
and \fIdestroy()\fP must be called instead of \fInew\fP and \fIdelete\fP.
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBSharedObject(3Go)\fP and \fBArray(3Go)\fP.
.nrPN \n%
