.\" $Id: ShBrush.n,v 1.1.1.1 1992/03/18 09:48:06 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH ShBrush 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBShBrush\fP \(em the shared brush object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/ShBrush.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBShBrush\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBSharedObject\fP class
.RE
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBShBrush\fP object is defined by a set of values which will be used by
a \fBGoInterf\fP instance for some drawings (see \fIGoInterf(3Go)\fP. These
values are described below in the \fIGBrushValues\fP structure. See also
\fIGCdef(3Go)\fP (which defines some constants used by \fIShBrush\fP) and
other graphic context objects (\fIShPen, ShTextBrush, ShImageBrush\fP).
.IP
The \fIShBrush\fP has default values: we can say the default \fIShBrush\fP
is \fIa black and solid brush\fP.
.IP
The \fIShBrush\fP object is a shared object (see \fISharedObject(3Go)\fP) and
may be shared between several other objects (e.g. \fIGo's\fP). The \fBBrush\fP
(See \fIBrush(3Go)\fP) gives a non-shared interface to the \fIShBrush\fP.
.sp 1
\fBGShBrush\fP is the C++ type for the \fIShBrush\fP object class.
.sp 1
.nf
.ta .15i .25i 1.0i
class GShBrush : public GSharedObject {
	public:
		friend GShBrush* GCreateShBrush ();
		friend GShBrush* GCreateShBrush (ulong \fImask\fP, const GBrushValues* \fIvalues\fP, const char* \fIname\fP = NULL);
		friend GShBrush* GCreateShBrush (const char* \fIname\fP);

		GShBrush* dup() const;
		GBool match (const GShBrush* \fIsh_brush\fP) const;
		void updatePostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GShBrush* \fIsh_brush\fP, ulong \fImask\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void destroyPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GShBrush* \fIsh_brush\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;

		// Getting values
		const GBrushValues* values() const;

		ulong function () const;
		ulong planeMask () const;
		const GShColor* color () const;
		const GShColor* altColor () const;

		ushort fillStyle () const;
		ushort fillRule () const;
		const GShPattern* tile () const;
		const GShPattern* stipple () const;
		GNumber xtsOrigin () const;
		GNumber ytsOrigin () const;

		// Modifying methods
		friend void GModify (GShBrush*& \fIsh_brush\fP, ulong \fImask\fP, const GBrushValues* \fIvalues\fP);
		friend void GRename (GShBrush*& \fIsh_brush\fP, const char* \fIname\fP);

		friend void GSetFunction (GShBrush*& \fIsh_brush\fP, ulong \fIfunction\fP);
		friend void GSetPlaneMask (GShBrush*& \fIsh_brush\fP, ulong \fIplane_mask\fP);
		friend void GSetColor (GShBrush*& \fIsh_brush\fP, const GShColor* \fIsh_color\fP);
		friend void GSetAltColor (GShBrush*& \fIsh_brush\fP, const GShColor* \fIsh_color\fP);

		friend void GSetFillStyle (GShBrush*& \fIsh_brush\fP, ushort \fIfill_style\fP);
		friend void GSetFillRule (GShBrush*& \fIsh_brush\fP, ushort \fIfill_rule\fP);
		friend void GSetTile (GShBrush*& \fIsh_brush\fP, const GShPattern* \fItile\fP);
		friend void GSetStipple (GShBrush*& \fIsh_brush\fP, const GShPattern* \fIstipple\fP);
		friend void GSetTsOrigin (GShBrush*& \fIsh_brush\fP, GNumber \fIx_origin\fP, GNumber \fIy_origin\fP);

		// updating named ShBrush
		friend void GModify (const char* \fIname\fP, ulong \fImask\fP, const GBrushValues* \fIvalues\fP);

		friend void GBrushFunction (const char* \fIname\fP, ulong \fIfunction\fP);
		friend void GBrushPlaneMask (const char* \fIname\fP, ulong \fIplane_mask\fP);
		friend void GBrushColor (const char* \fIname\fP, const GShColor* \fIsh_color\fP);
		friend void GBrushAltColor (const char* \fIname\fP, const GShColor* \fIsh_color\fP);

		friend void GBrushFillStyle (const char* \fIname\fP, ushort \fIfill_style\fP);
		friend void GBrushFillRule (const char* \fIname\fP, ushort \fIfill_rule\fP);
		friend void GBrushTile (const char* \fIname\fP, const GShPattern* \fItile\fP);
		friend void GBrushStipple (const char* \fIname\fP, const GShPattern* \fIstipple\fP);
		friend void GBrushTsOrigin (const char* \fIname\fP, GNumber \fIx_origin\fP, GNumber \fIy_origin\fP);

		static const char* classname();
};
.fi
.sp 1
.SH
\fBGBrushValues STRUCTURE\fP
.IP
This structure may be used when creating or modifying a \fIShBrush\fP
or a \fIBrush\fP (see \fIBrush(3Go)\fP) instance.
To set or to modify the brush characteristics, the appropriate members of
the \fBGBrushValues\fP structure and the corresponding value bitmask have to be
set before calling \fIGCreateShBrush()\fP or \fImodify()\fP methods.
If passed \fImask\fP is 0 values are set to \fIdefault values\fP.
.sp 1
\fBGBrushValues\fP structure:
.sp 1
.nf
.ta .25i .60i 1.80i
struct GBrushValues {
	ulong function;
	ulong plane_mask;
	GShColor* color;
	GShColor* alt_color;

	/* fill attributes */
	struct {
	    unsigned style : 2;
	    unsigned rule : 1;
	} fill;
	GShPattern* tile;
	GShPattern* stipple;
	GNumber ts_x_origin;
	GNumber ts_y_origin;
};
.fi
.sp 1
.RS .8i
.IP \fIfunction\fP .5i
.br
Defines the logical function allowing to combine the source and the destination
pixel values. Possible values are described in \fIGCdef(3Go)\fP, the value
for the default brush is \fIGCOPY\fP.
.IP \fIplane_mask\fP .5i
.br
Determines which planes of the output device will be affected by the drawing.
The value for the default brush is \fIGALL_PLANES\fP.
.IP \fIcolor\fP .5i
.br
Gives the color used by most of drawings. The value of the default brush is
``black'' (Rgb = (0, 0, 0)).
.IP \fIalt_color\fP .5i
.br
Gives the color used when the file style is \fIGFILL_OPAQUE_STIPPLED\fP for unset
bits of the stipple. There is no value for the default brush.
.IP \fIfill.style\fP .5i
.br
Determines if areas are filled using either a color, or a tile or a
stipple. Possible values are described in \fIGCdef(3Go)\fP. The value
for the default brush is \fIGFILL_SOLID\fP (i.e. areas are filled with
the color specified in the \fIcolor\fP field).
.IP \fIfill.rule\fP .5i
.br
Determines if overlapped areas, when drawing polygons are drawn or not
(see GCdef(3Go)). The value for the default brush is \fIGEVEN_ODD_RULE\fP,
that means if areas overlap an odd number of times, they are not drawn.
.IP \fItile\fP .5i
.br
Specifies the pattern (\fIShPattern\fP) used when the fill style is
\fIGFILL_TILED\fP. There is no value for the default brush.
.IP \fIstipple\fP .5i
.br
Specifies the 1-bit-depth pattern (monochorome \fIShPattern\fP) used
when the fill style is either \fIGFILL_STIPPLED\fP or \fIGFILL_OPAQUE_STIPPLED\fP.
There is no value for the default brush.
.IP "\fIts_x_origin, ts_y_origin\fP" .5i
Specify the origin (expressed in the absolute coordinate system) of both the \fItile\fP and
the \fIstipple\fP when they are used. The values for the default brush are
(0., 0.).
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
.nf
friend GShBrush* \fBGCreateShBrush\fP ();
friend GShBrush* \fBGCreateShBrush\fP (ulong \fImask\fP, const GBrushValues* \fIvalues\fP, const char* \fIname\fP = NULL);
friend GShBrush* \fBGCreateShBrush\fP (const char* \fIname\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to create instances of the \fIShBrush\fP class. Without any parameter
the default brush is returned. If the requested shared brush already exists, its reference
count is incremented and it is returned.
.IP \fImask\fP .5i
.br
Specifies the value bitmask, making valid \fIvalues\fP fields.
.IP \fIvalues\fP .5i
.br
Specifies a pointer to a \fIGBrushValues\fP structure.
.IP \fIname\fP .5i
.br
Specifies the name of the shared brush. If such a named shared brush exists, it
is returned, else a named shared brush is created. If the name parameter is given
with \fImask\fP and \fIvalues\fP, the concerned named shared brush is modified. 
.RE
.sp 1
.IP
GShBrush* \fBdup\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the current \fIShBrush\fP object but increments its
reference count. It allows to modify a copy of a shared \fIShBrush\fP instance.
For instance, this method is used when creating a \fIBrush\fP from an existing
\fIShBrush\fP (see \fIBrush(3Go)\fP).
.RE
.sp 1
.IP
GBool \fBmatch\fP (const GShBrush* \fIsh_brush\fP) const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns GTRUE if the given \fIShBrush\fP object values match the values
of the current object; that means either the two values mask does not intersect,
or if the masks intersect, the corresponding values are equal.
.IP \fIsh_brush\fP .5i
.br
Specifies the \fIShBrush\fP object used for the matching operation.
.RE
.sp 1
.IP
.nf
void \fBupdatePostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GShBrush* \fIsh_brush\fP, ulong \fImask\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method allows to add or to remove postcondition procedures when the \fBShBrush\fP is
updated. That means the \fImodify()\fP method has been applied on the current object. In other
terms, when the reference count of a shared object is 1 and if no other shared object \fImatches\fP
the modification, the current object can be directly updated.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the object will be updated. Postcondition procedures are
called after the modification is done. Its parameters are the \fIclosure\fP, the shared object \fIShBrush\fP
itself and the update \fImask\fP. The \fImask\fP determines the modified field only.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the postcondition procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the postcondition procedure \fIproc\fP will be added to the update
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp1
.IP
.nf
void \fBdestroyPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GShBrush* \fIsh_brush\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method allows to add or remove a postcondition procedures which will be called
when the shared object \fIShBrush\fP is destroyed.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the object will be destroyed.
DestroyPostcond procedures are called \fIjust before\fP the destruction of the object. Their parameters are
the \fIclosure\fP and the shared object \fIsh_brush\fP itself.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the
destruction callback list. If \fIadd\fP is GREMOVE, the callback procedure
\fIproc\fP will be removed from  the callback list.
.RE
.sp1
.IP
const GBrushValues* \fBvalues\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns a pointer to the values structure of the \fIShBrush\fP.
.RE
.sp 1
.IP
.nf
ulong \fBfunction\fP () const;
ulong \fBplaneMask\fP () const;
const GShColor* \fBcolor\fP () const;
const GShColor* \fBaltColor\fP () const;
.sp 1
ushort \fBfillStyle\fP () const;
ushort \fBfillRule\fP () const;
const GShPattern* \fBtile\fP () const;
const GShPattern* \fBstipple\fP () const;
GNumber \fBxtsOrigin\fP () const;
GNumber \fBytsOrigin\fP () const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to get field by field the values of the \fIShBrush\fP.
These fields are valid, only if the corresponding bits are set in the mask
(\fImask()\fP).
.RE
.sp 1
.IP
friend void \fBGModify\fP (GShBrush*& \fIsh_brush\fP, ulong \fImask\fP, const GBrushValues* \fIvalues\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to modify a shared brush. If the modified \fIShBrush\fP matches an already
existing \fIShBrush\fP, its reference count is incremented and it is returned in \fIsh_brush\fP.
If \fIthis\fP is named, the modification is done directly on it. When a shared object
is effectively updated, the postcondition callbacks are invoked.
.IP \fIsh_brush\fP .5i
.br
Specifies the shared brush to be modified. This pointer may be modified.
.IP "\fImask, values\fP"
.br
Specify which fields in the values structure have to be modified and how.
.RE
.sp 1
.IP
.nf
friend void \fBGSetFunction\fP (GShBrush*& \fIsh_brush\fP, ulong \fIfunction\fP);
friend void \fBGSetPlaneMask\fP (GShBrush*& \fIsh_brush\fP, ulong \fIplane_mask\fP);
friend void \fBGSetColor\fP (GShBrush*& \fIsh_brush\fP, const GShColor* \fIsh_color\fP);
friend void \fBGSetAltColor\fP (GShBrush*& \fIsh_brush\fP, const GShColor* \fIsh_color\fP);
.sp 1
friend void \fBGSetFillStyle\fP (GShBrush*& \fIsh_brush\fP, ushort \fIfill_style\fP);
friend void \fBGSetFillRule\fP (GShBrush*& \fIsh_brush\fP, ushort \fIfill_rule\fP);
friend void \fBGSetTile\fP (GShBrush*& \fIsh_brush\fP, const GShPattern* \fItile\fP);
friend void \fBGSetStipple\fP (GShBrush*& \fIsh_brush\fP, const GShPattern* \fIstipple\fP);
friend void \fBGSetTsOrigin\fP (GShBrush*& \fIsh_brush\fP, GNumber \fIx_origin\fP, GNumber \fIy_origin\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to modify field by field the \fIShBrush\fP values structure. These methods
behave like the \fImodify()\fP method when only only bit is set in the mask. For performance
reasons, the \fIGModify()\fP method should be preferred when several fields have to be modified
.RE
.sp 1
.IP
friend void \fBGRename\fP (GShBrush*& \fIsh_brush\fP, const char* \fIname\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to (re)name a shared brush. If such a named object exists, it is
returned in \fIsh_brush\fP (updatePostcond are invoked), else a new named shared brush
is created (its reference count is 1 and its values are the current values).
.IP \fIsh_brush\fP
.5i
Specifies the shared brush to be named.
.IP \fIname\fP .5i
.br
Specifies the new name. It may be NULL, in that case, the named shared brush becomes
unnamed.
.RE
.sp 1
.IP
friend void \fBGModify\fP (const char* \fIname\fP, ulong \fImask\fP, const GBrushValues* \fIvalues\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to update a named shared brush. If such a named shared brush does not
exists, it is created. Update postconditions are invoked.
.IP \fIname\fP .5i
.br
Identifies the named shared brush.
.IP "\fImask, values\fP" .5i
.br
Specify which fields in the values structure have to be modified and how.
.RE
.sp 1
.IP
.nf
friend void \fBGBrushFunction\fP (const char* \fIname\fP, ulong \fIfunction\fP);
friend void \fBGBrushPlaneMask\fP (const char* \fIname\fP, ulong \fIplane_mask\fP);
friend void \fBGBrushColor\fP (const char* \fIname\fP, const GShColor* \fIsh_color\fP);
friend void \fBGBrushAltColor\fP (const char* \fIname\fP, const GShColor* \fIsh_color\fP);
.sp 1
friend void \fBGBrushFillStyle\fP (const char* \fIname\fP, ushort \fIfill_style\fP);
friend void \fBGBrushFillRule\fP (const char* \fIname\fP, ushort \fIfill_rule\fP);
friend void \fBGBrushTile\fP (const char* \fIname\fP, const GShPattern* \fItile\fP);
friend void \fBGBrushStipple\fP (const char* \fIname\fP, const GShPattern* \fIstipple\fP);
friend void \fBGBrushTsOrigin\fP (const char* \fIname\fP, GNumber \fIx_origin\fP, GNumber \fIy_origin\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to modify field by field the named \fIShBrush\fP values structure. These methods
behave like the previous \fIGModify()\fP method when only only bit is set in the mask. For performance
reasons, the \fIGModify()\fP method should be preferred when several fields have to modified
.RE
.sp 1
.IP
static const char* \fBclassname\fP();
.RS .8i
.IP \fIDescription\fP .5i
This function returns a pointer to the string \fI``GShBrush''\fP.
.RE
.sp 1
.SH
\fBC BINDING\fP
.SS
\fBHeader File\fP
.IP
#include <Go/Tools/cShBrush.h>
.SS
\fBType Definitions\fP
.IP.nf
.ta .15i .25i 1.0i
typedef struct _GBrushValues
{
    ulong function;
    ulong plane_mask;
    GObjectId color;
    GObjectId alt_color;

    struct {
       unsigned style : 2;
       unsigned rule : 1;
    } fill;
    GObjectId tile;
    GObjectId stipple;
    GNumber   ts_x_origin;
    GNumber   ts_y_origin;
} GBrushValues;
.fi
\fISee GBrushValues STRUCTURE section and GCdef(3Go).\fP
.SS
\fBC Functions\fP
.IP
GObjectId \fBGGetNamedShBrush\fP (const char* \fIname\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP friend GShBrush* GCreateShBrush (const char* \fIname\fP.
.RE
.sp 1
.IP
void \fBGModifyShBrushByName\fP (const char* \fIname\dP, ulong \fImask\fP, const GBrushValues* \fIvalues\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP friend GModify (const char* \fIname\fP, ulong \fImask\fP, const GBrushValues* \fIvalues\fP);
.RE
.sp 1
.IP
const GBrushValues* \fBGGetShBrushValues\fP (const GObjectId \fIsh_brush\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP const GBrushValues* values();
.RE
.sp 1
.IP
const char* GShBrushClassName ();
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP const char* classname();
.RE
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
The \fBShBrush\fP class is a subclass of \fISharedObject\fP class. So, the \fIconstructor\fP
and \fIdestructor\fP methods are not public and the method \fIGCreateShBrush()\fP
and \fIdestroy()\fP must be called instead of \fInew\fP and \fIdelete\fP.
See also \fBBrush(3Go)\fP which is a non-shared object using a \fBShBrush\fP object.
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBBrush\fP, \fBGoInterf\fP, \fBGCdef(3Go)\fP, \fBSharedObject\fP, \fBShColor\fP and \fBShPattern\fP classes.
.nrPN \n%
