.\" $Id: ShColor.n,v 1.2 1992/07/20 07:39:30 smadja Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH ShColor 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBShColor\fP \(em the shared color object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/ShColor.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBShColor\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBSharedObject\fP class
.RE
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBShColor\fP object is defined by a set of three values, each representing
the color value depending of the output device capabilities (color, gray scale
or black and white). So, when something is drawn, the \fBGoInterf\fP
will use the appropriate value of the color according to the output
device capabilities. If the appropriate value is not defined, the
\fBGoInterface\fP will take the best decision.
.IP
The three color values are: \fBRgb\fP value, \fBGray\fP value, \fBHalftone\fP
value. The Rgb value contains the red, green and blue intensities, the Gray
value defines the gray level (0 is black, 0xff is white), the Halftone is
a pattern used to simulate a color on a black and white screen.
.IP
The \fBShColor\fP object is a shared object (see \fISharedObject(3Go)\fP) and
may be shared between several \fBGos\fP or \fIColormap\fP (see
\fIColormap(3Go)\fP).
.sp 1
\fBGShColor\fP is the C++ type of the \fIShColor\fP object class.
.sp 1
.nf
.ta .15i .25i .50i
class GShColor : public GSharedObject {
	public:
		friend GShColor* GCreateShColor ();
		friend GShColor* GCreateShColor (ulong \fImask\fP, const GColorValues* \fIvalues\fP,
			const char* \fIname\fP = NULL);
		friend GShColor* GCreateShColor (const GRgb* \fIrgb\fP);
		friend GShColor* GCreateShColor (uchar \fIgray\fP, const char* \fIname\fP = NULL);
		friend GShColor* GCreateShColor (const GShPattern* \fIhalftone\fP, const char* \fIname\fP = NULL);
		friend GShColor* GCreateShColor (const char* \fIname\fP);

		friend void GModify (GShColor*& \fIsh_color\fP, ulong \fImask\fP, const GColorValues* \fIvalues\fP);
		friend void GModify (const char* \fIname\fP, ulong \fImask\fP, const GColorValues* \fIvalues\fP);
		friend void GRename (GShColor*& \fIsh_color\fP, const char* \fIname\fP); 
		GShColor* dup () const;
		GBool match (const GShColor* \fIcolor\fP) const;

		void updatePostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GShColor* \fIsh_color\fP, ulong \fImask\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void incrRefPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GShColor* \fIsh_color\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void decrRefPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GShColor* \fIsh_color\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void destroyPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GShColor* \fIsh_color\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;

		const GColorValues* values () const;
		const GRgb* rgb() const;
		uchar gray() const;
		const GShPattern* halftone() const;
		GRgbValue brightness() const;
		static const char* classname();
};

GRgbValue GBrightness(GRgbValue red, GRgbValue green, GRgbValue blue);

.fi
.sp 1
.SH
\fBGRgb STRUCTURE\fP
.IP
This structure is used to set the red, green and blue intensities of the
color.
.sp 1
.nf
.ta .25i .60i 1.80i
struct GRgb {
	GRgbValue red;
	GRgbValue green;
	GRgbValue blue;

	GRgb ();
	GRgb (GRgbValue \fIred\fP, GRgbValue \fIgreen\fP, GRgbValue \fIblue\fP);
	GRgb (GRgb& \fIrgb\fP);
};
.fi
.sp 1
.RS .8i
.IP "\fIred, green, blue\fP" .5i
.br
Specify the three intensities from 0 to 65536.
.IP \fIGRgb()\fP .5i
.br
Is the constructor of the structure, it may be used (with parameters) to set the three R-G-B values.
.RE
.sp 1
.SH
\fBGColorValues STRUCTURE\fP
.IP
This structure may be used when creating or modifying a \fIShColor\fP
or \fIColor\fP (see \fIColor(3Go)\fP) instance.
To set or to modify the color characteristics, the appropriate members of
the \fBGColorValues\fP structure and the corresponding value bitmask have to be
set before calling \fIGCreateShColor()\fP or \fIGModify()\fP methods.
If the \fImask\fP is 0  the color will be undefined.
.sp 1
\fBGColorValues\fP structure:
.sp 1
.nf
.ta .25i .60i 1.80i
struct GColorValues {
	GRgb rgb;
	uchar gray;
	GShPattern* halftone;
} ;
.fi
.sp 1
.RS .8i
.IP \fIrgb\fP .5i
.br
Specifies the R-G-B- values which will be used on a color screen.
.IP \fIgray\fP .5i
.br
Specifies the gray value which will be used on a gray scale screen. 0 is
black and 0xff is white.
.IP \fIhalftone\fP .5i
.br
Specifies the monochrome pattern which will be used to paint the color
on a black and white screen.
.RE
.IP
.sp 1
\fBColor value mask bits\fP:
.sp 1
.sp 1
.nf
.ta .25i 1.5i 2.5i
	#define GCOLOR_RGB	(1L<<0)
	#define GCOLOR_GRAY	(1L<<1)
	#define GCOLOR_HALFTONE	(1L<<2)
.fi
.sp 1
.SH
\fBPUBLIC FUNCTIONS\fP
.IP
GRgbValue \fBGBrightness\fP (GRgbValue \fIred\fP, GRgbValue \fIgreen\fI, GRgbValue \fIblue\fP);
.RS .8i
.IP \fIDescription\fP .5i
The function returns the brightness of the rgb defined by the triple (\fIred,green,blue\fP).
It uses the YIQ model to compute it.
.SH
\fBPUBLIC METHODS\fP
.IP
friend GShColor* \fBGCreateShColor\fP ();
.br
friend GShColor* \fBGCreateShColor\fP (ulong \fImask\fP, const GColorValues* \fIvalues\fP, const char* \fIname\fP);
.br
friend GShColor* \fBGCreateShColor\fP (const GRgb* \fIrgb\fP, const char* \fIname\fP);
.br
friend GShColor* \fBGCreateShColor\fP (uchar \fIgray\fP, const char* \fIname\fP);
.br
friend GShColor* \fBGCreateShColor\fP (const GShPattern* \fIhalftone\fP, const char* \fIname\fP);
.br
friend GShColor* \fBGCreateShColor\fP (const char* \fIname\fP);
.RS .8i
.IP \fIDescription\fP .5i
These functions allow to create an instance of the \fIShColor\fP class. Some values may be set at the
creation time. If the requested \fIShColor\fP exists, its reference count is incremented and its
reference is yielded. When the \fIname\fP is present, a \fInamed ShColor\fP is referred.
.IP \fImask\fP .5i
.br
Specifies the value bitmask.
.IP \fIvalues\fP .5i
.br
Specifies a \fBGColorValues\fP value structure pointer.
.IP "\fIrgb, gray, halftone\fP" .5i
.br
Specify the \fIShColor\fP attributes.
.IP \fIname\fP .5i
.br
Specifies the name of the \fIShColor\fP.
.RE
.sp 1
.IP
friend void \fBGModify\fP (GShColor*& \fIsh_color\fP, ulong \fImask\fP, const GColorValues* values)
.RS .8i
.IP \fIDescription\fP .5i
This function allows to modify the color values. Like other shared
objects (see \fISharedObject(3Go)\fP), the modification function returns the
new \fIShColor\fP object (possibly the same). The rgb, pattern and name may
be freed after the modification.
.IP \fIsh_color\fP .5i
.br
Specifies the \fIShColor\fP object reference which has to be modified.
.IP \fImask\fP .5i
.br
Specifies the value bitmask for the modification.
.IP \fIvalues\fP .5i
.br
Specifies a \fBGColorValues\fP structure pointer. The fields of this
structure corresponding to the mask contain the new values.
.RE
.sp1
.IP
friend void \fBGModify\fP (const char* \fIname\fP, ulong \fImask\fP, const GColorValues* \fIvalues\fP)
.RS .8i
.IP \fIDescription\fP .5i
This function allows to modify a \fIShColor\fP object referred by its name.
.IP \fIname\fP .5i
Identifies the \fIShColor\fP. It it does not exist, it is created.
.IP \fImask\fP .5i
.br
Specifies the value bitmask for the modification.
.IP \fIvalues\fP .5i
.br
Specifies a \fIGColorValues\fP structure pointer. The fields of this
structure corresponding to the mask contain the new values.
.RE
.sp 1
.IP
friend void \fBGRename\fP (GShColor*& \fIsh_color\fP, const char* \fIname\fP)
.RS .8i
.IP \fIDescription\fP .5i
This function allows to (re)name a \fIShColor\fP. If the reference count is
greater than 1, a new \fIShColor\fP is looked for matching and a new instance
may created.
.IP \fIsh_color\fP .5i
Specifies the concerned \fIShColor\fP instance.
.IP \fIname\fP .5i
.br
Specifies the new name, it may be NULL.
.RE
.sp 1
.IP
GShColor* \fBdup\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This function returns the current \fIShColor\fP object but increments the
reference count. It allows to modify a copy of a shared \fIShColor\fP instance.
.RE
.sp1
.IP
GBool \fBmatch\fP (const GShColor* \fIsh_color\fP) const
.RS .8i
.IP \fIDescription\fP .5i
This function returns GTRUE if the given \fIShColor\fP object values match the values of
the current object; that means either the two values mask does not intersect, or
if the masks intersect, the corresponding values are the same.
.IP \fIsh_color\fP .5i
.br
Specifies the \fIShColor\fP object used to proceed the matching operation.
.RE
.sp1
.IP
.nf
void \fBupdatePostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GShColor* \fIsh_color\fP, ulong \fImask\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const
.fi
.RS .8i
.IP \fIDescription\fP
This method allows to add or to remove postcondition procedures when the shared object \fIShColor\fP is
updated. That means the \fIGModify()\fP method has been applied on the current object. In other
terms, when the reference count of a shared object is 1 and if no other shared object \fImatches\fP
the modification, the current object can be directly updated.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the object will be updated. Postcondition procedures are
called after the modification is done. Their parameters are the \fIclosure\fP, the shared object \fIShColor\fP
itself and the update \fImask\fP. The \fImask\fP determines the modified field only.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the postcondition procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the postcondition procedure \fIproc\fP will be added to the update
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp1
.IP
.nf
void \fBincrRefPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP,GShColor* \fIsh_color\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBdecrRefPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GShColor* \fIsh_color\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP
This function allows to add or to remove a callback procedure which will be called
when the shared object \fIShColor\fP
reference count is incremented or decremented. The reference count may be modified when
\fIGCreateShColor(), GModify(), dup() and destroy()\fP methods are called.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the object reference count will be modified.
The callback procedure is called after the increment/decrement. Its parameters are
the \fIclosure\fP and the shared object \fIsh_color\fP itself.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the
increment/decrement callback lists. If \fIadd\fP is GREMOVE, the callback procedure
\fIproc\fP will be removed from  the callback list.
.RE
.sp1
.IP
.nf
void \fBdestroyPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GShColor* \fIsh_color\fP, ulong \fImask\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method allows to add or remove postcondition procedures which will be called
when the shared object \fIShColor\fP is destroyed.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the object will be destroyed.
DestroyPostcond procedures are called \fIjust before\fP the destruction of the object. Their parameters are
the \fIclosure\fP and the shared object \fIsh_color\fP itself.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the
destruction callback list. If \fIadd\fP is GREMOVE, the callback procedure
\fIproc\fP will be removed from  the callback list.
.RE
.sp1
.IP
const GColorValues* \fBvalues\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This function returns the \fBGColorValues\fP structure of the \fIShColor\fP.
.RE
.sp 1
.IP
const GRgb* \fBrgb\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This function returns the rgb values of the \fIShColor\fP. It may be NULL if the
rgb field is not valid.
.RE
.sp 1
.IP
int \fBgray\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This function returns the gray value (<256) of the \fIShColor\fP. It may be -1, if
the gray level is not defined.
.RE
.sp 1
.IP
const GShPattern* \fBhalftone\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This function returns the gray value of the color, this pattern cannot
be modified. It may be NULL, if the halftone is not defined in the \fIShColor\fP.
.RE
.sp 1
.IP
GRgbValue \fBbrightness\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This function returns the brightness of the color. If GCOLOR_GRAY
is specified it uses the gray level. If GCOLOR_GRAY is not specified and GCOLOR_RGB
is returns the brightness od the color using the YIQ model else it returns 0.
.br
The result is in the range [0...GMAX_RGB_VALUE].
.RE
.sp 1
.IP
static const char* \fBclassname\fP ();
.RS .8i
.IP \fIDescription\fP .5i
This static method returns a pointer to the string \fI``GShColor''\fP.
.RE
.sp 1
.SH
\fBC BINDING\fP
.SS
\fBHeader file\fP
.IP
#include <Go/Tools/cShColor.h>
.SS
\fBType Definitions\fP
.IP
.nf
.ta .15i .25i 1.0i
typedef ushort GRgbValue;

#define GMAX_RGB_VALUE			((GRgbValue)-1)

typedef struct _GRgb {
	GRgbValue red;
	GRgbValue green;
	GRgbValue blue;
} GRgb;

(\fISee GRgb STRUCTURE section\fP).

#define GCOLOR_RGB			(1L<<0)
#define GCOLOR_GRAY			(1L<<1)
#define GCOLOR_HALFTONE			(1L<<2)

typedef struct _GColorValues
{
	GRgb rgb;
	uchar gray;
	GObjectId halftone;
} GColorValues;

(\fISee GColorValues STRUCTURE section\fP)
.SS
\fBC Functions\fP
.IP
GObjectId \fBGGetNamedShColor\fP (const char* \fIname\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GShColor* GCreateShColor (const char* \fIname\fP).
.RE
.sp 1
.IP
void \fBGModifyShColorByName\fP (const char* \fIname\fP, ulong \fImask\fP, const GColorValues* \fIvalues\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: void modify (const char* \fIname\fP, ulong \fImask\fP, const GColorValues* \fIvalues\fP).
.RE
.sp 1
.IP
const GColorValues* \fBGGetShColorValues\fP (const GObjectId \fIsh_color\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP const GColorValues* values().
.RE
.sp 1
.IP
const char* \fBGShColorClassName\fP ();
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP static const char* classname();
.RE
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
The \fIShColor\fP class is a subclass of \fISharedObject\fP class. So, the \fIconstructor\fP
and \fIdestructor\fP methods are not public and the method \fIGCreateShColor()\fP
and \fIdestroy()\fP must be called instead of \fInew\fP and \fIdelete\fP.
See also \fIColor(3Go)\fP which is a non-shared object using a \fIShColor\fP object.
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBSharedObject(3Go)\fP, \fBShColormap(3Go)\fP, \fBColor(3Go)\fP, \fBGoInterf(3Go)\fP.
.nrPN \n%
