.\" $Id: ShDash.n,v 1.1.1.1 1992/03/18 09:48:24 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH ShDash 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBShDash\fP \(em the shared dash object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/ShDash.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBShDash\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBSharedObject\fP class.
.RE
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBShDash\fP object is defined by a set of three values: \fIdash_offset, dash_number
dash_list\fP. These three values are gathered in a structure called \fIDashValues\fP
(see below).
.IP
The \fIdash_list\fP value is a list of dash element (dash or gap),
each element is a number representing the size in millimeters of the dash/gap.
The initial (0) and the alternating elements (2, 4, ...) are the even dashes/gaps,
the others are the odd dashes/gaps. The \fIdash_number\fP value is the number of elements
in the dash list.
The \fIdash_offset\fP value specifies the first element used in the drawing.
.IP
A \fIShDash\fP object is normally used in a \fBShPen\fP object when the line style is
\fILineOnOffDash\fP or \fILineDoubleDash\fP. When the line style is \fILineOnOffDash\fP,
the odd dashes are used as gaps. When the line style is \fILineDoubleDash\fP, both
are used.
.IP
The \fIShDash\fP object is a shared object (see \fISharedObject(3Go)\fP) and
may be shared between several \fBShPen\fP (see \fIShPen(3Go)\fP). The object
\fIDash\fP is the \fInon-shared\fP interface for \fIShDash\fP (see \fIDash(3Go)\fP).
.sp 1
\fBGShDash\fP is the C++ type for the \fIShDash\fP object class.
.sp 1
.nf
.ta .15i .25i 1.0i
class GShDash : public GSharedObject {
	public:
		GShDash* GCreateShDash (ulong \fImask\fP, const GDashValues* \fIvalues\fP, const char* \fIname\fP = NULL);
		GShDash* GCreateShDash (const char* \fIname\fP);

		friend void GModify (GShDash*& \fIsh_dash\fP, ulong \fImask\fP, const GDashValues* \fIvalues\fP);
		friend void GModify (const char* \fIname\fP, ulong \fImask\fP, const GDashValues* \fIvalues\fP);
		friend void GRename (GShDash*& \fIsh_dash\fP, const char* \fIname\fP);

		GShDash* dup () const;
		GBool match (const GShDash* \fIsh_dash\fP) const;

		void updatePostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GShDash* \fIsh_dash\fP, ulong \fImask\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void incrRefPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GShDash* \fIsh_dash\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void decrRefPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GShDash* \fIsh_dash\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void destroyPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GShDash* \fIsh_dash\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;

		const GDashValues& values () const;

		ushort dash_offset () const;
		ushort dash_GNumber () cons;
		const GNumber* dash_list () const;

		static const char* classname();
};
.fi
.sp 1
.SH
\fBGDashValues STRUCTURE\fP
.IP
This structure may be used when creating or modifying a \fBShDash\fP instance.
To set or to modify the dash characteristics, the appropriate members of
the \fIGDashValues\fP structure and the corresponding value bitmask have to be
set before calling \fIGCreateShDash()\fP or \fImodify()\fP methods. Unset
values are not set to \fIdefault values\fP.
.sp 1
\fIGDashValues\fP structure:
.sp 1
.nf
.ta .25i .60i 1.80i
struct GDashValues {
	ushort dash_number;
	ushort dash_offset;
	GNumber* dash_list;
} ;
.fi
.sp 1
.RS .8i
.IP \fIdash_number\fP .5i
.br
Specifies the element (dash/gap) number of the dash list.
.IP \fIdash_offset\fP .5i
.br
Specifies the first element in the list which will be used at the drawing
start.
.IP \fIdash_list\fP .5i
.br
Specifies the element table.
.RE
.IP
.sp 1
\fBDash value mask bits\fP:
.nf
.ta .25i 1.5i 2.5i
	#define GDASH_LIST	(1L<<0)
	#define GDASH_OFFSET	(1L<<1)
.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
GShDash* \fBGCreateShDash\fP (ulong \fImask\fP, const GDashValues* \fIvalues\fP, const char* \fIname\fP = NULL);
.br
GShDash* \fBGCreateShDash\fP (const char* \fIname\fP);
.RS .8i
.IP \fIDescription\fP .5i
These functions allow to create an instance of the \fBShDash\fP class.
.IP \fImask\fP .5i
.br
Specifies the value bitmask.
.IP \fIvalues\fP .5i
.br
Specifies a \fBGDashValues\fP value structure pointer.
.IP \fIname\fP .5i
.br
Specifies the dash name.
.RE
.sp 1
.IP
friend void \fBGModify\fP (GShDash*& \fIsh_dash\fP, ulong \fImask\fP, const GDashValues* values)
.RS .8i
.IP \fIDescription\fP .5i
This function allows to modify the dash values. Like other shared
objects (see \fISharedObject(3Go)\fP), the modification function returns the
new \fBShDash\fP object (possibly the same). The dash_list may
be freed after the modification.
.IP \fIsh_dash\fP .5i
.br
Specifies the \fIShDash\fP object reference which has to be modified.
.IP \fImask\fP .5i
.br
Specifies the value bitmask for the modification.
.IP \fIvalues\fP .5i
.br
Specifies a \fBGDashValues\fP structure pointer. The fields of this
structure corresponding to the mask contain the new values.
.RE
.sp 1
.IP
friend void \fBGModify\fP (const char* \fIname\fP, ulong \fImask\fP, const GDashValues* \fIvalues\fP)
.RS .8i
.IP \fIDescription\fP .5i
This function allows to modify a \fIShDash\fP object referred by its name.
.IP \fIname\fP .5i
Identifies the \fIShDash\fP. It it does not exist, it is created.
.IP \fImask\fP .5i
.br
Specifies the value bitmask for the modification.
.IP \fIvalues\fP .5i
.br
Specifies a \fIGDashValues\fP structure pointer. The fields of this
structure corresponding to the mask contain the new values.
.RE
.sp 1
.IP
friend void \fBGRename\fP (GShDash*& \fIsh_dash\fP, const char* \fIname\fP)
.RS .8i
.IP \fIDescription\fP .5i
This function allows to (re)name a \fIShDash\fP. If the reference count is
greater than 1, a new \fIShDash\fP is looked for matching and a new instance
may be created.
.IP \fIsh_dash\fP .5i
Specifies the concerned \fIShDash\fP instance.
.IP \fIname\fP .5i
.br
Specifies the new name, it may be NULL.
.RE
.sp1
.IP
GShDash* \fBdup\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This function returns the current \fBShDash\fP object but increments the
reference count. It allows to modify a copy of a shared \fBShDash\fP instance.
.RE
.sp1
.IP
GBool \fBmatch\fP (const GShDash* \fIsh_dash\fP) const
.RS .8i
.IP \fIDescription\fP .5i
This function returns GTRUE if the given \fIShDash\fP object matches with
the current object, that means the two values mask does not intersect, or
if the masks intersect, the corresponding values are the same.
.IP \fIsh_dash\fP .5i
Specifies the \fIShDash\fP object used to proceed the matching operation.
.RE
.sp1
.IP
.nf
void \fBupdatePostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GShDash* \fIsh_dash\fP, ulong \fImask\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP
This function allows to add or to remove callback procedure when the shared object \fIShDash\fP is
updated. That means the \fIGModify()\fP method has been applied on the current object. In other
terms, when the reference count of a shared object is 1 and if no other shared object \fImatches\fP
with the modification, the current object can be directly updated.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the object will be updated. The callback procedure is
called after the modification is done. Its parameters are the \fIclosure\fP, the shared object \fIsh_dash\fP
itself and the update \fImask\fP. The \fImask\fP determines the modified field only.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the update
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp1
.IP
.nf
void \fBincrRefPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GShDash* \fIsh_dash\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBdecrRefPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GShDash* \fIsh_dash\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP
This function allows to add or to remove a callback procedure which will be called
when the shared object \fIShDash\fP
reference count is incremented or decremented. The reference count may be modified when
\fIGCreateShDash(), GModify(), dup() and destroy()\fP methods are called.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the object reference count will be modified.
The callback procedure is called after the increment/decrement. Its parameters are
the \fIclosure\fP and the shared object \fIsh_dash\fP itself.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the
increment/decrement callback lists. If \fIadd\fP is GREMOVE, the callback procedure
\fIproc\fP will be removed from  the callback list.
.RE
.sp1
.IP
.nf
void \fBdestroyPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GShDash* \fIsh_dash\fP, ulong \fImask\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP
This method allows to add or remove a callback procedure which will be called
when the shared object \fIShDash\fP is destroyed.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the object will be destroyed.
The callback procedure is called \fIjust before\fP the destruction of the object. Its parameters are
the \fIclosure\fP and the shared object \fIsh_dash\fP itself.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the
destruction callback lists. If \fIadd\fP is GREMOVE, the callback procedure
\fIproc\fP will be removed from  the callback list.
.RE
.sp1
.IP
const GDashValues* \fBvalues\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This function returns the \fIGDashValues\fP structure of the dash.
.RE
.sp 1
.IP
ushort \fBdash_offset\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This function returns the current dash offset of the dash.
.RE
.sp 1
.IP
ushort \fBdash_number\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the dash list size.
.RE
.sp 1
.IP
const GNumber* \fBdash_list\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the pointer to the dash element table.
.RE
.sp 1
.IP
static const char* \fBclassname\fP();
.RS .8i
.IP \fIDescription\fP .5i
This static method returns a pointer to the string \fI``GShDash''\fP.
.RE
.sp 1
.SH
\fBC BINDING\fP
.SS
\fBHeader file\fP
.IP
#include <Go/Tools/cShDash.h>
.SS
\fBType Definitions\fP
.IP
.nf
.ta .15i .25i 1.0i
#define GDASH_LIST			(1L<<0)
#define GDASH_OFFSET			(1L<<1)

typedef struct _GDashValues
{
	ushort dash_number;
	ushort dash_offset;
	GNumber* dash_list;
} GDashValues;

(\fISee GDashValues STRUCTURE section\fP)
.SS
\fBC Functions\fP
.IP
GObjectId \fBGGetNamedShDash\fP (const char* \fIname\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GShDash* GCreateShDash (const char* \fIname\fP).
.RE
.sp 1
.IP
void \fBGGModifyShDashByName\fP (const char* \fIname\fP, ulong \fImask\fP, const GDashValues* \fIvalues\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: void GModify (const char* \fIname\fP, ulong \fImask\fP, const GDashValues* \fIvalues\fP).
.RE
.sp 1
.IP
const GDashValues* \fBGGetShDashValues\fP (const GObjectId \fIsh_dash\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP const GDashValues* values().
.RE
.sp 1
.IP
const char* \fBGShDashClassName\fP ();
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP static const char* classname();
.RE
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
The \fIShDash\fP class is a subclass of \fISharedObject\fP class. So, the \fIconstructor\fP
and \fIdestructor\fP methods are not public and the method \fIGCreateShDash()\fP
and \fIdestroy()\fP must be called instead of \fInew\fP and \fIdelete\fP.
See also \fIDash(3Go)\fP which is a non-shared object using a \fIShDash\fP object.
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBSharedObject(3Go)\fP, \fBGoInterf(3Go)\fP, \fBDash(3Go)\fP, \fBShPen(3Go)\fP.
.nrPN \n%
