.\" $Id: ShFont.n,v 1.1.1.1 1992/03/18 09:48:29 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH ShFont 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBShFont\fP \(em the font object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/ShFont.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBShFont\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBSharedObject\fP class
.RE
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBShFont\fP object allows to manage fonts for writing text (see \fIGoInterf(3Go)\fP).
The font characteristics are stored in a \fIFontValues\fP structure (see below).
The \fIShFont\fP interface is based on a \fIfont name\fP. This font name contains a set of
fields which are:
.RS .8i
.IP \fIregistered-name\fP .5i
.br
Specifies the name or identifier of the digital type foundry that digitized
and supplied the font data, or if different, the identifier of the organization
that last modified the font shape or metric information. Examples are
\fIAdobe, Bitstream, 
.IP \fIfamily-name\fP .5i
.br
Identifies the range (or family) of the typeface designs that are all
variations of one basic typographic style. Examples are: \fIHelvetica,
ITC Avant Garde Gothic, Times, Bitstream Amerigo\fP.
.IP \fIweight-name\fP .5i
.br
Identifies the font's typographic weight, i.e. the nominal \fIblackness\fP
of the font, according to the foundry's judgement. Examples are:
\fIMedium, Bold
.IP \fIslant-code\fP .5i
Indicates the overall posture of the typeface design used in the font.
The encoding is the following: \fIR\fP (Roman, upright design), \fII\fP
(Italic, italic design, slanted clockwise from vertical),
\fIO\fP (Oblique, obliqued upright design, slanted clockwise from vertical),
\fIRI\fP (italic design, slanted counter clockwise from vertical),
\fIRO\fP (Reverse Oblique, obliqued upright design, slanted counter clockwise
from vertical),
\fIOT\fP (Other).
.IP \fIsetwidth_name\fP
.br
Gives the font's typographic proportionate width, i.e. the
nominal width per horizontal unit of the font, according to
the foundry's judgment. Examples are: \fINormal, Condensed, Narrow, Double
Wide\fP.
.IP \fIadd_style_name
.br
Identifies additional typographic style information (needed to uniquely
identify the font). Examples are: \fISerif, Sans Serif, Informal, Decorated.\fP
.IP \fIspacing_code\fP
.br
Indicates the escapement class of the font. Examples are \fIM\fP (monospace,
fixed pitch), \fIP\fP (proportional, variable pitch), charcell (a special
monospaced font that conforms to the traditional data processing
character cell font model).
.IP \fIcharset_registry\fP
Specifies the registration authority that owns the specified encoding (example:
ISO8859).
.IP \fIcharset_encoding\fP
Specifies the the coded character set as defined by the \fIcharset-registry\fP
(example: 1, for ISO8859-1).
.RE
.sp 1
.IP
The \fIShFont\fP is a subclass of the \fISharedObject\fP class, the
\fIFontValues\fP structure allows to set define the font name fields and
other font characteristics (see below).
.sp 1
To simplify the programming interface, a font name format is defined by
the concatenation of the dash separated (possibly empty) fields:
.br
\fI-registry-family-weight-slant-setwidth-addstyle-spacing-charset-encoding\fP
.br
Example: -Adobe-Courier-Medium-R-Normal--M-ISO8859-1 is a valid font name.
.sp 1
\fBGShFont\fP is the C++ type for the \fIShFont\fP object class.
.sp 1
.nf
.ta .15i .25i 1.0i
class GShFont : public GSharedObject {
	public:
		GShFont* GCreateShFont (ulong \fImask\fP, GFontValues* \fIvalues\fP, const char* \fIname\fP = NULL);
		GShFont* GCreateShFont (char* \fIname\fP);
		GShFont* GCreateShFont ();

		friend void GModify (GShFont*& \fIsh_font\fP, ulong \fImask\fP, const GFontValues* \fIvalues\fP);
		friend void GModify (const char* \fIname\fP, ulong \fImask\fP, const GFontValues* \fIvalues\fP);
		friend void GRename (GShFont*& \fIsh_font\fP, const char* \fIname\fP);

		GShFont* dup() const;
		GBool match (const GShFont* \fIsh_font\fP);
		void updatePostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GShFont* \fIsh_font\fP, ulong \fImask\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void incrRefPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GShFont* \fIsh_font\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP= GADD) const;
		void decrRefPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GShFont* \fIsh_font\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void destroyPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GShFont* \fIsh_font\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;

		// Getting values
		const GFontValues* values () const;
		const char* fullName () const;
		const char* registry () const;
		const char* weight () const;
		const char* slant () const;
		const char* width () const;
		const char* addStyle () const;
		const char* spacing () const;
		const char* charset () const;
		const char* charcode () const;

		static const char* classname();
};
.fi
.sp 1
.SH
\fBGFontValues STRUCTURE\fP
.IP
This structure may be used when creating or modifying a \fIShFont\fP instance.
To set or to modify the font characteristics, the appropriate members of
the \fIGFontValues\fP structure and the corresponding value bitmask have to be
set before calling \fIGCreateShFont()\fP or \fIGModify()\fP methods. If passed \fImask\fP
is 0 values are set to \fIdefault values\fP.
.sp 1
\fIGFontValues\fP structure:
.sp 1
.nf
.ta .25i .60i 1.80i
structure GFontValues {
	char* registry;
	char* family;
	char* weight;
	char* slant;
	char* width;
	char* add_style;
	char* spacing;
	char* charset_registry;
	char* charset_encoding;
} ;
.fi
.IP
The structure fields specify the above characteristics of the font name.
.sp 1
\fBFont value mask bits\fP:
.sp 1
.nf
.ta .25i 1.5i 2.5i
	#define FONT_REGISTRY	(1L<<0)
	#define FONT_FAMILY	(1L<<1)
	#define FONT_WEIGHT	(1L<<2)
	#define FONT_SLANT	(1L<<3)
	#define FONT_WIDTH	(1L<<4)
	#define FONT_ADD_STYLE	(1L<<5)
	#define FONT_SPACING	(1L<<6)
	#define FONT_CHARSET	(1L<<7)
	#define FONT_CHARCODE	(1L<<8)
.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
GShFont* \fBGCreateShFont\fP (ulong \fImask\fP, GFontValues* \fIvalues\fP, const char* \fIname\fP = NULL);
.br
GShFont* \fBGCreateShFont\fP (char* \fIname\fP);
.br
GShFont* \fBGCreateShFont\fP ();
.RS .8i
.IP \fIDescription\fP .5i
These functions allow to create an instance of the \fIShFont\fP class. When
a font is created without any parameter, no default font is chosen. If
the requested font does not exist, NULL is returned.
.IP \fImask\fP .5i
.br
Specifies the value bitmask.
.IP \fIvalues\fP .5i
.br
Specifies a \fIGFontValues\fP value structure pointer.
.IP \fIname\fP .5i
.br
Specifies the font name as defined above.
.RE
.sp 1
.IP
friend void \fBGModify\fP (GShFont*& \fIsh_font\fP, ulong \fImask\fP, const GFontValues* values)
.RS .8i
.IP \fIDescription\fP .5i
This function allows to modify the font values. Like other shared
objects (see \fISharedObject(3Go)\fP), the modification function returns the
new \fIShFont\fP object (possibly the same).
.IP \fIsh_font\fP .5i
.br
Specifies the \fIShFont\fP object reference which has to be modified.
.IP \fImask\fP .5i
.br
Specifies the value bitmask for the modification.
.IP \fIvalues\fP .5i
.br
Specifies a \fIGFontValues\fP structure pointer. The fields of this
structure corresponding to the mask contain the new values.
.RE
.sp 1
.IP
friend void \fBGModify\fP (const char* \fIname\fP, ulong \fImask\fP, const GFontValues* \fIvalues\fP)
.RS .8i
.IP \fIDescription\fP .5i
This function allows to modify a \fIShFont\fP object referred by its name.
.IP \fIname\fP .5i
Identifies the \fIShFont\fP. It it does not exist, it is created.
.IP \fImask\fP .5i
.br
Specifies the value bitmask for the modification.
.IP \fIvalues\fP .5i
.br
Specifies a \fIGFontValues\fP structure pointer. The fields of this
structure corresponding to the mask contain the new values.
.RE
.sp 1
.IP
friend void \fBGRename\fP (GShFont*& \fIsh_font\fP, const char* \fIname\fP)
.RS .8i
.IP \fIDescription\fP .5i
This function allows to (re)name a \fIShFont\fP. If the reference count is
greater than 1, a new \fIShFont\fP is looked for matching and a new instance
may be created.
.IP \fIsh_font\fP .5i
Specifies the concerned \fIShFont\fP instance.
.IP \fIname\fP .5i
.br
Specifies the new name, it may be NULL.
.RE
.sp1
.IP
GShFont* \fBdup\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This function returns the current \fIShFont\fP object but increments the
reference count. It allows to modify a copy of a shared \fIShFont\fP instance.
.RE
.sp1
.IP
GBool \fBmatch\fP (const GShFont* \fIsh_font\fP) const
.RS .8i
.IP \fIDescription\fP .5i
This function returns GTRUE if the given \fIShFont\fP object matches with
the current object, that means the two values mask does not intersect, or
if the masks intersect, the corresponding values are the same.
.IP \fIsh_font\fP .5i
Specifies the \fIShFont\fP object used to proceed the matching operation.
.RE
.sp1
.IP
.nf
void \fBupdatePostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GShFont* \fIsh_font\fP, ulong \fImask\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP
This function allows to add or to remove callback procedure when the shared object \fIShFont\fP is
updated. That means the \fIGModify()\fP method has been applied on the current object. In other
terms, when the reference count of a shared object is 1 and if no other shared object \fImatches\fP
with the modification, the current object can be directly updated.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the object will be updated. The callback procedure is
called after the modification is done. Its parameters are the \fIclosure\fP, the shared object \fIsh_font\fP
itself and the update \fImask\fP. The \fImask\fP determines the modified field only.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the update
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp1
.IP
.nf
void \fBincrRefPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GShFont* \fIsh_font\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBdecrRefPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GShFont* \fIsh_font\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP
This function allows to add or to remove a callback procedure which will be called
when the shared object \fIShFont\fP
reference count is incremented or decremented. The reference count may be modified when
\fIGCreateShFont(), GModify(), dup() and destroy()\fP methods are called.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the object reference count will be modified.
The callback procedure is called after the increment/decrement. Its parameters are
the \fIclosure\fP and the shared object \fIsh_font\fP itself.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the
increment/decrement callback lists. If \fIadd\fP is GREMOVE, the callback procedure
\fIproc\fP will be removed from  the callback list.
.RE
.sp1
.IP
.nf
void \fBdestroyPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GShFont* \fIsh_font\fP, ulong \fImask\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP
This method allows to add or remove a callback procedure which will be called
when the shared object \fIShFont\fP is destroyed.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the object will be destroyed.
The callback procedure is called \fIjust before\fP the destruction of the object. Its parameters are
the \fIclosure\fP and the shared object \fIsh_font\fP itself.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the
destruction callback lists. If \fIadd\fP is GREMOVE, the callback procedure
\fIproc\fP will be removed from  the callback list.
.RE
.sp 1
.IP
const GFontValues* \fBvalues\fP ();
.RS .8i
.IP \fIDescription\fP .5i
This function returns the current \fIGFontValues\fP structure of the instance.
.RE
.sp 1
const char* \fBfullName\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the full name of the font, each field is separated by
the \fIGFONTNAME_SEPARATOR\fP (usually ``-'').
.RE
.sp 1
.IP
.nf
const char* \fBregistry\fP () const;
const char* \fBweight\fP () const;
const char* \fBslant\fP () const;
const char* \fBwidth\fP () const;
const char* \fBaddStyle\fP () const;
const char* \fBspacing\fP () const;
const char* \fBcharset\fP () const;
const char* \fBcharcode\fP () const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to get one by one the \fIGFontValues\fP structure fields.
.RE
.sp 1
.IP
static const char* \fBclassname\fP();
.RS .8i
.IP \fIDescription\fP .5i
This static method returns a pointer to the string \fI``GShFont''\fP.
.RE
.sp 1
.SH
\fBC BINDING\fP
.SS
\fBHeader file\fP
.IP
#include <Go/Tools/cShFont.h>
.SS
\fBType Definitions\fP
.IP
.nf
.ta .15i .25i 1.0i
typedef struct _GFontValues
{
	char* registry;
	char* family;
	char* weight;
	char* slant;
	char* width;
	char* add_style;
	char* spacing;
	char* charset_registry;
	char* charset_encoding;
} GFontValues;

(\fISee GFontValues STRUCTURE section\fP. See also Font value mask bits)
.SS
\fBC Functions\fP
.IP
GObjectId \fBGGetNamedShFont\fP (const char* \fIname\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GShFont* GCreateShFont (const char* \fIname\fP).
.RE
.sp 1
.IP
void \fBGModifyShFontByName\fP (const char* \fIname\fP, ulong \fImask\fP, const GFontValues* \fIvalues\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: void GModify (const char* \fIname\fP, ulong \fImask\fP, const GFontValues* \fIvalues\fP).
.RE
.sp 1
.IP
const GFontValues* \fBGGetShFontValues\fP (const GObjectId \fIsh_font\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP const GFontValues* values().
.RE
.sp 1
.IP
char* \fBGGetShFontFullName (const GObjectId \fIsh_font\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP const char* fullName ();
.RE
.sp 1
.IP
const char* \fBGShFontClassName\fP ();
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP static const char* classname();
.RE
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
The \fIShFont\fP class is a subclass of \fISharedObject\fP class. So, the \fIconstructor\fP
and \fIdestructor\fP methods are not public and the method \fIGCreateShFont()\fP
and \fIdestroy()\fP must be called instead of \fInew\fP and \fIdelete\fP.
See also \fIFont(3Go)\fP which is a non-shared object using a \fIShFont\fP object.
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBSharedObject(3Go)\fP, \fIGoInterf(3Go)\fP, \fIFont(3Go)\fP.
.nrPN \n%
