.\" $Id: ShImgBrush.n,v 1.1.1.1 1992/03/18 09:48:35 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH ShImageBrush 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBShImageBrush\fP \(em the shared Image brush object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/ShImageBrush.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBShImageBrush\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBSharedObject\fP class
.RE
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBShImageBrush\fP object is defined by a set of values which will be used by
a \fBGoInterf\fP instance for drawing Image (see \fIGoInterf(3Go)\fP. These
values are described below in the \fIGImageBrushValues\fP structure. See also
\fIGCdef(3Go)\fP which defines some constant values used by \fIShImageBrush\fP and
other graphic Image objects (\fIShPen, ShBrush, ShImageBrush\fP).
.IP
The \fIShImageBrush\fP has defaults values: we can say the default \fIShImageBrush\fP
is  a \fIback and white colormap with fill style solid\fP.
.IP
The \fIShImageBrush\fP object is a shared object (see \fISharedObject(3Go)\fP) and
may be shared between several other objects (i.e. \fIGo's\fP). The \fIImageBrush\fP
(See \fIImagebrush(3Go)\fP) gives a non-shared interface to the \fIShImageBrush\fP.
.sp 1
\fBGShImageBrush\fP is the C++ type for the \fIShImageBrush\fP object class.
.sp 1
.nf
.ta .15i .25i 1.0i
class GShImageBrush : public SharedObject {
	public:
		friend GShImageBrush* GCreateShImageBrush ();
		friend GShImageBrush* GCreateShImageBrush (ulong \fImask\fP, const GImageBrushValues* \fIvalues\fP,
			const char* \fIname\fP = NULL);
		friend GShImageBrush* GCreateShImageBrush (const char* \fIname\fP);

		GShImageBrush* dup() const;
		GBool match (const GShImageBrush* \fIsh_ibrush\fP) const;

		void updatePostcond (void \fIproc\fP(void* \fIclosure\fP, GShImageBrush* \fIsh_ibrush\fP, ulong \fImask\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void destroyPostcond (void \fIproc\fP(void* \fIclosure\fP, GShImageBrush* \fIsh_ibrush\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;

		// Getting values
		const GImageBrushValues* values() const;

		ulong function () const;
		ulong planeMask () const;
		ushort fillStyle () const;
		const GShPattern* stipple () const;
		const GShColormap* colormap () const;

		// Modifying methods
		friend void GModify (GShImageBrush*& \fIsh_ibrush\fP, ulong \fImask\fP, const GImageBrushValues* \fIvalues\fP);
		friend void GRename (GShImageBrush*& \fIsh_ibrush\fP, const char* \fIname\fP);

		friend void GSetPlaneMask (GShImageBrush*& \fIsh_ibrush\fP, ulong \fIplane_mask\fP);
		friend void GSetStipple (GShImageBrush*& \fIsh_ibrush\fP, const class GShPattern* \fIstipple\fP);
		friend void GSetColormap (GShImageBrush*& \fIsh_ibrush\fP, const class GShColormap* \fIcolormap\fP);

		// updating named ShImageBrush
		friend void GModify (const char* \fIname\fP, ulong \fImask\fP, const GImageBrushValues* \fIvalues\fP);

		friend void GImageBrushFunction (const char* \fIname\fP, ulong \fIfunction\fP);
		friend void GImageBrushPlaneMask (const char* \fIname\fP, ulong \fIplane_mask\fP);
		friend void GImageBrushFillStyle (const char* \fIname\fP, ushort \fIfill_style\fP);
		friend void GImageBrushColormap (const char* \fIname\fP, const class GShColormap* \fIcolormap\fP);
		friend void GImageBrushStipple (const char* \fIname\fP, const class GShPattern* \fIstipple\fP);

		static const char* classname();
}
.fi
.sp 1
.SH
\fBGImageBrushValues STRUCTURE\fP
.IP
This structure may be used when creating or modifying a \fIShImageBrush\fP
or \fIImageBrush\fP (see \fIImageBrush(3Go)\fP) instance.
To set or to modify the image brush characteristics, the appropriate members of
the \fIGImageBrushValues\fP structure and the corresponding value bitmask have to be
set before calling \fIGCreateShImageBrush()\fP or \fIGModify()\fP methods.
If the passed \fImask\fP is 0 values are set to \fIdefault values\fP.
.sp 1
\fIGImageBrushValues\fP structure:
.sp 1
.nf
.ta .25i .60i 1.80i
struct GImageBrushValues {
	ulong function;
	ulong plane_mask;
	/* fill attributes */
	struct {
	    unsigned style : 2;
	} fill;
	class GShPattern* stipple;
	class GShColormap* cmap;
};
.fi
.sp 1
.RS .8i
.IP \fIfunction\fP .5i
.br
Defines the logical function allowing to combine the source and the destination
pixel values. Possible values are described in \fIGCdef(3Go)\fP, the value
for the default imagebrush is \fIGCOPY\fP.
.IP \fIplane_mask\fP .5i
.br
Determines which planes of the output device will be affected by the drawing.
The value for the default imagebrush is \fIGALL_PLANES\fP.
.IP \fIcmap\fP .5i
.br
Gives the colormap used to map pixels of an image. The value of the default imagebrush is
``black'' (Rgb = (0, 0, 0)) and ``white'' (Rgb(65535, 65535, 65535)).
.IP \fIfill.style\fP .5i
.br
Determines if image is masked with the \fIstipple\fP or not.
Possible values to use the \fIstipple\fP are \fIGFILL_STIPPLED\fP or \fIGFILL_OPAQUE_STIPPLE\fP.
The value for the default imagebrush is \fIGFILL_SOLID\fP.
.IP \fIstipple\fP .5i
.br
Specifies the 1-bit-depth pattern (monochrome \fIShPattern\fP) used
when the fill style is either \fIGFILL_STIPPLED\fP or \fIGFILL_OPAQUE_STIPPLED\fP.
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
.nf
friend GShImageBrush* \fBGCreateShImageBrush\fP ();
friend GShImageBrush* \fBGCreateShImageBrush\fP (ulong \fImask\fP, const GImageBrushValues* \fIvalues\fP, const char* \fIname\fP = NULL);
friend GShImageBrush* \fBGCreateShImageBrush\fP (const char* \fIname\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to create instances of the \fIShImageBrush\fP class. Without any parameter
the default imagebrush is returned. If the requested shared imagebrush already exists,
its reference count is incremented and it is returned.
.IP \fImask\fP .5i
.br
Specifies the value bitmask, making valid \fIvalues\fP fields.
.IP \fIvalues\fP .5i
.br
Specifies a pointer to a \fIGImageBrushValues\fP structure.
.IP \fIname\fP .5i
.br
Specifies the name of the shared imagebrush. If such a named shared imagebrush exists, it
is returned, else a named shared imagebrush is created. If the name parameter is given
with \fImask\fP and \fIvalues\fP, the concerned named shared imagebrush is modified. 
.RE
.sp 1
.IP
GShImageBrush* \fBdup\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the current \fIShImageBrush\fP object but increments its
reference count. It allows to modify a copy of a shared \fIShImageBrush\fP instance.
For instance, this method is used when creating a \fIImagebrush\fP from an existing
\fIShImageBrush\fP (see \fIImagebrush(3Go)\fP).
.RE
.sp 1
.IP
GBool \fBmatch\fP (const GShImageBrush* \fIsh_ibrush\fP) const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns GTRUE if the given \fIShImageBrush\fP object values match the values
of the current object; that means either the two values mask does not intersect,
or if the masks intersect, the corresponding values are equal.
.IP \fIsh_ibrush\fP .5i
.br
Specifies the \fIShImageBrush\fP object used for the matching operation.
.RE
.sp 1
.IP
.nf
void \fBupdatePostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GShImageBrush* \fIsh_ibrush\fP, ulong \fImask\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method allows to add or to remove postcondition procedures when the \fBShImageBrush\fP is
updated. That means the \fIGModify()\fP method has been applied on the current object. In other
terms, when the reference count of a shared object is 1 and if no other shared object \fImatches\fP
the modification, the current object can be directly updated.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the object will be updated. Postcondition procedures are
called after the modification is done. Its parameters are the \fIclosure\fP, the shared object \fIShImageBrush\fP
itself and the update \fImask\fP. The \fImask\fP determines the modified field only.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the postcondition procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the postcondition procedure \fIproc\fP will be added to the update
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp1
.IP
.nf
void \fBdestroyPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GShImageBrush* \fIsh_ImageBrush\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method allows to add or remove a postcondition procedures which will be called
when the shared object \fIShImageBrush\fP is destroyed.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the object will be destroyed.
DestroyPostcond procedures are called \fIjust before\fP the destruction of the object. Their parameters are
the \fIclosure\fP and the shared object \fIsh_ImageBrush\fP itself.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the
destruction callback list. If \fIadd\fP is GREMOVE, the callback procedure
\fIproc\fP will be removed from  the callback list.
.RE
.sp1
.IP
const GImageBrushValues* \fBvalues\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns a pointer to the values structure of the \fIShImageBrush\fP.
.RE
.sp 1
.IP
.nf
ulong \fBfunction\fP () const;
ulong \fBplaneMask\fP () const;
ushort \fBfillStyle\fP () const;
const GShPattern* \fBstipple\fP () const;
const GShColormap* \fBcolormap\fP () const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to get field by field the values of the \fIShImageBrush\fP.
These fields are valid, only if the corresponding bits are set in the mask
(\fImask()\fP).
.RE
.sp 1
.IP
friend void \fBGModify\fP (GShImageBrush*& \fIsh_ImageBrush\fP, ulong \fImask\fP, const GImageBrushValues* \fIvalues\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to modify a shared ImageBrush. If the modified \fIGShImageBrush\fP matches an already
existing \fIShImageBrush\fP, its reference count is incremented and it is returned in \fIsh_ImageBrush\fP.
If \fIthis\fP is named, the modification is done directly on it. When a shared object
is effectively updated, the postcondition callbacks are invoked.
.IP \fIsh_ImageBrush\fP .5i
.br
Specifies the shared ImageBrush to be modified. This pointer may be modified.
.IP "\fImask, values\fP"
.br
Specify which fields in the values structure have to be modified and how.
.RE
.sp 1
.IP
.nf
friend void \fBGSetPlaneMask\fP (GShImageBrush*& \fIsh_ImageBrush\fP, ulong \fIplane_mask\fP);
friend void \fBGSetColormap\fP (GShImageBrush*& \fIsh_ImageBrush\fP, const GShColormap* \fIsh_colormap\fP);
friend void \fBGSetStipple\fP (GShImageBrush*& \fIsh_ImageBrush\fP, const GShPattern* \fIstipple\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to modify field by field the \fIShImageBrush\fP values structure. These methods
behave like the \fIGModify()\fP method when only only bit is set in the mask. For performance
reasons, the \fIGModify()\fP method should be preferred when several fields have to modified
.RE
.sp 1
.IP
friend void \fBGRename\fP (GShImageBrush*& \fIsh_ImageBrush\fP, const char* \fIname\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to (re)name a shared ImageBrush. If such a named object exists, it is
returned in \fIsh_ImageBrush\fP (updatePostcond are invoked), else a new named shared ImageBrush
is created (its reference count is 1 and its values are the current values).
.IP \fIsh_ImageBrush\fP
.5i
Specifies the shared ImageBrush to be named.
.IP \fIname\fP .5i
.br
Specifies the new name. It may be NULL, in that case, the named shared ImageBrush becomes
unnamed.
.RE
.sp 1
.IP
friend void \fBGModify\fP (const char* \fIname\fP, ulong \fImask\fP, const GImageBrushValues* \fIvalues\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to update a named shared ImageBrush. If such a named shared ImageBrush does not
exists, it is created. Update postconditions are invoked.
.IP \fIname\fP .5i
.br
Identifies the named shared ImageBrush.
.IP "\fImask, values\fP" .5i
.br
Specify which fields in the values structure have to be modified and how.
.RE
.sp 1
.IP
.nf
friend void \fBGImageBrushFunction\fP (const char* \fIname\fP, ulong \fIfunction\fP);
friend void \fBGImageBrushPlaneMask\fP (const char* \fIname\fP, ulong \fIplane_mask\fP);
friend void \fBGImageBrushFillStyle\fP (const char* \fIname\fP, ushort \fIfill_style\fP);
friend void \fBGImageBrushStipple\fP (const char* \fIname\fP, const GShPattern* \fIstipple\fP);
friend void \fBGImageBrushColormap\fP (const char* \fIname\fP, const GShColormap* \fIcolormap\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to modify field by field the named \fIShImageBrush\fP values structure. These methods
behave like the previous \fIGModify()\fP method when only only bit is set in the mask. For performance
reasons, the \fIGModify()\fP method should be preferred when several fields have to be modified
.RE
.sp 1
.IP
static const char* \fBclassname\fP();
.RS .8i
.IP \fIDescription\fP .5i
This static method returns a pointer to the string \fI``GShImageBrush''\fP.
.RE
.sp 1
.SH
\fBC BINDING\fP
.SS
\fBHeader file\fP
.IP
#include <Go/Tools/cShImgBrush.h>
.SS
\fBType Definitions\fP
.IP
.nf
.ta .15i .25i 1.0i
typedef struct _GImageBrushValues
{
	ulong function;
	ulong plane_mask;

	/* fill attributes */
	struct {
		unsigned style : 2;
	} fill;

	ObjectId stipple;
	ObjectId cmap;
} GImageBrushValues;

(\fISee GImageBrushValues STRUCTURE section\fP and ImageBrush value mask bits in
\fIGCdef(3Go)\fP))
.SS
\fBC Functions\fP
.IP
ObjectId \fBGGetNamedShImageBrush\fP (const char* \fIname\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GShImageBrush* GCreateShImageBrush (const char* \fIname\fP).
.RE
.sp 1
.IP
void \fBGModifyShImageBrushByName\fP (const char* \fIname\fP, ulong \fImask\fP, const GImageBrushValues* \fIvalues\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: void GModify (const char* \fIname\fP, ulong \fImask\fP, const GImageBrushValues* \fIvalues\fP).
.RE
.sp 1
.IP
const GImageBrushValues* \fBGGetShImageBrushValues\fP (const ObjectId \fIsh_ibrush\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP const GImageBrushValues* values().
.RE
.sp 1
.IP
const char* \fBGShImageBrushClassName\fP ();
.RS .8i
.IP \fIDescription\fP .5i
\fISee:\fP static const char* classname();
.RE
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
The \fIShImageBrush\fP class is a subclass of \fISharedObject\fP class. So, the \fIconstructor\fP
and \fIdestructor\fP methods are not public and the method \fIGCreateShImageBrush()\fP
and \fIdestroy()\fP must be called instead of \fInew\fP and \fIdelete\fP.
See also \fIImageBrush(3Go)\fP which is a non-shared object using a \fIShImageBrush\fP object.
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBSharedObject(3Go)\fP, \fBShPattern(3Go)\fP, \fBShColormap(3Go)\fP  \fBImageBrush(3Go)\fP.
.nrPN \n%
