.\" $Id: ShPattern.n,v 1.1.1.1 1992/03/18 09:48:40 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH ShPattern 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBShPattern\fP \(em the shared pattern object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/ShPattern.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBPattern\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBSharedObject\fP class
.RE
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBShPattern\fP object is a pixel (or bit) array independent of the
pixel number. The size of the pattern is defined in mm.
.IP
The \fIShPattern\fP object points to a \fBShPixelArray\fP (see \fIShPixelArray(3Go)\fP) object which is
the value of the pattern and to a \fIShColormap\fP (see \fIShColormap(3Go)\fP) which defines the
pixel colors. If the \fIShPattern\fP size is defined (> 0),
the \fBGoInterf\fP (see \fIGoInterf(3Go)\fP) will scale the pixel array to match with the pattern
size. If the \fIShPattern\fP size is undefined, the \fIGoInterf\fP
will directly use the pixel array size without any transformation.
.IP
The \fIShPattern\fP object is a \fISharedObject\fP (see \fISharedObject(3Go)\fP) and
may be shared between several \fIGC\fP objects (\fIShPen, ShBrush, ShTextBrsuh, ShImageBrush\fP).
The \fBPattern\fP (see \fIPattern(3Go)\fP) gives a non-shared object interface to the
\fIShPattern\fP).
.sp 1
\fBGShPattern\fP is the C++ type of the \fIShPattern\fP object class.
.sp 1
.nf
.ta .15i .25i 1.50i
class GShPattern : public GSharedObject {
  public:
		friend GShPattern* GCreateShPattern (const ShPixelArray* \fIsh_pixelArray\fP, const ShColormap* \fIsh_cmap\fP,
			Number \fIwidth\fP = 0, Number \fIheight\fP = 0, const char* \fIname\fP = NULL);
		friend GShPattern* GCreateShPattern (ulong \fImask\fP, GPatternValues \fIvalues\fP, const char* \fIname\fP = NULL);
		friend GShPattern* GCreateShPattern (const char* \fIname\fP);

		friend void GModify (GShPattern*& \fIsh_pattern\fP, ulong \fImask\fP, const GPatternValues* \fIvalues\fP);
		friend void GModify (const char* \fIname\fP, ulong \fImask\fP, const GPatternValues* \fIvalues\fP);
		friend void GRename (GShPattern*& \fIsh_pattern\fP, const char* \fIname\fP);

		GShPattern* dup() const;
		GBool match (const GShPattern* \fIsh_pattern\fP) const;

		void updatePostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GShPattern* \fIsh_pattern\fP, ulong \fImask\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void incrRefPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GShPattern* \fIsh_pattern\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void decrRefPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GShPattern* \fIsh_pattern\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void destroyPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GShPattern* \fIsh_pattern\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;

		const GPatternValues values() const;
		const GShPixelArray* shPixelArray() const;
		const GShColormap* shColormap() const;
		GNumber width() const;
		GNumber height() const;
		static const char* classname();
};
.fi
.sp 1
.SH
\fBGPatternValues STRUCTURE\fP
.IP
This structure may be used when creating or modifying a \fIShPattern\fP instance.
To set or to modify the pattern characteristics, the appropriate members of
the \fIGPatternValues\fP structure and the corresponding value bitmask have to be
set before calling \fIGCreateShPattern()\fP or \fIGModify()\fP methods. Unset
values are not set to \fIdefault values\fP execpt for \fIwidth\fP and
\fIheight\fP.
.sp 1
\fIGPatternValues\fP structure:
.sp 1
.nf
.ta .25i .60i 1.80i
struct GPatternValues {
	GShPixelArray* pixelArray;
	GShColormap*   colormap;
	GNumber        width;
	GNumber        height;
}
.fi
.sp 1
.RS .8i
.IP \fIpixelArray\fP .5i
Specifies the pixel map.
.IP \fIcolormap\fP .5i
Specifies the pixel colors.
.IP \fIwidth\fP .5i
.br
Specifies the width in mm. If width is undefined, the \fIGoInterface\fP
will use the pixel array size.
.IP \fIheight\fP .5i
.br
Specifies the height in mm. If height is undefined, the \fIGoInterface\fP
will use the pixel array size.
.RE
.sp 1
.IP
.sp 1
\fBPattern value mask bits\fP:
.sp 1
.nf
.ta .25i 1.5i 2.5i
	#define GPTRN_PIXEL_ARRAY	(1L<<0)
	#define GPTRN_COLORMAP	(1L<<1)
	#define GPTRN_WIDTH	(1L<<2)
	#define GPTRN_HEIGHT	(1L<<3)
.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
.nf
friend GShPattern* \fBGCreateShPattern\fP (const GShPixelArray* \fIsh_pixelArray\fP, const GShColormap* \fIsh_cmap\fP,
	GNumber \fIwidth\fP = 0, GNumber \fIheight\fP = 0, const char* \fIname\fP = NULL);
friend GShPattern* \fBGCreateShPattern\fP (ulong \fImask\fP, const GPatternValues* \fIvalues\fP,
	const char* \fIname\fP = NULL);
friend GShPattern* \fBGCreateShPattern\fP (const char* \fIname\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These functions allow to create or to share an instance of the \fIShPattern\fP
class.
.IP \fIsh_pixelArray\fP .5i
.br
Specifies the pixel array which will be used to draw the pattern.
.IP \fIsh_cmap\fP .5i
Specifies the colormap used to draw each pixel of the pixel array.
.IP "\fIwidth, height\fP" .5i
.br
Specify the size of the pattern.
.IP \fIname\fP .5i
Specifies the name of the pattern.
.IP \fImask\fP .5i
.br
Specifies the value bitmask.
.IP \fIvalues\fP .5i
.br
Specifies the \fIGPatternValues\fP structure which describes the pattern
characteristics.
.RE
.sp 1
.IP
friend void \fBGModify\fP (GShPattern*& \fIsh_pattern\fP, ulong \fImask\fP, const GPatternValues* values)
.RS .8i
.IP \fIDescription\fP .5i
This function allows to modify the pixel array values. Like other shared
objects (see \fISharedObject(3Go)\fP), the modification function returns the
new \fIShPattern\fP object (possibly the same).
.IP \fIsh_pattern\fP .5i
.br
Specifies the \fIShPattern\fP object reference which has to be modified.
.IP \fImask\fP .5i
.br
Specifies the value bitmask for the modification.
.IP \fIvalues\fP .5i
.br
Specifies a \fIGPatternValues\fP structure pointer. The fields of this
structure corresponding to the mask contain the new values.
.RE
.sp 1
.IP
friend void \fBGModify\fP (const char* \fIname\fP, ulong \fImask\fP, const GPatternValues* \fIvalues\fP)
.RS .8i
.IP \fIDescription\fP .5i
This function allows to modify a \fIShPattern\fP object referred by its name.
.IP \fIname\fP .5i
Identifies the \fIShPattern\fP. It it does not exist, it is created.
.IP \fImask\fP .5i
.br
Specifies the value bitmask for the modification.
.IP \fIvalues\fP .5i
.br
Specifies a \fIGPatternValues\fP structure pointer. The fields of this
structure corresponding to the mask contain the new values.
.RE
.sp 1
.IP
friend void \fBGRename\fP (GShPattern*& \fIsh_pattern\fP, const char* \fIname\fP)
.RS .8i
.IP \fIDescription\fP .5i
This function allows to (re)name a \fIShPattern\fP. If the reference count is
greater than 1, a new \fIShPattern\fP is looked for matching and a new instance
may be created.
.IP \fIsh_pattern\fP .5i
Specifies the concerned \fIShPattern\fP instance.
.IP \fIname\fP .5i
.br
Specifies the new name, it may be NULL.
.RE
.sp1
.IP
GShPattern* \fBdup\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This function returns the current \fIShPattern\fP object but increments the
reference count. It allows to modify a copy of a shared \fIShPattern\fP instance.
.RE
.sp1
.IP
GBool \fBmatch\fP (const GShPattern* \fIsh_pattern\fP) const
.RS .8i
.IP \fIDescription\fP .5i
This function returns TRUE if the given \fIShPattern\fP object matches with
the current object, that means the two values mask does not intersect, or
if the masks intersect, the corresponding values are the same.
.IP \fIsh_pattern\fP .5i
Specifies the \fIShPattern\fP object used to proceed the matching operation.
.RE
.sp1
.IP
.nf
void \fBupdatePostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GShPattern* \fIsh_pattern\fP, ulong \fImask\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP
This function allows to add or to remove callback procedure when the shared object \fIShPattern\fP is
updated. That means the \fIGModify()\fP method has been applied on the current object. In other
terms, when the reference count of a shared object is 1 and if no other shared object \fImatches\fP
with the modification, the current object can be directly updated.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the object will be updated. The callback procedure is
called after the modification is done. Its parameters are the \fIclosure\fP, the shared object \fIsh_pattern\fP
itself and the update \fImask\fP. The \fImask\fP determines the modified field only.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the update
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp1
.IP
.nf
void \fBincrRefPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GShPattern* \fIsh_pattern\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBdecrRefPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GShPattern* \fIsh_pattern\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP
This function allows to add or to remove a callback procedure which will be called
when the shared object \fIShPattern\fP
reference count is incremented or decremented. The reference count may be modified when
\fIGCreateShPattern(), GModify(), dup() and destroy()\fP methods are called.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the object reference count will be modified.
The callback procedure is called after the increment/decrement. Its parameters are
the \fIclosure\fP and the shared object \fIsh_pattern\fP itself.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the
increment/decrement callback lists. If \fIadd\fP is GREMOVE, the callback procedure
\fIproc\fP will be removed from  the callback list.
.RE
.sp1
.IP
.nf
void \fBdestroyPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GShPattern* \fIsh_pattern\fP, ulong \fImask\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP
This method allows to add or remove a callback procedure which will be called
when the shared object \fIShPattern\fP is destroyed.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the object will be destroyed.
The callback procedure is called \fIjust before\fP the destruction of the object. Its parameters are
the \fIclosure\fP and the shared object \fIsh_pattern\fP itself.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the
destruction callback lists. If \fIadd\fP is GREMOVE, the callback procedure
\fIproc\fP will be removed from  the callback list.
.RE
.sp 1
.IP
const GPatternValues* \fBvalues\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This function returns the \fIGPatternValues\fP structure of the current
pattern.
.RE
.sp 1
.IP
const PixelArray* \fBpixelArray\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the \fIShPixelArray\fP object used to draw the pattern.
.RE
.sp 1
.IP
const colormap* \fBcolormap\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
this method returns the \fIShColormap\fP object used to draw the pixels.
.sp 1
.IP
GNumber \fBwidth\fP () const;
.br
GNumber \fBheight\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
These methods return the width and the height of the \fIShPattern\fP.
.RE
.sp 1
.IP
static const char* \fBclassname\fP();
.RS .8i
.IP \fIDescription\fP .5i
This static method returns a pointer to the string \fI``GShPattern''\fP.
.RE
.sp 1
.SH
\fBC BINDING\fP
.IP
\fITo be completed\fP.
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
The \fIShPattern\fP class is a subclass of \fISharedObject\fP class. So, the \fIconstructor\fP
and \fIdestructor\fP methods are not public and the method \fIGCreateShPattern()\fP
and \fIdestroy()\fP must be called instead of \fInew\fP and \fIdelete\fP.
See also \fIPattern(3Go)\fP which is a non-shared object using a \fIShPattern\fP object.
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBSharedObject\fP, \fBShPixelArray\fP, \fBShColormap\fP, \fIGoInterf\fP and \fBPatern\fP classes.
.nrPN \n%
