.\" $Id: ShPen.n,v 1.1.1.1 1992/03/18 09:48:46 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH ShPen 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBShPen\fP \(em the shared pen object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/ShPen.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBShPen\fP inherits behavior from:
.RS 10
.IP \(em 3
\fBSharedObject\fP class
.RE
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBShPen\fP object is defined by a set of values which will be used by
a \fBGoInterf\fP instance for some drawings (see \fIGoInterf(3Go)\fP. These
values are described below in the \fIPenValues\fP structure. See also
\fIGCdef(3Go)\fP which defines some constant used by \fIShPen\fP and
other graphic context objects (\fIShBrush, ShTextBrush, ShImageBrush\fP).
.IP
The \fIShPen\fP has defaults values: we can say the default \fIShPen\fP
is \fIa black thin and solid line\fP.
.IP
The \fIShPen\fP object is a shared object (see \fISharedObject(3Go)\fP) and
may be shared between several other objects (e.g. \fIGo's\fP). The \fBPen\fP
(See \fIPen(3Go)\fP) gives a non-shared interface to the \fIShPen\fP.
.sp 1
\fBGShPen\fP is the C++ type for the \fIShPen\fP object class.
.sp 1
.nf
.ta .15i .25i 1.0i
class GShPen : public GSharedObject {
	public:
		friend GShPen* GCreateShPen ();
		friend GShPen* GCreateShPen (ulong \fImask\fP, const GPenValues* \fIvalues\fP, const char* \fIname\fP = NULL);
		friend GShPen* GCreateShPen (const char* \fIname\fP);

		GShPen* dup() const;
		GBool match (const GShPen* \fIsh_pen\fP) const;
		void updatePostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GShPen* \fIsh_pen\fP, ulong \fImask\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void destroyPostcond (void (*\fIproc\fP)(void* \fIclosure\fP, GShPen* \fIsh_pen\fP),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;

		// Getting values
		const GPenValues* values() const;

		ulong function() const;
		ulong planeMask() const;
		const GShColor* color() const;
		const GShColor* altColor() const;

		GNumber lineWidth() const;
		ushort lineStyle() const;
		ushort capStyle() const;
		ushort joinStyle() const;
		GNumber miterLimit() const;
		const GShDash* dash() const;

		ushort fillStyle() const;
		const GShPattern* tile() const;
		const GShPattern* stipple() const;
		GNumber xtsOrigin() const;
		GNumber ytsOrigin() const;

		// Modifying methods
		friend void GModify (GShPen*& \fIsh_pen\fP, ulong \fImask\fP, const GPenValues* \fIvalues\fP);
		friend void GRename (GShPen*& \fIsh_pen\fP, const char* \fIname\fP);

		friend void GSetFunction (GShPen*& \fIsh_pen\fP, ulong \fIfunction\fP);
		friend void GSetPlaneMask (GShPen*& \fIsh_pen\fP, ulong \fIplane_mask\fP);
		friend void GSetColor (GShPen*& \fIsh_pen\fP, const GShColor* \fIsh_color\fP);
		friend void GSetAltColor (GShPen*& \fIsh_pen\fP, const GShColor* \fIsh_color\fP);

		friend void GSetLineWidth (GShPen*& \fIsh_pen\fP, GNumber \fIline_width\fP);
		friend void GSetLineStype (GShPen*& \fIsh_pen\fP, ushort \fIline_style\fP);
		friend void GSetCapStyle (GShPen*& \fIsh_pen\fP, ushort \fIcap_style\fP);
		friend void GSetJoinStyle (GShPen*& \fIsh_pen\fP, ushort \fIjoin_style\fP);
		friend void GSetMiterLimit (GShPen*& \fIsh_pen\fP, GNumber \fImiter_limit\fP);
		friend void GSetDash (GShPen*& \fIsh_pen\fP, const GShDash* \fIsh_dash\fP);

		friend void GSetFillStyle (GShPen*& \fIsh_pen\fP, ushort \fIfill_style\fP);
		friend void GSetTile (GShPen*& \fIsh_pen\fP, const GShPattern* \fItile\fP);
		friend void GSetStipple (GShPen*& \fIsh_pen\fP, const GShPattern* \fIstipple\fP);
		friend void GSetTsOrigin (GShPen*& \fIsh_pen\fP, GNumber \fIx_origin\fP, GNumber \fIy_origin\fP);

		// updating named ShPen
		friend void GModify (const char* \fIname\fP, ulong \fImask\fP, const GPenValues* \fIvalues\fP);

		friend void GPenFunction (const char* \fIname\fP, ulong \fIfunction\fP);
		friend void GPenPlaneMask (const char* \fIname\fP, ulong \fIplane_mask\fP);
		friend void GPenColor (const char* \fIname\fP, const GShColor* \fIsh_color\fP);
		friend void GPenAltColor (const char* \fIname\fP, const GShColor* \fIsh_color\fP);

		friend void GPenLineWidth (const char* \fIname\fP, GNumber \fIline_width\fP);
		friend void GPenLineStype (const char* \fIname\fP, ushort \fIline_style\fP);
		friend void GPenCapStyle (const char* \fIname\fP, ushort \fIcap_style\fP);
		friend void GPenJoinStyle (const char* \fIname\fP, ushort \fIjoin_style\fP);
		friend void GPenMiterLimit (const char* \fIname\fP, GNumber \fImiter_limit\fP);
		friend void GPenDash (const char* \fIname\fP, const GShDash* \fIsh_dash\fP);

		friend void GPenFillStyle (const char* \fIname\fP, ushort \fIfill_style\fP);
		friend void GPenTile (const char* \fIname\fP, const GShPattern* \fItile\fP);
		friend void GPenStipple (const char* \fIname\fP, const GShPattern* \fIstipple\fP);
		friend void GPenTsOrigin (const char* \fIname\fP, GNumber \fIx_origin\fP, GNumber \fIy_origin\fP);
		static const char* classname();
};
.fi
.sp 1
.SH
\fBGPenValues STRUCTURE\fP
.IP
This structure may be used when creating or modifying a \fBGShPen\fP
or \fIPen\fP (see \fIPen(3Go)\fP) instance.
To set or to modify the pen characteristics, the appropriate members of
the \fIGPenValues\fP structure and the corresponding value bitmask have to be
set before calling \fIGCreateShPen()\fP or \fIGModify()\fP methods.
If the passed \fImask\fP is 0 values are set to \fIdefault values\fP.
.sp 1
\fIGPenValues\fP structure:
.sp 1
.nf
.ta .25i .60i 1.80i
struct GPenValues {
	ulong function;
	ulong plane_mask;
	GShColor*  color;
	GShColor*  alt_color;

	/* line attributes */
	GNumber line_width;
	struct {
	    unsigned style : 2;
	    unsigned cap : 2;
	    unsigned join : 2;
	} line;
	GNumber miter_limit;
	GShDash* dash;

	/* fill attributes */
	struct {
	    unsigned style : 2;
	} fill;
	GShPattern* tile;
	GShPattern* stipple;
	GNumber   ts_x_origin;
	GNumber   ts_y_origin;
};
.fi
.sp 1
.RS .8i
.IP \fIfunction\fP .5i
.br
Defines the logical function allowing to combine the source and the destination
pixel values. Possible values are described in \fIGCdef(3Go)\fP, the value
for the default pen is \fIGCOPY\fP.
.IP \fIplane_mask\fP .5i
.br
Determines which planes of the output device will be affected by the drawing.
The value for the default pen is \fIGALL_PLANES\fP.
.IP \fIcolor\fP .5i
.br
Gives the color used by most of drawings. The value of the default pen is
``black'' (Rgb = (0, 0, 0)).
.IP \fIalt_color\fP .5i
.br
Gives the color used when the file style is \fIGFILL_OPAQUE_STIPPLED\fP for unset
bits of the stipple. There is no value for the default pen.
.IP \fIline_width\fP .5i
.br
Specifies the pen width expressed in millimiters. \fI0.\fP is interpreted
as the thinest line that can be rendered on the output device. The value of
the default pen is 0.3 mm.
.IP \fIline.style\fP .5i
.br
Determines if lines are solid or dashed lines.
Possible values are described in \fIGCdef(3Go)\fP. The values for the default pen is
\fIGLINE_SOLID\fP.
.IP \fIline.cap\fP .5i
.br
Specifies the appearance of the line ends and the dash ends (in some cases).
Possible values are described in \fIGCdef(3Go)\fP.
The value for the default pen is \fIGCAP_BUTT\fP.
.IP \fIline.join\fP .5i
.br
Specifies the appearance of joints between consecutive lines drawn within
a single graphic method. Possible values are described in \fIGCdef(3Go)\fP. The
value for the default pen is \fIGJOIN_MITER\fP.
.IP \fImiter_limit\fP .5i
.br
Specifies the limiy of the miter length (see \fIGCdef(3Go)\fP). The value
for the default pen is \fIGNO_MITER_LIMIT\fP.
.IP \fIdash\fP .5i
.br
Specifies the dash appearance when \fIline.style\fP is \fIGLINE_ON_OFF_DASH\fP
or \fIGLINE_DOUBLE_DASH\fP. There is no value for the default pen.
.IP \fIfill.style\fP .5i
.br
Determines if lines are rendered using either a color, or a tile or a
stipple. Possible values are described in \fIGCdef(3Go)\fP. The value
for the default pen is \fIGFILL_SOLID\fP (i.e. lines are rendered using
the color specified in the \fIcolor\fP field).
.IP \fItile\fP .5i
.br
Specifies the pattern (\fIShPattern\fP) used when the fill style is
\fIGFILL_TILED\fP. There is no value for the default pen.
.IP \fIstipple\fP .5i
.br
Specifies the 1-bit-depth pattern (monochorome \fIShPattern\fP) used
when the fill style is either \fIGFILL_STIPPLED\fP or \fIGFILL_OPAQUE_STIPPLED\fP.
There is no value for the default pen.
.IP "\fIts_x_origin, ts_y_origin\fP .5i
Specify the origin (expressed in the absolute coordinate system) of both the \fItile\fP and
the \fIstipple\fP when they are used. The values for the default pen are
(0., 0.).
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
.nf
friend GShPen* \fBGCreateShPen\fP ();
friend GShPen* \fBGCreateShPen\fP (ulong \fImask\fP, const GPenValues* \fIvalues\fP, const char* \fIname\fP = NULL);
friend GShPen* \fBGCreateShPen\fP (const char* \fIname\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to create instances of the \fIShPen\fP class. Without any parameter
the default pen is returned. If the requested shared pen already exists, its reference
count is incremented and it is yielt.
.IP \fImask\fP .5i
.br
Specifies the value bitmask, making valid \fIvalues\fP fields.
.IP \fIvalues\fP .5i
.br
Specifies a pointer to a \fIGPenValues\fP structure.
.IP \fIname\fP .5i
.br
Specifies the name of the shared pen. If such a named shared pen exists, it
is returned, else a named shared pen is created. If the name parameter is given
with \fImask\fP and \fIvalues\fP, the concerned named shared pen is modified. 
.RE
.sp 1
.IP
GShPen* \fBdup\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns the current \fIShPen\fP object but increments its
reference count. It allows to modify a copy of a shared \fIShPen\fP instance.
For instance, this method is used when creating a \fIPen\fP from an existing
\fIShPen\fP (see \fIPen(3Go)\fP).
.RE
.sp 1
.IP
GBool \fBmatch\fP (const GShPen* \fIsh_pen\fP) const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns GTRUE if the given \fIShPen\fP object values match the values
of the current object; that means either the two values mask does not intersect,
or if the masks intersect, the corresponding values are equal.
.IP \fIsh_pen\fP .5i
.br
Specifies the \fIShPen\fP object used for the matching operation.
.RE
.sp 1
.IP
.nf
void \fBupdatePostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GShPen* \fIsh_pen\fP, ulong \fImask\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method allows to add or to remove postcondition procedures when the \fBShPen\fP is
updated. That means the \fIGModify()\fP method has been applied on the current object. In other
terms, when the reference count of a shared object is 1 and if no other shared object \fImatches\fP
the modification, the current object can be directly updated.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the object will be updated. Postcondition procedures are
called after the modification is done. Its parameters are the \fIclosure\fP, the shared object \fIShPen\fP
itself and the update \fImask\fP. The \fImask\fP determines the modified field only.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the postcondition procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the postcondition procedure \fIproc\fP will be added to the update
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp1
.IP
.nf
void \fBdestroyPostcond\fP (void (*\fIproc\fP)(void* \fIclosure\fP, GShPen* \fIsh_pen\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
This method allows to add or remove a postcondition procedures which will be called
when the shared object \fIShPen\fP is destroyed.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the object will be destroyed.
DestroyPostcond procedures are called \fIjust before\fP the destruction of the object. Their parameters are
the \fIclosure\fP and the shared object \fIsh_pen\fP itself.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the
destruction callback list. If \fIadd\fP is GREMOVE, the callback procedure
\fIproc\fP will be removed from  the callback list.
.RE
.sp1
.IP
const GPenValues* \fBvalues\fP() const;
.RS .8i
.IP \fIDescription\fP .5i
This method returns a pointer to the values structure of the \fIShPen\fP.
.RE
.sp 1
.IP
.nf
ulong \fBfunction\fP() const;
ulong \fBplaneMask\fP() const;
const GShColor* \fBcolor\fP() const;
const GShColor* \fBaltColor\fP() const;
.sp 1
GNumber \fBlineWidth\fP() const;
ushort \fBlineStyle\fP() const;
ushort \fBcapStyle\fP() const;
ushort \fBjoinStyle\fP() const;
GNumber \fBmiterLimit\fP() const;
const GShDash* \fBdash\fP() const;
.sp 1
ushort \fBfillStyle\fP() const;
const GShPattern* \fBtile\fP() const;
const GShPattern* \fBstipple\fP() const;
GNumber \fBxtsOrigin\fP() const;
GNumber \fBytsOrigin\fP() const;
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to get field by field the values of the \fIShPen\fP.
These fields are valid, only if the corresponding bits are set in the mask
(\fImask()\fP).
.RE
.sp 1
.IP
friend void \fBGModify\fP (GShPen*& \fIsh_pen\fP, ulong \fImask\fP, const GPenValues* \fIvalues\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to modify a shared pen. If the modified \fIShPen\fP matches an already
existing \fIShPen\fP, its reference count is incremented and it is returned in \fIsh_pen\fP.
If \fIthis\fP is named, the modification is done directly on it. When a shared object
is effectively updated, the postcondition callbacks are invoked.
.IP \fIsh_pen\fP .5i
.br
Specifies the shared pen to be modified. This pointer may be modified.
.IP "\fImask, values\fP"
.br
Specify which fields in the values structure have to be modified and how.
.RE
.sp 1
.IP
.nf
friend void \fBGSetFunction\fP (GShPen*& \fIsh_pen\fP, ulong \fIfunction\fP);
friend void \fBGSetPlaneMask\fP (GShPen*& \fIsh_pen\fP, ulong \fIplane_mask\fP);
friend void \fBGSetColor\fP (GShPen*& \fIsh_pen\fP, const GShColor* \fIsh_color\fP);
friend void \fBGSetAltColor\fP (GShPen*& \fIsh_pen\fP, const GShColor* \fIsh_color\fP);
.sp 1
friend void \fBGSetLineWidth\fP (GShPen*& \fIsh_pen\fP, GNumber \fIline_width\fP);
friend void \fBGSetLineStype\fP (GShPen*& \fIsh_pen\fP, ushort \fIline_style\fP);
friend void \fBGSetCapStyle\fP (GShPen*& \fIsh_pen\fP, ushort \fIcap_style\fP);
friend void \fBGSetJoinStyle\fP (GShPen*& \fIsh_pen\fP, ushort \fIjoin_style\fP);
friend void \fBGSetMiterLimit\fP (GShPen*& \fIsh_pen\fP, GNumber \fImiter_limit\fP);
friend void \fBGSetDash\fP (GShPen*& \fIsh_pen\fP, const GShDash* \fIsh_dash\fP);
.sp 1
friend void \fBGSetFillStyle\fP (GShPen*& \fIsh_pen\fP, ushort \fIfill_style\fP);
friend void \fBGSetTile\fP (GShPen*& \fIsh_pen\fP, const GShPattern* \fItile\fP);
friend void \fBGSetStipple\fP (GShPen*& \fIsh_pen\fP, const GShPattern* \fIstipple\fP);
friend void \fBGSetTsOrigin\fP (GShPen*& \fIsh_pen\fP, GNumber \fIx_origin\fP, GNumber \fIy_origin\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to modify field by field the \fIShPen\fP values structure. These methods
behave like the \fIGModify()\fP method when only only bit is set in the mask. For performance
reasons, the \fIGModify()\fP method should be prefered when several fields have to be modified
.RE
.sp 1
.IP
friend void \fBGRename\fP (GShPen*& \fIsh_pen\fP, const char* \fIname\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to (re)name a shared pen. If such a named object exists, it is
returned in \fIsh_pen\fP (updatePostcond are invoked), else a new named shared pen
is created (its reference count is 1 and its values are the current values).
.IP \fIsh_pen\fP
.5i
Specifies the shared pen to be named.
.IP \fIname\fP .5i
.br
Specifies the new name. It may be NULL, in that case, the named shared pen becomes
unnamed.
.RE
.sp 1
.IP
friend void \fBGModify\fP (const char* \fIname\fP, ulong \fImask\fP, const GPenValues* \fIvalues\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method allows to update a named shared pen. If such a named shared pen does not
exists, it is created. Update postconditions are invoked.
.IP \fIname\fP .5i
.br
Identifies the named shared pen.
.IP "\fImask, values\fP" .5i
.br
Specify which fields in the values structure have to be modified and how.
.RE
.sp 1
.IP
.nf
friend void \fBGPenFunction\fP (const char* \fIname\fP, ulong \fIfunction\fP);
friend void \fBGPenPlaneMask\fP (const char* \fIname\fP, ulong \fIplane_mask\fP);
friend void \fBGPenColor\fP (const char* \fIname\fP, const GShColor* \fIsh_color\fP);
friend void \fBGPenAltColor\fP (const char* \fIname\fP, const GShColor* \fIsh_color\fP);
.sp 1
friend void \fBGPenLineWidth\fP (const char* \fIname\fP, GNumber \fIline_width\fP);
friend void \fBGPenLineStype\fP (const char* \fIname\fP, ushort \fIline_style\fP);
friend void \fBGPenCapStyle\fP (const char* \fIname\fP, ushort \fIcap_style\fP);
friend void \fBGPenJoinStyle\fP (const char* \fIname\fP, ushort \fIjoin_style\fP);
friend void \fBGPenMiterLimit\fP (const char* \fIname\fP, GNumber \fImiter_limit\fP);
friend void \fBGPenDash\fP (const char* \fIname\fP, const GShDash* \fIsh_dash\fP);
.sp 1
friend void \fBGPenFillStyle\fP (const char* \fIname\fP, ushort \fIfill_style\fP);
friend void \fBGPenTile\fP (const char* \fIname\fP, const GShPattern* \fItile\fP);
friend void \fBGPenStipple\fP (const char* \fIname\fP, const GShPattern* \fIstipple\fP);
friend void \fBGPenTsOrigin\fP (const char* \fIname\fP, GNumber \fIx_origin\fP, GNumber \fIy_origin\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to modify field by field the named \fIShPen\fP values structure. These methods
behave like the previous \fIGModify()\fP method when only only bit is set in the mask. For performance
reasons, the \fIGModify()\fP method should be prefered when several fields have to modified
.RE
.sp 1
.IP
static const char* \fBclassname\fP();
.RS .8i
.IP \fIDescription\fP .5i
This static method returns a pointer to the string \fI``GShPen''\fP.
.RE
.sp 1
.SH
\fBC BINDING\fP
.IP
\fITo be completed\fP
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
The \fBShPen\fP class is a subclass of \fBSharedObject\fP class. So, the \fIconstructor\fP
and \fIdestructor\fP methods are not public and the method \fIGCreateShPen()\fP
and \fIdestroy()\fP must be called instead of \fInew\fP and \fIdelete\fP.
See also \fBPen(3Go)\fP which is a non-shared object using a \fBShPen\fP object.
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBPen\fP, \fBGoInterf\fP, \fBSharedObject\fP, \fBShColor\fP, \fBShDash\fP and \fBShPattern\fP classes.
.nrPN \n%
