.\" $Id: SharedObj.n,v 1.1.1.1 1992/03/18 09:49:04 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH SharedObject 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBSharedObject\fP \(em the shared object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/SharedObj.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBSharedObject\fP does not inherit behavior from any other class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBSharedObject\fP class allows the application to share objects instead
to create unuseful instances. Such objects are defined by a set of attributes
(\fIthe values\fP) which may be set or not. Initialized attributes are identified
by a bitmask (\fIthe mask\fP). Unset attributes have undefined value. The
\fISharedObject\fP class maintains a reference count for each shared object.
.IP
To \fBcreate\fP such a shared object, the application cannot directly call the
constructor but instead, it has to call a specific method for creation
(\fIGCreateSuchShObject()\fP). If the requested object already exists, this
method will return the existing object else, it will create a new one.
An existing object will match with the application request if its mask does
intersect with the mask request or if the values corresponding to the
anded masks are the same.
.IP
To \fBmodify\fP a shared object, an application is provided with the method
\fImodify()\fP which may return an different shared object (if the
reference count > 1, and an initialized value has to be modified.
.IP
To make a \fBcopy\fP of a shared object, the application may call the
\fIdup()\fP method, the reference count is simply incremented.
.IP
To \fBdestroy\fP a shared object, the application cannot directly
call the destructor (the reference count may be > 1), instead, the
application has to call the \fIdestroy()\fP method.
.IP
A \fISharedObject\fP instance may be \fInamed\fP. That means this shared object
is explicitly known by the application and to create/to modify a named shared
object will always refers the same object. With name the object sharing is
really controlled by the application, without name, the sharing is controlled
by the \fISharedObject\fP class.
.IP
A set of post-conditions callback lists are also available in order
to notify the application if a real modification (\fIupdate\fP), an
increment/decrement occur. The application may be notified on
the destruction of a shared object.
.IP
Normally the \fISharedObject\fP public methods are not directly called,
instead the subclass methods should be called (i.e.. \fIShColor(3Go),
ShPen(3Go), ...\fP). See \fIUSAGE INFORMATION\fP section.
.sp 1
\fBGSharedObject\fP is the C++ type of the \fISharedObject\fP object class.
.sp 1
.nf
.ta .15i .25i 1.i
class GSharedObject : public GList {
	public:
		int refcnt() const;
		ulong mask() const;
		const char* name();
		GBool isNamed() const;

		GSharedObject* headOfList() const;
		GSharedObject* next() const;

		const char* getClassname() const;
		static const char* classname() const;

		void destroy ();

		void modify (GSharedObject*& \fIsho\fP, ulong \fImask\fP, const GPointer \fIvalues\fP);
		void rename (GSharedObject*& \fIsho\fP, const char* \fIname\fP);
		GSharedObject* dup();

		void updatePostcond (void \fIproc\fP (void*, GSharedObject*, ulong update_mask),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void incrRefPostcond (void \fIproc\fP (void*, GSharedObject*),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void decrRefPostcond (void \fIproc\fP (void*, GSharedObject*),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
		void destroyPostcond (void \fIproc\fP (void*, GSharedObject*),
			const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
};
.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
int \fBrefcnt\fP () const
.RS .8i
.IP \fIDescription\fP .5i
This method returns the reference count of the shared object. It cannot be null.
.RE
.sp1
.IP
ulong \fBmask\fP () const
.RS .8i
.IP \fIDescription\fP .5i
This method returns the bit mask of the shared object values. it may be null.
.RE
.sp 1
.IP
const char* \fBname\fP () const
.RS .8i
.IP \fIDescription\fP .5i
This method returns a pointer to the name of the shared object or NULL if the
shared object is unnamed.
.RE
.sp 1
.IP
GBool \fBisNamed\fP () const
.RS .8i
.IP \fIDescription\fP .5i
This method returns GTRUE is the shared object is a \fInamed\fP shared object,
else it returns GFALSE.
.RE
.sp 1
.IP
GSharedObject* \fBheadOfList\fP () const
.RS .8i
.IP \fIDescription\fP .5i
This method returns head of list of \fIthis\fP.
.RE
.sp 1
.IP
GSharedObject* \fBnext\fP () const
.RS .8i
.IP \fIDescription\fP .5i
This method returns the \fInext\fP sharedobject. The current is \fIthis\fP. It is a convenient method: a SharedObject interface for the \fInext\fP method of the \fIList\fP class. Remember that \fISharedObject\fP is a subclass of \fIList\fP.
.RE
.sp1
.IP
const char* \fBgetClassname\fP() const
.RS .8i
.IP \fIDescription\fP .5i
This function returns the classname of the shared object (i.e. \fIGSharedObject\fP).
.RE
.sp 1
.IP
static const char* \fBclassname\fP() const
.RS .8i
.IP \fIDescription\fP .5i
This function returns a pointer to the string ``\fIGSharedObject\fP''.
.RE
.sp 1 
.IP
void \fBdestroy\fP ()
.RS .8i
.IP \fIDescription\fP .5i
This method allows to decrement the reference count of the shared object, if the reference
count becomes null, the destructor is called. The \fIdestroyPostcond\fP is called just
before calling the destructor.
.RE
.sp 1
.IP
void \fBmodify\fP (GSharedObject*& \fIsho\fP, ulong \fImask\fP, const GPointer \fIvalues\fP)
.RS .8i
.IP \fIDescription\fP .5i
This methods allows to modify the shared object values. If the shared object is a
\fInamed\fP shared object, the shared object is updated and the \fIupdatedPostcond\fP
is called. If the shared object is unnamed, the method may returns another shared
object which matches the requested values. \fIUpdatePostcond\fP, \fIdecrRefPostcond\fP
and \fIincrRefPostcond\fP may be called after the modification.
.IP \fIsho\fP .5i
.br
Specifies a reference to the shared object, this reference may be modified if the
shared object is not named.
.IP \fImask\fP .5i
.br
Specifies the value bitmask for the modification.
.IP \fIvalues\fP .5i
.br
Specifies a pointer to the values.
.RE
.sp 1
.IP
void \fBrename\fP (GSharedObject*& \fIsho\fP, const char* \fIname\fP)
.RS .8i
.IP \fIDescription\fP .5i
This method allows to rename a shared object. If a shared object with
the requested name exists, it is returned, its refcnt is incremented.
If such an object does not exist a new named shared object is created
with the current values, its refcnt is 1.
When needed, \fIincrRefPostcond\fP and/or \fIdecrrefPostcond\fP are called.
.IP \fIsho\fP .5i
.br
Specifies the shared object to be renamed.
.IP \fIname\fP .5i
Specifies the new name of the object. If may be NULL, in that case, this
method removes the existing name.
.RE
.sp 1
.IP
GSharedObject* \fBdup\fP () const
.RS .8i
.IP \fIDescription\fP .5i
This method increments the reference count and returns the current shared object.
.RE
.sp 1
.IP
.nf
void \fBupdatePostcond\fP (void \fIproc\fP (void*, GSharedObject*, ulong update_mask),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP
This function allows to add or to remove callback procedure when the shared object is
updated. That means the \fImodify()\fP method has been applied on the current object.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the object will be updated. The callback procedure is
called after the modification is done. Its parameters are the \fIclosure\fP, the shared object
itself and the update \fImask\fP. The \fImask\fP determines the modified field only.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the update
callback list. If \fIadd\fP is GREMOVE, the callback procedure \fIproc\fP will be removed
from  the callback list.
.RE
.sp1
.IP
.nf
void \fBincrRefPostcond\fP (void \fIproc\fP (void*, GSharedObject*),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
void \fBdecrRefPostcond\fP (void \fIproc\fP (void*, GSharedObject*),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP
This function allows to add or to remove a callback procedure which will be called
when the shared object
reference count is incremented or decremented. The reference count may be modified when
creation, modify(), rename(), dup() and destroy()\fP methods are called.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the object reference count will be modified.
The callback procedure is called after the increment/decrement. Its parameters are
the \fIclosure\fP and the shared object itself.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the
increment/decrement callback lists. If \fIadd\fP is GREMOVE, the callback procedure
\fIproc\fP will be removed from  the callback list.
.RE
.sp1
.IP
.nf
void \fBdestroyPostcond\fP (void \fIproc\fP (void*, GSharedObject*),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP = GADD) const;
.fi
.RS .8i
.IP \fIDescription\fP
This method allows to add or remove a callback procedure which will be called
when the shared object is destroyed.
.IP \fIproc\fP .5i
.br
Specifies the procedure which will be called when the object will be destroyed.
The callback procedure is called \fIjust before\fP the destruction of the object. Its parameters are
the \fIclosure\fP and the shared object itself.
.IP \fIclosure\fP .5i
.br
Specifies a used data passed to the callback procedure.
.IP \fIadd\fP .5i
.br
If \fIadd\fP is GADD (default value), the callback procedure \fIproc\fP will be added to the
destruction callback lists. If \fIadd\fP is GREMOVE, the callback procedure
\fIproc\fP will be removed from  the callback list.
.RE
.sp 1
.SH
\fBC BINDING\fP
.SS
\fBHeader File\fP
.IP
#include <Go/Tools/cSharedObj.h>
.IP
This file is automatically included when using a \fISharedObject\fP subclass.
.SS
\fBC Functions\fP
.IP
GObjectId \fBGShCreate\fP  (const char* \fIsh_subclass_name\fP, ulong \fImask\fP, const void* \fIvalues\fP, const char* \fIname\fP);
.RS .8i
.IP \fIDescription\fP .5i
This function allows to create a \fISharedObject\fP subclass instance.
\fISh_subclass_name\fP gives the classname (i.e. ShColor::classname()).
.RE
.sp 1
.IP
void \fBGShDestroy\fP (GObjectId \fIsh_object\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: void destroy().
.RE
.sp 1
.IP
ulong \fBGShMask\fP (const GObjectId \fIsh_object\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP ulong mask().
.RE
.sp 1
.IP
void \fBGShRename\fP  (GObjectId* \fIsh_object\fP, const char* \fIname\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void rename (GSharedObject*& \fIsh_object\fP, const char* \fIname\fP).
.RE
.sp 1
.IP
void \fBGShModify\fP (GObjectId* \fIsh_object\fP, ulong \fImask\fP, const void* \fIvalues\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP void modify (GSharedObject*& \fIsh_object\fP, ulong \fImask\fP, const GPointer \fIvalues\fP).
.RE
.sp 1
.IP
GObjectId \fBGShDup\fP (const GObjectId \fIsh_object\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GSharedObject* dup().
.RE
.sp 1
.IP
long \fBGShRefcnt\fP (const GObjectId \fIsh_object\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: int refcnt() const.
.RE
.sp 1
.IP
char* \fBGShName\fP (const GObjectId \fIsh_object\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: const char* name().
.RE
.sp 1
.IP
GBool \fBGShIsNamed\fP (const GObjectId \fIsh_object\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP: GBool isNamed() const.
.RE
.sp 1
.IP
const char* \fBGShClassName\fP (const GObjectId \fIsh_object\fP);
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP the virtual method: const char* getClassname() const.
.RE
.sp 1
.IP
.nf
void \fBGShUpdatePostcond\fP (GObjectId \fIsh_object\fP, GAddOrRemove \fIadd\fP,
     void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIsh_object\fP, ulong \fIupdate_mask\fP),
     const void* \fIclosure\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP:
.nf
  void updatePostcond (void \fIfunction\fP (void* \fIclosure\fP, GSharedObject* \fIsh_object\fP, ulong \fIupdate_mask\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;
.fi
.RE
.sp 1
.IP
.nf
void \fBGShDestroyPostcond\fP (GObjectId \fIsh_object\fP, GAddOrRemove add,
     void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIsh_object\fP), const void* \fIclosure\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP:
.nf
  void destroyPostcond (void \fIfunction\fP (void* \fIclosure\fP, GSharedObject* \fIsh_object\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;
.fi
.RE
.sp 1
.IP
.nf
void \fBGShIncrRefPostcond\fP (GObjectId \fIsh_object\fP, GAddOrRemove \fIadd\fP,
     void (*\fIfunction\fP)(void* \fIclosure\fP, GObjectId \fIsh_object\fP), const void* \fIclosure\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP:
.nf
  void incrRefPostcond (void \fIfunction\fP (void* \fIclosure\fP, GSharedObject* \fIsh_object\fP),
  	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;
.fi
.RE
.sp 1
.IP
.nf
void \fBGShDecrRefPostcond\fP (GObjectId \fIsh_object\fP, GAddOrRemove \fIadd\fP,
     void (*\fIfunction\fP)(void* \fIclosure\fP, const GObjectId \fIsh_object\fP),
     const void* \fIclosure\fP);
.fi
.RS .8i
.IP \fIDescription\fP .5i
\fISee\fP:
.nf
  void decrRefPostcond (void \fIfunction\fP (void* \fIclosure\fP, GSharedObject* \fIsh_object\fP),
	const void* \fIclosure\fP, GAddOrRemove \fIadd\fP) const;
.fi
.RE
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
A \fISharedObject\fP instance cannot be created but instead a subclass instance
(see for example, \fBShColor\fP, \fBShPen\fP ... subclasses).
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBSharedObject\fP subclasses, \fBBool\fP, \fBList(3Go)\fP.
.nrPN \n%
