.\" $Id: StrAssoc.n,v 1.1.1.1 1992/03/18 09:49:13 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH StringAssoc 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBStringAssoc\fP \(em the association object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/StringAssoc.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBStringAssoc\fP does not inherit anything from another class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
The \fBStringAssoc\fP class implements the association object. An association
object is a set of couples. A couple associates an association key with
a set of values. The first element of the couple is the \fIAssocation Key\fP
and the second element is the set of values associated with the key.
A key is a string and a value is seen as a void*.
.IP
By using a \fBStringAssoc\fP instance, the application will be able to set, add,
get or remove association couples.
.IP
The \fIAssoc\fP class allows to use \fIinteger\fP as type for the association key (see \fIAssoc(3Go)\fP).
.sp 1
\fBGStringAssoc\fP is the C++ type for the \fIStringAssoc\fP object class.
.sp 1
.br
.nf
.ta .15i .25i 1.0i
class GStringAssoc {
	public:
		GStringAssoc();
		~GStringAssoc();

		void set (const char* \fIkey\fP, const void* \fIvalue\fP);
		void set (const char* \fIkey\fP, int \fPsize\fP, const void* \fIaddr\fP);
		int add (const char* \fIkey\fP, const void* \fIvalue\fP);
		int add (const char* \fIkey\fP, int \fIsize\fP, const void* \fIaddr\fP);
		void* get (const char* \fIkey\fP) const;
		const void* get (const char* \fIkey\fP, int& \fInumElem\fP) const;
		void rem (const char* \fIkey\fP);
		int rem (const char* \fIkey\fP, const void* \fIvalue\fP);
		int rem (const char* \fIkey\fP, int \fIsize\fP, const void* \fIaddr\fP);

		void setArraySize(int \fIn\fP); //\fImust be a power of 2 <= 256\fP
};
.fi
.sp 1
.SH
\fBPUBLIC METHODS\fP
.IP
\fBGStringAssoc\fP ();
.RS .8i
.IP \fIDescription\fP .5i
This function allows to create an instance of the \fBStringAssoc\fP class.
.RE
.sp 1
.IP
\fB~GStringAssoc\fP ();
.RS .8i
.IP \fIDescription\fP .5i
This method is called when an instance of this class is deleted.
.RE
.sp 1
.IP
void \fBset\fP (const char* \fIkey\fP, const void* \fIvalue\fP);
.br
void \fBset\fP (const char* \fIkey\fP, int \fPsize\fP, const void* \fIaddr\fP);
.RS .8i
.IP \fIDescription\fP .5i
These functions allow to associate a value to a key. If such an association
already exists, it is removed.
.IP \fIkey\fP .5i
.br
Specifies the key used as the identifier of the association.
.IP \fIvalue\fP .5i
.br
Specifies the value of the association which is a void*.
.IP "\fIsize, addr\fP" .5i
.br
Specify the value of the association which is a \fIsize\fP byte buffer located
at the address \fIaddr\fP. The buffer is copied inside the \fBAssoc\fP
instance and then may be freed by the application.
.RE
.sp 1
.IP
void \fBadd\fP (const char* \fIkey\fP, const void* \fIvalue\fP);
.br
void \fBadd\fP (const char* \fIkey\fP, int \fIsize\fP, const void* \fIaddr\fP);
.RS .8i
.IP \fIDescription\fP .5i
These functions allow to add a value to an existing association. If the
association does not exist, it is created.
.IP \fIkey\fP .5i
.br
Specifies the key used as the identifier of the association.
.IP \fIvalue\fP .5i
.br
Specifies the value of the association which is a void*.
.IP "\fIsize, addr\fP" .5i
.br
Specify the value of the association which is a \fIsize\fP byte buffer located
at the address \fIaddr\fP. The buffer is copied inside the \fBAssoc\fP
instance and then may be freed by the application.
.RE
.sp 1
.IP
void* \fBget\fP (const char* \fIkey\fP) const;
.br
const void* \fBget\fP (const char* \fIkey\fP, int& \fInumElem\fP) const;
.RS .8i
.IP \fIDescription\fP .5i
These methods allow to get an association. The first method returns the first
value associated to the given key. The second allows to get all the
values associated to a key.
.IP \fIkey\fP .5i
.br
Specifies the key used as the identifier of the association.
.IP \fInumElem\fP .5i
.br
Specifies the number of association returned by the function.
.RE
.sp 1
.IP
void \fBrem\fP (const char* \fIkey\fP);
.br
void \fBrem\fP (const char* \fIkey\fP, const void* \fIvalue\fP);
.br
void \fBrem\fP (const char* \fIkey\fP, int \fIsize\fP, const void* \fIaddr\fP);
.RS .8i
.IP \fIDescription\fP .5i
These functions allow to remove associations. The association may be totally
broken if no specific value is given, else only the association of the 
given value is broken. 
.IP \fIkey\fP
.br
Specifies the key used as the identifier of the association.
.IP \fIvalue\fP .5i
.br
Specifies the value of the association which is a void*.
.IP "\fIsize, addr\fP" .5i
.br
Specify the value of the association which is a \fIsize\fP byte buffer located
at the address \fIaddr\fP.
.RE
.sp 1
.IP
void \fBsetArraySize\fP (int \fIn\fP);
.RS .8i
.IP \fIdescription\fP .5i
This method allows to set the hash code array (by default this array is 1,
if the number of associations increases (>= 10), it is automatically set to 256). This
functions allows to set this upper limit.
.IP \fIn\fP .5i
.br
Specifies the hash code array size. It must be less than 256 and a power of 2.
.RE
.sp 1
.SH
\fBC BINDING\fP
.IP
\fITo be defined\fP.
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBAssoc\fP class.
.nrPN \n%
