.\" $Id: Undo.n,v 1.2 1992/12/28 12:43:01 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.de BP
.ti -.2i
\(**
..
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH UndoManager 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH \fBNAME\fP
.LP
\fBUndoManager\fP \(em help for an undo management.

.SH \fBSYNOPSIS\fP
.LP
\fI#include <Go/Tools/Undo.h>\fP

.SH \fBCLASS\fP
.LP
The \fBGUndoManager\fP class does not inherit from any other class.

.SH \fBDESCRIPTION\fP
.LP
The \fBUndo\fP class try to help you in undo storage and management.
.br
First we will define some words:
.TP
.I an action Ai
is a functionality which has a corresponding undo action.
.TP
.I an undo action UAi
is the undo action of \fIAi\fP.
.br
The undo action of \fIUAi\fP is often (but not necessarely) \fIAi\fP.
.LP
A simple implementation of undo management would use a stack to push
every undo actions.
.br
Therefore after the execution of n actions \fIAi\fP we will have this
stack:
.br
	\fIUA1 ... UAn\fP

And the call of \fIundo()\fP will execute \fIUAn\fP and pop the last
element of the stack:
.br
	\fIUA1 ... UAn-1\fP

The problem of this implementation is that when you execute many undos
you cannot go back and undo \fIundo actions\fP (i.e. redo them).
.br
Therefore, a better solution is to store a list (and not a stack) with a
pointer to the current undo action.
.br
In the following we will consider that \fIAi\fP is the undo action of
\fIUAi\fP (and not only that \fIUAi\fP is the undo action of \fIAi\fP).
This is not mandatory but makes all the following more readable.

After n actions, we get:
.br
	\fIUA1 ... UAn\fP ^
.br
					(^ is the pointer)

after 1 undo, we get:
.br
	\fIUA1 ... UAn-1 ^ An\fP

and after some undos, we get:
.br
	\fIUA1 ... UAi ^ Ai+1 ... An\fP

now, if we call \fIundoUndo\fP, we get:
.br
	\fIUA1 ... UAi UAi+1 ^ Ai+2 ... An\fP

This way we can navigate (i.e. undo and undoUndo (or redo)) from \fI(U)A1\fP
to \fI(U)An\fP.

We must also explain what is done when someone execute an action \fIB\fP
while the undo stack is in this state:
.br
	\fIUA1 ... UAi ^ Ai+1 ... An\fP

The GUndoManager class removes all undo actions after the pointer and stores
\fIUB\fP:
.br
	\fIUA1 ... UAi UB\fP ^

All this (somewhat complicated) undo management is managed by the GUndoManager
class. The only method programers have to call inside actions if \fIpush()\fP.
They do not have to care about undo undo !

As an example, look at these two complementary methods:

.nf
.cs R 20
	void select (someObject)
	{
	    ... select part ...
	    undoMgr.pushUndo(unselect, someObject);
	}

	void unselect (someObject)
	{
	    ... unselect part ...
	    undoMgr.pushUndo(select, someObject);
	}
.cs R
.fi

It is the job of GUndoManager to know if the pushUndo'ed action is to
be inserted as an undo action or as an undo-undo (or redo) action,
that is left of the pointer or right of the pointer.

.TP
Some more features:
.BP
You can set the maximum count of stored undo actions (see \fImaxCount()\fP).
.BP
You can group many undo actions using \fIopenMark()\fP and \fIcloseMark()\fP.
.BP
You can make the undo list empty using \fIreset()\fP.

.nf
.cs R 20

	class GUndoManager
	{
	    public:
	        GUndoManager();
	       ~GUndoManager();

	        void push (GUndoProc \fIundoProc\fP, void* \fIclosure\fP,
	                   GUndoProc \fIfreeProc\fP = NULL, void* \fIfreeClosure\fP = NULL);

	        void undo ();
	        void undoUndo ();

	        GBool undoEmpty () const;
	        GBool undoUndoEmpty () const;

	        int maxCount () const;
	        void maxCount (int \fIcount\fP);

	        void openMark ();
	        void closeMark ();

	        void reset ();
	};
.cs R
.fi

.SH \fBPUBLIC VARIABLES AND TYPES\fP
.LP
.B typedef void (*GUndoProc)(void*);
.TP
.I description
This is the type of procedures that are passed to the \fIpush()\fP method.
.LP
.B const int gDefaultUndoActionsMaxCount = 128;
.TP
.I description
This is the default size of the GUndoManager "stack". You may set or get
the value of this "stack" size with the \fImaxCount()\fP method.

.SH \fBPUBLIC METHODS\fP
.LP
void \fBpush\fP (GUndoProc \fIundoProc\fP, void* \fIclosure\fP,
.br
 		GUndoProc \fIfreeProc\fP = NULL, void* \fIfreeClosure\fP = NULL);
.TP
.I description
This method pushes its parameters onto the undo stack or onto the redo stack.
.br
If an undo procedure is running (someone has called \fIundo()\fP, and it is
not yet finished) parameters will be pushed onto the redo stack (undoUndo)
otherwise the undo stack is used.
.TP
.I undoProc, closure
This is the undo procedure with its associated data.
.br
\fIundoProc\fP is called this way:
.br
	\fIundoProc(closure);\fP
.br
by the GUndoManager class when someone calls the \fIundo()\fP method.
.TP
.I freeProc, freeClosure
Often an action need to store many informations to be able to realize the
correct undo. This information will be allocated via malloc() (or any
memory allocator). Of course, the \fIundoProc\fP after finishing its job, must
also free this memory.
.br
But do not forget that the undo stack has a maximum size
(see \fImaxCount()\fP), or that sometimes you may reset the undo stack (see
\fIreset()\fP). For both reasons, sometimes an undo action must be removed
without calling it. In such cases, if the \fIfreeProc\fP is not NULL, it is
called.
.br
If \fIfreeClosure\fP is present and differant than NULL, it is passed to
\fIfreeProc\fP, else \fIclosure\fP is passed to \fIfreeProc\fP:
.br
	\fIfreeProc(closure)\fP
.br
		if \fIfreeClosure\fP is missing or is NULL.
.br
	\fIfreeProc(fclosure)\fP
.br
		otherwise.
.LP
void \fBundo\fP ();
.TP
.I description
This method calls the last action pushed onto the undo stack.
.br
If the undo stack is empty nothing is done.

.LP
void \fBundoUndo\fP();
.TP
.I description
This method calls the last action pushed onto the undoUndo stack.
.br
Yes, we could have called it \fIredo()\fP.
.br
If the undoUndo stack is empty nothing is done.

.LP
GBool \fBundoEmpty\fP () const;
.br
GBool \fBundoUndoEmpty\fP () const;
.TP
.I description
These methods return GTRUE if the undo stack (or the undoUndo stack) is empty.

.LP
int \fBmaxCount\fP () const;
.br
void \fBmaxCount\fP (int \fImax_count\fP) const;
.TP
.I description
These methods get or set the maximum size of the undo stack. Everything
which is enclosed between an open mark and the corresponding close mark
is counted for 1 (see methods \fIopenMark()\fP and \fIcloseMark()\fP).
.br
If the undo stack reaches its maximum size, new undo actions are always stored
but first undo actions are removed.
.br
The default maximum size is \fIgDefaultUndoActionsMaxCount\fP.
.br
If the maximum size of the undo stack is 0 (or negative), nothing is pushed,
and therefore the undo is disabled.

.LP
void \fBopenMark\fP ();
.br
void \fBcloseMark\fP ();
.TP
.I description
Often a semantic action is compound of many small actions which each
of them has its own undo management. Then if you call \fIundo()\fP, you
will not undo the big semantic action, but only the last small one. To
correct this, at the beginning of the big action you must put an open mark,
and at the end a close mark.
.br
Then, if you call \fIundo()\fP or \fIundoUndo()\fP, all \fIundoProc\fPs
between the open and the close mark will be called.
.br
Undo marks may be nested. In this case the outermost is used.

.LP
void \fBreset\fP ();
.TP
.I description
After the call of this method, there are no more undos nor undoUndos.
(of course, while reseting the two stacks, if GUndoManager find some
\fIfreeProc\fPs, it calls them).

.SH \fBC BINDING\fP
.LP
\fITo be completed\fP.
