.\" $Id: Vector.n,v 1.1.1.1 1992/03/18 09:49:38 uep Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" licence from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH Vector 3Go "February 1992" "Version 1.1" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fBNAME\fP
.IP
\fBVector\fP \(em the geometric vector object class.
.sp 1
.SH 
\fBSYNOPSIS\fP
.IP
\fI#include <Go/Tools/Vector.h>\fP
.sp 1
.SH 
\fBCLASS\fP
.IP
\fBVector\fP does not inherit from any other class.
.sp 1
.SH 
\fBDESCRIPTION\fP
.IP
A \fBVector\fP class instance is defined by a couple of Number: (\fIx, y\fP).
It has to be seen as a one column and two rows matrix
.EQ
size 6
left (
matrix {
ccol {x above y}
}
right )
" ."
.EN
.sp 1
\fBGVector\fP is the C++ type for the \fIVector\fP object class.
.sp 1
.nf
.ta .15i .25i 1.50i
struct GVector {
		// Instance variables
		GNumber x, y;

		// Public methods
		GVector ();
		GVector (GNumber \fIx\fP, GNumber \fIy\fP);
		GVector (const GVector& \fIvector\fP);

		GNumber size () const;
		GNumber squareSize () const;
		GNumber angle () const;
		GBool null () const;

		// Operators
		GVector& operator += (const GVector& \fIv\fP);
		GVector& operator -= (const GVector& \fIv\fP);
		GVector& operator *= (GNumber \fIn\fP);
		GVector& operator /= (GNumber \fIn\fP);
		GVector& neg ();
		GVector& resize (GNumber \fIn\fP);
		GVector& rotate (GNumber \fIangle\fP);
		GVector& setAngle (GNumber \fIangle\fP)

		GVector operator - () const;

		friend GBool operator == (const GVector& \fIv1\fP, const GVector \fIv2\fP);
		friend GBool operator != (const GVector& \fIv1\fP, const GVector \fIv2\fP);

		friend GVector operator + (const GVector& \fIv1\fP, const GVector& \fIv2\fP);
		friend GVector operator - (const GVector& \fIv1\fP, const GVector& \fIv2\fP);
		friend GVector operator * (const GVector& \fIv\fP, GNumber \fIn\fP);
		friend GVector operator * (GNumber \fIn\fP, const GVector& \fIv\fP);
		friend GVector operator / (const GVector& \fIv\fP, GNumber \fIn\fP);

		friend GNumber operator * (const GVector& \fIv1\fP, const GVector& \fIv2\fP);
		friend void operator *= (GVector& \fIv\fP, const class Matrix& \fImatrix\fP);

		friend GNumber GAngle (const GVector& \fIv1\fP, const GVector& \fIv2\fP);
};
.fi
.sp 1
.SH
\fBPUBLIC VARIABLES\fP
.sp 1
.IP
GNumber \fBx\fP;
.br
GNumber \fBy\fP;
.RS .8i
.IP \fIDescription\fP .5i
These variables specify the two numbers which define the \fBVector\fP instance.
.sp 1
.SH
\fBPUBLIC METHODS\fP
.sp 1
.IP
\fBGVector\fP ();
.br
\fBGVector\fP (GNumber \fIx\fP, GNumber \fIy\fP);
.br
\fBGVector\fP (const GVector& \fIvector\fP);
.RS .8i
.IP \fIDescription\fP .5i
These functions allow to create an instance of the \fBVector\fP structure.
When no parameters are specified, the \fIx\fP and \fIy\fP instance variable
are set to 0.
.IP "\fIx, y\fP" .5i
.br
Specify the vector coordinates.
.IP \fIvector\fP .5i
.br
Specifies the vector from which the \fBVector\fP instance is
created.
.RE
.sp 1
.IP
GNumber \fBsize\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This function returns the size of the vector:
.ft I
.EQ
sqrt{x sup 2 + y sup 2}
" ."
.EN
.ft R
.RE
.sp 1
.IP
GNumber \fBsquareSize\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This function returns the
.ft I
.EQ
(size) sup 2
.EN
.ft R
of the vector :
..ft I
.EQ
x sup 2 + y sup 2
" ."
.EN
.ft R
.RE
.sp 1
.IP
GNumber \fBangle\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This function returns the angle (in radians) between the vector and the
X axis.
.RE
.sp 1
.IP
GBool \fBnull\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This function returns GTRUE is the instance variables \fIx\fP and \fIy\fP
are equal to 0, else it returns GFALSE.
.RE
.sp 1
.IP
GVector& \fBoperator +=\fP (const GVector& \fIv\fP);
.br
GVector& \fBoperator -=\fP (const GVector& \fIv\fP);
.RS .8i
.IP \fIDescription\fP .5i
These functions return a \fIVector\fP which is the result of the addition/substraction of the
instance and the vector \fIv\fP.
.IP \fIv\fP
.br
Specifies the vector to be added or substracted.
.RE
.sp 1
.IP
GVector& \fBoperator *=\fP (GNumber \fIn\fP);
.br
GVector& \fBoperator /=\fP (GNumber \fIn\fP);
.RS .8i
.IP \fIDescription\fP .5i
These functions return a \fIVector\fP which is the result of the multiplication/division
of the instance and \fIn\fP.
.IP "\fIn\fP" .5i
.br
Specifies the number used as the multiplier/divisor.
.RE
.sp 1
.IP
GVector& \fBneg\fP ();
.RS .8i
.IP \fIDescription\fP .5i
This function returns a \fIVector\fP which is the result of the unary minus operation
of the instance.
.RE
.sp 1
.IP
GVector& \fBresize\fP (GNumber \fIsize\fP);
.RS .8i
.IP \fIDescription\fP .5i
This function returns a \fIVector\fP which is a resized instance of the current instance.
.IP \fIsize\fP .5i
.br
Specifies the size of the vector. If the vector is null (\fIx=0, y=0\fP),
this function does not affect it, because it is not possible to determine
the angle between the vector and the X axis.
.RE
.sp 1
.IP
GVector& \fBrotate\fP (GNumber \fIangle\fP);
.RS .8i
.IP \fIDescription\fP .5i
This function returns a \fIVector\fP which the result of a rotation of the current instance.
.IP \fIangle\fP .5i
.br
Specifies the rotation angle. It is expressed in radians relatively to
tha X axis.
.RE
.sp 1
.IP
GVector& \fBsetAngle\fP (GNumber \fIangle\fP);
.RS .8i
.IP \fIDescription\fP .5i
This function returns a \fIVector\fP which is the same that the current but with another
angle relatively to the X axis.
.IP \fIangle\fP .5i
.br
Specifies the angle between the new vector and the X axis.
.RE
.sp 1
.IP
GVector \fBoperator -\fP () const;
.RS .8i
.IP \fIDescription\fP .5i
This function returns a \fInew\fP vector. This instance is opposite to the current
vector.
.RE
.sp 1
.IP
friend GBool \fBoperator ==\fP (const GVector& \fIv1\fP, const GVector \fIv2\fP);
.br
friend GBool \fBoperator !=\fP (const GVector& \fIv1\fP, const GVector \fIv2\fP);
.RS .8i
.IP \fIDescription\fP .5i
These function allow to compare two vectors (\fIv1, v2\fP).
.IP "\fIv1, v2\fP" .5i
.br
Specify the two vectors used in the comparison operation.
.RE
.sp 1
.IP
friend GVector \fBoperator +\fP (const GVector& \fIv1\fP, const GVector& \fIv2\fP);
.br
friend GVector \fBoperator -\fP (const GVector& \fIv1\fP, const GVector& \fIv2\fP);
.RS .8i
.IP \fIDescription\fP .5i
These functions return an \fInew\fP \fBVector\fP instance which is the result
of the addition/substraction of two other vectors.
.IP "\fIv1, v2\fP" .5i
Specify the two vectors used as the operation operands.
.RE
.sp 1
.IP
friend GVector \fBoperator *\fP (const GVector& \fIv\fP, GNumber \fIn\fP);
.br
friend GVector \fBoperator *\fP (GNumber \fIn\fP, const GVector& \fIv\fP);
.br
GVector \fBoperator /\fP (const GVector& \fIv\fP, GNumber \fIn\fP);
.RS .8i
.IP \fIDescription\fP .5i
These functions return an \fInew\fP \fBVector\fP instance which is the
result of the multiplication/division by a number.
.IP \fIn\fP .5i
.br
Specifies the number used as multiplier or divisor.
.RE
.sp 1
.IP
friend GNumber \fBoperator *\fP (const GVector& \fIv1\fP, const GVector& \fIv2\fP);
.RS .8i
.IP \fIDescription\fP .5i
This function return \fI(v1.x * v2.x) + (v1.y * v2.y)\fP.
.IP "\fIv1, v2\fP" .5i
.br
Specify the two vectors used in this operation.
.RE
.sp 1
.IP
friend void \fBoperator *=\fP (GVector& \fIv\fP, const class Matrix& \fImatrix\fP);
.RS .8i
.IP \fIDescription\fP .5i
This function allows to multiply a vector by a matrix. This operation may
be considered as a base change.
.IP \fIv\fP .5i
Specify the vector which is going to be modified.
.IP \fImatrix\fP .5i
Specify the matrix used as multiplier.
.RE
.sp 1
.IP
friend GNumber GAngle (const GVector& \fIv1\fP, const GVector& \fIv2\fP);
.RS .8i
.IP \fIDescription\fP .5i
This method returns the angle expressed in radians between the two
vectors \fIv1\fP and \fPv2\fP.
.RE
.sp 1
.SH
\fBC BINDING\fP
.IP
\fITo be completed\fP.
.sp 1
.SH
\fBUSAGE INFORMATION\fP
.IP
.sp 1
.SH
\fBSEE ALSO\fP
.IP
\fBNumber\fP, \fBPoint\fP and \fBMatrix\fP classes.
.nrPN \n%
