.\" $Id: ch02.n,v 1.2 1992/12/28 16:40:09 davy Exp $
.\"
.\"
.\" Copyright (c) 1990, 1991 Bull S.A., Paris, France
.\"
.\" Permission to use, copy, modify, distribute FREE OF CHARGE this software
.\" and its documentation for any purpose is hereby granted without fee,
.\" provided that (i) the above copyright notices and this permission notice
.\" appear in all copies of the software and related documentation, and
.\" (ii) the name of Bull may not be used in any advertising or publicity
.\" relating to the software without the specific, prior written permission
.\" of Bull.
.\" 
.\" The permission to distribute or sublicense FOR CHARGE either this software
.\" (all or part) or products derived from this software is subject to prior
.\" license from Bull under separate agreement.
.\"
.\" The information in this software is subject to change without
.\" notice and should not be construed as a commitment by Bull.
.\"
.\" Bull assumes no responsibility for the use or inability to use any of its
.\" software. The software is provided "AS IS" without warranty of any
.\" kind, and Bull expressly disclaims all implied warranties, including
.\" but not limited to the implied warranties of merchantability and
.\" fitness for a particular purpose.
.\"
.\" In no event shall Bull be liable for any special, incidental, indirect
.\" or consequential damages of any kind, or any damages whatsoever
.\" resulting from loss of use, data or profits, whether or not advised of
.\" the possibility of damage, and on any theory of liability, arising out
.\" of or in connection with the use or performance of this software.
.\"
.\"
.EH ''''
.OH ''''
.EF ''''
.OF ''''
.TH \fBGo\fP \fB3Go\fP "December 1992" "Version 1.2" "Go Reference Manual" 
.nr% \n(PN+1
.SH 
\fB2. CONVENTIONS\fP
.LP
.SH
\fB2.1 Manual Entry\fP
.LP
The \fIGo Reference Manual\fP contains one entry per
object class available in the \fBGo\fP libraries. Some object classes are
\fIabstract classes\fP, that means instances cannot be directly created;
they have to be subclass instances. \fIAbstract classes\fP define common
behavior for subclasses. A typical entry looks like an
Unix\u\s4TM\s0\d man page entry. The sections are:
.sp 1
.br
.nf
.ta .5i 2.3i
	\fBNAME\fP	Gives the name of the object.
	\fBSYNOPSIS\fP	Gives the header files needed.
	\fBCLASS\fP	Gives the class hierarchy; it is very useful to know
		inherited methods or behavior.
	\fBDESCRIPTION\fP	Gives the object description and the public part of
		the object structure. It may includes some constants or
		types definitions 
	\fBPUBLIC METHODS\fP	Describes each public methods. This section
		may be divided into several sub sections.
	\fBUSER INTERACTION\fP	Describes how the object can be used from an user
		interaction (\fISensor\fP names, action names, ...).
	\fBC BINDING\fP	When needed, \fIC\fP binding functions are listed.
	\fBUSAGE INFORMATION\fP	Gives complementary information for object usage.
	\fBSEE ALSO\fP	Refers other objects or manuals.
.fi
.br
.LP
Note the entry for the \fITools\fP object is the object name without the
\fIG\fP prefix. For example, the entry \fIColor\fP is the manual for the
\fIGColor\fP object. See below other naming conventions.
.SH
\fB2.2. Naming Conventions\fP
.LP
The following naming have been adopted for \fBGo\fP.
.LP
\fBClass Names and Types\fP
.in +0.5i
The class names start with \fIGo\fP for \fBGo\fP basic classes (\fIGo, GoStream,
GoInterf, GoUI, ...\fP and subclasses (\fIGoPolyline, GoAscii, ...\fP).
It start with \fIG\fP for others (\fIGColor, GCoordSys, ...\fP).
.br
Words in the names are separated with capital letters.
.in
.LP
\fBMacros, Defines and Enums\fP
.in +0.5i
The macros names, defined symbols and \fIenum\fP values start with
the prefix \fIGo\fP or \fIG\fP depending of the referred object class (\fIGo\fP
is the object class start with Go
.SH
\fB2.3. C Language Binding\fP
.LP
The \fIC language binding\fP allows to use \fBGo\fP from a C application. The
model used in order to give a C interface to \fBGo\fP is based on the work
done by \fIArnaud Lehors\fP (Bull Research Center), see \fIXglib, an
X Graphic Library for Motif Applications, Xhibition 91, San Jose, CA\fP.
.LP
The C interface is based on the \fIargument list\fP (\fBGArg\fP) use
as it is done in the \fIXt Intrinsics\fP toolkit (from the MIT). That means
a set of \fBresources\fP has been defined and two functions which are
\fBGoSetValues\fP and \fBGoGetValues\fP can be called in order to set or to
get them. Here, resources are any settable/gettable values. See \fBcGo(3Go)\fP.
In addition to these to functions a set of convenient functions has been
defined to match the need of every object class.
.IP "\fIResource Names\fP"
Resource names start with the prefix \fBgoN\fP followed with the C++
method name needed to set/get this resource (example: \fIgoNreparent\fP is
the resource name used to set/get the \fIGo\fP parent, the corresponding
C++ method is \fIGo::reparent()\fP).
.IP "\fIFunction Names\fP"
C function names start with an upper case letter (i.e. \fIGoSetValues()\fP).
Function names have been chosen to be as natural as possible
in the English language (i.e \fICreatePen()\fP has been preferred rather than
\fIPenCreate()\fP) and as close as possible to the corresponding C++ method
(i.e. \fIGoMap()\fP is the C binding for \fIGo::map()\fP.).
.IP "\fPFunction Parameters\fP"
The first parameter of the C functions is a pointer to the referred C++ object
and its type is \fBObjectId\fP (i.e \fIGoMap (ObjectId go)\fP is the C
binding of \fIgo->map()\fP).
.IP "\fIParameters\fP"
Parameters are values or pointers depending on their type. Char, bool, short,
integer, long, void* are usually passed as values. Pointers are used for
float (GNumber), double, structure.
.in 0
.nrPN \n%
